//SY20ZR00 JOB 1,PDS-7003,MSGCLASS=A,CLASS=A,REGION=256K
//*
//*   PROBLEM DESCRIPTION(S):
//*     PDS -
//*       Refit TSO PDS command version 7.0 to run on MVT.
//*
//*       This is version 7.0.03 of the MVT PDS command.
//*
//*       All native PDS 7.0 subcommands are supported under MVT.
//*       Supported subcommands are:
//*
//*         ATTRIB   - Display (or modify) load module attributes
//*         ALIAS    - Assign an alias to a member
//*         CHANGE   - Change to a different data set
//*         COMPARE  - Compare two members
//*         COMPRESS - Compress the data set
//*         CONTROL  - Set program control variables
//*         DISPLAY  - Display all or part of the directory
//*         DIRENTRY - Dump a member's directory entry
//*         DELETE   - Delete a member
//*         DSNAME   - Display the current data set allocation
//*         END      - Terminate the PDS command
//*         EXEC     - Execute PDS subcommands from a CLIST source
//*         FIND     - List lines containing a search string
//*         FIXPDS   - Modify the allocated partitioned data set
//*         FSE      - Edit a member with the fse command
//*         HELP     - Display subcommand help for PDS
//*         HISTORY  - List history of a load module
//*         IF       - Test a member for given attributes
//*         LIST     - List contents of a member
//*         MAP      - Map a load module
//*         MEMBERS  - Display members in a group
//*         OPTIONS  - Display the subcommand menu
//*         OUTCOPY  - Output IEBCOPY SELECT statements
//*         PATTERN  - Display directory based on member name segments
//*         RECALL   - Display or reissue the previous subcommand
//*         RENAME   - Rename a member
//*         RESTORE  - Resurrect a previously deleted member
//*         REVIEW   - Browse data with the REVIEW command
//*         SUBMIT   - Submit a JCL member
//*         TSO      - Execute a TSO command
//*         TSOEDIT  - Edit a member with TSO edit
//*         USAGE    - List data set statistics
//*         VERIFY   - Check the data set for validity errors
//*
//*       The following external programs are required for the
//*       indicated subcommands:
//*
//*       Subcommand   Programs             Source
//*       ----------   ------------------   ---------------------------
//*       REVIEW       REVIEW               CBT FILE 296; CBT FILE 300
//*       COMPARE      COMPARE, COMPAREB    CBT FILE 296; CBT FILE 300
//*
//*       A PDS help member is also included.
//*
//*       Because ISPF is not available, ISPF-related subcommands
//*       BROWSE, EDIT/SPFEDIT, ISPMODE and MEMLIST are not available
//*       in MVT.  Subcommands that link to other external command
//*       processors, DSPRINT, PRINTOFF and TSOLIST, are also disabled
//*       in the MVT environment.
//*
//*       MVT does not provide the System Track Allocation Routine
//*       (STAR), which supports the TRKCALC macro.  STAR logic
//*       from MVS 3.8 has been rewritten as a local subroutine
//*       and included with PDS.  The STAR subroutine to apply
//*       tolerance factors has been modified to support all devices
//*       that require it (the MVS 3.8 version is hard-coded for 2314
//*       only).  Because this requires more registers than are used
//*       by the MVS version, the caller of TRKCALC must provide the
//*       address of a standard save area in R13, and specify
//*       REGSAVE=YES on the TRKCALC macro invocation.  PDS usage of
//*       TRKCALC includes REGSAVE=YES.
//*
//*       Several macros not available or incomplete in MVT have
//*       been created or supplied from MVS 3.8 macro libraries.
//*       They are:
//*
//*         ESTAE    (mapped to MVT STAE)
//*         IHADVCT  (Device Characteristics Table mapping)
//*         IHASDWA  (SDWA, first 104 bytes)
//*         IKJEFFDF (DAIRFAIL parm list)
//*         IKJEFFMT (IKJEFF02 message handler parameter list)
//*         IKJTSMSG (IKJEFF02 message handler message description)
//*         SETRP    (generates MVT STAE return linkage)
//*         STFSMODE (set full screen mode, acts as a no-op)
//*         STLINENO (set next non-full-screen line number)
//*         TRKCALC  (modified to call local STAR subroutine)
//*
//*       By default, PDS uses the unit name "SYSDA" for allocating disk
//*       data sets.  To use a different unit, change the conditional
//*       assembly variable &DAUNIT in member PDSGEN70 to the desired
//*       value.
//*
//*   SPECIAL CONDITIONS:
//*     DEPENDENCY:
//*       Assembly of PDS requires the OS/VS XF assembler IFOX00.
//*
//*     DEPENDENCY:
//*       PDS uses System/370 instructions.  The hardware or hardware
//*       emulator MVT is running on must support System/370 instructions,
//*       or the version of MVT being used must include software
//*       simulation of System/370 instructions.
//*
//*     DEPENDENCY:
//*       STLINENO acts as a no-op unless usermod TMVT818 or
//*       equivalent is installed to add STLINENO functionality
//*       to MVT SVC 94.
//*
//*   COMMENTS:
//*     LAST CHANGE:  2021/08/18
//*
//*     REWORK HISTORY:
//*      2021/08/18 $D06 7.0.03: Change default unit from SYSALLDA
//*                              to SYSDA.
//*      2017/08/01 $D05 7.0.02: Support for translator history.
//*      2010/05/04 $D04 7.0.01: Support extended DIRENTRY display.
//*      2010/05/04 $D03 7.0.01: Support for MAP JCL.
//*      2010/05/04 $D02 7.0.01: Fix AMODE errors.
//*      2010/05/04 $D01 7.0.01: Refit to support MVT.
//*
//*     THE FOLLOWING MODULES AND/OR MACROS ARE AFFECTED BY THIS USERMOD:
//*
//*     MODULES
//*       PDS7003
//*
//*     MACROS
//*       PDS7003 (help member)
//*       ESTAE
//*       IHADVCT
//*       IHASDWA
//*       IKJEFFDF
//*       IKJEFFMT
//*       IKJTSMSG
//*       SETRP
//*       SGSTAR
//*       STARRTN
//*       STFSMODE
//*       STLINENO
//*       TRKCALC
//*
//*       Note:  All macros except the help member PDS7003 are
//*       installed in the private library SYS2.PDS.R703.ASM and
//*       will not be placed in system libraries.
//*
//*     DISK SPACE REQUIREMENTS:
//*        PDS requires disk space as follows:
//*
//*        component        DASD type   tracks
//*        ---------        ---------   ------
//*        PDS load module  3330        10
//*        PDS source       3330        155
//*        help member      3330        25
//*
//*     MAIN STORAGE REQUIREMENTS:
//*        PDS requires 85K for program code and at least 8K
//*        working storage.  The code is reentrant and refreshable,
//*        so it may be placed in the link pack area or time sharing
//*        link pack area if desired.
//*
//*     INSTALLATION INSTRUCTIONS:
//*       (A) Modify the symbolic parameter WKUNIT on the PROC
//*           statement if you need to use a DASD unit name other
//*           than SYSDA.
//*
//*       (B) Modify the ALLOC step to set your preferences for:
//*
//*          1) Target load library (default is SYS2.LINKLIB).  This
//*             should be a link list library, or a library in the
//*             STEPLIB concatention in the TSO procedure.
//*
//*          2) Target library for help member (default is SYS1.HELP).
//*
//*          3) Unit and volume for source data set (unit default
//*             is SYSDA, volume default is ASPSUP).  Data set
//*             SYS2.PDS.R703.ASM will be created on the designated
//*             volume.
//*
//*       (C) Modify PDS configuration options in the PDSGEN70 member
//*           if desired.  Options you might want to modify include:
//*
//*              &DAUNIT  - Unit name used by PDS for DASD allocation
//*                         (default is SYSDA).
//*
//*              &TUNIT   - Unit name for DASD utility data sets in JCL
//*                         generated by MAP (default is SYSDA).
//*
//*           For proper assembly, &MVT must remain set to 1 and
//*           &MVSLEV to "MVS038".
//*
//*       (D) Run the job.
//*
//*       (E) Verify successful completion.  All steps should complete
//*           with return code zero except the LKED step, which
//*           should produce a return code of 4 and msgIEW0461 due to
//*           the absence of optional user exits VSUBCMD and VTSOCMD.
//*
/*JOBPARM LINES=9999,LINECT=0
//*MAIN LINES=100
//*
//PDSINST  PROC WKUNIT='SYSDA'            <-- change if necessary
//*
//*-----------------------------------------------------------------***
//*     Define target data sets.  Modify values below as            ***
//*     appropriate for your installation.                          ***
//*-----------------------------------------------------------------***
//ALLOC   EXEC PGM=IEFBR14
//LOADLIB  DD DISP=SHR,DSN=SYS2.LINKLIB   <-- target load library
//HELP     DD DISP=SHR,DSN=SYS1.HELP      <-- target help library
//ASM      DD DISP=OLD,
//            VOL=SER=ASPSUP,             <-- target source volume
//            UNIT=SYSDA                  <-- target source unit
//*
//*-----------------------------------------------------------------***
//*     Delete any existing PDS source data set.                    ***
//*-----------------------------------------------------------------***
//CLEANUP EXEC PGM=IEFBR14
//SYSUT2   DD DSN=SYS2.PDS.R703.ASM,
//            DISP=(MOD,DELETE),
//            UNIT=&WKUNIT,
//            SPACE=(TRK,(0))
//*
//*-----------------------------------------------------------------***
//*     Create data set with PDS source and macros.                 ***
//*-----------------------------------------------------------------***
//UPDASM  EXEC PGM=IEBUPDTE,PARM=NEW
//SYSUT2   DD DSN=SYS2.PDS.R703.ASM,
//            DISP=(NEW,CATLG),
//            DCB=(DSORG=PO,RECFM=FB,LRECL=80,BLKSIZE=3120),
//            VOL=REF=*.ALLOC.ASM,
//            SPACE=(3120,(640,,5))
//SYSPRINT DD SYSOUT=A
//*
//*-----------------------------------------------------------------***
//*     Assemble PDS.                                               ***
//*-----------------------------------------------------------------***
//ASMPDS   EXEC PGM=IFOX00,PARM='DECK,NOOBJ,RENT',REGION=1024K
//SYSLIB   DD  DISP=SHR,DSN=SYS2.PDS.R703.ASM,DCB=BLKSIZE=6160
//         DD  DISP=SHR,DSN=SYS1.MACLIB
//         DD  DISP=SHR,DSN=SYS1.MODGEN
//SYSUT1   DD  DSN=&&SYSUT1,UNIT=&WKUNIT,SPACE=(CYL,(15,8))
//SYSUT2   DD  DSN=&&SYSUT2,UNIT=&WKUNIT,SPACE=(CYL,(15,8))
//SYSUT3   DD  DSN=&&SYSUT3,UNIT=&WKUNIT,SPACE=(CYL,(10,5))
//SYSPRINT DD  SYSOUT=A
//SYSGO    DD  DUMMY
//SYSLIN   DD  DUMMY
//SYSPUNCH DD  DSN=&&OBJSET(PDS7003),UNIT=&WKUNIT,
//             SPACE=(TRK,(30,5,2)),DISP=(MOD,PASS)
//SYSIN    DD  DISP=SHR,DSN=SYS2.PDS.R703.ASM(PDS7003)
//*
//*-----------------------------------------------------------------***
//*     Assemble STAR.                                              ***
//*-----------------------------------------------------------------***
//ASMSTAR  EXEC PGM=IFOX00,PARM='DECK,NOOBJ,RENT',REGION=1024K
//SYSLIB   DD  DISP=SHR,DSN=SYS2.PDS.R703.ASM,DCB=BLKSIZE=6160
//         DD  DISP=SHR,DSN=SYS1.MACLIB
//         DD  DISP=SHR,DSN=SYS1.MODGEN
//SYSUT1   DD  DSN=&&SYSUT1,UNIT=&WKUNIT,SPACE=(CYL,(10,5))
//SYSUT2   DD  DSN=&&SYSUT2,UNIT=&WKUNIT,SPACE=(CYL,(10,5))
//SYSUT3   DD  DSN=&&SYSUT3,UNIT=&WKUNIT,SPACE=(CYL,(10,5))
//SYSPRINT DD  SYSOUT=A
//SYSGO    DD  DUMMY
//SYSLIN   DD  DUMMY
//SYSPUNCH DD  DSN=&&OBJSET(STARRTN),UNIT=&WKUNIT,
//             SPACE=(TRK,(30,5,2)),DISP=(MOD,PASS)
//SYSIN    DD  DISP=SHR,DSN=SYS2.PDS.R703.ASM(STARRTN)
//*
//*-----------------------------------------------------------------***
//*     Link PDS.                                                   ***
//*-----------------------------------------------------------------***
//LKED   EXEC  PGM=IEWL,PARM='MAP,RENT,REUS,REFR,LET,NCAL',
//             COND=(0,LT),REGION=256K
//SYSPRINT DD  SYSOUT=A
//SYSPUNCH DD  DSN=&&OBJSET,DISP=(OLD,DELETE)
//SYS2LINK DD  DISP=SHR,DSN=SYS2.LINKLIB
//SYSLMOD  DD  DISP=SHR,DSN=*.ALLOC.LOADLIB
//SYSUT1   DD  UNIT=&WKUNIT,SPACE=(TRK,(30,5))
//SYSLIN   DD  DISP=SHR,DSN=SYS2.PDS.R703.ASM(LNK7003)
//*
//*-----------------------------------------------------------------***
//*     Add help member.                                            ***
//*-----------------------------------------------------------------***
//UPDHELP EXEC PGM=IEBUPDTE,PARM=NEW,REGION=128K,COND=(4,LT)
//SYSUT2   DD  DISP=SHR,DSN=*.ALLOC.HELP
//SYSPRINT DD  SYSOUT=A
/*
//          PEND
//*
//PDSINST  EXEC PDSINST
//UPDASM.SYSIN  DD  DATA,DLM='??'
./ ADD NAME=ESTAE
         MACRO ,
&NAME    ESTAE &EXIT,&TYPE,&PARAM=I,&XCTL=NO,&MF=I,&PURGE=,&ASYNCH=,   +
               &TCB=,&ESTAR=,&TERM=,&RECORD=,&BRANCH=,&SVEAREA=,       +
               &RELATED=,&KEY=
.*/*******************************************************************/
.*/*                                                                 */
.*/* Description - Extended Specify Task Abnormal Exit               */
.*/*                                                                 */
.*/* Function    - Map MVS ESTAE parameters to corresponding         */
.*/*               MVT STAE parameters, and issue the appropriate    */
.*/*               STAE macro.                                       */
.*/*                                                                 */
.*/*               The STAE macro instruction permits control to     */
.*/*               be returned to a user exit routine when a task    */
.*/*               is scheduled for ABEND.                           */
.*/*                                                                 */
.*/*               Note the following differences between STAE       */
.*/*               and MVS ESTAE:                                    */
.*/*                                                                 */
.*/*               o  The TERM keyword is not supported.  With       */
.*/*                  ESTAE, TERM allows a recovery routine to       */
.*/*                  receive control, for cleanup only, in the      */
.*/*                  event of an x22 ABEND.                         */
.*/*                                                                 */
.*/*               o  When a STAE exit requests retry, the STAE      */
.*/*                  environment is deleted.  If continued          */
.*/*                  STAE protection is desired, the retry          */
.*/*                  routine must issue a new STAE macro.  This     */
.*/*                  is unlike MVS ESTAE, where the ESTAE           */
.*/*                  environment remains in force even across       */
.*/*                  retry until cancelled.                         */
.*/*                                                                 */
.*/*               o  The STAE retry routine interface is            */
.*/*                  limited.  At entry to the retry routine,       */
.*/*                  R1 points to the 104-byte SDWA and R15         */
.*/*                  points to the retry routine entry address.     */
.*/*                  It is the user's responsibility to free the    */
.*/*                  SDWA and restore registers as required after   */
.*/*                  the retry routine receives control.            */
.*/*                                                                 */
.*/*******************************************************************/
&NAME    STAE  &EXIT,&TYPE,PARAM=&PARAM,MF=&MF,XCTL=&XCTL,             +
               PURGE=&PURGE,ASYNCH=&ASYNCH,TCB=&TCB
         MEND  ,
./ ADD NAME=IHASDWA
         MACRO                                                          00800000
         IHASDWA &DSECT=YES,&VRAMAP=NO                                  00810002
.*A000000                                                        Y02704 00850002
*                                                                    */ 00900002
*%SDWABSL1 : ;                                                          01312002
* /*******************************************************************/ 01312402
* /*                                                                 */ 01312802
* /* THE SDWA (SYSTEM DIAGNOSTIC WORK AREA) IS USED BY BOTH (E)STA   */ 01313202
* /* EXIT ROUTINES AND FRR ROUTINES AS THE COMMUNICATION AREA        */ 01313602
* /* BETWEEN THE RTM AND THE (E)STA OR FRR WHEN ERRORS OCCUR.        */ 01313702
* /* IT IS ALSO REFERRED TO AS THE RTCA (RECOVERY TERMINATION        */ 01313802
* /* COMMUNICATION AREA). IT CONTAINS DATA CONCERNING THE ORIGINAL   */ 01313902
* /* ERROR AND ALSO CONCERNING ACTIONS OF PREVIOUSLY ENTERED         */ 01315302
* /* RECOVERY ROUTINES.                                              */ 01317302
* /*                                                                 */ 01317502
* /* METHOD OF ACCESS                                                */ 01317902
* /* BAL                                                             */ 01318002
* /*             IHASDWA DSECT =  YES                                */ 01318102
* /*                              NO                                 */ 01318202
* /* DSECT = YES IS THE DEFAULT AND WILL PRODUCE THE SDWA            */ 01318302
* /*            AS A DSECT.                                          */ 01318502
* /* DSECT = NO WILL PRODUCE THE SDWA AS A CONTINUATION OF           */ 01318902
* /*            DEFINED STORAGE. (NO DSECT CARD PRODUCED)            */ 01319002
* /* PLS                                                             */ 01319402
* /*   IF MACRO VARIABLE %SDWA9999 IS NOT EQUAL TO ','               */ 01319602
* /*   AND %SDWALVL IS NULL, THE SDWA WILL BE INCLUDED               */ 01319702
* /*   AS A LEVEL 1 STRUCTURE BASED ON SDWAPTR.                      */ 01319802
* /*                                                                 */ 01325902
* /*   IF %SDWALVL IS SPECIFIED AS A NUMBER FROM 1 TO 4              */ 01327902
* /*   THE SDWA WILL BE A NON-BASED STRUCTURE WITH THE               */ 01329902
* /*   TOP LEVEL EQUAL TO %SDWALVL.                                  */ 01331902
* /*                                                                 */ 01332302
* /*   IF SDWA9999 IS EQUAL TO ',' THE SDWA WILL                     */ 01332702
* /*   TERMINATE WITH A COMMA RATHER THAN A                          */ 01332802
* /*   SEMI-COLON.                                                   */ 01332902
* /*                                                                 */ 01340702
* /*                                                                 */ 01342702
* /* MACMEAN SDWA MEANS SYSTEM DIAGNOSTIC WORK AREA                  */ 01348602
* /* MACCOMP Y-1 SC1C5/PZD81                                         */ 01356402
* /* MACSTAT Y-1 72318/Y02703,Y02704                                 */ 01364202
* /* UPDATED 9/23/76 SU33                                    @G33SPHW*/ 01364443
* /*                                                                 */ 01364602
* /*******************************************************************/ 01366202
*%       GOTO SDWABSL;  /*                                              01372002
         AIF ('&DSECT' EQ 'YES').SDWA001                                01379802
SDWA     DS   0D -                                                      01387602
         AGO  .SDWA002                                                  01395402
.SDWA001 ANOP                                                           01403202
SDWA     DSECT , -     SDWAPTR                                          01411002
.SDWA002 SPACE 2                                                        01418802
SDWAPARM DS    A -     PARAMETER LIST ADDRESS IF (E)STA MACRO           01426602
*                      SPECIFIED PARAM OPTION OR 0. FOR FRRS THIS       01434402
*                      IS THE ADDRESS OF THE 6 WORD PARM AREA           01436402
*                      RETURNED BY THE SETFRR MACRO WHEN THE            01438402
*                      PARMAD KEYWORD IS SPECIFIED ON THE SETFRR        01440402
SDWAFIOB DS    0A -    ADDRESS OF PURGE I/O REQUEST LIST (PIRL)         01442202
*                      OR 0 IF HALT I/O IS REQUESTED ON ENTRY TO        01450002
*                      RETRY ROUTINE FOR (E)STA.                        01460002
SDWAABCC DS    0BL4 -  ABEND COMPLETION CODE ON ENTRY TO EXIT ROUTINE.  01500002
SDWACMPF DS    B -     FLAG BITS IN COMPLETION CODE.                    01550002
SDWAREQ  EQU   X'80' - ON, DUMP TO BE GIVEN. SET IF DUMP                01560002
*                      REQUESTED BY ABEND, CALLRTM OR SETRP MACRO.      01610002
SDWASTEP EQU   X'40' - ON, JOBSTEP TO BE TERMINATED.                    07200000
*                      SET IF STEP OPTION SPECIFIED                     07250002
*                      ON ABEND MACRO.                                  07300002
SDWASTCC EQU   X'10' - ON, DON'T STORE COMPLETION CODE.                 07600000
*                      NOT USED IN OS/VS2 R2.                           08000002
SDWACMPC DS    BL3 -   SYSTEM COMPLETION CODE (FIRST 12 BITS) AND       08400000
*                      USER COMPLETION CODE (SECOND 12 BITS).           08800000
SDWACTL1 DS    0CL8 -  BC MODE PSW AT TIME OF ERROR                     09200002
*                      NOT INITIALIZED FOR FRRS.                        09250002
SDWACMKA DS    B -     CHANNEL INTERRUPT MASKS.                         09600000
SDWAIOA  EQU   X'FE' - I/O INTERRUPTS (ALL ZEROS OR ALL ONES).          10000000
SDWAEXTA EQU   X'01' - EXTERNAL INTERRUPT.                              10400000
SDWAMWPA DS    B -     PSW KEY AND 'M-W-P'.                             10800000
SDWAKEYA EQU   X'F0' - PSW KEY.                                         11200000
SDWAMCKA EQU   X'04' - MACHINE CHECK INTERRUPT.                         11600000
SDWAWATA EQU   X'02' - WAIT STATE.                                      12000000
SDWASPVA EQU   X'01' - SUPERVISOR/PROBLEM-PROGRAM MODE.                 12400000
SDWAINTA DS    CL2 -   INTERRUPT CODE (LAST 2 BYTES OF INTERRUPT        12800000
*                      CODE IF I/O INTERRUPT).                          13200000
SDWAPMKA DS    B -     INSTRUCTION LENGTH CODE, CONDITION CODE,         13600000
*                      AND PROGRAM MASKS.                               14000000
SDWAILA  EQU   X'C0' - INSTRUCTION LENGTH CODE.                         14400000
SDWACCA  EQU   X'30' - LAST CONDITION CODE.                             14800000
SDWAFPA  EQU   X'08' - FIXED-POINT OVERFLOW.                            15200000
SDWADOA  EQU   X'04' - DECIMAL OVERFLOW.                                15600000
SDWAEUA  EQU   X'02' - EXPONENT UNDERFLOW.                              16000000
SDWASGA  EQU   X'01' - SIGNIFICANCE.                                    16400000
SDWANXTA DS    AL3 -   ADDRESS OF NEXT INSTRUCTION TO BE EXECUTED.      16800000
*                                                                       17200000
SDWACTL2 DS    0CL8 -  BC MODE PSW FROM LAST PRB ON RB CHAIN.           17600002
*                      ZERO FOR FRRS.                                   17650002
SDWACMKP DS    B -     CHANNEL INTERRUPT MASKS.                         18000000
SDWAIOP  EQU   X'FE' - I/O INTERRUPTS (ALL ZEROS OR ALL ONES).          18400000
SDWAEXTP EQU   X'01' - EXTERNAL INTERRUPT.                              18800000
SDWAMWPP DS    B -     PSW KEY AND 'M-W-P'.                             19200000
SDWAKEYP EQU   X'F0' - PSW KEY.                                         19600000
SDWAMCKP EQU   X'04' - MACHINE CHECK INTERRUPT.                         20000000
SDWAWATP EQU   X'02' - WAIT STATE.                                      20400000
SDWASPVP EQU   X'01' - SUPERVISOR/PROBLEM-PROGRAM MODE.                 20800000
SDWAINTP DS    CL2 -   INTERRUPT CODE (LAST 2 BYTES OF INTERRUPT        21200000
*                      CODE IF I/O INTERRUPT).                          21600000
SDWAPMKP DS    B -     INSTRUCTION LENGTH CODE, CONDITION CODE,         22000000
*                      AND PROGRAM MASKS.                               22400000
SDWAILP  EQU   X'C0' - INSTRUCTION LENGTH CODE.                         22800000
SDWACCP  EQU   X'30' - LAST CONDITION CODE.                             23200000
SDWAFPP  EQU   X'08' - FIXED-POINT OVERFLOW.                            23600000
SDWADOP  EQU   X'04' - DECIMAL OVERFLOW.                                24000000
SDWAEUP  EQU   X'02' - EXPONENT UNDERFLOW.                              24400000
SDWASGP  EQU   X'01' - SIGNIFICANCE.                                    24800000
SDWANXTP DS    AL3 -   ADDRESS OF NEXT INSTRUCTION TO BE EXECUTED.      25200000
*                                                                       25600000
SDWAGRSV DS    0CL64 - GENERAL PURPOSE REGISTERS AT TIME OF ERROR       26000002
SDWAGR00 DS    F -     GPR 0.                                           26400000
SDWAGR01 DS    F -     GPR 1.                                           26800000
SDWAGR02 DS    F -     GPR 2.                                           27200000
SDWAGR03 DS    F -     GPR 3.                                           27600000
SDWAGR04 DS    F -     GPR 4.                                           28000000
SDWAGR05 DS    F -     GPR 5.                                           28400000
SDWAGR06 DS    F -     GPR 6.                                           28800000
SDWAGR07 DS    F -     GPR 7.                                           29200000
SDWAGR08 DS    F -     GPR 8.                                           29600000
SDWAGR09 DS    F -     GPR 9.                                           30000000
SDWAGR10 DS    F -     GPR 10.                                          30400000
SDWAGR11 DS    F -     GPR 11.                                          30800000
SDWAGR12 DS    F -     GPR 12.                                          31200000
SDWAGR13 DS    F -     GPR 13.                                          31600000
SDWAGR14 DS    F -     GPR 14.                                          32000000
SDWAGR15 DS    F -     GPR 15.                                          32400000
*                                                                       32800000
SDWANAME DS    0CL8 -  IF PROBLEM PROGRAM MODE NAME                     33200002
*                      OF ABENDING PROGRAM, OR ZERO                     33600002
*                      IF NO NAME IS AVAILABLE.                         33650002
*                      ZERO IF NOT RUNNING UNDER AN RB                  33700002
SDWARBAD DS    A -     RB ADDRESS OF ABENDING PROGRAM (IF SUPERVISOR    34000000
*                      MODE PROGRAM RUNNING UNDER AN RB)                34400002
         DS    XL4 -   CONTAINS ZEROS IF SUPERVISOR MODE PROGRAM        34800002
*                      RUNNING UNDER AN RB OR IF PROGRAM NOT            34850002
*                      RUNNING UNDER AN RB                              34900002
SDWAEPA  DS    A -     ENTRY POINT ADDRESS OF ABENDING PROGRAM.         35600002
*                      ZERO IF NOT RUNNING UNDER AN RB                  35650002
SDWAIOBR DS    A -     POINTER TO SDWAFIOB FIELD,                       36000002
*                      OR 0 IF NO RETRY, OR 0 IF HALT I/O               36400002
*                      IS REQUESTED FOR (E)STA EXITS.                   36402002
*                      ZERO FOR FRRS                           ICB377   36404002
**** END OF MVT SDWA ****
SDWAEND  EQU  * -      END OF SDWA
SDWALEN  EQU  SDWAEND-SDWA -  LENGTH OF SDWA                            37575802
         MEND  ,
./ ADD NAME=IHADVCT
         MACRO
         IHADVCT   &DSECT=YES
.* /* START OF SPECIFICATIONS ****
.*
.*01  MODULE-NAME = IHADVCT
.*
.*01  COPYRIGHT = NONE
.*
.*01  STATUS = OS/VS2 RELEASE 2, LEVEL 0
.*
.*01  CHANGE-ACTIVITY = NONE
.*
.*01  DESCRIPTIVE-NAME = DEVICE CHARACTERISTICS TABLE MAPPING
.*
.*01  FUNCTION = THIS TABLE DESCRIBES PHYSICAL ATTRIBUTES OF EACH DASD
.*    DEVICE WHICH HAS BEEN SYSGENED
.*
.*01  NOTES = THE TABLE IS POINTED TO BY CVTZDTAB.
.*
.*01  MODULE-TYPE = MACRO
.*02    PROCESSOR = ASSEMBLER-370R
.*
.*02    MACRO-SIZE = 200 STATEMENTS
.*
.**** END OF SPECIFICATIONS ***/
* /* MACCOMP Y-2 SC1D0/SJD48                                    */
* /* MACSTAT Y-2 73226/021160                                   */
*/***************************************************************/
*/*             DEVICE CHARACTERISTICS TABLE                    */
*/***************************************************************/
*/*                                                             */
*/*     THIS TABLE MAY BE USED TO FIND THE CHARACTERISTICS      */
*/*     OF DIRECT ACCESS DEVICES.  THE APPLICABLE DEVICES ARE   */
*/*     THOSE CONTAINING UCBDACC IN UCBTBYT3 (SEE IEFUCBOB).    */
*/*                                                             */
*/*     THE TABLE IS COMPOSED OF AN INDEX FOLLOWED BY ONE       */
*/*     ENTRY FOR EACH DASD DEVICE WHICH HAS BEEN SYSGENED      */
*/*                                                             */
*/*     FOR ASSEMBLER USE, TWO SEPARATE DSECTS ARE PROVIDED.    */
*/*     A USING ON DVCTI GIVES ADDRESSIBILITY TO THE INDEX,     */
*/*     AND A USING ON DVCT GIVES ADDRESSIBILITY TO AN ENTRY.   */
*/*     SPECIFYING DSECT=NO SUPPRESSES THE INDEX AND PROVIDES   */
*/*     AN ENTRY DESCRIPTION WITHOUT A DSECT STATEMENT          */
*/*                                                             */
*/*     THE DEFAULT SETTINGS WILL PROVIDE ADDRESSIBILITY TO     */
*/*     ALL FIELDS, BUT DEPEND ON CVT AND UCB ADDRESSIBILITY.   */
*/*                                                             */
*/*               FORMAT OF EACH ENTRY                          */
*/*         _____________________________________________       */
*/*   0(00) |                     |                     |       */
*/*         |       DVCCYL        |       DVCTRK        |       */
*/*         |_____________________|_____________________|       */
*/*   4(04) |                     |       DVCOVHD       |       */
*/*         |       DVCTRKLN      | DVCOVNLB | DVCOVLB  |       */
*/*         |_____________________|__________|__________|       */
*/*   8(08) |          |          |                     |       */
*/*         | DVCOVNK  | DVCFLAGS |       DVCTOL        |       */
*/*         |__________|__________|_____________________|       */
*/*  12(0C) |                     |______________________       */
*/*         |       DVCALT        |                     |       */
*/*         |_____________________|       DVCOVR0       |  RPS  */
*/*         ______________________|_____________________|  ONLY */
*/*  16(10) |          |          |                             */
*/*         | DVCSECT  | DVCSECTD |                             */
*/*         |__________|__________|                             */
*/***************************************************************/
*%/*
DVCTI    DSECT ,              INDEX TO DVCT
*              THIS INDEX IS LOCATED FROM CVTZDTAB.
*              THE PROPER ENTRY IS FOUND BY ADDING THE LOW ORDER
*              4 BITS OF UCBTYP TO THE ADDRESS IN CVTZDTAB.
DVCTYPMK EQU   15                       TYPICAL USAGE:
*              LA    RWRK,DVCTYPMK      MASK FOR UNIT TYPE NUMBER
*              N     RWRK,UCBTYP        PICK UP UNIT TYPE NUMBER
*              IC    RWRK,DVCTIOFF(RWRK)  PICK UP OFFSET
DVCTIOFF DS    AL1                      OFFSET TO DVCT ENTRY
******************************************************************
         SPACE 3
DVCT     DSECT , -                      FORMAT OF DVCT ENTRY
*              THE ENTRY IS LOCATED BY ADDING DVCTIOFF TO CVTZDTAB
*
DVCCYL   DS    H -                      PHYS NO. CYL PER VOLUME
DVCTRK   DS    H -                      NO. TRACKS PER CYLINDER
DVCTRKLN DS    H -                      NO. OF BYTES PER TRACK
*
DVCOVHD  DS    0H -                     BLOCK OVERHEAD IF DVC2BOV=1
*              USE FOLLOWING TWO CONSTANTS IF DVC2BOV=0
DVCOVNLB DS    XL1 -                    OVERHEAD NOT LAST BLOCK
DVCOVLB  DS    XL1 -                    OVERHEAD LAST BLOCK
*
DVCOVNK  DS    XL1 -                    OVERHEAD DECREMENT
*                                       NOT KEYED
*
DVCFLAGS DS    BL1 -
DVC2BOV  EQU   X'08' -                  IF 1, USE DVCOVHD
*                                       IF 0, USE DVCOVNLB,DVCOVLB
DVCFTOL  EQU   X'01' -                  IF 1, APPLY TOLERANCE
*                                             FACTOR
*
DVCTOL   DS    H -                      TOLERANCE FACTOR
*              APPLY TOLERANCE FACTOR AS FOLLOWS:
*              1. ADD BLOCKSIZE AND KEYLENGTH
*              2. MULTIPLY BY DVCTOL
*              3. SHIFT RIGHT DVCTSHFT BITS
*              4. ADD APPROPRIATE OVERHEADS
DVCTSHFT EQU   9 -                      SHIFT TO DIVIDE BY 512
*
DVCALT   DS    H -                      NUMBER ALTERNATE TRACKS
*                                       PER VOLUME
*
DVCENTLG EQU   *-DVCT -                 BASIC SIZE OF DEVICE TABLE
*                                       ENTRY, NOT INCLUDING ADD'L
*                                       CHARACTERISTICS FOR RPS
******************************************************************
*              THE FOLLOWING SECTION OF THE TABLE IS             *
*              PRESENT ONLY FOR RPS DEVICES--TEST UCBTBYT2       *
*              FOR UCB2OPT3                                      *
******************************************************************
DVCRPS   DS    0CL4 -                   RPS SECTION
DVCOVR0  DS    H -                      OVERHEAD BYTES FOR
*                                       RECORD 0
DVCSECT  DS    XL1 -                    NUMBER SECTORS IN FULL
*                                       TRACK
DVCSECTD DS    XL1 -                    NUMBER DATA SECTORS
*
*              END OF DVCT
         MEND
./ ADD NAME=IKJEFFDF
         MACRO                                                          01200002
         IKJEFFDF &DFDSECT=NO,&DFDSEC2=NO                               01800000
.*A-000000-999999                                               Y02993  02400002
.*C-REL. 4 UPDATE CHANGES FOR LENGTH OF POSSIBLE VALUES        @Z40NQKQ 02450000
.*C-IDNUM AND ALTERNATE NAME FOR IDNUM                         @Z40NQKQ 02500000
.*C-TWO BUFFERS FOR EXTRACTING MESSAGES                        @Z40GQKU 02550000
.*C198000                                                     @ZA61225  02600000
         AGO .DFBAL01                  **SKIP PLS MACRO STATEMENT ** */ 03000002
*%DFPLS1: ;                            /* BAL/PLS HEADER                03600002
.DFBAL01 ANOP                                                        */ 04200002
*/********************************************************************/ 04800002
*/*                                                                  */ 05400002
*/* *** IKJEFFDF ***     LEVEL=06/19/75     OS/VS2 RELEASE 4.0       */ 06000000
*/*                                                          @Z40NQKJ*/ 06050000
*/* DESCRIPTION - BILINGUAL MAPPING MACRO FOR IKJEFF18 PARAMETER     */ 07200002
*/*               LIST (DYNAMIC ALLOCATION SVC99 FAILURES OR         */ 07800002
*/*               DAIR FAILURES)                                     */ 08400002
*/*                                                                  */ 09000002
*/* FUNCTION   - THE PARAMETER LIST IS THE INTERFACE                 */ 09600002
*/*              TO IKJEFF18 FROM CALLER WITH AN ERROR RETURN        */ 10200002
*/*              FROM SVC99 OR DAIR                                  */ 10800002
*/*                                                                  */ 11400002
*/*              REGISTER 1 CONTAINS THE ADDRESS OF DFPARMS          */ 12000002
*/*              REGISTER 15 WILL CONTAIN IKJEFF18'S RETURN CODE     */ 12600002
*/*                          TO THE CALLER (0 IF MESSAGE(S)          */ 13200002
*/*                          ISSUED SUCCESSFULLY)                    */ 13800002
*/*                                                                  */ 14400002
*/* METHOD OF ACCESS                                                 */ 15000002
*/*      PL/S   - %DFTYPE='BDY(WORD)'- - - IF DON'T WANT BASED       */ 15600002
*/*                                        (THIS IS THE DEFAULT)     */ 16200002
*/*               %DFTYPE2='BASED(DFBUFP)' IF WANT TO HAVE   @Z40GQKU*/ 16250000
*/*                                        BASED (THIS IS THE@Z40GQKU*/ 16300000
*/*                                        DEFAULT)          @Z40GQKU*/ 16350000
*/*               %INCLUDE SYSLIB(IKJEFFDF)                          */ 17400002
*/*                                                                  */ 18000002
*/*      BAL    - DFDSECT=YES  IF DON'T WANT TO GET CORE             */ 18600002
*/*                 THEN CODE      LA    REG,MYDFCORE  *CALLER AREA  */ 19200002
*/*                               USING DFDSECTD,REG         @ZA61225*/ 19800000
*/*               DFDSECT=NO   IS THE DEFAULT.                       */ 20400002
*/*               DFDSEC2=YES  IF DON'T WANT TO GET CORE     @Z40GQKU*/ 20450000
*/*                 THEN CODE      LA    REG,MYDFCORE        @Z40GQKU*/ 20500000
*/*                                           *CALLER AREA   @Z40GQKU*/ 20550000
*/*                                USING DFDSECT2,REG        @Z40GQKU*/ 20600000
*/*               DFDSEC2=NO   THIS IS THE DEFAULT           @Z40GQKU*/ 20650000
*/*                                                                  */ 21000002
*/*               IKJEFFDF                                           */ 21300002
*/*                                                                  */ 21600002
*/* NOTES       - IKJEFF18 WILL INDEX INTO THE S99RB FOR SVC 99      */ 22200002
*/*               ERRORS AND THE DAIR PARAMETER BLOCK FOR DAIR       */ 22800002
*/*               ERRORS TO OBTAIN DSNAME, DDNAME, VOLSER,ETC,       */ 23400002
*/*               INFORMATION WHICH MAY BE INSERTED INTO THE         */ 24000002
*/*               OUTPUT MESSAGE                                     */ 24600002
*/*                                                                  */ 25200002
*/* F.E.'S      - MICROFICHE LISTING    IKJEFFDF                     */ 25800002
*/*                                                                  */ 26400002
*/********************************************************************/ 27000002
*        %GOTO DFPLS2;                 /* BAL ONLY FOLLOWS              28200002
.*       SET UP DSECT CARD IF DFDSECT-YES ON MACRO                      28800002
         AIF   ('&DFDSECT' EQ 'NO').DFBAL1                              29400002
DFDSECTD DSECT                                                          30000002
.DFBAL1  ANOP                          **MACRO STATEMENT**              30600002
         DS    0F                                                       31200002
DFPARMS  EQU   *                                                        31800002
DFS99RBP DS    A                      *ADDRESS OF THE FAILING SVC 99    32400000
*                                      REQUEST BLOCK FOR SVC 99 ERRORS  33000002
DFDAPLP  EQU   DFS99RBP               *ADDRESS OF THE FAILING DAIR      33600000
*                                      PARAMETER LIST FOR DAIR ERRORS   34200002
DFRCP    DS    A                      *ADDRESS OF A FOUR BYTE STORAGE   34800000
*                                      AREA CONTAINING THE SVC 99 OR    35400002
*                                      THE DAIR REGISTER 15 RETURN CODE 36000002
DFJEFF02 DS    A                      *ADDRESS OF A FOUR BYTE AREA      36600000
*                                      WHICH CONTAINS EITHER THE ENTRY  37200002
*                                      POINT ADDRESS OF IKJEFF02        37800002
*                                      (MESSAGE WRITER FOR IKJEFF18) OR 38400002
*                                      ZEROES IF ENTRY ADDRESS IS       39000002
*                                      UNKNOWN                          39600002
DFIDP    DS    A                      *ADDRESS OF A TWO BYTE AREA       40200000
*                                      CONTAINING A CALLER IDENTIFIER   40800000
*                                      NUMBER DESCRIBED BELOW  @Z40GQKU 41400000
DFCPPLP  DS    A                      *ADDRESS OF THE CPPL - THIS IS    42000000
*                                      NEEDED ONLY WHEN IKJEFF18 IS     46200002
*                                      CALLED WITH AN SVC 99 ERROR      46800002
DFBUFP   DS    A                      *ADDRESS OF DFBUFS IF DFBUFSW OR  47400000
*                                      DFBUFS2 ON              @Z40GQKU 47450000
DFLEN    EQU   *-DFPARMS                                                48600002
**********************************************************************  49200002
* POSSIBLE VALUES FOR THE CALLER IDENTIFIER POINTED TO BY DFIDP         49800002
**********************************************************************  50400002
*                                                                       51000002
DFSVC99  EQU   50                      GENERAL CALLER WITH AN SVC 99    51600002
*                                      ERROR                            51900002
DFFREE   EQU   51                      FREE COMMAND WITH AN SVC 99      52200002
*                                      ERROR                            52500002
DFDAIR   EQU   1                       GENERAL CALLER WITH A DAIR ERROR 52800002
*                                                                       52880002
DFWTP    EQU   X'80'                   THE HIGH ORDER BIT ON IN THE     52960002
*                                      CALLER IDENTIFIER INDICATES      53040002
*                                      A WRITE TO PROGRAMMER IS         53120002
*                                      NEEDED INSTEAD OF THE DEFAULT    53200002
*                                      PUTLINE                          53280002
DFBUFSW  EQU   X'40'                   ON IF CALLER WANTS      @Z40GQKU 53284000
*                                      MESSAGE TEXT RETURNED IN@Z40GQKU 53288000
*                                      BUFFERS INSTEAD OF      @Z40GQKU 53292000
*                                      DEFAULT PUTLINE         @Z40GQKU 53296000
DFBUFS2  EQU   X'20'                   ON IF WANT DFBUFSW      @Z40GQKU 53300000
*                                      FUNCTION PLUS PUTLINE   @Z40GQKU 53304000
*                                      (OR WTP)                @Z40GQKU 53308000
*/***********************************************************@Z40GQKU*/ 53312000
*/* MAP OF CALLER-SUPPLIED BUFFERS POINTED TO BY DFBUFP      @Z40GQKU*/ 53316000
*/***********************************************************@Z40GQKU*/ 53320000
.*       SET UP DSECT CARD IF DFDSEC2-YES ON MACRO             @Z40GQKU 53324000
         AIF   ('&DFDSEC2' EQ 'NO').DFBAL2                     @Z40GQKU 53328000
DFDSECT2 DSECT                                                 @Z40GQKU 53332000
.DFBAL2  ANOP                          **MACRO STATEMENT**     @Z40GQKU 53336000
DFBUFS   DS    0F                      (NEED NOT INITIALIZE)   @Z40GQKU 53340000
DFBUF1   EQU   *                                               @Z40GQKU 53344000
DFBUFL1  DS    FL2                     LENGTH OF AREA USED IN  @Z40GQKU 53348000
*                                      DFBUF1 (INCLUDES DFBUFL1@Z40GQKU 53352000
*                                      AND DFBUFO2 FIELDS)     @Z40GQKU 53356000
DFBUFO1  DS    FL2                     OFFSET IS ZERO ON RETURN@Z40GQKU 53360000
DFBUFT1  DS    CL251                   TEXT OF FIRST LEVEL     @Z40GQKU 53364000
*                                      MESSAGE                 @Z40GQKU 53368000
DFBUF2   DS    0H                                              @Z40GQKU 53372000
DFBUFL2  DS    FL2                     LENGTH (INCLUDES LLOO   @Z40GQKU 53376000
*                                      FIELDS)                 @Z40GQKU 53380000
DFBUFO2  DS    FL2                     OFFSET                  @Z40GQKU 53384000
DFBUFT2  DS    CL251                   TEXT OF SECOND LEVEL    @Z40GQKU 53388000
*                                      MESSAGE                 @Z40GQKU 53392000
DFLEN2   EQU   *-DFBUFS                LENGTH OF BUFFER PARMS  @Z40GQKU 53396000
**********************************************************************  53400002
* END OF IKJEFFDF MAPPING MACRO                                         54000002
**********************************************************************  54600002
         MEND                                                      , */ 55200002
./ ADD NAME=IKJEFFMT
*        %GOTO MTPLS1;              /* BILINGUAL MAPPING
         MACRO
         IKJEFFMT &MTDSECT=NO,&MTNINST=4
         AGO .MTBAL01              ** SKIP PLS MACRO STATEMENT **   */
*%MTPLS1: ;                        /* BAL/PLS HEADER
.MTBAL01  ANOP                                                       */
*/********************************************************************/
*/*                                                                  */
*/* *** IKJEFFMT ***     MVS 3.8 macro reworked for MVT 21.8         */
*/*                                                                  */
*/* Description - Mapping macro for parameter list to IKJEFF02       */
*/*               (TSO message issuer service routine).              */
*/*                                                                  */
*/* Function    - The parameter list identifies a message, describes */
*/*               insert(s) for the message, and indicates whether   */
*/*               to issue the message as a PUTLINE, PUTGET, WTO,    */
*/*               or a write to programmer.                          */
*/*                                                                  */
*/*               The parameter list also points to a message        */
*/*               CSECT containing the message's text.  The          */
*/*               IKJTSMSG macro is used to generate the             */
*/*               necessary DCs for the text and the offsets         */
*/*               to inserts in the message.  The last entry in      */
*/*               the CSECT must be an IKJTSMSG macro with no        */
*/*               operands.                                          */
*/*                                                                  */
*/*               Register 1 -> MTPARML = MSGTABLE parmlist          */
*/*               Register 15 will contain IKJEFF02's return code    */
*/*                           to the caller (0 if successful,        */
*/*                           76 if parameter list error (message is */
*/*                           also issued), or error return code     */
*/*                           from PUTLINE or PUTGET)                */
*/*                                                                  */
*/********************************************************************/
*        %GOTO MTPLS2;              /* BAL ONLY FOLLOWS
.*       SET UP DSECT CARD IF MTDSECT=YES ON MACRO
         AIF   ('&MTDSECT' EQ 'NO').MTBAL1  **MACRO STATEMENT**
MTDSECTD DSECT
.MTBAL1  ANOP             **MACRO STATEMENT**
         DS    0F
MTPARML  EQU   * -        .<<PARAMETER LIST TO IKJEFF02>>
*                         .   UNUSED NON-INSERT FIELDS MUST BE ZEROED
LISTPTR  DS    0A -       .ALTERNATE NAME FOR MTPLPTR
MTPLPTR  DC    A(0) -     .LISTPTR = POINTER TO MESSAGE DESCRIPTION
*                         .   SECTION OF PARAMETER LIST
TMCTPTR  DS    0A -       .ALTERNATE NAME FOR MTCPPLP
MTCPPLP  DC    A(0) -     .TMCTPTR = POINTER TO TMP'S CPPL CONTROL
*                         .   BLOCK (REQUIRED FOR PUTLINE OR PUTGET)
ECBPTR   DS    0A -       .ALTERNATE NAME FOR MTECBP
MTECBP   DC    A(0) -     .ECBPTR = OPTIONAL PUTGET/PUTLINE ECB POINTER
***********************************************************************
*  IKJEFFMT - MESSAGE DESCRIPTION SECTION OF PARAMETER LIST           *
***********************************************************************
MTCSECTP DC    A(0) -     .MSGCSECT = POINTER TO CSECT WITH CALLER'S
*                         .   MESSAGE TEXTS, BUILT WITH IKJTSMSG MACRO
SW       DS    0B -       .ALTERNATE NAME FOR MTSW1
MTSW1    DC    B'0' -     .SW = BYTE OF SWITCHES
MTNOIDSW EQU   X'80' -    -- PRINTING DATA;
*                            THE MESSAGE IS AN INFORMATION MESSAGE.
*                            THERE IS NO MESSAGE IDENTIFIER.
MTPUTLSW EQU   X'40' -    -- ISSUE MESSAGE AS PUTLINE, NOT PUTGET;
*                            RELATED MESSAGES ARE TO BE PUT OUT IN
*                            REVERSE ORDER, STARTING WITH THE LAST
*                            ONE IN THE CHAIN.  NO REPLY IS CALLED
*                            FOR IN THIS CASE.
MTWTOSW  EQU   X'20' -    -- ISSUE MESSAGE AS A WTO;
*                            IN THIS CASE, THE TMCT POINTER SHOULD
*                            POINT TO THE CONSOLE ID.  SECONDARY
*                            LEVELS ARE NOT CHECKED FOR.
MTHEXSW  EQU   X'10' -    -- TRANSLATE NUMERIC INSERTS TO PRINTABLE HEX
*---------------------------------------------------------------------*
*        Following MTSW1 flags defined in MVS 3.8 are not             *
*        supported in MVT.                                            *
*---------------------------------------------------------------------*
MTKEY1SW EQU   X'08' -    -- DO MODESET TO KEY 0 BEFORE PUTLINE/PUTGET
MTJOBISW EQU   X'04'      -- COMPRESS BLANKS OUT OF XX(YY) INSERT
MTWTPSW  EQU   X'02'      -- ISSUE MESSAGE AS A WRITE TO PROGRAMMER
MTNHEXSW EQU   X'01'      -- TRANSLATE ALL NUMERIC INSERTS TO DECIMAL
*---------------------------------------------------------------------*
*        End of MTSW1 flags not supported in MVT.                     *
*---------------------------------------------------------------------*
RETMSG   DS    0AL3 -     .ALTERNATE NAME FOR MTREPLYP
MTREPLYP DC    AL3(0)     .RETMSG = POINTER TO REPLY FROM PUTGET,
*                         .   IN THE FORMAT LL-TEXT, WHERE LL IS
*                         .   A TWO-BYTE LENGTH FIELD WITH LENGTH OF
*                         .   THE REPLY (INCLUDING LENGTH OF LL FIELD).
*                         .   IKJEFF02 OBTAINS THIS BUFFER IN SUBPOOL 0
*                         .   AND IT MAY BE FREED BY THE CALLER.
*                         .   THE REPLY IS CONVERTED TO UPPER CASE.
MSGID    DS    0CL4 -     .ALTERNATE NAME FOR MTMSGID
MTMSGID  DC    C'XXXX'    .MSGID = ID USED TO SEARCH FOR MESSAGE
*                         .   TEXT IN THE MESSAGE CSECT
L1       DS    0AL1 -     .ALTERNATE NAME FOR MTLEN
MTLEN    DS    0AL1       .LENGTH OF AN INSERT FOR THE MESSAGE.
MTHIGHL  DS    BL1        .HIGH-ORDER BIT ON IF TRANSLATE
VAR1     DS    0AL3 -     .ALTERNATE NAME FOR MTADDR
MTADDR   DS    AL3        .ADDRESS OF AN INSERT FOR THE MESSAGE.
L2       DS    0AL1 -     .ALTERNATE NAME FOR MTLEN2
MTLEN2   DS    0AL1       .LENGTH OF AN INSERT FOR THE MESSAGE.
MTHIGHL2 DS    BL1        .HIGH-ORDER BIT ON IF TRANSLATE
VAR2     DS    0AL3 -     .ALTERNATE NAME FOR MTADDR2
MTADDR2  DS    AL3        .ADDRESS OF AN INSERT FOR THE MESSAGE.
L3       DS    0AL1 -     .ALTERNATE NAME FOR MTLEN3
MTLEN3   DS    0AL1       .LENGTH OF AN INSERT FOR THE MESSAGE.
MTHIGHL3 DS    BL1        .HIGH-ORDER BIT ON IF TRANSLATE
VAR3     DS    0AL3 -     .ALTERNATE NAME FOR MTADDR3
MTADDR3  DS    AL3        .ADDRESS OF AN INSERT FOR THE MESSAGE.
L4       DS    0AL1 -     .ALTERNATE NAME FOR MTLEN4
MTLEN4   DS    0AL1       .LENGTH OF AN INSERT FOR THE MESSAGE.
MTHIGHL4 DS    BL1        .HIGH-ORDER BIT ON IF TRANSLATE
VAR4     DS    0AL3 -     .ALTERNATE NAME FOR MTADDR4
MTADDR4  DS    AL3        .ADDRESS OF AN INSERT FOR THE MESSAGE.
         DS    A
         MEND                                                      , */
*%MTPLS2: ;
* /* MVT PRIVATE MACRO PL/S MAPPING FOR IKJEFFMT */
*        DCL  1  MSGTABLE BASED (MSGPTR),    /* MESSAGE TABLE    */     04000020
*                2 LISTPTR  PTR (31),        /*   TO LIST        */     08000020
*                2 TMCTPTR  PTR (31),        /*   TO TMCT        */     12000020
*                2 ECBPTR   PTR (31),        /*   TO COMM ECB    */     16000020
*                2 MSGCSECT PTR (31),        /* LIST - MSG CSECT */     20000020
*                2 SW       PTR  (8),        /*   SW             */     24000020
*                2 RETMSG   PTR (24),        /*   RETURN MSG     */     28000020
*                2 MSGID CHAR (4),           /*   MESSAGE ID     */     32000020
*                2 L1       PTR  (8),        /*   LEN            */     36000020
*                  3 HIGHL1 BIT (1),                                    40000020
*                2 VAR1     PTR (24),        /*     VARIABLE     */     44000020
*                2 L2       PTR  (8),        /*   LEN            */     48000020
*                  3 HIGHL2 BIT (1),                                    52000020
*                2 VAR2     PTR (24),        /*     VARIABLE     */     56000020
*                2 L3 PTR (8),                                          56011020
*                  3 HIGHL3 BIT (1),                                    56020020
*                2 VAR3 PTR (24),                                       56030020
*                2 L4 PTR (8),                                          56040020
*                  3 HIGHL4 BIT (1),                                    56050020
*                2 VAR4 PTR (24),                                       56060020
*                2 MSGRTN   PTR (31);        /* MSG RTN ADDR     */     60000020
*        DCL 1 RET BDY (WORD) BASED (RETMSG),  /* RETURN MESSAGE */     64000020
*                2 RETSIZE FIXED (15),         /*   SIZE         */     68000020
*                2 RETCHAR CHAR (18);          /*   RETURN TEXT  */     72000020
*        DCL MSGTMCT BASED (TMCTPTR);          /* TMCT FOR MSG RTN */   76000020
*        DCL MSGECB BASED (ECBPTR);            /* ECB FOR MSG RTN  */   80000020
./ ADD NAME=IKJTSMSG
         MACRO                                                          02000020
&MESS    IKJTSMSG  &PARTS,&ID,&SECID                                    04000020
         LCLA  &A                                                       06000020
         LCLA  &B                                                       08000020
         LCLA  &C                                                       10000020
         LCLC  &LP                                                      12000020
         LCLC  &LEN                                                     14000020
         SPACE 2                                                        16000020
&A       SETA  1                                                        18000020
&B       SETA  N'&PARTS                                                 20000020
&LEN     SETC  'A'.'&SYSNDX'                                            22000020
         AIF   (T'&ID NE 'O').PRID                                      24000020
         AIF   (T'&PARTS NE 'O').ID                                     26000020
         DC    CL4'    '           INDICATES END OF MSG CSECT           28000020
         AGO   .OUT                                                     30000020
.ID      ANOP                                                           32000020
         MNOTE 8,'SPECIFY MESSAGE ID'                                   34000020
.PRID    ANOP                                                           36000020
&MESS    DC    CL4'&ID'            ID                                   38000020
         AIF   (T'&SECID NE 'O').SECOND                                 40000020
         DC    CL4'    '           NO FOLLOWING MESSAGE                 42000020
         AGO   .NB                                                      44000020
.SECOND  ANOP                                                           46000020
         DC    CL4'&SECID'         ID OF FOLLOWING MSG                  48000020
.NB      ANOP                                                           50000020
         DC    AL2(&LEN-*+8)       TOTAL LENGTH                         52000020
         DC    AL1(&B)             NB OF PARTS TO MSG                   54000020
.LOOP    ANOP                                                           56000020
         AIF   (T'&PARTS(&A) NE 'O').SKP                                58000020
         DC    AL1(0)              A VARIABLE                           60000020
         AGO   .INC                                                     62000020
.SKP     ANOP                                                           64000020
&LP  SETC  '&LEN'.'&A'                                                  66000020
         DC    AL1(&LP-*-1)        LENGTH OF MSG PART                   68000020
         AIF   ('&PARTS(&A)'(1,1) EQ '''').QUO                          70000020
         MNOTE 12,'QUOTES MISSING ON OPERAND'                           72000020
.QUO     ANOP                                                           74000020
         DC    C&PARTS(&A)         MSG PART                             76000020
&LP      EQU   *                                                        78000020
.INC     ANOP                                                           80000020
&A       SETA  &A+1                                                     82000020
         AIF   (&A LE N'&PARTS).LOOP                                    84000020
&LEN     EQU   *                                                        86000020
.OUT     ANOP                                                           88000020
         SPACE 4                                                        90000020
         MEND                                                           92000020
./ ADD NAME=LNK7003
 INCLUDE SYSPUNCH(PDS7003)
 INCLUDE SYSPUNCH(STARRTN)
 ENTRY PDSMAIN
 ALIAS PDS
 NAME PDS7003(R)
./       ADD   NAME=PDSGEN70
         TITLE 'P D S  --  PDS PROGRAM GENERATION OPTIONS             ' 00010000
         SPACE 1                                                   @D01
***                                                                @D01
*** UPDATE (UU) NUMBER IN MESSAGE PDS100I                          @D01
***                                                                @D01
&VERS    SETC  '7.0.03 FOR MVT'                                    @D06
         SPACE 2                                                   @D01
***                                                                @D01
*** DATE OF LAST MAINTENANCE FOR PDS                               @D01
***                                                                @D01
&FIXDATE SETC  'AUGUST 18, 2021'                                   @D06
         SPACE 2                                                   @D01
***                                                                     00020000
*** SET THE LEVEL OF YOUR OPERATING SYSTEM WITH ANY OF THREE VALUES:    00030000
***                                                                     00040000
*&MVSLEV  SETC  'MVS13X'    ***  FOR MVS SP 1.3 OR LATER           @D01 00050000
*&MVSLEV  SETC  'MVS12X'   ***  FOR MVS SP 1.2, 1.1 OR ANY SE SYSTEM    00060000
&MVSLEV  SETC  'MVS038'   ***  FOR MVS 3.8 (also set for MVT)      @D01
&MVT     SETB  1          ***  For MVT                             @D01
         SPACE 2                                                        00080000
***                                                                @D01
*** Define unit name for default DASD allocation                   @D01
***                                                                @D01
&DAUNIT  SETC  'SYSDA'                                             @D06
         SPACE 2                                                   @D01
***                                                                     00090000
*** IF PDS IS TO RUN IN A XA-370 MIXED MODE AND YOU USE XA MACLIBS,     00100000
***    UNCOMMENT THE FOLLOWING STATEMENT:                               00110000
***                                                                     00120000
*        SPLEVEL SET=1                                         SS NOV84 00130000
         SPACE 2                                                        00140000
***                                                                     00150000
*** SET THE TYPE OF TERMINAL ACCESS METHOD:                             00160000
***                                                                     00170000
*&CONVTAM SETC  'VTAMONLY'  ***  FOR VTAM ONLY                     @D01 00180000
*&CONVTAM SETC  'TCAMONLY' ***  FOR TCAM ONLY                           00190000
&CONVTAM SETC  'VTAMTCAM' ***  FOR VTAM AND TCAM                   @D01 00200000
         SPACE 2                                                        00210000
***                                                                     00220000
*** SET THE OPTION FOR DISPLAY WITH A SINGLE PARAMETER:                 00230000
***                                                                     00240000
&CONDRNG SETC  'N'         ***  CONTINUE TO THE END OF THE DIRECTORY    00250000
*&CONDRNG SETC  'Y'        ***  TREAT  DISPLAY XX  LIKE  DISPLAY XX:XX  00260000
         SPACE 2                                                        00270000
***                                                                     00280000
*** SET THE DIALOG DISPLAY SIZE FOR ISPMODE:                   SS JUL84 00290000
***                                                                     00300000
&SPFSIZE SETC  '1000'   NUMBER OF LINES IN THE TABLE                    00310000
         SPACE 2                                                        00320000
***                                                                     00330000
*** SET THE DIALOG DISPLAY MAXIMUM SIZE FOR ANY ONE            SS JUL84 00340000
*** SUBCOMMAND FOR OPERATION UNDER THE ISPMODE SUBCOMMAND.              00350000
*** THIS IS FOR LARGE AMOUNTS OF OUTPUT FROM ONE SUBCOMMAND             00360000
*** WHICH MIGHT OTHERWISE OVERFLOW THE ABOVE DISPLAY SIZE:              00370000
***                                                                     00380000
&SPFMAX  SETC  '2000'   NUMBER OF LINES                                 00390000
         SPACE 2                                                        00400000
***                                                                     00410000
*** SET THE DIALOG CHECKPOINT DEFAULT SIZE FOR ISPMODE;        SS JUL84 00420000
*** THIS IS FOR LARGE AMOUNTS OF OUTPUT FROM ONE SUBCOMMAND.            00430000
*** IT ALLOWS THE USER TO CHECK THE OUTPUT AFTER XXX LINES              00440000
*** BEFORE ALL OUTPUT FROM THE SUBCOMMAND HAS BEEN PRODUCED             00450000
*** AND THE USER MAY CONTINUE OR STOP THE SUBCOMMAND.                   00460000
***                                                                     00470000
&SPFCKPT SETC  '250'    NUMBER OF LINES                                 00480000
         SPACE 2                                                        00490000
***                                                                     00500000
*** SET THE DEFAULT MESSAGE FOR THE DSNAME SUBCOMMAND AND               00510000
*** FOR DATA SET ALLOCATION:                                            00520000
***                                                                     00530000
&CONADEF SETC  'FDSNMSG'   ***  SEE PDS200I MESSAGE EXAMPLE BELOW       00540000
*&CONADEF SETC  'FDSNTSO'  ***  SEE PDS210I MESSAGE EXAMPLE BELOW       00550000
*&CONADEF SETC  'FDSNJCL'  ***  SEE PDS220I MESSAGE EXAMPLE BELOW       00560000
***                                                                     00570000
*PDS200I DISP UNIT  REC LRECL BLKSZ  ALLOCTRK FREETRK SECONDARY FREEDIR 00580000
*PDS200I SHR  3380  VB    255  9040  1X    15       7     0 CYL      18 00590000
*                                                                       00600000
*PDS210I ALLOC F(SYS00007) DA('HABL.LIB.CLIST') SHR UNIT(3380)          00610000
*PDS210I   RECFM(V B) LRECL(255) BLKSIZE(9040) VOLUME(TSO002)           00620000
*PDS210I   CYL SPACE(1) DIR(40)              /*FREE TRK=7,FREE DIR=18*/ 00630000
*                                                                       00640000
*PDS220I //SYS00007  DD  DSN=HABL.LIB.CLIST,DISP=SHR,UNIT=3380,         00650000
*PDS220I //  DCB=(RECFM=VB,LRECL=255,BLKSIZE=9040),VOL=SER=TSO002,      00660000
*PDS220I //  SPACE=(CYL,(1,,40))             /*FREE TRK=7,FREE DIR=18*/ 00670000
*                                                                       00680000
         SPACE 3                                                        00690000
***                                                                     00700000
*** SET THE OPTION TO CIRCUMVENT APAR OZ80528 (PERMANENT RESTRICTION -  00710000
*** SYMPTOM IS IGNORED EDIT OR BROWSE AFTER PF4 IN ISPF SUBCOMMAND).    00720000
***                                                                     00730000
*** THE CIRCUMVENTION TESTS FOR THE EXIT TYPE AND ISSUES DOUBLE EDIT    00740000
*** OR BROWSE SUBCOMMANDS SUBSEQUENTLY IF REQUIRED.                     00750000
***                                                                     00760000
&RETURNX SETC  'YES'       ***  REISSUE EDIT OR BROWSE AFTER RETURN     00770000
*&RETURNX SETC  'NO'       ***  DO NOT REISSUE SUBCOMMANDS AFTER RETURN 00780000
         SPACE 3                                                   @D03
****************************************************************** @D03
***                                                                @D03
*** SET THE UNIT NAME FOR //SYSUT4 DATA SET USED BY COPY           @D03
*** CAUTION: THIS UNIT NAME MUST NOT MAP TO A VIO DEVICE           @D03
***                                                                @D03
&TUNIT   SETC  'SYSDA'    ***  COPY TEMPORARY //SYSUT4 UNIT        @D06
*&TUNIT   SETC  'PUBDA'    ***  COPY TEMPORARY //SYSUT4 UNIT       @D03
         EJECT                                                          00790000
***                                                                     00800000
*** SET THE UNIT NAME STRING (1 TO 8 CHARACTERS -- A GENERIC NAME       00810000
*** MAY BE USED) ACCORDING TO TYPE OF DEVICE.  THESE NAMES WILL BE      00820000
*** USED BY THE DSNAME SUBCOMMAND.                                      00830000
***                                                                     00840000
&UN2311  SETC  '2311    '    ***  2311    DEVICE                   @D01
&UN2301  SETC  '2301    '    ***  2301    DEVICE                   @D01
&UN2303  SETC  '2303    '    ***  2303    DEVICE                   @D01
&UN2302  SETC  '2302    '    ***  2302    DEVICE                   @D01
&UN2321  SETC  '2321    '    ***  2321    DEVICE                   @D01
&UN23051 SETC  '2305-1  '    ***  2305-1  DEVICE                        00850000
&UN23052 SETC  '2305-2  '    ***  2305-2  DEVICE                        00860000
&UN2314  SETC  '2314    '    ***  2314    DEVICE                        00870000
&UN3330  SETC  '3330    '    ***  3330-1  DEVICE                        00880000
&UN3340  SETC  '3340    '    ***  3340    DEVICE                        00890000
&UN3350  SETC  '3350    '    ***  3350    DEVICE                        00900000
&UN3375  SETC  '3375    '    ***  3375    DEVICE                        00910000
&UN33301 SETC  '3330-1  '    ***  3330-11 DEVICE                        00920000
&UN3380  SETC  '3380    '    ***  3380    DEVICE                        00930000
&UN3390  SETC  '3390    '    ***  3390    DEVICE                   @D01
         SPACE 3                                                        00940000
***                                                                     00950000
*** SET THE INITIAL BUFFERING MODE FOR EACH DEVICE TYPE USING ONE       00960000
*** OF THE FOLLOWING VALUES:                                            00970000
***      SINGLE:   SINGLE BUFFERING                                     00980000
***      DOUBLE:   DOUBLE BUFFERING                                     00990000
***      MULTIPLE: MULTIPLE BUFFERING (READ MULTIPLE CCW)               01000000
***                                                                     01010000
&DB2311  SETC  'DOUBLE'   ***  2311    INITIAL BUFFERING           @D01
&DB2301  SETC  'DOUBLE'   ***  2301    INITIAL BUFFERING           @D01
&DB2303  SETC  'DOUBLE'   ***  2303    INITIAL BUFFERING           @D01
&DB2302  SETC  'DOUBLE'   ***  2302    INITIAL BUFFERING           @D01
&DB2321  SETC  'DOUBLE'   ***  2321    INITIAL BUFFERING           @D01
&DB23051 SETC  'DOUBLE'   ***  2305-1  INITIAL BUFFERING                01020000
&DB23052 SETC  'DOUBLE'   ***  2305-2  INITIAL BUFFERING                01030000
&DB2314  SETC  'DOUBLE'   ***  2314    INITIAL BUFFERING                01040000
&DB3340  SETC  'MULTIPLE' ***  3340    INITIAL BUFFERING                01050000
&DB3350  SETC  'MULTIPLE' ***  3350    INITIAL BUFFERING                01060000
&DB3375  SETC  'MULTIPLE' ***  3375    INITIAL BUFFERING                01070000
&DB3380  SETC  'MULTIPLE' ***  3380    INITIAL BUFFERING                01080000
&DB3330  SETC  'DOUBLE'   ***  3330-1  INITIAL BUFFERING                01090000
&DB33301 SETC  'DOUBLE'   ***  3330-11 INITIAL BUFFERING                01100000
&DB3390  SETC  'MULTIPLE' ***  3390    INITIAL BUFFERING           @D01
*                                                                       01110000
* NOTE: &DB3330 AND &DB33301 ARE SET TO DOUBLE SINCE READ MULTIPLE      01120000
*       MAY NOT WORK FOR 3330-1 AND 3330-11 DISK DEVICES.               01130000
*                                                                       01140000
*       READ MULTIPLE WILL PROBABLY NOT WORK ON A 3830-1 STORAGE        01150000
*       CONTROL UNIT.                                                   01160000
*                                                                       01170000
*       READ MULTIPLE SHOULD WORK ON A 3830-2 STORAGE CONTROL UNIT IF   01180000
*       ITS MICROCODE SUPPORTS 3340 AND 3350 DISK DEVICES.              01190000
*                                                                       01200000
*       IF YOU ARE CONFIDENT THAT READ MULTIPLE WILL WORK FOR YOUR      01210000
*       3330 DEVICES, CHANGE THE ABOVE DEFAULTS TO MULTIPLE.            01220000
*                                                                       01230000
*       OTHERWISE, GENERATE THE PROGRAM WITH THE DOUBLE DEFAULTS AND    01240000
*       TEST A DATA SET USING "CONTROL TESTREAD" ON EACH COMBINATION    01250000
*       OF DEVICE (3330-1 AND 3330-11) AND STORAGE CONTROL UNIT.  IF    01260000
*       READ MULTIPLE IS OPERATIONAL FOR ALL OF THESE SITUATIONS, THE   01270000
*       DEFAULTS FOR &DB3330 AND &DB33301 CAN BE SET TO 'MULTIPLE' AND  01280000
*       THE PROGRAM CAN BE REASSEMBLED (OR THE PROGRAM MAY BE ZAPPED).  01290000
*                                                                       01300000
         EJECT                                                          01310000
***                                                                     01320000
***                                                                     01330000
*** THE FOLLOWING STATEMENTS SET SUBCOMMAND NAMES.  NOTE THAT           01340000
*** THESE SUBCOMMAND NAMES ARE CURRENTLY LISTED IN THE ORDER OF THE     01350000
*** SUBCOMMANDS IN THE PDSTBL70 COPY MEMBER:                            01360000
***   A.  TO NULLIFY A SUBCOMMAND, CODE ITS SETC VALUE AS ''            01370000
***   B.  TO RENAME A SUBCOMMAND, CHANGE ITS SETC VALUE TO A            01380000
***       DIFFERENT VALUE (ONE TO EIGHT CHARACTERS).                    01390000
***         1.  NOTE THAT DUE TO THE SUBCOMMAND NAME SCAN USED,         01400000
***             ALIASES FOR OTHER SUBCOMMANDS MAY CHANGE.               01410000
***         2.  FOR EXAMPLE, IF DSPRINT WERE RENAMED TO EXTRA, THE      01420000
***             SUBCOMMAND "E " WOULD BECOME "EXTRA" INSTEAD OF         01430000
***             "EDIT" DUE TO THE RELATIVE POSITIONS OF "DSPRINT"       01440000
***             AND "EDIT" IN THE SUBCOMMAND SCAN TABLE -- THE FIRST    01450000
***             MATCH FOR THE NUMBER OF CHARACTERS ENTERED IS USED.     01460000
***         3.  TO AVOID THIS PROBLEM WHEN YOU RENAME ANY SUBCOMMANDS,  01470000
***             EDIT MEMBERS PDSTBL70 AND DIATBL70 AFTER THIS MEMBER    01480000
***             AND MOVE THE LINES REPRESENTING SUBCOMMANDS TO THEIR    01490000
***             DESIRED NEW POSITIONS.                                  01500000
***   C.  IF SUBCOMMANDS ARE NULLIFIED OR RENAMED, BE SURE TO MAKE      01510000
***       CORRESPONDING CHANGES IN THE HELP MEMBER AND THE ISPF PANELS. 01520000
***   D.  TO PREVENT THE USE OF ANY SUBCOMMAND ABBREVIATION, CODE       01530000
***       ONE OF THE &NABX STATEMENTS TO ANY SUBSTRING DESIRED.  FOR    01540000
***       EXAMPLE, TO PREVENT THE USE OF THE SUBCOMMANDS "E " OR "EN ", 01550000
***       YOU COULD CODE:  &NAB1  SETC  'EN'                            01560000
***   E.  SEVERAL ADDITIONAL ALIASES FOR THE PRINTOFF INTERFACE HAVE    01570000
***       BEEN ADDED FOR INSTALLATION DEPENDENT USES (&NXS1 - &NXS3)    01580000
***                                                                     01590000
&NAB1    SETC  ''                                                       01600000
&NAB2    SETC  ''                                                       01610000
&NAB3    SETC  ''                                                       01620000
&NATT    SETC  'ATTRIB'                                                 01630000
&NALI    SETC  'ALIAS'                                                  01640000
&NBRO    SETC  ''             'BROWSE'                             @D01
&NCHA    SETC  'CHANGE'                                                 01660000
&NCAR    SETC  'COMPARE'                                                01670000
&NCMX    SETC  'COMPRESS'                                               01680000
&NCON    SETC  'CONTROL'                                                01690000
&NDIS    SETC  'DISPLAY'                                                01700000
&NDIR    SETC  'DIRENTRY'                                               01710000
&NDEL    SETC  'DELETE'                                                 01720000
&NDSN    SETC  'DSNAME'    **DO NOT NULLIFY**                           01730000
&NDSP    SETC  ''             'DSPRINT'                            @D01
&NEDI    SETC  ''             'EDIT'                               @D01
&NEND    SETC  'END'       **DO NOT NULLIFY**                           01760000
&NEXE    SETC  'EXEC'                                                   01770000
&NFIN    SETC  'FIND'                                                   01780000
&NFIX    SETC  'FIXPDS'                                                 01790000
&NFSE    SETC  'FSE'                                                    01800000
&NKLE    SETC  'KLEAR'     **UNDOCUMENTED -- CLEAR SCREEN SUBCOMMAND    01810000
&NHEL    SETC  'HELP'                                                   01820000
&NHIS    SETC  'HISTORY'                                                01830000
&NIFX    SETC  'IF'                                                     01840000
&NISP    SETC  ''             'ISPF'                               @D01
&NISM    SETC  ''             'ISPMODE'                            @D01
&NLIS    SETC  'LIST'                                                   01870000
&NMAP    SETC  'MAP'                                                    01880000
&NMEM    SETC  'MEMBERS'                                                01890000
&NMML    SETC  ''             'MEMLIST'                            @D01
&NOPT    SETC  'OPTIONS'                                                01910000
&NOUT    SETC  'OUTCOPY'                                                01920000
&NPAT    SETC  'PATTERN'                                                01930000
&NPDS    SETC  'PDS70'     **UNDOCUMENTED -- ALIAS FOR CHANGE           01940000
&NPRI    SETC  ''             'PRINTOFF'                           @D01
&NREC    SETC  'RECALL'                                                 01960000
&NREN    SETC  'RENAME'                                                 01970000
&NRES    SETC  'RESTORE'                                                01980000
&NREV    SETC  'REVIEW'                                                 01990000
&NSPF    SETC  ''             'SPFEDIT'   **UNDOCUMENTED           @D01
&NSUB    SETC  'SUBMIT'                                                 02010000
&NSCR    SETC  'SCRATCH'   **ALIAS FOR DELETE (NULLIFY IF NOT USED)     02020000
&NTSO    SETC  'TSO'                                                    02030000
&NTSE    SETC  'TSOEDIT'                                                02040000
&NTSL    SETC  ''             'TSOLIST'                            @D01
&NUSA    SETC  'USAGE'                                                  02060000
&NUT1    SETC  ''             'UT1'   **UNDOCUMENTED -- UTILITIES  @D01
&NUT2    SETC  ''             'UT2'   **UNDOCUMENTED -- UTILITIES  @D01
&NVER    SETC  'VERIFY'                                                 02090000
&NXS1    SETC  ''                                                  @D01
**       SETC  'VPSPRINT'  ***INTERFACE FOR THE VPS DSPRINT REPLAC @D01
&NXS2    SETC  ''                                                  @D01
**       SETC  'PCLIST1'   **PDS TEST CLIST                        @D01
&NXS3    SETC  ''                                                       02120000
         SPACE 3                                                        02130000
***                                                                     02140000
***                                                                     02150000
*** THE FOLLOWING STATEMENTS SET THE NAMES OF ATTACHED TSO COMMANDS.    02160000
***  EACH OF THESE &N... SYMBOLS IS ASSOCIATED WITH AN &C... SYMBOL     02170000
***  WITH THE SAME LAST THREE CHARACTERS AS DEFINED ABOVE.              02180000
***                                                                     02190000
*** NOTE: TO NULLIFY A SUBCOMMAND, DO NOT USE THE &C... SYMBOL;         02200000
***       USE THE ASSOCIATED &N... SYMBOL.                              02210000
***                                                                     02220000
*** NOTE: TO USE A DIFFERENT TSO COMMAND NAME, CHANGE ITS SETC VALUE    02230000
***       TO A DIFFERENT VALUE (ONE TO EIGHT CHARACTERS) AND ALSO       02240000
***       MAKE CORRESPONDING CHANGES IN THE HELP MEMBER.                02250000
***                                                                     02260000
*** NOTE: COMPARE, DSPRINT, PRINTOFF, REVIEW, SUBMIT AND TSOLIST (AS    02270000
***       WELL AS &NX1, &NX2 AND &NX3) CAN INVOKE A CLIST INSTEAD OF    02280000
***       A TSO COMMAND BY CHANGING THE SETC VALUE TO A % FOLLOWED BY   02290000
***       ONE TO SEVEN CHARACTERS; BE SURE TO MAKE CORRESPONDING        02300000
***       CHANGES IN THE HELP MEMBER:                                   02310000
***         1. COMPARE CLIST INPUT -  DSNAME1(MEMBER1) DSNAME2(MEMBER2) 02320000
***            FOLLOWED BY ANY ADDITIONAL DATA TYPED BY THE USER.       02330000
***         2. OTHER CLIST INPUT -  DSNAME(MEMBER) FOLLOWED BY ANY      02340000
***            ADDITIONAL DATA TYPED BY THE USER.                       02350000
***                                                                     02360000
         SPACE  3                                                       02370000
*** NOTE: THE FOLLOWING OPTIONAL TSO COMMANDS ARE REFERENCED IN THE     02380000
***       REMAINDER OF THIS MEMBER:                                     02390000
***                                                                     02400000
***    COMMAND NAME        SOURCE                                       02410000
***    ------------        ------                                       02420000
***    COMPARE, COMPAREB   CBT MODS TAPE FILE 296; CBT FILE 300         02430000
***    SPFCOPY             IBM ISPF INSTALL; CBT FILE 300               02440000
***    PDSFAST             SOFTWARE ENGINEERING OF AMERICA              02450000
***    DSPRINT             IBM FDP                                      02460000
***    DPSPRINT            MEMOREX                                      02470000
***    VPSPRINT            LEVI, RAY AND SHOUP                          02480000
***    RELEASE             CBT FILE 300                                 02490000
***    FSE                 CBT FILE 207                                 02500000
***    FSE                 PALM BEACH ASSOCIATES FSE+                   02510000
***    HEL                 CBT FILE 296                                 02520000
***    PRINTOFF            CBT FILE 300; CBT FILE 205; CBT FILE 234,236 02530000
***    REVIEW              CBT FILE 296; CBT FILE 300                   02540000
***    LIST                CBT FILE 300; IBM COMMAND PACKAGE            02550000
***    LIST                PALM BEACH ASSOCIATES SUPERSET UTILITIES     02560000
***                                                                     02570000
       SPACE 3                                                          02580000
*==> &CCAR: THE COMPARE COMMAND CAN BE OBTAINED FROM THE CBT            02590000
***   THE CBT TAPE, FILE 296 (UPDATED IN 1984), OR FROM JIM             02600000
***   MARSHALL'S TSO MODIFICATIONS ON THE CBT TAPE, FILE 300;           02610000
***   NOTE THAT A RELATED PROGRAM (COMPAREB) FROM THE SAME FILE         02620000
***   MUST ALSO BE INSTALLED.                                           02630000
&CCAR    SETC   'COMPARE'                                               02640000
*&CCAR    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   02650000
         SPACE  2                                                       02660000
*==> &C296: IF THE COMPARE PROGRAM WAS OBTAINED FROM THE CBT TAPE,      02670000
***   FILE 296, IT CAN PASS DATA DIRECTLY TO THE PDS COMMAND AND        02680000
***   THE COMPARE OUTPUTS CAN BE MANAGED IN ISPMODE.  NOTE: THE         02690000
***   INTERFACE USED CAN BE CHANGED VIA ZAP AT LABEL COMPAZAP.          02700000
&C296    SETC   'YES'         *** IF COMPARE IS FROM CBT 296            02710000
*&C296    SETC   'NO'         *** IF COMPARE IS FROM ANOTHER SOURCE     02720000
         SPACE  2                                                       02730000
*==> &CCMX: ONE OF THE FOLLOWING MAY BE USED FOR A COMPRESS PROGRAM.    02740000
****** SPFCOPY IS THE SPF AUTHORIZATION FRONT END FOR IEBCOPY           02750000
***    WHICH IS AVAILABLE IN THE SPF INSTALLATION MATERIALS OR FROM     02760000
***    JIM MARSHALL'S TSO MODIFICATIONS ON THE CBT TAPE, FILE 300.      02770000
*&CCMX    SETC   'SPFCOPY'                                         @D01 02780000
****** PDSFAST IS THE IEBCOPY "REPLACEMENT" PROGRAM FROM SOFTWARE       02790000
***    ENGINEERING OF AMERICA (AN "EXTRA FEATURE", EF-002, MUST BE      02800000
***    INSTALLED IN PDSFAST TO ALLOW ITS USE BY A TSO COMMAND).         02810000
*&CCMX    SETC   'PDSFAST'                                              02820000
****** IEBCOPY IS IBM'S PDS COPY UTILITY; AUTHORIZATION CODE MUST BE    02830000
***    ENABLED IN PDS VIA ZAP NEAR LABEL COMPRZAP, HOWEVER.             02840000
***    Note authorization is not applicable in MVT.                @D01
&CCMX    SETC   'IEBCOPY'                                          @D01 02850000
         SPACE  2                                                       02860000
*==> &CDSP: DSPRINT IS THE DATA SET PRINT COMMAND FROM IBM; HOWEVER,    02870000
***   DSPRINT COULD ACTUALLY BE AN ALIAS FOR ONE OF THE OTHER VTAM      02880000
***   PRINTER PRODUCTS SUCH AS DPS OR VPS.                              02890000
&CDSP    SETC   'DSPRINT'                                               02900000
*&CDSP    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   02910000
         SPACE  2                                                       02920000
*==> &CEXE: THE EXEC COMMAND IS INVOKED FOR THE EXEC SUBCOMMAND         02930000
***   (EXPLICIT USE) AND SUBCOMMANDS BEGINNING WITH % (IMPLICIT USE).   02940000
&CEXE    SETC   'EXEC'                                                  02950000
         SPACE  2                                                       02960000
*==> &CFIX: FIXPDS INVOKES THE RELEASE COMMAND; RELEASE MAY BE OBTAINED 02970000
***   FROM JIM MARSHALL'S TSO MODIFICATIONS ON THE CBT TAPE, FILE 300.  02980000
***   NOTE:                                                             02990000
***     1.  FIXPDS RELEASE       INVOKES:  RELEASE 'DSNAME'             03000000
***     2.  FIXPDS RELEXTENT     INVOKES:  RELEASE 'DSNAME' EXT         03010000
***     3.  FIXPDS RELSAVE(123)  INVOKES:  RELEASE 'DSNAME' SAV(123)    03020000
&CFIX    SETC   'RELEASE'                                               03030000
         SPACE  2                                                       03040000
*==> &CFSE: FSE IS A FULL-SCREEN EDIT COMMAND.  USE FSE FROM THE CBT    03050000
***   TAPE, FILE 207 OR THE FSE+ PRODUCT FROM PALM BEACH ASSOCIATES.    03060000
&CFSE    SETC   'FSE'                                                   03070000
         SPACE  2                                                       03080000
*==> &CHEL: EITHER OF THE FOLLOWING MAY BE USED FOR A HELP COMMAND.     03090000
****** HEL IS A FULL-SCREEN HELP COMMAND FROM THE CBT TAPE, FILE 296.   03100000
*&CHEL   SETC   'HEL'                                              @D01 03110000
****** HELP IS THE STANDARD HELP COMMAND FROM IBM.                      03120000
&CHEL    SETC   'HELP'                                             @D01 03130000
         SPACE  2                                                       03140000
*==> &CISP: THE LEVEL OF SPF/ISPF IS SET WITH THIS VARIABLE.            03150000
****** IF YOU USE ISPF AND ISPF/PDF VERSION 1 AND OPTIONALLY VERSION 2: 03160000
*&CISP     SETC   'ISPF'    *** FOR 5665-268 AND 5668-960 OR ABOVE @D01 03170000
****** IF YOU USE ONLY ISPF AND ISPF/PDF VERSION 2:                     03180000
*&CISP    SETC   'ISPFV2'  *** FOR 5665-317 AND 5665-319                03190000
****** IF YOU USE SPF AND OPTIONALLY ANY ISPF VERSION:                  03200000
*&CISP    SETC   'SPF'     *** FOR 5668-009 OR ABOVE                    03210000
****** IF YOU WANT TO DISABLE BROWSE, EDIT, ISPF, ISPMODE OR MEMLIST:   03220000
&CISP    SETC   ''                                                 @D01 03230000
         SPACE  2                                                       03240000
*==> &CPRI: THE PRINTOFF COMMAND IS AVAILABLE FROM SEVERAL MOD TAPES    03250000
***   AND FROM ANY IBM IPO PACKAGE.                                     03260000
&CPRI    SETC   'PRINTOFF'                                              03270000
*&CPRI    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   03280000
         SPACE  2                                                       03290000
*==> &CREV: REVIEW IS A FULL-SCREEN BROWSE COMMAND WHICH IS AVAILABLE   03300000
***   FROM THE CBT TAPE, FILE 296 (UPDATED IN 1984), OR FROM            03310000
***   JIM MARSHALL'S TSO MODIFICATIONS ON THE CBT TAPE, FILE 300.       03320000
&CREV    SETC   'REVIEW'                                                03330000
*&CREV    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   03340000
         SPACE  2                                                       03350000
*==> &CSUB: THE SUBMIT COMMAND IS AVAILABLE ON MOST MVS SYSTEMS.        03360000
&CSUB    SETC   'SUBMIT'                                                03370000
*&CSUB    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   03380000
         SPACE  2                                                       03390000
*==> &CTSL: THE TSO LIST COMMAND MAY BE OBTAINED FROM JIM MARSHALL'S    03400000
***   TSO MODIFICATIONS ON THE CBT TAPE, FILE 300; A PRODUCT VERSION    03410000
***   IS IN IBM'S TSO UTILITIES PACKAGE; AND A FULL-SCREEN LIST COMMAND 03420000
***   IS AVAILABLE FROM PALM BEACH ASSOCIATES:                          03430000
&CTSL    SETC   'LIST'                                                  03440000
*&CTSL    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   03450000
         SPACE  2                                                       03460000
*==> &CTSO: IF YOUR INSTALLATION HAS TSO/E RELEASE 2, PDS CAN INVOKE    03470000
***   TSOEXEC INSTEAD OF THE THE TSO COMMAND; THUS, INSTEAD OF TYPING   03480000
***   TSO TSOEXEC AUTHPROG ..., YOU TYPE TSO AUTHPROG.                  03490000
&CTSO    SETC   ' NOTSO/E'    *** IF NO TSO/E RELEASE 2                 03500000
*&CTSO    SETC   'TSOEXEC'                                              03510000
         SPACE  2                                                       03520000
*==> &CTSE: THE TSO EDIT COMMAND IS AVAILABLE ON MOST MVS SYSTEMS.      03530000
&CTSE    SETC   'EDIT'                                                  03540000
         SPACE  2                                                       03550000
*==> &CUT1: THIS NAMES THE PANEL TO BE INVOKED BY THE UT1 SUBCOMMAND    03560000
***   FOR SELECT PANEL SUPPORT:                                SS NOV84 03570000
&CUT1    SETC   'PDS70UT1'                                     SS NOV84 03580000
         SPACE  2                                                       03590000
*==> &CUT2: THIS NAMES THE PANEL TO BE INVOKED BY THE UT2 SUBCOMMAND    03600000
***   FOR SELECT PANEL SUPPORT:                                SS NOV84 03610000
&CUT2    SETC   'PDS70UT2'                                     SS NOV84 03620000
         SPACE  2                                                       03630000
*==> &CXS1: THIS COMMAND IS FOR INSTALLATION DEPENDENT USE; IT IS AN    03640000
***   ALIAS FOR THE PRINTOFF INTERFACE:                                 03650000
&CXS1    SETC   'VPSPRINT'    *** REPLACEMENT FOR THE DSPRINT COMMAND   03660000
*&CXS1    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   03670000
         SPACE  2                                                       03680000
*==> &CXS2: THIS COMMAND IS FOR INSTALLATION DEPENDENT USE; IT IS AN    03690000
***   ALIAS FOR THE PRINTOFF INTERFACE:                                 03700000
&CXS2    SETC   '%PCLIST1'    *** AN INSTALLATION-DEFINED CLIST IS USED 03710000
*&CXS2    SETC   ' '          *** IF NOT USED                           03720000
         SPACE  2                                                       03730000
*==> &CXS2: THIS COMMAND IS FOR INSTALLATION DEPENDENT USE; IT IS AN    03740000
***   ALIAS FOR THE PRINTOFF INTERFACE:                                 03750000
&CXS3    SETC   ' '           *** NOT USED                              03760000
*&CXS3    SETC   '%NAME567'   *** IF A CLIST IS TO BE INVOKED INSTEAD   03770000
./       ADD   NAME=PDSTBL70
         PUSH  PRINT                                               @D01
         PRINT GEN                                                 @D01
*                                                                       00010000
*    ---  SUBCOMMAND NAME SCAN TABLE  ---                               00020000
*                                                                       00030000
*                                                                       00040000
*   NOTES:                                                              00050000
*                                                                       00060000
*     1.  ENTRIES WITH A BLANK SUBCOMMAND NAME ARE CONSIDERED DISABLED. 00070000
*                                                                       00080000
*     2.  THE SUBCOMMAND NAME ORDER IS SIGNIFICANT BECAUSE AMBIGUITIES  00090000
*         ARE RESOLVED BY TAKING THE FIRST NAME MATCH FOR THE NUMBER OF 00100000
*         LETTERS ENTERED BY THE USER.                                  00110000
*                                                                       00120000
*                                                                       00130000
$TBL DS 0F    +08         +0C         +0D      +10         +14   +1C    00140000
*LBL  SUBCOMM,OF,ROUTINE ,  FLAGS    ,  PCL   , POST-PARSE, CALL,OPTOFF 00150000
****  *******,**,********,***********,********,***********,*****,****** 00160000
$AB1 $T &NAB1,00,+INVABBR,@S+00+@N+00,00000000,00,00000000,*****,ONIX   00170000
$AB2 $T &NAB2,00,+INVABBR,@S+00+@N+00,00000000,00,00000000,*****,ONIX   00180000
$AB3 $T &NAB3,00,+INVABBR,@S+00+@N+00,00000000,00,00000000,*****,ONIX   00190000
$ATT $T &NATT,00,++ATTRIB,00+@Q+@G+@B,+PCLATTR,$D,+ZATTRIB,*****,OATT   00200000
$ALI $T &NALI,00,+++ALIAS,00+00+@R+@B,PCLALIAS,00,00000000,*****,OALI   00210000
$BRO $T &NBRO,0B,++BROWSE,@S+@I+@G+@B,PCLBROWS,$D,00000000,&CBRO,OBRO   00220000
$CHA $T &NCHA,00,++CHANGE,@S+00+00+@C,+PCLMAIN,00,ZMAINPDL,*****,OCHA   00230000
$CAR $T &NCAR,08,+COMPARE,00+00+@R+@B,PCLCOMPA,00,ZCOMPARE,&CCAR,OCAR   00240000
$CMX $T &NCMX,00,COMPRESS,00+00+00+@C,PCLCOMPR,00,ZCOMPRES,&CCMX,OCMX   00250000
$CON $T &NCON,00,+CONTROL,@S+00+00+@C,+PCLCONT,00,ZCONTROL,*****,OCON   00260000
$DIS $T &NDIS,00,+DISPLAY,00+00+00+00,PCLDSPLY,$M,00000000,*****,ODIS   00270000
*DIR $T &NDIR,00,DIRENTRY,00+@Q+@G+@B,++PCLDIR,$D,00000000,*****,ODIR   00280000
$DIR $T &NDIR,00,DIRENTRY,00+@Q+@G+@B,++PCLDIR,$D,ZDIRENTR,*****,ODIR   00280000
$DEL $T &NDEL,00,++DELETE,00+@Q+@G+@B,PCLDELET,00,+ZDELETE,*****,ODEL   00290000
$DSN $T &NDSN,00,+DSNAMES,@S+00+00+00,+PCLDSNA,00,ZDSNAMES,*****,ODSN   00300000
$DSP $T &NDSP,00,PRINTOFF,@S+@Q+@G+@B,PCLPRINT,$D,ZPRINTOF,&CDSP,ODSP   00310000
$EDI $T &NEDI,00,++BROWSE,@S+@I+@G+@C,+PCLEDIT,$D,+++ZEDIT,&CEDI,OEDI   00320000
$END $T &NEND,00,++RETURN,@S+00+@N+00,00000000,00,00000000,*****,OEND   00330000
$EXE $T &NEXE,00,++++EXEC,@S+00+@N+00,00000000,00,00000000,&CEXE,OEXE   00340000
$FIN $T &NFIN,00,++++FIND,@S+@Q+@G+@B,+PCLFIND,00,00+ZFIND,*****,OFIN   00350000
$FIX $T &NFIX,00,++FIXPDS,@S+00+00+@C,0+PCLFIX,00,+ZFIXPDS,&CFIX,OFIX   00360000
$FSE $T &NFSE,00,+TSOEDIT,@S+@Q+@G+@C,+PCLEDIT,$D,00+ZEDIT,&CFSE,OFSE   00370000
$KLE $T &NKLE,00,+++KLEAR,@S+00+@N+00,00000000,00,00000000,*****,ONIX   00380000
$HEL $T &NHEL,00,++++HELP,@S+00+@N+00,00000000,00,00000000,&CHEL,OHEL   00390000
$HIS $T &NHIS,00,+HISTORY,00+@Q+@G+@B,+PCLHIST,00,ZHISTORY,*****,OHIS   00400000
$IFX $T &NIFX,00,++++++IF,00+@Q+@G+@B,PCLIFTTR,00,0000+ZIF,*****,OIFX   00410000
$ISP $T &NISP,00,++BROWSE,@S+00+00+@C,+PCLISPF,00,00+ZISPF,&CISP,OISP   00420000
$ISM $T &NISM,00,++BROWSE,@S+00+00+00,+PCLISPM,00,00+ZISPM,*****,OISM   00430000
$LIS $T &NLIS,00,++++LIST,@S+00+@G+@B,+PCLLIST,00,00+ZLIST,*****,OLIS   00440000
$MAP $T &NMAP,00,+++++MAP,00+@Q+@G+@B,++PCLMAP,00,000+ZMAP,*****,OMAP   00450000
$MEM $T &NMEM,00,++NEWCMD,00+00+@G+@B,+PCLMEMB,00,00000000,*****,OMEM   00460000
$MML $T &NMML,00,++BROWSE,00+@Q+@G+@B,+PCLMEML,$D,ZMEMLIST,*****,OMML   00470000
$OPT $T &NOPT,00,+OPTIONS,@S+00+@N+00,00000000,00,00000000,*****,OOPT   00480000
$OUT $T &NOUT,09,+OUTCOPY,00+@Q+@G+@B,++PCLOUT,00,ZOUTCOPY,*****,OOUT   00490000
$PAT $T &NPAT,00,+PATTERN,00+00+00+00,PCLPATTR,$M,00000000,*****,OPAT   00500000
$PDS $T &NPDS,00,++CHANGE,@S+00+00+@C,+PCLMAIN,00,ZMAINPDL,*****,ONIX   00510000
$PRI $T &NPRI,01,PRINTOFF,@S+@Q+@G+@B,PCLPRINT,$D,ZPRINTOF,&CPRI,OPRI   00520000
$REC $T &NREC,00,00000000,@S+00+@N+00,00000000,00,00000000,*****,OREC   00530000
$REN $T &NREN,00,++RENAME,00+00+@R+@B,PCLRENAM,00,+ZRENAME,*****,OREN   00540000
$RES $T &NRES,00,+RESTORE,00+00+@R+@C,PCLRESTO,00,ZRESTORE,*****,ORES   00550000
$REV $T &NREV,02,PRINTOFF,@S+@Q+@G+@B,PCLPRINT,$D,ZPRINTOF,&CREV,OREV   00560000
$SPF $T &NSPF,00,++BROWSE,@S+@I+@G+@C,+PCLEDIT,$D,+++ZEDIT,&CEDI,ONIX   00570000
$SUB $T &NSUB,03,PRINTOFF,@S+00+@G+@B,PCLPRINT,00,ZPRINTOF,&CSUB,OSUB   00580000
$SCR $T &NSCR,00,++DELETE,00+@Q+@G+@B,PCLDELET,00,+ZDELETE,*****,ONIX   00590000
$TSO $T &NTSO,04,+++++TSO,@S+00+@N+@C,00000000,00,00000000,&CTSO,OTSO   00600000
$TSE $T &NTSE,00,+TSOEDIT,@S+00+@G+@C,PCLTSOED,00,ZTSOEDIT,&CTSE,OTSE   00610000
$TSL $T &NTSL,00,PRINTOFF,@S+00+@G+@B,PCLPRINT,00,ZPRINTOF,&CTSL,OTSL   00620000
$USA $T &NUSA,00,+++USAGE,@S+00+@N+00,00000000,00,00000000,*****,OUSA   00630000
$UT1 $T &NUT1,00,++BROWSE,@S+00+00+@C,+PCLISPF,$J,00+ZISPF,&CUT1,ONIX   00640000
$UT2 $T &NUT2,04,++BROWSE,@S+@Q+@G+@B,PCLPRINT,$P,ZPRINTOF,&CUT2,ONIX   00650000
$VER $T &NVER,00,++VERIFY,@S+@I+@G+@B,PCLVERIF,$D,+ZVERIFY,*****,OVER   00660000
$XS1 $T &NXS1,05,PRINTOFF,@S+@Q+@G+@B,PCLPRINT,$D,ZPRINTOF,&CXS1,ONIX   00670000
$XS2 $T &NXS2,06,PRINTOFF,@S+@Q+@G+@B,PCLPRINT,$D,ZPRINTOF,&CXS2,ONIX   00680000
$XS3 $T &NXS3,07,PRINTOFF,@S+@Q+@G+@B,PCLPRINT,$D,ZPRINTOF,&CXS3,ONIX   00690000
$NNN $T   NNN,00,CMDSCAN4,@S+00+@N+00,00000000,00,00000000,*****,ONIX   00700000
     $T     W,00,++NEWCMD,@S+00+@N+00,00000000,00,00000000,*****,ONIX   00710000
$XXX $T     X,04,+++++TSO,@S+00+@N+@C,00000000,00,00000000,&CTSO,ONIX   00720000
         PRINT GEN                                                      00730000
$TIM $T  TIME,00,++++TIME,@S+00+@N+00,00000000,00,00000000,*****,ONIX   00740000
         DC    X'FF'     TABLE TERMINATOR                               00750000
PTW      EQU   32        SUBCOMMAND TABLE WIDTH                         00760000
         EJECT                                                          00770000
*** FIELD DESCRIPTIONS FOR THE ABOVE TABLE:                             00780000
*OFFSET: +0   +08         +0C         +0D      +10         +14   +1C    00790000
*LBL  SUBCOMM,OF,ROUTINE ,  FLAGS    ,  PCL   , POST-PARSE, CALL,OPTOFF 00800000
*                                                                       00810000
*                                                                       00820000
*     NAME    | LABEL    | OFFSET  | DESCRIPTION                        00830000
*     --------+----------+---------+------------                        00840000
*     LBL     |          |         | OPTION TABLE ENTRY LABEL           00850000
*     SUBCOMM | ##SUBCOM | +0      | ACTUAL SUBCOMMAND NAME             00860000
*     OF      | ##ADRCM# | +8      | INDEX FOR SAVETEXT DATA            00870000
*     ROUTINE | ##ADRCMD | +9      | SUBCOMMAND ROUTINE ADDRESS         00880000
*     FLAGS   | ##ADRPC# | +C      | SUBCOMMAND FLAGS                   00890000
*     PCL     | ##ADRPCL | +D      | SUBCOMMAND PCL ADDRESS             00900000
*     POST    | ##ADRPA# | +10     | SUBCOMMAND FLAGS                   00910000
*     PARSE   | ##ADRPAR | +11     | POST-PARSE ROUTINE ADDRESS         00920000
*     CALL    | ##SUBCAL | +14     | EXTERNAL TSO ROUTINE OR PANEL      00930000
*     OPTOFF  | ##HELOFF | +1C     | OFFSET TO OPTIONS HELP ENTRY       00940000
     SPACE 3                                                            00950000
*** FLAG DESCRIPTIONS FOR ##ADRPC#:                                     00960000
*@Q      EQU   X'80'     QUIET MODE FOR SUBCOMMAND                      00970000
*@I      EQU   X'40'+@Q  BROWSE, EDIT, AND VERIFY CHECK FOR :           00980000
*@N      EQU   X'20'     OPERAND IS IGNORED IF PRESENT                  00990000
*@R      EQU   X'10'     OPERAND REQUIRED, PARSE IS ALWAYS CALLED       01000000
*@S      EQU   X'08'     SUBCOMMAND WORKS FOR NON-PARTITIONED DATA SETS 01010000
*@G      EQU   X'04'     MEMBER GROUP AND MEMBER DEFAULT ALLOWED        01020000
*@B      EQU   X'02'     BLDL REQUIRED TO VERIFY FIRST MEMBER EXISTS    01030000
*@C      EQU   X'01'     SUBCOMMAND INVALIDATES BLDL                    01040000
         SPACE 1                                                        01050000
*** FLAG DESCRIPTIONS FOR ##ADRPA#:                                     01060000
*$F      EQU   X'80'          FINDLIST -- CONVERTS TO LIST AFTER FIND   01070000
*$D      EQU   X'40'          DEFAULT MEMBER MESSAGE IS SUPPRESSED      01080000
*$Q      EQU   X'20'          QUIET MODE PROCESSING FLAG                01090000
*$M      EQU   X'10'          DISPLAY OR PATTERN SUBCOMMAND             01100000
*$A      EQU   X'08'          DO NOT ACCEPT ATTENTIONS                  01110000
*$P      EQU   X'02'          SPF PANEL NAME IN ##SUBCAL       SS NOV84 01120000
*$J      EQU   X'01'+$P       SPF PANEL PARSE WITH NO MEMBERS  SS NOV84 01130000
         POP   PRINT                                               @D01
./ ADD NAME=PDS7003
PDSMAIN  TITLE 'P D S  --  PDS COMMAND PROCESSOR       2010/05/04' @D04
***********************************************************************
*                                                                     *
*                                                                     *
* Module name  =  PDS70                                               *
*                                                                     *
*                                                                     *
* Descriptive name  =  TSO PDS command processor                      *
*                                                                     *
*                                                                     *
* Function  =  To provide the TSO user with the capability to         *
*              manipulate partitioned and sequential data sets.       *
*                                                                     *
*                                                                     *
* Notes  =  See below.                                                *
*                                                                     *
*   Dependencies  =  PDS uses System/370 instructions.  Assembly      *
*                    of PDS requires the OS/VS XF assembler IFOX00.   *
*                    The hardware or hardware emulator on which the   *
*                    host operating system is running must support    *
*                    System/370 instructions, or the host operating   *
*                    system must include software simulation of       *
*                    System/370 instructions.                         *
*                                                                     *
*   Patch space  =  Eighteen halfwords of X'00' at label "PATCH".     *
*                                                                     *
*   Discussion  =  Refitting of PDS to run under MVT required         *
*                  a number of changes to the MVS code.  Generally,   *
*                  the changes fell into the following categories:    *
*                                                                     *
*                  (1)  SVC 99 dynamic allocations were changed       *
*                       to use DAIR.                                  *
*                                                                     *
*                  (2)  Recovery procedures were modified to use      *
*                       STAE instead of ESTAE.                        *
*                                                                     *
*                  (3)  MVT does not provide the System Track         *
*                       Allocation Routine (STAR), which supports     *
*                       the TRKCALC macro.  STAR logic from MVS 3.8   *
*                       was rewritten as a local subroutine and       *
*                       included with PDS.  The MVS STAR subroutine   *
*                       to apply tolerance factors was modified to    *
*                       support all devices that require it (the      *
*                       MVS 3.8 version is hard-coded for 2314 only). *
*                       Because this requires more registers than     *
*                       are used by the MVS version, the MVT caller   *
*                       of TRKCALC must provide the address of a      *
*                       standard save area in R13, and specify        *
*                       REGSAVE=YES on the TRKCALC macro invocation.  *
*                       PDS usage of TRKCALC includes REGSAVE=YES.    *
*                                                                     *
*                  (4)  ISPF-related code was removed wherever        *
*                       possible to reduce the size of the PDS        *
*                       load module.                                  *
*                                                                     *
*                  (5)  PDS logic to determine whether to use set     *
*                       sector/read sector in a DASD channel program  *
*                       was changed to base the decision on the UCB   *
*                       RPS feature bit.  The MVS code uses RPS for   *
*                       all devices except 2314s.                     *
*                                                                     *
*                  (6)  Other MVS macros and services not available   *
*                       in MVT were changed to use MVT equivalents.   *
*                       For example, SVC 120 GETMAIN/FREEMAIN RU      *
*                       requests were changed to use SVC 10           *
*                       GETMAIN/FREEMAIN R.                           *
*                                                                     *
*                  (7)  Missing mapping macros were provided from     *
*                       MVT source, or were built based on MVS 3.8    *
*                       macros.                                       *
*                                                                     *
*                  (8)  The help member was updated to reflect        *
*                       the MVT environment.                          *
*                                                                     *
*                  Original block comments in the MVS PDS source      *
*                  below have not been modified for MVT, and should   *
*                  be understood from that perspective.               *
*                                                                     *
*                                                                     *
* Module type  =  CSECT                                               *
*                                                                     *
*   Processor =  OS/VS XF assembler IFOX00                            *
*                                                                     *
*   Module size  =  See assembly listing.                             *
*                                                                     *
*   Attributes  =  Reentrant, task mode, enabled, problem state,      *
*                  user key.                                          *
*                                                                     *
*                                                                     *
* Change activity      =                                              *
*                                                                     *
*   Flag  Date        By    Description                               *
*   ----  ----------  ----  ----------------------------------------  *
*   $D06  2021/08/18  KL    V 7.0.03: Change default unit from        *
*                                     SYSALLDA to SYSDA.              *
*   $D05  2017/08/01  KL    V 7.0.02: Support for translator          *
*                                     history.                        *
*   $D04  2010/05/04  KL    V 7.0.01: Support for extended DIRENTRY   *
*                                     display.                        *
*   $D03  2010/05/04  KL    V 7.0.01: Support for MAP JCL.            *
*   $D02  2010/05/04  KL    V 7.0.01: Support for AMODE64; errors     *
*                                     in PDS 7.0 AMODE code had       *
*                                     to be fixed as a prerequsite    *
*                                     for later changes.              *
*   $D01  2010/05/04  KL    V 7.0.01: Refit to support MVT.           *
*                                                                     *
*                                                                     *
***********************************************************************
         EJECT ,
***********************************************************************
*   DATA SET PDS AT LEVEL 7.0 ON   1/15/85  (SDS -- THIS VERSION)     * 00002000
*   DATA SET PDS AT LEVEL 6 AS OF  7/16/83  (ABL -- MVS/XA VERSION)   * 00003000
*   DATA SET PDS AT LEVEL 5 AS OF  7/08/82  (ABL -- MEMBER GROUPS)    * 00004000
*   DATA SET PDS AT LEVEL 4 AS OF  9/30/80  (ABL -- MVS ONLY VERSION) * 00005000
*   DATA SET PDS AT LEVEL 3 AS OF  1/28/80  (ABL -- MVS VERSION)      * 00006000
*   DATA SET PDS AT LEVEL 2 AS OF 11/14/77  (ABL -- MVT VERSION)      * 00007000
*   DATA SET PDS AT LEVEL 1 AS OF  6/12/75  (UCLA VERSION)            * 00008000
*   DATA SET PDS AT LEVEL 0 AS OF  3/20/72  (FIREMAN'S FUND VERSION)  * 00009000
*                                                                     * 00010000
***                                                                   * 00011000
*** BEFORE ASSEMBLING, THE COPY CODE IN PDSGEN70 SHOULD BE MODIFIED   * 00012000
*** TO REFLECT RESOURCES AVAILABLE AT YOUR INSTALLATION.              * 00013000
***                                                                   * 00014000
*** NOTE: PDS CAN BE LINKED INTO SYS1.LPALIB TO REDUCE EACH PDS       * 00015000
***       USER'S SWAP LOAD; HOWEVER, YOU SHOULD ALSO KEEP A COPY      * 00016000
***       OF PDS IN YOUR LINK LIST (WITH THE SAME OR A DIFFERENT      * 00017000
***       MEMBER NAME) AS A BACKUP IN CASE YOUR LPALIB IS REPLACED    * 00018000
***       IN A FUTURE SYSTEM.                                         * 00019000
***                                                                   * 00020000
         TITLE 'P D S  --  PDS SUPPORT REPRESENTATIVE          1/15/85' 00021000
*** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** 00022000
*                                                                     * 00023000
*                                                                     * 00024000
* PLEASE REPORT ANY PROBLEMS, ENHANCEMENTS, SUGGESTIONS OR COMMENTS   * 00025000
* CONCERNING THE PDS COMMAND TO BRUCE LELAND AT:                      * 00026000
*                                                                     * 00027000
*     HITACHI AMERICA, LTD.     OR         6084 CRIMSON DRIVE         * 00028000
*     2210 O'TOOLE AVENUE                  SAN JOSE, CALIF 95120      * 00029000
*     SAN JOSE, CALIF. 95131                                          * 00030000
*     (408) 435-2143                       (408) 997-2366             * 00031000
*                                                                     * 00032000
*                                                                     * 00033000
*                                                                     * 00034000
*  IF AN ERROR OR ABEND CONDITION PERSISTS IN PDS, TRY THE            * 00035000
*  FOLLOWING STEPS FOR PROBLEM RESOLUTION:                            * 00036000
*                                                                     * 00037000
*                                                                     * 00038000
*   1.  CONTACT THE IBM SUPPORT CENTER FOR KNOWN MVS PROBLEMS         * 00039000
*                                                                     * 00040000
*                                                                     * 00041000
*   2.  REPORT THE PROBLEM (WHETHER RESOLVED OR NOT) TO BRUCE LELAND. * 00042000
*       PLEASE INCLUDE APPROPRIATE DOCUMENTATION FOR UNRESOLVED       * 00043000
*       PROBLEMS AS FOLLOWS:                                          * 00044000
*                                                                     * 00045000
*       A.  PLEASE USE AN UNLABELLED, 1600 OR 6250 BPI TAPE WITH      * 00046000
*           AS MANY FILES AS REQUIRED FOR DOCUMENTATION.              * 00047000
*                                                                     * 00048000
*       B.  INDICATE IF YOU HAVE SPF, ISPF VERSION 1 OR 2 AND IF      * 00049000
*           THE PROBLEM INVOLVES THE SPF INTERFACE CODE IN PDS.       * 00050000
*                                                                     * 00051000
*       C.  IF POSSIBLE, DUPLICATE THE ERROR ON PAPER BY EXECUTING    * 00052000
*           PDS IN BACKGROUND MODE.                                   * 00053000
*                                                                     * 00054000
*       D.  NOTE YOUR MVS OPERATING SYSTEM LEVEL (FOR EXAMPLE,        * 00055000
*           SP 1.3.3 AT 8402).                                        * 00056000
*                                                                     * 00057000
*       E.  NOTE THE PDS LEVEL (OR BETTER YET, UNLOAD A COPY OF THE   * 00058000
*           PDS SOURCE CODE INSTALLED AT YOUR INSTALLATION).          * 00059000
*                                                                     * 00060000
*       F.  UNLOAD A COPY OF THE PDS LOAD MODULE USING IEBCOPY.       * 00061000
*                                                                     * 00062000
*       G.  UNLOAD THE DATA SET IN QUESTION WITH IEBCOPY OR AN        * 00063000
*           APPROPRIATE UTILITY.                                      * 00064000
*                                                                     * 00065000
*       H.  BE SURE TO INCLUDE YOUR NAME AND PHONE NUMBER SO THAT     * 00066000
*           ANY RESULTS OR QUESTIONS CAN BE REFERRED BACK TO YOU.     * 00067000
*                                                                     * 00068000
*                                                                     * 00069000
*** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** 00070000
         TITLE 'P D S  --  PDS COMMAND PURPOSE                 1/15/85' 00071000
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 00072000
* TITLE -      P D S     --    TSO PDS COMMAND PROCESSOR              * 00073000
*                                                                     * 00074000
* FUNCTION -   PROVIDE A TSO USER WITH THE CAPABILITY                 * 00075000
*              TO MANIPULATE A PARTITIONED DATA SET                   * 00076000
*                                                                     * 00077000
* OPERATION -  ACCEPT FROM THE TSO USER THE NAME OF A PARTITIONED     * 00078000
*              DATA SET AND PERFORM ANY OF THE SUBCOMMANDS:           * 00079000
*                                                                     * 00080000
*        ATTRIB   - DISPLAY (OR MODIFY) LOAD MODULE ATTRIBUTES        * 00081000
*        ALIAS    - ASSIGN AN ALIAS TO A MEMBER                       * 00082000
*        BROWSE   - BROWSE A MEMBER WITH SPF (SPF DIALOG)             * 00083000
*        CHANGE   - CHANGE TO A DIFFERENT DATA SET                    * 00084000
*        COMPARE  - COMPARE TWO MEMBERS                               * 00085000
*        COMPRESS - COMPRESS THE DATA SET                             * 00086000
*        CONTROL  - SET PROGRAM CONTROL VARIABLES                     * 00087000
*        DISPLAY  - DISPLAY ALL OR PART OF THE DIRECTORY              * 00088000
*        DIRENTRY - DUMP A MEMBER'S DIRECTORY ENTRY                   * 00089000
*        DELETE   - DELETE A MEMBER                                   * 00090000
*        DSNAME   - DISPLAY THE CURRENT DATA SET ALLOCATION           * 00091000
*        DSPRINT  - PRODUCE A HARDCOPY USING DSPRINT                  * 00092000
*        EDIT     - EDIT A MEMBER USING SPF                           * 00093000
*        END      - TERMINATE THE PDS COMMAND                         * 00094000
*        EXEC     - EXECUTE PDS SUBCOMMANDS FROM A CLIST SOURCE       * 00095000
*        FIND     - LIST LINES CONTAINING A SEARCH STRING             * 00096000
*        FIXPDS   - MODIFY THE ALLOCATED PARTITIONED DATA SET         * 00097000
*        FSE      - EDIT A MEMBER WITH THE FSE COMMAND                * 00098000
*        HELP     - DISPLAY SUBCOMMAND HELP FOR PDS                   * 00099000
*        HISTORY  - LIST HISTORY OF A LOAD MODULE                     * 00100000
*        IF       - TEST A MEMBER FOR GIVEN ATTRIBUTES                * 00101000
*        ISPF     - INVOKE ISPF PRIMARY OPTIONS PANEL WITH OPTIONS    * 00102000
*        ISPMODE  - INVOKE DIALOG SUPPORT FOR PDS                     * 00103000
*        LIST     - LIST CONTENTS OF A MEMBER                         * 00104000
*        MAP      - MAP A LOAD MODULE                                 * 00105000
*        MEMBERS  - DISPLAY MEMBERS IN A GROUP                        * 00106000
*        OPTIONS  - DISPLAY THE SUBCOMMAND MENU                       * 00107000
*        OUTCOPY  - OUTPUT IEBCOPY SELECT STATEMENTS                  * 00108000
*        PATTERN  - DISPLAY DIRECTORY BASED ON MEMBER NAME SEGMENTS   * 00109000
*        PRINTOFF - PRINT A MEMBER WITH THE TSO PRINTOFF COMMAND      * 00110000
*        RECALL   - DISPLAY OR REISSUE THE PREVIOUS SUBCOMMAND        * 00111000
*        RENAME   - RENAME A MEMBER                                   * 00112000
*        RESTORE  - RESURRECT A PREVIOUSLY DELETED MEMBER             * 00113000
*        REVIEW   - BROWSE DATA WITH THE REVIEW COMMAND               * 00114000
*        SUBMIT   - SUBMIT A JCL MEMBER                               * 00115000
*        TSO      - EXECUTE A TSO COMMAND                             * 00116000
*        TSOEDIT  - EDIT A MEMBER WITH TSO EDIT                       * 00117000
*        TSOLIST  - LIST A MEMBER WITH THE TSO LIST COMMAND           * 00118000
*        USAGE    - LIST DATA SET STATISTICS                          * 00119000
*        VERIFY   - CHECK THE DATA SET FOR VALIDITY ERRORS            * 00120000
*                                                                     * 00121000
* WRITTEN    - BY TOM SPRINGER AT FIREMAN'S FUND (NOW WITH IBM)       * 00122000
* MODIFIED   - BY WILLIAM FINKELSTEIN, WITH CITIBANK IN LOS ANGELES   * 00123000
* MODIFIED   - BY STEVEN SMITH, WITH SECURITY PACIFIC NATIONAL BANK   * 00124000
* MAINTAINED - BY BRUCE LELAND, WITH HITACHI AMERICA, LTD.            * 00125000
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 00126000
         TITLE 'P D S  --  PDS COMMAND CHANGE DOCUMENTATION    1/15/85' 00127000
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 00128000
*                                                                     * 00129000
*  CHANGE SECTION:                                                    * 00130000
*                                                                     * 00131000
****VER 2.0: ADDED FORMATTING OPTIONS FOR LIST;                    **** 00132000
*            ADDED EDIT, FIND AND SUBMIT SUBCOMMANDS.                 * 00133000
*                                                                     * 00134000
****VER 2.2: CORRECTED AN ERROR IN LIST AND FIND FOR DATA SETS     **** 00135000
*       WITH ASA OR MACHINE CARRIAGE CONTROLS.                        * 00136000
*                                                                     * 00137000
****VER 2.3: MADE SEVERAL IMPROVEMENTS AS SUGGESTED BY DINESH      **** 00138000
*       DATTANI FROM PRUDENTIAL INSURANCE CO. OF AMERICA, TORONTO     * 00139000
*       1.  OUTPUT THE PROGRAM OPTION LIST IN SORTED ORDER.           * 00140000
*       2.  ADDED SEVERAL EDIT DESCRIPTIVE QUALIFIERS.                * 00141000
*                                                                     * 00142000
****VER 3.0: UPDATED THE PDS COMMAND FOR MVS USE BASED ON A        **** 00143000
*       VERSION OF THE PDS COMMAND ON THE CBT MODS TAPE.              * 00144000
*       1.  ADDED EXEC (EXPLICIT AND IMPLIED) AND HELP SUBCOMMANDS.   * 00145000
*       2.  A SINGLE CHARACTER SUBCOMMAND NAME IS NOT AMBIGUOUS.      * 00146000
*       3.  SUPPORT WAS ADDED IN THE FOLLOWING AREAS:                 * 00147000
*           -- SSI INFORMATION DISPLAY                                * 00148000
*           -- APF DATA CAN BE LISTED AND MODIFIED                    * 00149000
*           -- HEXADECIMAL MEMBER NAMES ALLOWED AS INPUT              * 00150000
*           -- HEXADECIMAL OUTPUT ADDED - DISPLAY, PATTERN, MEMBERS   * 00151000
*           -- $PUTGET, $PUTLINE AND MESSAGE MACROS WERE ADDED        * 00152000
*           -- ATTRIB LISTS ALL ALIASES FOR A GIVEN MODULE            * 00153000
*       4.  SEVERAL SOURCES OF 0C7'S WERE CORRECTED FOR IDR DATA.     * 00154000
*       5.  THE MEMBER NAME VALIDITY CHECK ROUTINE HAD TWO BUGS:      * 00155000
*           --  THE MEMBER NAME LENGTH USED WAS THE INPUT NAME        * 00156000
*               LENGTH (INCORRECT FOR HEXADECIMAL NAMES)              * 00157000
*           --  PROMPTING FOR INVALID MEMBER NAMES WAS INCORRECT      * 00158000
*       6.  THE ATTRIB SUBCOMMAND SOMETIMES LISTED SSI INFORMATION    * 00159000
*           FOR NON-LOAD MODULES WHICH DID NOT HAVE ANY SSI DATA.     * 00160000
*                                                                     * 00161000
****VER 3.1: SEVERAL GENERAL CHANGES WERE MADE                     **** 00162000
*       1.  THE PATTERN SUBCOMMAND WAS ADDED.                         * 00163000
*       2.  DEFAULT MEMBER NAMES ARE ALLOWED FOR ATTRIB, BROWSE,      * 00164000
*           DELETE, DIRENTRY, DSPRINT, EDIT, FSE, FIND, HISTORY, IF,  * 00165000
*           LIST, MAP, MEMBERS, OUTCOPY, PRINTOFF, REVIEW, SPFEDIT,   * 00166000
*           SUBMIT AND TSOLIST SUBCOMMANDS.                           * 00167000
*       3.  PDS WAS ADDED AS AN ALIAS FOR THE CHANGE SUBCOMMAND.      * 00168000
*       4.  ALIAS SUBCOMMAND IS NOT PREVENTED FROM WORKING IF THE     * 00169000
*           APF DATA LENGTH IS INVALID (APF=0 IS USED).               * 00170000
*       5.  EDIT PREVIOUSLY USED THE PREVIOUS PDL FOR DEFAULT         * 00171000
*           MEMBERS; NOW THE EDIT WORK AREA IS SAVED BEFORE EACH      * 00172000
*           SUBCOMMAND SCAN.                                          * 00173000
*                                                                     * 00174000
****VER 4.0: MADE SEVERAL IMPROVEMENTS AS SUGGESTED BY SEYMOUR     **** 00175000
*        METZ FROM COMNET IN WASHINGTON, D.C.:                        * 00176000
*        1.  REPLACED IBM/360 INSTRUCTIONS WITH THEIR IBM/370         * 00177000
*            EQUIVALENTS (ICM, STCM, MVCL, ...)                       * 00178000
*        2.  REPLACED BCR INSTRUCTIONS WITH EQUIVALENT MNEMONICS.     * 00179000
*        3.  TSO SERVICE ROUTINE ADDRESSES ARE NOW OBTAINED FROM      * 00180000
*            THE CVT INSTEAD OF VIA LOAD/DELETE CODE.                 * 00181000
*                                                                     * 00182000
****VER 4.1: SEVERAL ADDITIONAL CHANGES WERE MADE TO TAKE          **** 00183000
*        ADVANTAGE OF MVS PROGRAM LOGIC AND SERVICE ROUTINES:         * 00184000
*        1.  USED THE DAIRFAIL MESSAGE ROUTINE INSTEAD OF INTERNALLY  * 00185000
*            GENERATING MESSAGES AS SUGGESTED BY SEYMOUR METZ.        * 00186000
*        2.  USED THE GENERAL FAIL MESSAGE ROUTINE FOR PARSE ERRORS.  * 00187000
*        3.  USED THE TSO DEFAULT ROUTINE TO FULLY QUALIFY DSNAMES.   * 00188000
*        4.  CHANGED THE ALLOCATION STRATEGY TO "PERMANENTLY"         * 00189000
*            ALLOCATE DATA SETS SO THAT EXTERNAL PDS SUBCOMMANDS      * 00190000
*            CAN USE AN UNCATALOGED DATA SET AFTER IT IS ALLOCATED    * 00191000
*            BY PDS.  THIS CHANGE WAS SUGGESTED BY JOE RAREY          * 00192000
*            WITH MARTIN-MARRIETA IN FLORIDA.                         * 00193000
*                                                                     * 00194000
****VER 4.2: AFTER THE DAIRFAIL CHANGES INDICATED ABOVE, THE       **** 00195000
*            VOLUME PARAMETER FOR UNCATALOGED DATA SETS DID NOT WORK. * 00196000
*                                                                     * 00197000
****VER 4.3: CORRECTED ONE SOURCE OF 0C4'S IN LISTING HISTORY      **** 00198000
*            DATA AS REPORTED BY ARNIE CASINGHINO FROM CBT.           * 00199000
*                                                                     * 00200000
****VER 4.4: ADDED THE RESTORE SUBCOMMAND TO RESURRECT DELETED     **** 00201000
*            PDS MEMBERS.  ALSO, CLEANED UP SOME PDS CODE AS          * 00202000
*            SUGGESTED BY SEYMOUR METZ FROM COMNET AND ADDED A        * 00203000
*            SYSPARM ASSEMBLY PARAMETER FOR GENERATING PDS.           * 00204000
*                                                                     * 00205000
****VER 4.5: ADDED THE FOLLOWING SUBCOMMANDS                       **** 00206000
*                                                                     * 00207000
*            TSOLIST: A SUBCOMMAND TO LINK TO THE TSO LIST COMMAND    * 00208000
*            AS SUGGESTED BY SEYMOUR METZ.                            * 00209000
*                                                                     * 00210000
*            PRINTOFF: A SUBCOMMAND TO LINK TO THE PRINTOFF COMMAND   * 00211000
*            AS SUGGESTED BY DAVID FILSINGER OF FACSO (SHARE CODE CB) * 00212000
*                                                                     * 00213000
*            DELETE:  NEW, PREFERRED ALIAS FOR THE SCRATCH SUBCOMMAND * 00214000
*                                                                     * 00215000
****VER 5.0: ADDED ANOTHER BASE REGISTER AND MADE SEVERAL          **** 00216000
*            SUBCOMMAND CHANGES:                                      * 00217000
*                                                                     * 00218000
*        ATTRIB, BROWSE, DELETE, DIRENTRY, DSPRINT, EDIT, FIND, FSE,  * 00219000
*        HISTORY, IF, LIST, MAP, MEMBERS, OUTCOPY, PRINTOFF, REVIEW,  * 00220000
*        SPFEDIT, SUBMIT AND TSOLIST:                                 * 00221000
*          1.  ADDED THE * NOTATION (MEANS USE PREVIOUS MEMBER NAME)  * 00222000
*          2.  ADDED MEMBER NAME GROUPS (RANGES AND PATTERNS)         * 00223000
*          3.  ENTER "HELP GROUP" FOR MORE INFORMATION                * 00224000
*                                                                     * 00225000
*        BROWSE AND SPFEDIT: ADDED SUBCOMMANDS WHICH MAKE PDS A SPF   * 00226000
*        DIALOG SO IT CAN USE BROWSE AND EDIT SERVICE FOR A MEMBER.   * 00227000
*        HELP ON FULL SCREEN, SPF AND ISPF INTERFACES WAS PROVIDED    * 00228000
*        BY MIKE LOOS WITH DELUXE CHECK PRINTERS IN MINNESOTA.        * 00229000
*                                                                     * 00230000
*        ATTRIB:                                                      * 00231000
*          1.  FORMAT AND DISPLAY ANY SPF STATISTICS IN SPF FORMAT.   * 00232000
*          2.  DISPLAY ENTRY POINT ADDRESS, MODULE SIZE AND THE LAST  * 00233000
*              LINKAGE-EDIT DATE FOR LOAD MODULES.                    * 00234000
*          3.  FIXED A STORAGE OVERLAY FOR MEMBERS WITH MANY ALIASES. * 00235000
*          4.  ADDED THE PAGE AND NOPAGE KEYWORDS.                    * 00236000
*                                                                     * 00237000
*        ALIAS:                                                       * 00238000
*          1.  NOW WORKS FOR SCATTER LOADED MEMBERS                   * 00239000
*          2.  IF A MODULE IS CREATED BY THE OS/VS LINKAGE EDITOR     * 00240000
*              AND HAS SSI INFORMATION, THE ALIAS WILL ALSO.          * 00241000
*          3.  AN ALIAS CAN NOW BE ASSIGNED TO AN ALIAS MEMBER.       * 00242000
*          4.  FIXED A BUG: AN ASSIGNED ENTRY POINT OF ZERO           * 00243000
*              SOMETIMES DID NOT GET THE ENTRY POINT ZERO FLAG SET.   * 00244000
*                                                                     * 00245000
*        EDIT: ALLOWS EDITING OF NEW MEMBERS.                         * 00246000
*                                                                     * 00247000
*        RESTORE: NOW OPERATES ON LOAD MODULES.                       * 00248000
*                                                                     * 00249000
*        ATTRIB AND MAP: IF NO MAIN MEMBER NAME CAN BE FOUND FOR AN   * 00250000
*        ALIAS IN A LOAD LIBRARY, THE NAME STORED IN THE DIRECTORY    * 00251000
*        ENTRY AS THE MAIN ENTRY IS DISPLAYED.                        * 00252000
*                                                                     * 00253000
*        FIND: ADDED FIRST/NOFIRST KEYWORDS AND HEXADECIMAL STRINGS.  * 00254000
*                                                                     * 00255000
*        FIND AND LIST:                                               * 00256000
*          1.  ADDED SUPPORT FOR RECORD FORMAT U DATA SETS.           * 00257000
*          2.  ADDED SUPPORT FOR NON-PARTITIONED DATA SETS.           * 00258000
*          3.  ADDED LBLOCK, LDUMP, BLOCK AND DUMP FORMATS.           * 00259000
*          4.  ADDED SKIPREC, MAXIN, MAXOUT, SKIPCOL AND MAXLEN.      * 00260000
*          5.  NUM FORMAT CHECKS FOR DATA SAVED BY SPF EDIT.          * 00261000
*          6.  NUM FORMAT CHECKS FOR NUMERIC LINE NUMBERS AND         * 00262000
*              SWITCHES TO NONUM MODE FOR THE REMAINDER OF A          * 00263000
*              MEMBER IF AN INVALID LINE NUMBER IS ENCOUNTERED.       * 00264000
*                                                                     * 00265000
*        PATTERN AND DISPLAY:  UNPRINTABLE LETTERS ARE DISPLAYED AS   * 00266000
*        PERIODS.  ALSO, HEXADECIMAL/CHARACTER DISPLAYS ARE FORCED    * 00267000
*        FOR ANY MEMBER NAME WHICH IS NOT VALID.  NOTE: VALID MEMBER  * 00268000
*        NAMES CONTAIN UPPER-CASE ALPHANUMERIC CHARACTERS (WHICH      * 00269000
*        INCLUDES #, $ AND @) AND THE FIRST CHARACTER OF A VALID      * 00270000
*        MEMBER NAME IS UPPER-CASE ALPHABETIC.                        * 00271000
*                                                                     * 00272000
*        CHANGE AND PDS:                                              * 00273000
*          1.  IF A DSNAME IS NOT ENTERED WITH THE SUBCOMMAND,        * 00274000
*              THE PREVIOUSLY USED DATA SET IS ASSUMED.               * 00275000
*          2.  ADDED THE SHR AND OLD DATA SET KEYWORDS.               * 00276000
*                                                                     * 00277000
*        DIRENTRY: SUBCOMMAND WAS ADDED TO DUMP A DIRECTORY ENTRY.    * 00278000
*                                                                     * 00279000
*        MEMBERS: SUBCOMMAND WAS ADDED TO DISPLAY A MEMBER GROUP.     * 00280000
*                                                                     * 00281000
*        RESTORE, LIST, MAP, HISTORY AND ALIAS: FIXED A BUG; THE      * 00282000
*        NEWEXTENT SUBROUTINE ALLOWED THE USE OF ONE TOO MANY EXTENTS.* 00283000
*                                                                     * 00284000
****VER 5.1:  MADE SOME CODE CLEANUP CHANGES;                      **** 00285000
*                                                                     * 00286000
*        DELETED THE READ OF THE JFCB FOR THE INPUT DATA SET.         * 00287000
*                                                                     * 00288000
*        EXCP'S ARE NOW ALL IN AN EXCP SUBROUTINE; SET AND READ       * 00289000
*        SECTORS ARE PERFORMED FOR ALL DISK DRIVES EXCEPT 2314'S.     * 00290000
*                                                                     * 00291000
*                                                                     * 00292000
*        AN OBTAIN IS ALWAYS PERFORMED ONCE FOR EACH INPUT DATA       * 00293000
*        SET (NOT WHEN NEEDED AS BEFORE IN RESTORE AND USAGE).        * 00294000
*                                                                     * 00295000
*        ALL PDS BLDL'S ARE PERFORMED BEFORE INVOKING THE PROCESSING  * 00296000
*        SUBROUTINE.  IN ADDITION, PDS MAINTAINS THE STATUS OF THE    * 00297000
*        CURRENT BLDL SO THAT UNNECESSARY BLDL'S CAN BE AVOIDED.      * 00298000
*                                                                     * 00299000
*        ADDED A RESTORE SUBCOMMAND TEST FACILITY:  AN EXISTING       * 00300000
*        MEMBER MAY BE "RESTORED" IF THE RESTORE MEMBER NAME BEGINS   * 00301000
*        WITH "TEMP".  USE THE DIRENTRY SUBCOMMAND TO COMPARE THEIR   * 00302000
*        DIRECTORY ENTRIES (REMEMBER TO DELETE THE TEMP MEMBER SINCE  * 00303000
*        YOU HAVE AN APPARENT ALIAS -- NEITHER HAS AN ALIAS BIT SET). * 00304000
*                                                                     * 00305000
****VER 5.2:  ADDED SUPPORT FOR TRACK OVERFLOW RECORDS AS WELL     **** 00306000
*        AS THE FOLLOWING OTHER CHANGES:                              * 00307000
*                                                                     * 00308000
*        CHANGE AND PDS: IF A VOLUME NAME IS SUPPLIED, SYSALLDA IS    * 00309000
*        USED AS THE UNIT NAME; OTHERWISE, THE UNIT NAME FROM THE     * 00310000
*        PSCB WOULD BE USED (WHICH MIGHT NOT COVER THE VOLUME TO BE   * 00311000
*        ALLOCATED).  REPORTED BY BILL COWAN WITH THE COCA-COLA       * 00312000
*        COMPANY IN ATLANTA, GEORGIA.                                 * 00313000
*                                                                     * 00314000
*        DELETE: ALLOWS MEMBER GROUPS AND DEFAULT MEMBER NAMES AS     * 00315000
*        REQUESTED BY ARNIE CASINGHINO FROM CBT.                      * 00316000
*                                                                     * 00317000
*        ATTENTION HANDLING IMPROVEMENTS -- TWO ATTENTIONS IN A ROW   * 00318000
*        ARE GENERALLY REQUIRED TO TERMINATE PDS; ALL SUBCOMMANDS     * 00319000
*        NOW RECOGNIZE ATTENTION INTERRUPTS TO SOME DEGREE:           * 00320000
*        A.  PDS ATTENTION HANDLING IS NOW DOCUMENTED IN PDS'S HELP   * 00321000
*            (ENTER "HELP ATTN" FOR MORE INFORMATION).                * 00322000
*        B.  FIXED A BUG: A NULL RESPONSE TO "ENTER OPTION" AFTER     * 00323000
*            AN ATTENTION DID NOT ALLOW THE SUBCOMMAND TO CONTINUE.   * 00324000
*        C.  THE INPUT ROUTINE NOW ALSO CHECKS FOR ATTENTION -- THIS  * 00325000
*            ELIMINATES WAITING UNTIL A MESSAGE IS OUTPUT AS BEFORE.  * 00326000
*                                                                     * 00327000
*        OPEN: FIXED ABEND 013-D0 FOR RECFM=FS OR FBS.  THIS PROBLEM  * 00328000
*        WAS REPORTED BY JAMES BERRY FROM WESTLAKE VILLAGE, CALIF.    * 00329000
*                                                                     * 00330000
*        ALIAS, RENAME AND RESTORE: CHANGE THE DEFAULT MEMBER NAME AS * 00331000
*        SUGGESTED BY JOHN SULLIVAN AT LOMA LINDA UNIVERSITY, CALIF.  * 00332000
*                                                                     * 00333000
****VER 5.3:  CHANGED THE CSECT STRUCTURE OF PDS AND MADE THE      **** 00334000
*        FOLLOWING OTHER CHANGES:                                     * 00335000
*                                                                     * 00336000
*        SPFEDIT AND BROWSE:                                          * 00337000
*        A.  THE INITIALIZATION ADDRESS FOR PDS PASSED TO ISPF IS     * 00338000
*            NOW CONVERTED TO DECIMAL BEFORE THE CALL AND CONVERTED   * 00339000
*            BACK TO BINARY ON THE RECURSIVE ENTRY IN PDS DUE TO THE  * 00340000
*            POTENTIAL PROBLEM OF A X'5D' (A RIGHT PARENTHESIS) IN    * 00341000
*            THE ADDRESS.  THIS WAS REPORTED BY SEYMOUR METZ, U.S.    * 00342000
*            DEPARTMENT OF STATE.                                     * 00343000
*        B.  A PARAMETER LIST PASSED TO INITIALIZE SPF OR ISPF MUST   * 00344000
*            NOT BE REUSED BY THE CALLING PROGRAM SINCE SPF USES IT   * 00345000
*            LATER IF IT SPLITS THE USER'S SCREEN.  THIS PROBLEM WAS  * 00346000
*            RESOLVED BY MIKE LOOS WITH DELUXE CHECK PRINTERS.        * 00347000
*        BROWSE: THE ALLOCATED FILE IS NOW FREED BEFORE EACH CALL     * 00348000
*        TO SPF SINCE THE DATA SET COULD BE UPDATED IN A SUBSEQUENT   * 00349000
*        SPLIT SCREEN.                                                * 00350000
*                                                                     * 00351000
*        EDIT AND SPFEDIT: ADDED NEW AND OLD KEYWORDS TO ALLOW BLDL   * 00352000
*        CHECKING OF MEMBER NAMES BEFORE ENTERING EITHER EDITOR.      * 00353000
*                                                                     * 00354000
*        END: THE RETURN CODE ASSIGNED BY THE PROGRAM IS NOW SAVED    * 00355000
*        TEMPORARILY IN THE PROGRAM'S STORAGE; IN VERSION 5.2 THE     * 00356000
*        RETURN CODE IS CHANGED DURING A CALL TO FREE THE FILE AND    * 00357000
*        A STACK DELETE IS INCORRECTLY ISSUED AT PDS TERMATION.       * 00358000
*                                                                     * 00359000
*        CHANGE AND PDS: THE DATA SET ALLOCATION STATUS IS DISPLAYED  * 00360000
*        AFTER EACH DATA SET IS ALLOCATED.                            * 00361000
*                                                                     * 00362000
*        ATTRIB:                                                      * 00363000
*          1.  ADDED ALIASINFO AND NOALIASINFO KEYWORDS               * 00364000
*          2.  ADDED LKEDDATE AND NOLKEDDATE KEYWORDS                 * 00365000
*          3.  A LIST OF ATTRIBUTES TO BE ASSIGNED TO A MODULE        * 00366000
*              CAN NO LONGER BE PLACED IN PARENTHESES.                * 00367000
*                                                                     * 00368000
*        UNDOCUMENTED SUBCOMMANDS:                                    * 00369000
*          1. COMPRESS OPERAND "SHR" -- EVALUATE THIS BEFORE USING    * 00370000
*          2. KLEAR (OR K -- CLEARS 3270 DISPLAY SCREENS)             * 00371000
*          3. W (DUMMY SUBCOMMAND FOR EXECUTING PDS UNDER TEST)       * 00372000
*                                                                     * 00373000
*                                                                     * 00374000
*                                                                     * 00375000
*        IF: ADDED SUBCOMMAND TO TEST MEMBERS FOR GIVEN ATTRIBUTES    * 00376000
*        AND PERFORM CONDITIONAL PROCESSING AS SUGGESTED BY JIM BERRY * 00377000
*        FROM WESTLAKE VILLAGE, CALIFORNIA:                           * 00378000
*                                                                     * 00379000
*        FIND: ADDED THEN AND ELSE CONDITIONAL PROCESSING             * 00380000
*        CAPABILITIES AS IMPLEMENTED IN THE IF SUBCOMMAND.            * 00381000
*                                                                     * 00382000
*        MAP: DELETED THE SMAP SUBCOMMAND AND MADE SEVERAL CHANGES -  * 00383000
*           1.  ADDED FULL, SHORT AND ENTRY KEYWORDS                  * 00384000
*           2.  ADDED MODULE NAME FILTERING                           * 00385000
*                                                                     * 00386000
*        HISTORY: ADDED TRANSLATOR IDENTIFICATION MESSAGES AND        * 00387000
*        MADE SEVERAL ADDITIONAL CHANGES -                            * 00388000
*           1.  ADDED MODULE NAME FILTERING                           * 00389000
*           2.  ADDED TRAN(PARTNAME)                                  * 00390000
*           3.  ADDED ZAP(PARTNAME)                                   * 00391000
*           4.  ADDED USER(PARTNAME)                                  * 00392000
*           5.  FIXED A BUG - IF A IDR USER RECORD HAD CONTINUED      * 00393000
*               HEADER DATA, ITS DATE WAS NOT INITIALIZED.            * 00394000
*                                                                     * 00395000
*        MEMBER PROTECTION: THE DELETE, EDIT, FIXPDS, FSE, SPF AND    * 00396000
*        RENAME SUBCOMMANDS ISSUE SPF-STYLE ENQUEUE CHECKS BEFORE     * 00397000
*        UPDATING THE ALLOCATED DATA SET.  THIS ENQUEUE CHECK CANNOT  * 00398000
*        DETECT A USER FROM ANOTHER CPU UPDATING THE MEMBER THROUGH   * 00399000
*        SHARED DASDI (THIS IS ALSO AN SPF PROBLEM).                  * 00400000
*                                                                     * 00401000
*                                                                     * 00402000
*                                                                     * 00403000
*        DATA SET PROTECTION: THE PDS GENERATION OPTIONS OF OLD, SHR, * 00404000
*        AND OPER HAVE BEEN REMOVED -- THE DATA SET'S INTEGRITY CAN   * 00405000
*        BE INSURED BY USING DISPOSITION "OLD" ON THE CHANGE OR PDS   * 00406000
*        SUBCOMMAND.  ALSO, SEE THE FOLLOWING NOTES ON SHR UPDATES    * 00407000
*        AND MEMBER PROTECTION.                                       * 00408000
*                                                                     * 00409000
*        SHR UPDATES: PDS NOW USES SPF RESERVE LOGIC TO PROTECT THE   * 00410000
*        INTEGRITY OF DATA SETS ALLOCATED AS SHR DURING ANY UPDATES.  * 00411000
*        THIS CHANGE AFFECTS THOSE PDS SUBCOMMANDS WHICH UPDATE THE   * 00412000
*        DATA SET BEING PROCESSED (ALIAS, ATTRIB WITH ATTRIBUTE       * 00413000
*        CHANGES, DELETE, FIXPDS, RENAME, RESTORE AND VERIFY          * 00414000
*        SUBCOMMANDS) AND WAS SUGGESTED BY ARNIE CASINGHINO WITH CBT. * 00415000
*        ENTER "HELP UPDATE" FOR MORE INFORMATION.                    * 00416000
*                                                                     * 00417000
*        ESTAE PROCESSING: PDS CAN NOW RECOVER FROM ABENDS (EXCEPT    * 00418000
*        IN THE SPFEDIT AND BROWSE SUBCOMMANDS).  ENTER "HELP ABEND"  * 00419000
*        FOR MORE INFORMATION.                                        * 00420000
*                                                                     * 00421000
*        RESTORE: ADDED CONTROL KEYWORDS AS SUGGESTED BY              * 00422000
*        GEORGE GOFFE WITH THE AMDAHL CORPORATION, SUNNYVALE, CALIF.  * 00423000
*                                                                     * 00424000
*        EXTERNAL SUBCOMMANDS: SUBCOMMANDS EXTERNAL TO PDS ARE NOW    * 00425000
*        ATTACHED INSTEAD OF LINKED TO.  THIS WAS SUGGESTED BY        * 00426000
*        SEYMOUR METZ WITH THE STATE DEPARTMENT.  THIS CHANGE MAKES   * 00427000
*        THE FOLLOWING IMPROVEMENTS POSSIBLE:                         * 00428000
*           1.  PDS CAN RECOVER FROM ABENDS IN THESE SUBCOMMANDS      * 00429000
*           2.  PDS CAN FREE ALLOCATED FILES AND MOST OTHER RESOURCES * 00430000
*               OBTAINED BY THESE SUBCOMMANDS                         * 00431000
*           3.  PDS CAN PERFORM ATTENTION PROCESSING IN BEHALF OF     * 00432000
*               THESE SUBCOMMANDS                                     * 00433000
*                                                                     * 00434000
*        ATTRIB: ANY APPARENT ALIASES FOR A MEMBER ARE DISPLAYED (AS  * 00435000
*        WELL AS ACTUAL ALIASES) DURING THE ALIAS SEARCH FOR A MEMBER.* 00436000
*                                                                     * 00437000
*        ATTRIB AND MAP: ALL CORRESPONDING MAIN MEMBERS FOR AN ALIAS  * 00438000
*        MEMBER ARE DISPLAYED (NOT JUST THE FIRST ONE AS BEFORE).     * 00439000
*                                                                     * 00440000
*        BACKGROUND USE OF PDS: A BLANK LINE IS OUTPUT BETWEEN EACH   * 00441000
*        SUBCOMMAND FOR READABILITY; ALSO, THE PROGRAM CIRCUMVENTS    * 00442000
*        PROMPTS FOR YES/NO DECISIONS BY SIMULATING YES RESPONSES.    * 00443000
*                                                                     * 00444000
*        TSSO SUPPORT:  A SINGLE SUBCOMMAND MAY NOW BE ENTERED ON THE * 00445000
*        PRIMARY COMMAND LINE; PDS WILL PROCESS THE SUBCOMMAND AND    * 00446000
*        TERMINATE.  THIS WAS SUGGESTED BY ARNIE CASINGHINO WITH CBT. * 00447000
*                                                                     * 00448000
*        FIXPDS:  ADDED SUBCOMMAND TO MODIFY THE ALLOCATED DATA SET.  * 00449000
*        THE EXPANDDIR OPTION WAS DERIVED FROM FILE 288 OF THE CBT    * 00450000
*        TAPE AS SUGGESTED BY ARNIE CASINGHINO WITH CBT.              * 00451000
*                                                                     * 00452000
*        NON-PARTITIONED DATA SETS:  PARSE DATA FOR THE MEMBER NAME   * 00453000
*        POSITITION IS NO LONGER ENTERED. ALSO, SUPPORT HAS BEEN      * 00454000
*        ADDED FOR NON-PARTITIONED DATA SETS FOR BROWSE, EDIT,        * 00455000
*        DSPRINT, FIND, FSE, LIST, PRINTOFF, SPFEDIT, SUBMIT,         * 00456000
*        REVIEW, TSOLIST AND VERIFY.                                  * 00457000
*                                                                     * 00458000
****VER 6.0:  MADE THE FOLLOWING CHANGES:                          **** 00459000
*                                                                     * 00460000
*        SPF AND ISPF USERS: PDS CAN BE INVOKED AS A SPF DIALOG USING * 00461000
*        THE PROVIDED SPF PANEL AND MESSAGE MEMBER.  THIS CHANGE      * 00462000
*        WAS SUGGESTED BY JAMES W. BERRY FROM WESTLAKE VILLAGE, CAL.  * 00463000
*                                                                     * 00464000
*        RENAME: IF A NON-ALIAS LOAD MODULE IS RENAMED, ADDITIONAL    * 00465000
*        CODE IN RENAME WILL UPDATE THE CHANGED NAME POINTERS IN      * 00466000
*        ANY ASSOCIATED ALIAS DIRECTORY ENTRIES.                      * 00467000
*                                                                     * 00468000
*        VERIFY: ADDED A SUBCOMMAND TO CHECK A DATA SET FOR           * 00469000
*        VALIDITY ERRORS.                                             * 00470000
*                                                                     * 00471000
*        IF: ADDED SEVERAL MEMBER VALIDITY CHECKS IN SUPPORT OF       * 00472000
*        THE NEW VERIFY SUBCOMMAND.                                   * 00473000
*                                                                     * 00474000
*        FROM ARNIE CASINGHINO (CBT):                                 * 00475000
*        A.  MODIFIED THE SCREEN CLEAR TPUT FOR KLEAR TO SUPPORT      * 00476000
*            3278-5 TERMINALS UNDER ACF/TCAM.                         * 00477000
*        B.  MODIFIED RESERVE LOGIC FOR BATCH EXECUTIONS OF PDS       * 00478000
*            TO HOLD RESERVES UNTIL A NEW DATA SET IS SELECTED.       * 00479000
*        C.  ADDED KEYWORDS TO THE RESTORE SUBCOMMAND TO ALLOW        * 00480000
*            MULTIPLE MEMBER RESTORATIONS WITH AND WITHOUT PROMPTING. * 00481000
*        D.  MODIFIED FIXPDS TO ADD AN PADDING DIRECTORY BLOCK IF     * 00482000
*            A TRACK WILL BE FILLED WITH DIRECTORY BLOCKS.  THIS      * 00483000
*            IS DONE TO ENSURE THAT THE END OF FILE MARK IS ON THE    * 00484000
*            FOLLOWING TRACK AND IT AVOIDS IEBCOPY ABENDS.            * 00485000
*        E.  MODIFIED RENAME TO WORK ON A RANGE OF MEMBERS.           * 00486000
*                                                                     * 00487000
*        FROM GEORGE GOFFE (AMDAHL CORPORATION):                      * 00488000
*        A.  ADDED A SWAP OPERAND TO THE RENAME SUBCOMMAND TO         * 00489000
*            ALLOW TWO MEMBERS TO EXCHANGE MEMBER NAMES.              * 00490000
*        B.  THE PATTERN SUBCOMMAND MAY BE ENTERED WITHOUT OPERANDS   * 00491000
*            AND THE PREVIOUS PATTERN OPERAND(S) WILL BE USED.        * 00492000
*        C.  ADDED THE RECALL SUBCOMMAND TO DISPLAY OR REISSUE        * 00493000
*            AND DISPLAY THE PREVIOUSLY ENTERED SUBCOMMAND.           * 00494000
*                                                                     * 00495000
*        FROM JOHN SULLIVAN (LOMA LINDA UNIVERSITY MEDICAL CENTER):   * 00496000
*        A.  ADDED A NONE OPERAND FOR THE ATTRIB SUBCOMMAND TO        * 00497000
*            CHANGE ALL ATTRIBUTES OF A MODULE TO DEFAULT VALUES.     * 00498000
*        B.  CHANGED ALL MODULE SIZE DISPLAYS TO OUTPUT THE NEXT      * 00499000
*            HIGHER 1K BOUNDARY RATHER THAN THE CLOSEST 1K BOUNDARY.  * 00500000
*        C.  MODIFIED ATTRIB TO ALLOW DC ATTRIBUTE CHANGES.           * 00501000
*                                                                     * 00502000
*        HISTORY:  CORRECTED TO LIST HISTORY DATA IN DESCENDING ORDER * 00503000
*        IN EACH GROUP BY LAST CHANGE DATE, ADDED LINKAGE-EDITOR NAME * 00504000
*        FILTERING AND CHANGED SUBCOMMAND DEFAULTS.                   * 00505000
*                                                                     * 00506000
*        USE OF PDS CLISTS OR STACKED INPUT: THE PROGRAM CIRCUMVENTS  * 00507000
*        PROMPTS FOR YES/NO DECISIONS BY ASSUMING YES RESPONSES.      * 00508000
*                                                                     * 00509000
*        IF, VERIFY, ATTRIB: MADE CHANGES TO CHECK FOR MUTUALLY       * 00510000
*        EXCLUSIVE LOAD MODULE ATTRIBUTES (FOR EXAMPLE, OVERLAY       * 00511000
*        ATTRIBUTE WITH THE REENTRANT ATTRIBUTE).                     * 00512000
*                                                                     * 00513000
*        MVS/XA SUPPORT - MADE CHANGES FOR THE FOLLOWING SUBCOMMANDS: * 00514000
*        A.  IF: ADDED SELECTION BY RMODE AND AMODE                   * 00515000
*        B.  ATTRIB: ADDED RMODE AND AMODE ATTRIBUTE SUPPORT:         * 00516000
*              1.  ADDED RMODE AND AMODE CHANGE CAPABILITY            * 00517000
*              2.  ADDED RMODE AND AMODE DISPLAY CAPABILITY FOR       * 00518000
*                  MODULES WHOSE RMODE AND AMODE ARE NOT BOTH 24      * 00519000
*              3.  IF RMODE OR AMODE IS CHANGED FOR A NON-ALIAS       * 00520000
*                  MODULE, ADDITIONAL CODE IN ATTRIB WILL UPDATE      * 00521000
*                  THE RMODE AND THE MAIN MODULE AMODE VALUE FOR      * 00522000
*                  ANY ASSOCIATED ALIAS DIRECTORY ENTRIES.            * 00523000
*        C.  RESTORE: ADDED CODE TO SET THE RMODE AND AMODE FOR       * 00524000
*            A MODULE BASED ON INFORMATION FROM ITS ESD ENTRIES       * 00525000
*        D.  ALIAS: ADDED CODE TO SET THE RMODE AND AMODE BASED ON    * 00526000
*            ESD INFORMATION AND THE ALIAS BASE ENTRY'S ATTRIBUTES    * 00527000
*        E.  MAP: ADDED CODE TO DISPLAY RMODE AND AMODE FOR CSECTS    * 00528000
*            WHOSE RMODE AND AMODE ARE NOT BOTH 24                    * 00529000
*                                                                     * 00530000
*        OUTCOPY: ADDED A NEW SUBCOMMAND TO PRODUCE IEBCOPY CONTROL   * 00531000
*        STATEMENTS WHICH CAN BE USED TO SELECTIVELY COPY PDS MEMBERS * 00532000
*                                                                     * 00533000
*        FROM WALT FARRELL WITH RAINER NATIONAL BANK IN SEATTLE:      * 00534000
*        A.  THE "ENTER OPTION" PROMPT MESSAGE HAS BEEN EXPANDED      * 00535000
*            TO INCLUDE THE DSNAME AND VOLUME SERIAL NAME.            * 00536000
*        B.  ATTRIB FOR NON-LOAD MEMBERS, BROWSE, DELETE, FIND, FSE,  * 00537000
*            HISTORY, IF, MAP, OUTCOPY, PRINTOFF, REVIEW AND SPF      * 00538000
*            SUBCOMMANDS:  THE MEMBER NAME IDENTIFICATION FOR MEMBER  * 00539000
*            GROUPS IS NORMALLY SUPPRESSED.  FOR THE DELETE, FIND,    * 00540000
*            HISTORY, IF AND MAP SUBCOMMANDS, HOWEVER, THE HEADER IS  * 00541000
*            WRITTEN IF ANY OUTPUT IS GENERATED FOR A MEMBER.         * 00542000
*                                                                     * 00543000
*        SPFEDIT AND BROWSE: A DIALOG ERROR NO LONGER TERMINATES THE  * 00544000
*        PDS COMMAND, HOWEVER, THE PDS COMMAND WILL NOT ATTEMPT TO    * 00545000
*        REUSE THE SPF INTERFACE AFTER A DIALOG ERROR.                * 00546000
*                                                                     * 00547000
*        ATTENTION PROCESSING: STAX PROCESSING HAS BEEN MODIFIED      * 00548000
*        AND TWO ATTENTIONS SHOULD NOW TERMINATE A PDS PROGRAM LOOP.  * 00549000
*                                                                     * 00550000
*        FIXPDS:  MODIFIED TO PREVENT A RESET OR EXPANDED DIRECTORY   * 00551000
*        FROM OVERFLOWING THE FIRST DISK EXTENT.                      * 00552000
*                                                                     * 00553000
*        FROM RICHARD MCCARTY WITH HITACHI AMERICA IN SAN JOSE:       * 00554000
*        IN FIXPDS EXPAND, IF THE LAST ALLOCATED DIRECTORY BLOCK WAS  * 00555000
*        COMPLETELY FULL, PDS COULD NOT ADD ANY DIRECTORY BLOCKS.     * 00556000
*                                                                     * 00557000
*        DELETE: ADDED THE ALIAS OPERAND                              * 00558000
*                                                                     * 00559000
*        ATTRIB FOR NON-LOAD MEMBERS, BROWSE, FSE, PRINTOFF, REVIEW   * 00560000
*        AND SPFEDIT SUBCOMMANDS: THE DEFAULT MEMBER NAME MESSAGE IS  * 00561000
*        SUPPRESSED TO REDUCE THE LEVEL OF REDUNDANT INFORMATION.     * 00562000
*                                                                     * 00563000
*        FROM BEN MOORE (FEDERAL EXPRESS):                            * 00564000
*        A.  IF, ATTRIB, VERIFY: CHECKS FOR THE DIRECTORY             * 00565000
*            RLD/CONTROL COUNT NOT MATCHING THE FIRST RLD ENTRY.      * 00566000
*        B.  IF: ADDED THE RLDZERO AND NORLDZERO KEYWORDS.            * 00567000
*                                                                     * 00568000
****VER 6.1:  MADE SEVERAL MODIFICATIONS:                          **** 00569000
*                                                                     * 00570000
*        FIND AND LIST:                                               * 00571000
*        A.  CHANGED LOGIC TO SUPPORT OUTPUT OF CSECT INFORMATION     * 00572000
*            AS SUGGESTED BY BEN MOORE WITH FEDERAL EXPRESS.          * 00573000
*        B.  ADDED A SECOND DISPLACEMENT FIELD FOR LBLOCK, LDUMP      * 00574000
*            BLOCK AND DUMP OUTPUT FORMATS.                           * 00575000
*        C.  CHANGED SPELLING OF MULTILINE TO LBLOCK.                 * 00576000
*        D.  CHANGED SPELLING OF LINEDUMP TO LDUMP.                   * 00577000
*        E.  DEFAULT OUTPUT FORMAT FOR LOAD MODULES IS LDUMP.         * 00578000
*        F.  ADDED MODULE AND OFFSET OPERANDS FOR LBLOCK AND LDUMP.   * 00579000
*                                                                     * 00580000
*        FROM JOHN SULLIVAN (LOMA LINDA MEDICAL CENTER):              * 00581000
*        A.  MODIFIED HISTORY TO LIST SPF STATISTICS (LIKE THE        * 00582000
*            ATTRIB SUBCOMMAND) FOR NON-LOAD MEMBERS.                 * 00583000
*        B.  ADDED THE CONTROL SUBCOMMAND.                            * 00584000
*        C.  ADDED THE LIKE KEYWORD ON THE RESTORE SUBCOMMAND.        * 00585000
*        D.  CHANGED RESTORE SCAN TO ALSO CHECK THE PROVIDED TTR      * 00586000
*            TO SEE IF IT IS A DELETED MEMBER.                        * 00587000
*                                                                     * 00588000
*        PROGRAM INPUT PROCESSING: DOUBLE BUFFERING HAS BEEN ADDED.   * 00589000
*                                                                     * 00590000
*        DELETE: REWRITTEN TO TAKE ADVANTAGE OF DOUBLE BUFFERING.     * 00591000
*                                                                     * 00592000
*        PDS DIALOG ENTRY: CODE FOR LOCATING THE TSO ECT HAS BEEN     * 00593000
*        ADDED AS PROVIDED BY MIKE LOOS WITH DELUXE CHECK PRINTERS.   * 00594000
*                                                                     * 00595000
*        TSO SERVICE ROUTINE ADDRESSES: SINCE SOME INSTALLATIONS      * 00596000
*        MAY MOVE ROUTINES LIKE IKJPARS OUT OF LPALIB, PDS HAS BEEN   * 00597000
*        MODIFIED TO TEST FOR AN ACTUAL ADDRESS IN THE CVT AND        * 00598000
*        TO LOAD AND DELETE ANY REQUIRED MODULES AS SUGGESTED BY      * 00599000
*        JERRY MORRIS WITH GTE DATA SERVICES IN TAMPA, FLORIDA.       * 00600000
*                                                                     * 00601000
*        FIXPDS: BLOCKSIZE VALUES FOR DATA KEYWORDS SUCH AS ASM,      * 00602000
*        CLIST, CNTL, LOAD OR OBJECT ARE BASED ON THE DEVICE TYPE.    * 00603000
*                                                                     * 00604000
*        TSO TIME SUBCOMMAND: IF TIME IS REQUESTED, PDS LINKS TO      * 00605000
*        IKJEFT25 INSTEAD OF TIME AS SUGGESTED BY MARK HUTCHINSON     * 00606000
*        WITH BURLINGTON INDUSTRIES IN GREENSBORO, NORTH CAROLINA.    * 00607000
*                                                                     * 00608000
*        REVIEW: SUBCOMMAND ADDED TO LINK TO THE REVIEW COMMAND       * 00609000
*        FROM THE CBT TAPE, FILE 300 (AIR FORCE TSO MODIFICATIONS).   * 00610000
*                                                                     * 00611000
*        EDIT, FSE, PRINTOFF, REVIEW, SUBMIT AND TSOLIST: PDS CHECKS  * 00612000
*        FOR VALID MEMBER NAMES BEFORE LINKING TO THE COMMAND.        * 00613000
*                                                                     * 00614000
*        IF: FIXED A MINOR PROBLEM WITH AUTHORIZED MODULE CHECKING;   * 00615000
*        ALSO, ADDED THE APFERR AND NOAPFERR KEYWORDS.                * 00616000
*                                                                     * 00617000
*        DISPLAY AND PATTERN: ADDED MEMBER GROUP SYNTAX AS AN         * 00618000
*        ALTERNATE WAY TO SPECIFY MEMBER NAMES.                       * 00619000
*                                                                     * 00620000
*        VERIFY: ADDED THE UPDATE AND NOUPDATE KEYWORDS.              * 00621000
*                                                                     * 00622000
*      ERRORS NOTED BY ARNOLD CASINGHINO AT CBT:                      * 00623000
*        HISTORY: ALWAYS DISPLAYED LINKAGE-EDITOR MOD LEVEL AS ZERO.  * 00624000
*        MAP: SOMETIMES DISPLAYED AMODE24 AND RMODE24 ATTRIBUTES.     * 00625000
*        EDIT, FSE, PRINTOFF, REVIEW, SUBMIT AND TSOLIST:             * 00626000
*        INTRODUCED A PROBLEM WITH SINGLE CHARACTER MEMBER NAMES.     * 00627000
*                                                                     * 00628000
****VER 6.2:  MADE SEVERAL MODIFICATIONS:                          **** 00629000
*                                                                     * 00630000
*        CONSOLIDATED ALL MESSAGES AND ADDED MESSAGE IDENTIFIERS      * 00631000
*        FOR USE BY THE TSO MESSAGE FORMATTING MODULE (IKJEFF18).     * 00632000
*                                                                     * 00633000
*        ADDED AN EXTENDED HELP (.?) FACILITY TO HELP EXPLAIN         * 00634000
*        ERRORS DETECTED DURING PDS PROCESSING.                       * 00635000
*                                                                     * 00636000
*        SUBCOMMANDS ADDED:                                           * 00637000
*        COMPARE: ATTACHES BILL GODFREY'S COMPARE PREPROCESSOR FROM   * 00638000
*                 JIM MARSHALL'S TSO UTILITIES.                       * 00639000
*        COMPRESS: FOR PDS COMPRESS FUNCTIONS.                        * 00640000
*        DSNAME: DISPLAYS THE CURRENT ALLOCATION AS SUGGESTED BY      * 00641000
*                DAVID FILSINGER AND JOHN SULLIVAN.                   * 00642000
*        DSPRINT: AS SUGGESTED BY WILLIAM SMITH IN PALO ALTO, CALIF.  * 00643000
*                                                                     * 00644000
*        OUTCOPY:                                                     * 00645000
*        A.  ECHO MODE IS NOW A DEFAULT.                              * 00646000
*        B.  ALIAS OPERAND WAS ADDED.                                 * 00647000
*                                                                     * 00648000
*        CONTROL: ADDED THE MSGS AND TESTREAD OPERANDS AND            * 00649000
*        DELETED THE UPDATEALIAS/NOUPDATEALIAS OPERANDS.              * 00650000
*                                                                     * 00651000
*        ALLOCATION/UNALLOCATION: REWRITTEN TO USE SVC 99 INSTEAD     * 00652000
*        OF DAIR.                                                     * 00653000
*                                                                     * 00654000
*      FROM STEVE SMITH WITH SECURITY PACIFIC BANK IN GLENDALE, CAL.  * 00655000
*        DISPLAY: THE SECOND OPERAND IS MADE OPTIONAL.                * 00656000
*        ISPF: ADDED SUBCOMMAND FOR DIRECT ENTRY INTO SPF.            * 00657000
*        INVALID SUBCOMMAND MESSAGE: ADDED FOR SUBCOMMAND RENAMES.    * 00658000
*        SUBCOMMAND TABLE: MOVED INTO THE COPY LIBRARY.               * 00659000
*                                                                     * 00660000
*      FROM MIKE LOOS WITH DELUXE CHECK PRINTERS:                     * 00661000
*        ALLOCATION: ADDED SUPPORT FOR ALIAS DATA SET NAMES.          * 00662000
*        IF: ADDED CREATED AND CHANGED KEYWORDS.                      * 00663000
*                                                                     * 00664000
*      FROM SAM LEPORE WITH WELLS FARGO BANK IN SAN FRANCISCO:        * 00665000
*        SPF HELP: ADDED A HELP SCREEN FOR THE PDS ENTRY PANEL.       * 00666000
*        RECALL: ADDED NULLS SO CHARACTER INSERT ON 3270'S WILL WORK. * 00667000
*        EXTENDED HELP: USED .? INSTEAD OF ! FOR THE KEY SYMBOL.      * 00668000
*        ALLOCATION: ADDED * NOTATION FOR THE DATA SET NAME POSITION. * 00669000
*                                                                     * 00670000
*      FROM GRAY MADDRY AT THE COOPER GROUP IN APEX, NORTH CAROLINA:  * 00671000
*        MEMBER IN USE MESSAGE: MODIFIED TO INCLUDE THE NAME OF THE   * 00672000
*        USER MODIFYING THE MEMBER.                                   * 00673000
*                                                                     * 00674000
*      FROM MARC SCHARE WITH BELL LABORATORIES IN PISCATAWAY, NJ:     * 00675000
*        ALLOCATION: ADDED SUPPORT FOR FILE(FILENAME).                * 00676000
*        ESTAE EXIT: FIXED AN S0C4 ABEND FOR MVS/XA 2.1.2.            * 00677000
*                                                                     * 00678000
*      FROM JOHN SULLIVAN WITH LOMA LINDA UNIVERSITY MEDICAL CENTER:  * 00679000
*        VERIFY: FIXED A BUG WHICH CAUSED S0C4 ABENDS WHEN PROCESSING * 00680000
*        DATA SETS WITH LARGE DIRECTORIES.                            * 00681000
*                                                                     * 00682000
*      FROM KAVIN MC CARTHY WITH CONTINENTAL BANK IN CHICAGO:         * 00683000
*        IMPLIED CLIST (%): FIXED A BUG WHICH REQUIRED CLISTS TO      * 00684000
*        HAVE A PROC STATEMENT.                                       * 00685000
*                                                                     * 00686000
*      FROM ARNOLD CASINGHINO WITH CBT:                               * 00687000
*        SUBCOMMANDS WITH DEFAULT MEMBERS: ADDED MEMBER LIST SUPPORT. * 00688000
*        SCREEN UTILIZATION: SUBCOMMANDS WHICH OUTPUT VARIABLE        * 00689000
*        AMOUNTS OF DATA ON AN OUTPUT LINE (SUCH AS THE DISPLAY       * 00690000
*        SUBCOMMAND) USE THE FULL TERMINAL LINE WIDTH.                * 00691000
*                                                                     * 00692000
*      FROM MICHAEL EMIGH FROM UNITED AIR LINES (LISTM COMMAND):      * 00693000
*        DATA SET OPEN: ADDED A DIRECTORY COUNTING CCW CHAIN.         * 00694000
*                                                                     * 00695000
*      FROM DAVID SAGER WITH JOHNS HOPKINS UNIVERSITY/APL:            * 00696000
*        COMMAND SECURITY: ADDED A SAMPLE RACF TSO VALIDATION EXIT.   * 00697000
*        VALIDATION: ADDED TSO COMMAND AND SUBCOMMAND AUTHORIZATION   * 00698000
*        EXITS SIMILAR TO TSO COMMAND EXITS FROM APL LABORATORIES.    * 00699000
*        PROGRAM GENERATION: ADDED INSTALLATION SUBCOMMAND CONTROLS.  * 00700000
*                                                                     * 00701000
*      FROM DICK HINTON WITH LOCKHEED AIRCRAFT, BURBANK, CALIF.       * 00702000
*        ESTAE EXIT: FIXED AN S0C6 ABEND FOR MVS/XA 2.1.2.            * 00703000
*                                                                     * 00704000
*        IF/FIND WITH THEN OR ELSE OPERANDS: MESSAGE SUPPRESSION      * 00705000
*        HAS BEEN ADDED FOR SUBCOMMANDS WHICH DISPLAY MEMBER NAMES.   * 00706000
*                                                                     * 00707000
*        PFK SUPPORT: INPUT CAN OPTIONALLY INCLUDE PF KEYS (THIS IS   * 00708000
*        NOT YET FULLY DOCUMENTED DUE TO A CURRENT IBM APAR).         * 00709000
*                                                                     * 00710000
*        INPUT BUFFERING:                                             * 00711000
*          SINGLE - NAME CHANGED FROM NODOUBLE; ONE BLOCK PER EXCP.   * 00712000
*          DOUBLE - CHANGED TO GET TWO BLOCKS PER EXCP.               * 00713000
*          MULTIPLE - ADDED TO GET A FULL TRACK PER EXCP.             * 00714000
*                                                                     * 00715000
*        OPTIONS: REVISED TO SUPPORT THE DELETION OF ANY SUBCOMMAND   * 00716000
*        DURING THE PROGRAM GENERATION PROCESS.                       * 00717000
*                                                                     * 00718000
*        USAGE: REWRITTEN TO ADD MORE DATA SET INFORMATION.           * 00719000
*                                                                     * 00720000
*        MEMBER BLDL: PERFORMED FOR EACH SUBCOMMAND WITH A SIMPLE     * 00721000
*        MEMBER NAME SO THAT PDS WILL BE AWARE OF CHANGES TO THE      * 00722000
*        DATA SET FROM OTHER ADDRESS SPACES.                          * 00723000
         EJECT                                                          00724000
****VER 6.3:  ADDED DIALOG DISPLAY MODE:                           **** 00725000
*                                                                     * 00726000
*      FROM STEVE SMITH WITH SECURITY PACIFIC BANK IN GLENDALE, CAL.  * 00727000
*                                                                     * 00728000
*                                                              SS JUL84 00729000
*        ADDED SUPPORT OF DIALOG DISPLAY MODE USING            SS JUL84 00730000
*        A DIALOG TABLE TO DISPLAY PDS OUTPUT                  SS JUL84 00731000
*                                                              SS JUL84 00732000
*                                                                     * 00733000
*        FROM BARB COUTURE WITH DELUXE CHECK PRINTERS IN MINNESOTA:   * 00734000
*        PROFILE NOPREFIX CAUSED A S0C4 FOR DSNAME ALLOCATION AND     * 00735000
*        FILE(FILENAME) ALLOCATION DID NOT WORK IF PROFILE NOPREFIX.  * 00736000
*                                                                     * 00737000
*        FROM JIM MELNYK WITH GREAT-WEST LIFE ASSURANCE CO. IN        * 00738000
*        WINNIPEG, CANADA:  PDS DATA.SET VOL(XXX) OLD DID NOT WORK    * 00739000
*                       BUT PDS DATA.SET OLD VOL(XXX) DID WORK.       * 00740000
*                                                                     * 00741000
*        FROM FRANK PAJERSKI WITH ATARI INCORPORATED IN SUNNYVALE:    * 00742000
*        CERTAIN FOCUS LOAD MODULES GOT S0C7 ABENDS USING HISTORY.    * 00743000
*                                                                     * 00744000
*        FROM ARNOLD CASINGHINO WITH CBT: WHEN PDS IS INVOKED AS A    * 00745000
*        SUBCOMMAND, IT USES THE PRIMARY COMMAND NAME (LIKE EDIT);    * 00746000
*        THIS PREVENTED SPFEDIT IN PDS UNDER EDIT FROM WORKING.       * 00747000
*                                                                     * 00748000
*        FOR THE STAX EXIT FROM RICHARD SCHAFER AT RICE UNIVERSITY:   * 00749000
*          1.  TCLEARQ SHOULD BE ISSUED TO SYNCRONIZE INPUTS.         * 00750000
*          2.  STATUS STOP SHOULD BE ISSUED FOR ANY SUBTASKS.         * 00751000
*          3.  STACK DELETE=ALL IS ISSUED TO FLUSH THE CURRENT STACK. * 00752000
*          4.  THE PUTGET IN THE ATTENTION ROUTINE SHOULD ACCEPT      * 00753000
*              TERMINAL INPUT ONLY.                                   * 00754000
*                                                                     * 00755000
*        FOR THE ESTAE EXIT FROM RICHARD SCHAFER AT RICE UNIVERSITY:  * 00756000
*          1.  STACK DELETE=ALL IS ISSUED TO FLUSH THE CURRENT STACK. * 00757000
*                                                                     * 00758000
*        FROM SAM LEPORE WITH WELLS FARGO BANK IN SAN FRANCISCO:      * 00759000
*        THE PDS200I MESSAGE WAS REDESIGNED TO MAKE IT MORE USEFUL.   * 00760000
*                                                                     * 00761000
*        FROM MARC SCHARE WITH BELL LABORATORIES IN PISCATAWAY, NJ:   * 00762000
*        IF AND HISTORY: ADDED A "SYSMOD" ALIAS FOR THE USER KEYWORD. * 00763000
*                                                                     * 00764000
*        FROM BEN MOORE (FEDERAL EXPRESS):                            * 00765000
*        FIND: ASIS AND CAPS KEYWORDS HAVE BEEN ADDED TO ALLOW        * 00766000
*        THE SPECIFICATION OF LOWER-CASE SEARCH STRINGS.              * 00767000
*                                                                     * 00768000
*        FROM BILL SMITH WITH SYNTEX: ADDED CONTROLS TO SPECIFY       * 00769000
*        THE NUMBER OF MEMBERS IN THE DATA SET TO AVOID SB37          * 00770000
*        ABENDS IN THE COMPRESS SUBCOMMAND.                           * 00771000
*                                                                     * 00772000
*        BACKGROUND USE OF PDS: CONTROL NORECOVER IS MADE A DEFAULT   * 00773000
*        TO PREVENT INADVERTENT RECOVERY AFTER AN ERROR.              * 00774000
*                                                                     * 00775000
*        FROM JIM MELNYK WITH GREAT-WEST LIFE ASSURANCE CO. IN        * 00776000
*        WINNIPEG, CANADA:  CHANGED THE RESERVE/DEQ MAJOR NAME FROM   * 00777000
*        SPFDSN TO SPFEDIT (AS IN PTF UZ65671).                       * 00778000
*                                                                     * 00779000
*        VERIFY: ADDED A MAXIMUM PHYSICAL BLKSIZE MESSAGE.            * 00780000
*                                                                     * 00781000
*        FROM SAM LEPORE WITH WELLS FARGO BANK IN SAN FRANCISCO -     * 00782000
*        COMPARE, DSPRINT, PRINTOFF, REVIEW, SUBMIT AND TSOLIST:      * 00783000
*        PERMIT CLIST INVOCATION INSTEAD OF A TSO COMMAND.            * 00784000
*                                                                     * 00785000
*        SPFEDIT, BROWSE, ISPF AND ISPMODE: AFTER A RETURN COMMAND    * 00786000
*        IN SPF, SUBSEQUENT SPF SUBCOMMANDS WERE TERMINATED WITHOUT   * 00787000
*        PROCESSING.  NOW, THEY ARE REINVOKED AFTER A RETURN KEY IF   * 00788000
*        &RETURNX IS YES.                                             * 00789000
*                                                                     * 00790000
*    SESSION MANAGER PROBLEMS:                                        * 00791000
*        FROM MARSHALL WERNICK WITH ARCO PETROLEUM PRODUCTS IN        * 00792000
*        LOS ANGELES: USING SESSION MANAGER, THE ENTRY TO PDS         * 00793000
*        VIA THE SPF PDS PANEL CAUSED AN S0C4 ABEND.                  * 00794000
*                                                                     * 00795000
*        FROM BILL SMITH WITH SYNTEX: USING SESSION MANAGER, PDS      * 00796000
*        LINE MODE OUTPUT FOLLOWING SPFEDIT OR BROWSE SUBCOMMANDS     * 00797000
*        WERE NOT CAPTURED BY SESSION MANAGER.                        * 00798000
*                                                                     * 00799000
*        FROM CHARLES HOFFMAN WITH GTE LABORATORIES IN                * 00800000
*        WALTHAM, MASS: USING SESSION MANAGER, RESTORE WITH PROMPT    * 00801000
*        DID DOUBLE PROMPTING AND INCORRECT "INVALID SUBCOMMAND"      * 00802000
*        MESSAGES OCCURED FOR FOLLOWING PDS SUBCOMMANDS.              * 00803000
*                                                                     * 00804000
*        FROM JAMES BERRY AT WESTLAKE VILLAGE, CALIF:  WITH           * 00805000
*        SESSION MANAGER, THE SCREEN CLEAR FUNCTION (SUBCOMMAND K)    * 00806000
*        CLEARS THE SESSION MANAGER CONTROL CHARACTERS; NOW IF THE    * 00807000
*        SESSION MANAGER TMP IS IN USE, ONLY A BLANK LINE IS OUTPUT.  * 00808000
*                                                                     * 00809000
*                                                                     * 00810000
****VER 7.0:  ADDED MEMLIST SUBCOMMAND:                            **** 00811000
*                                                                     * 00812000
*      FROM STEVE SMITH WITH SECURITY PACIFIC BANK IN GLENDALE, CAL.  * 00813000
*                                                                     * 00814000
*                                                              SS SEP84 00815000
*        ADDED SUPPORT OF MEMLIST WITH LINE MODE SUBCOMMANDS   SS SEP84 00816000
*                                                              SS SEP84 00817000
*                                                                     * 00818000
*        FROM SAM LEPORE WITH WELLS FARGO:                            * 00819000
*          1.  VERIFY APPLIES TO DATA SETS AND INDIVIDUAL MEMBERS.    * 00820000
*          2.  MEMLIST OR ISPMODE ON THE PRIMARY COMMAND LINE         * 00821000
*              DETERMINES THE INITIAL PROGRAM PROCESSING MODE.        * 00822000
*          3.  THE DEFAULT MEMBER GROUP IS FORMATTED ON THE           * 00823000
*              PDS300A MESSAGE (FIRST SPECIFICATION FOR A LIST).      * 00824000
*                                                                     * 00825000
*        PDS ENTRY PANEL: CHANGED TO ALLOW LINE/ISPMODE/MEMLIST       * 00826000
*        ENTRY MODES.                                                 * 00827000
*                                                                     * 00828000
*        DEFAULT MEMBER GROUP: NOT MODIFIED BY PDS LINE COMMANDS.     * 00829000
*                                                                     * 00830000
*        ISPMODE: THE ENTERED SUBCOMMAND IS ECHOED IN UPPER AND       * 00831000
*        LOWER CASE.                                                  * 00832000
*                                                                     * 00833000
*        IF AND FIND: ADDED THEN(VERIFY) AND ELSE(VERIFY)             * 00834000
*        IF AND FIND: ADDED THEN(MEMLIST) AND ELSE(MEMLIST)           * 00835000
*                                                                     * 00836000
*        CONTROL: OPERANDS CALLED CPULOOP, ABEND, OUTLOOP AND MSGS    * 00837000
*        ARE NOW TESTCPULOOP, TESTABEND, TESTOUTLOOP AND TESTMSGS.    * 00838000
*                                                                     * 00839000
*        ISPMODE: CHKMAX, CMDMAX AND TBLMAX DIALOG CONTROL OPERANDS   * 00840000
*        HAVE BEEN ADDED AS SUGGESTED BY STEVE SMITH WITH SPNB.       * 00841000
*                                                                     * 00842000
*        PDS200I MESSAGE: CHANGED TO ADD NUMBER OF EXTENTS.           * 00843000
*                                                                     * 00844000
*        COMPRESS: CHANGED TO ALLOCATE COMPRESS WORK SPACE BASED      * 00845000
*        ON THE NUMBER OF DIRECTORY BLOCKS IN USE AS SUGGESTED BY     * 00846000
*        JOHN SULLIVAN WITH THE LOMA LINDA MEDICAL CENTER.            * 00847000
*                                                                     * 00848000
*        TSO SUBCOMMAND:                                              * 00849000
*          1.  CHANGED TO INVOKE CLISTS AS SUGGESTED BY               * 00850000
*              SAM LEPORE AND JOHN SULLIVAN.                          * 00851000
*          2.  CHANGED TO OPTIONALLY INVOKE TSOEXEC FOR TSO/E REL 2   * 00852000
*              AS SUGGESTED BY MIKE LOOS WITH DELUXE CHECK PRINTERS.  * 00853000
*                                                                     * 00854000
*        CONTROL: ADDED OPERANDS TO PROVIDE A HARDCOPY OR DATA SET    * 00855000
*        LOG AS SUGGESTED BY BILL SMITH WITH SYNTEX.                  * 00856000
*                                                                     * 00857000
*        PFK SUPPORT: DROPPED DUE TO ITS INCLUSION IN SPF DIALOGS.    * 00858000
*                                                                     * 00859000
*        TIME SUBCOMMAND: ADDED AS SUGGESTED BY ARNOLD CASINGHINO.    * 00860000
*                                                                     * 00861000
*        COMPARE: MODIFIED THE TSO COMMAND TO RETURN OUTPUT LINES     * 00862000
*        TO THE PDS PUTLINE ROUTINE FOR SESSION DISPLAY AND LOGGING.  * 00863000
*                                                                     * 00864000
*        ATTRIB AND IF: ADDED SSI CHANGE AND TESTING CAPABILITY.      * 00865000
*                                                                     * 00866000
*        FIXPDS CHANGES:                                              * 00867000
*          1.  ALLOW FIXPDS USE FOR SEQUENTIAL DATA SETS.             * 00868000
*          2.  ADDED THE MAXSPACE OPERAND TO ALLOW RESTORING OF       * 00869000
*              MEMBERS AFTER A COMPRESS OF THE DATA SET AS SUGGESTED  * 00870000
*              BY JOHN SULLIVAN WITH THE LOMA LINDA MEDICAL CENTER.   * 00871000
*          3.  ADDED THE RELEASE, RELEXTENT AND RELSAVE OPERANDS.     * 00872000
*          4.  REDUCED THE DEFAULT BLOCKSIZES FOR 3350, 3375 AND      * 00873000
*              3380 DISKS.                                            * 00874000
*                                                                     * 00875000
*        SPFEDIT: ADDED THE MACRO KEYWORD FOR ISPF V2 AS SUGGESTED    * 00876000
*        BY MARC SCHARE WITH BELL LABORATORIES IN PISCATAWAY, NJ.     * 00877000
*                                                                     * 00878000
*        3278-5 TERMINALS: IF ISPMODE OR SESSION LOGGING IS ON, PDS   * 00879000
*        OUTPUT LINES ARE LIMITED TO 80 CHARACTERS AS SUGGESTED BY    * 00880000
*        ARNOLD CASINGHINO WITH CBT.                                  * 00881000
*                                                                     * 00882000
*        IF: FIXED A PROBLEM WITH CHANGED AND CREATED KEYWORDS FOR    * 00883000
*        LOAD MEMBER CHECKING AS REPORTED BY JOHN SULLIVAN AT LOMA    * 00884000
*        LINDA (CHECKING ACROSS A YEAR BOUNDARY WAS INCORRECT).       * 00885000
*                                                                     * 00886000
*        TSOEDIT AND EDIT: SUBCOMMAND EDIT WAS RENAMED AS TSOEDIT     * 00887000
*        AND SPFEDIT WAS RENAMED AS EDIT AS SUGGESTED BY STEVE SMITH. * 00888000
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 00889000
         TITLE 'P D S  --  PDS MACROS                          1/15/85' 00890000
         MACRO                                                          00891000
&NAME    ENTER &TYPE                                                    00892000
         LCLC  &LABEL                                                   00893000
&LABEL   SETC  'IHB'.'&SYSNDX'                                          00894000
         AIF   ('&TYPE' EQ 'VALCHECK').VALCK                            00895000
         AIF   ('&TYPE' EQ 'ATTNEXIT').ATTN                             00896000
         AIF   ('&TYPE' EQ '').MAIN                                     00897000
         MNOTE 8,'INVALID TYPE ''&TYPE'''                               00898000
         MEXIT                                                          00899000
.MAIN    ANOP                                                           00900000
&NAME    CSECT                                                          00901000
         SAVE  (14,12),,*                                               00902000
         LCLA  &R                                                       00903000
&R       SETA  0                                                        00904000
.EQU     ANOP                                                           00905000
R&R      EQU   &R                                                       00906000
&R       SETA  &R+1                                                     00907000
         AIF   (&R LT 16).EQU                                           00908000
         LR    R9,R15                                                   00909000
         USING &NAME,R9,R10,R11,R12                                     00910000
         LA    R12,2048                                                 00911000
         LA    R10,2048(R9,R12)                                         00912000
         LA    R11,2048(R10,R12)                                        00913000
         LA    R12,2048(R11,R12)                                        00914000
         MEXIT                                                          00915000
.VALCK   ANOP                                                           00916000
&NAME    CSECT                                                          00917000
         SAVE  (14,12)                                                  00918000
         LR    R8,R15             BASE REGISTER ADDRESS                 00919000
         USING &NAME,R8           BASE REGISTER NOTIFICATION            00920000
         L     R7,4(,R1)          WORK AREA ADDRESS                     00921000
         LM    R9,R12,BASES       RESTORE BASE REGISTERS                00922000
         L     R6,0(R1)           PDE ADDRESS                           00923000
         LA    R15,VALSAVE                                              00924000
         AGO   .CHAIN                                                   00925000
.ATTN    ANOP                                                           00926000
&NAME    SAVE  (14,12)                                                  00927000
         L     R7,8(,R1)                                                00928000
         LM    R9,R12,BASES                                             00929000
         LA    R15,ATTNSAVE                                             00930000
.CHAIN   ST    R13,4(,R15)                                              00931000
         ST    R15,8(,R13)                                              00932000
         LR    R13,R15                                                  00933000
         SPACE 1                                                        00934000
         MEND                                                           00935000
         SPACE 1                                                        00936000
         MACRO TSMSG   -   OUTPUT A STATUS OR ERROR MESSAGE WITH MSGID  00937000
&NAME    TSMSG &NUM                                                     00938000
         AIF   ('&NUM' EQ '(1)' OR '&NUM' EQ '(R1)').CALL               00939000
&NAME    LA    R1,&NUM                                                  00940000
         BAL   R14,TSMSGRT                                              00941000
         MEXIT                                                          00942000
.CALL    ANOP                                                           00943000
&NAME    BAL   R14,TSMSGRT                                              00944000
         MEND                                                           00945000
         SPACE 2                                                        00946000
         MACRO                                                          00947000
&L       $T    &Z,&PF,&RTN,&O,&PCL,&P,&PP,&CR,&HD                       00948000
         LCLC  &NAME                                                    00949000
         AIF   ('&Z' NE '').GEN1                                   @D01
         MNOTE *,'&L, &RTN DISABLED'                               @D01
         MEXIT ,                                                   @D01
.GEN1    ANOP  ,                                                   @D01
&NAME    SETC  '&Z'.' '                                                 00950000
&L       DC    0F'0',CL8'&NAME'                *** SUBCOMMAND NAME      00951000
         DC    X'&PF',AL3(&RTN)                *** OFF, SUBCOMMAND ADDR 00952000
         DC    AL1(&O),AL3(&PCL)               *** FLAGS, PCL ADDRESS   00953000
         DC    AL1(&P),AL3(&PP)                *** FLAGS, PP ADDRESS    00954000
         DC    CL8'&CR'                        *** ATTACHED TSO COMMAND 00955000
         DC    AL2(&HD-ONIX),XL2'FFFF'         *** HELP, AVAILABLE      00956000
.EXIT    MEND                                                           00957000
         SPACE 2                                                        00958000
         MACRO                                                          00959000
&L       $TL   &F,&F2,&TB,&P,&P2,&PMID                         SS NOV84 00960000
&L       DC    AL1(&F),AL1(&F2)                *** FLAGS 1 AND 2        00961000
         DC    AL2(&TB-$TBL)                   *** TABLE OFFSET         00962000
         DC    AL1(&P),AL1(&P2)                *** PROC1,PROC2 SS NOV84 00963000
         DC    AL2(&PMID)                      *** MSGID       SS NOV84 00964000
         MEND                                                           00965000
         SPACE 2                                                        00966000
         MACRO                                                          00967000
&L       $TX   &F,&F2,&TB,&P,&P2,&PMID                         SS NOV84 00968000
&L       DC    AL1(&F+#X),AL1(&F2)             *** FLAGS 1 AND 2        00969000
         DC    AL2(&TB-ISP$TX)                                 SS SEP84 00970000
         DC    AL1(&P),AL1(&P2)                *** PROC1,PROC2 SS NOV84 00971000
         DC    AL2(&PMID)                      *** MSGID       SS NOV84 00972000
         MEND                                                           00973000
         SPACE 2                                                        00974000
         MACRO                                                 SS NOV84 00975000
&L       $TC   &F,&F2,&TB,&P,&P2,&PMID                         SS NOV84 00976000
&L       DC    AL1(&F),AL1(&F2+#C)             *** FLAGS 1     SS NOV84 00977000
         DC    CL2&TB                                          SS NOV84 00978000
         DC    AL1(&P),AL1(&P2)                *** PROC1,PROC2 SS NOV84 00979000
         DC    AL2(&PMID)                      *** MSGID       SS NOV84 00980000
         MEND                                                           00981000
         SPACE 2                                                        00982000
         MACRO                                                          00983000
&NAME    EXIT  &LV=                                                     00984000
         AIF   ('&LV' EQ '').A0                                         00985000
&NAME    LR    R2,R13                         ADDR OF THIS SAVE AREA    00986000
         L     R13,4(,R13)                                              00987000
         AGO   .A1                                                      00988000
.A0      ANOP                                                           00989000
&NAME    L     R13,4(,R13)                                              00990000
.A1      STM   R15,R1,16(R13)                 RETURN REGS 15, 0, 1      00991000
         AIF   ('&LV' EQ '').A2 NOT DYNAMIC STORAGE                     00992000
         FREEMAIN R,LV=&LV,A=(R2)                                       00993000
.A2      ANOP                                                           00994000
         RETURN (14,12),T                                               00995000
         MEND                                                           00996000
         SPACE 2                                                        00997000
         MACRO                                                          00998000
&NAME    MSG   &TEXT                                                    00999000
         LCLA  &A                                                       01000000
&A       SETA  K'&TEXT-2+4                                              01001000
&NAME    DC    AL2(&A,0),C&TEXT              NORMAL MESSAGE             01002000
         MEND                                                           01003000
         SPACE 3                                                        01004000
         MACRO $PUTGET -  OUTPUT A DATA LINE AND GET RESPONSE           01005000
&NAME   $PUTGET  &LINE,&ATTN=                                           01006000
         AIF   ('&LINE' EQ '(1)' OR '&LINE' EQ '(R1)').CALL             01007000
         AIF   ('&LINE'(1,1) EQ '(').R                                  01008000
&NAME    LA    R1,&LINE                                                 01009000
         BAL   R14,$PUTGET                                              01010000
         AGO   .ATTN                                                    01011000
.R       ANOP                                                           01012000
&NAME    LR    R1,&LINE(1)                                              01013000
         BAL   R14,$PUTGET                                              01014000
         AGO   .ATTN                                                    01015000
.CALL    ANOP                                                           01016000
&NAME    BAL   R14,$PUTGET                                              01017000
.ATTN    ANOP                                                           01018000
         AIF   ('&ATTN' EQ '').NOATTN                                   01019000
         B     &ATTN                         EXIT IF ATTENTION OCCURRED 01020000
         AGO   .END                                                     01021000
.NOATTN  NOP   0                             IGNORE ATTENTIONS          01022000
.END     MEND                                                           01023000
         SPACE 2                                                        01024000
         MACRO $PUTLINE -  OUTPUT A DATA LINE                           01025000
&NAME   $PUTLINE &LINE,&ATTN=                                           01026000
         AIF   ('&LINE' EQ '(1)' OR '&LINE' EQ '(R1)').CALL             01027000
         AIF   ('&LINE'(1,1) EQ '(').R                                  01028000
&NAME    LA    R1,&LINE                      ADDRESS OF DATA LINE       01029000
         BAL   R14,$PUTLINE                  INVOKE PUTLINE INTERFACE   01030000
         AGO   .ATTN                                                    01031000
.R       ANOP                                                           01032000
&NAME    LR    R1,&LINE(1)                   ADDRESS OF DATA LINE       01033000
         BAL   R14,$PUTLINE                  INVOKE PUTLINE INTERFACE   01034000
         AGO   .ATTN                                                    01035000
.CALL    ANOP                                                           01036000
&NAME    BAL   R14,$PUTLINE                  INVOKE PUTLINE INTERFACE   01037000
.ATTN    ANOP                                                           01038000
         AIF   ('&ATTN' EQ '').NOATTN                                   01039000
         B     &ATTN                         EXIT IF ATTENTION OCCURRED 01040000
         AGO   .END                                                     01041000
.NOATTN  NOP   0                             IGNORE ATTENTIONS          01042000
.END     MEND                                                           01043000
         SPACE 2                                                        01044000
         MACRO MESSAGE - OUTPUT AN ERROR/STATUS MESSAGE                 01045000
&NAME    MESSAGE &MSG1,&MSG2                                            01046000
         AIF   ('&MSG1' EQ '(1)' OR '&MSG1' EQ '(R1)').MSGDS            01047000
         AIF   ('&MSG1'(1,1) EQ '(').RMSG1                              01048000
         AIF   ('&MSG1' EQ 'MSGTEXT1' AND '&MSG2' EQ '').NOR1           01049000
&NAME    LA    R1,&MSG1                                                 01050000
         AGO   .MSG2                                                    01051000
.NOR1    ANOP                                                           01052000
&NAME    BAL   R14,MESSTXT1                                             01053000
         MEXIT                                                          01054000
.RMSG1   ANOP                                                           01055000
&NAME    LR    R1,&MSG1(1)                                              01056000
         AGO   .MSG2                                                    01057000
.MSGDS   ANOP                                                           01058000
         AIF   ('&MSG2' NE '').SECOND                                   01059000
&NAME    BAL   R14,MESSAGE0                                             01060000
         MEXIT                                                          01061000
.SECOND  ANOP                                                           01062000
&NAME    DS    0H                                                       01063000
.MSG2    ANOP                                                           01064000
         AIF   ('&MSG2' EQ '').NOMSG2 NO SECONDARY MESSAGE              01065000
         AIF   ('&MSG2' EQ '(0)' OR '&MSG2' EQ '(R0)').CALL             01066000
         AIF   ('&MSG2'(1,1) EQ '(').RMSG2                              01067000
         LA    R0,&MSG2                                                 01068000
         AGO   .CALL                                                    01069000
.RMSG2   ANOP                                                           01070000
         LR    R0,&MSG2(1)                                              01071000
.CALL    ANOP                                                           01072000
         BAL   R14,MESSAGE                                              01073000
         AGO   .END                                                     01074000
.NOMSG2  ANOP                                                           01075000
         BAL   R14,MESSAGE0                                             01076000
.END     MEND                                                           01077000
         SPACE 3                                                        01078000
         MACRO                                                          01079000
&L       COND  &OPRAND,&OPRAT                                           01080000
         AIF   ('&L' EQ '').EXIT                                        01081000
         &OPRAND &OPRAT                                                 01082000
.EXIT    MEND                                                           01083000
         SPACE 2                                                        01084000
         MACRO                                                          01085000
&L       CONDIKJ &OPRAT                                                 01086000
         AIF   ('&L' EQ '').EXIT                                        01087000
         IKJNAME &OPRAT                                                 01088000
.EXIT    MEND                                                           01089000
         SPACE 3                                                        01090000
*----------------------------------------------------------------* @D01
*        The ACTR counter is set to a high value because of      * @D01
*        all the AIF/AGO conditional assembly logic added for    * @D01
*        the MVT version.                                        * @D01
*----------------------------------------------------------------* @D01
         ACTR  99999                                               @D01
         SPACE 1                                                   @D01
         GBLC  &VERS                                               @D01
         GBLC  &FIXDATE                                            @D01
         GBLC  &DAUNIT                                             @D01
         GBLC  &TUNIT                                              @D03
         SPACE 1                                                   @D01
         GBLC  &MVSLEV,&CONADEF,&CONVTAM,&CONGLBL,&CONDRNG,&RETURNX     01091000
         GBLB  &MVT                                                @D01
         SPACE 1                                                        01092000
         GBLC  &DB2311,&DB2301,&DB2303,&DB2302,&DB2321,&DB3390     @D01
         GBLC  &DB23051,&DB23052,&DB2314,&DB3330,&DB3340                01093000
         GBLC  &DB3350,&DB3375,&DB33301,&DB3380                         01094000
         SPACE 1                                                        01095000
         GBLC  &UN2311,&UN2301,&UN2303,&UN2302,&UN2321,&UN3390     @D01
         GBLC  &UN23051,&UN23052,&UN2314,&UN3330,&UN3340                01096000
         GBLC  &UN3350,&UN3375,&UN33301,&UN3380                         01097000
         SPACE 1                                                        01098000
         GBLC  &NAB1,&NAB2,&NAB3,&NXS1,&NXS2,&NXS3                      01099000
         GBLC  &NATT,&NALI,&NBRO,&NCHA,&NCAR,&NCMX                      01100000
         GBLC  &NCON,&NDIS,&NDIR,&NDEL,&NDSN,&NDSP,&NEDI                01101000
         GBLC  &NEND,&NEXE,&NFIN,&NFIX,&NFSE,&NKLE,&NHEL                01102000
         GBLC  &NHIS,&NIFX,&NISP,&NISM,&NLIS,&NMAP,&NMEM                01103000
         GBLC  &NMML,&NOPT,&NOUT,&NPAT,&NPDS,&NPRI,&NREC                01104000
         GBLC  &NREN,&NRES,&NREV,&NSPF,&NSUB,&NSCR                      01105000
         GBLC  &NTSO,&NTSE,&NTSL,&NUSA,&NVER                            01106000
         GBLC  &NUT1,&NUT2,&CUT1,&CUT2                         SS NOV84 01107000
         SPACE 1                                                        01108000
         GBLC  &CXS1,&CXS2,&CXS3,&C296                                  01109000
         GBLC  &CBRO,&CCAR,&CCMX,&CDSP,&CEDI,&CEXE                      01110000
         GBLC  &CFIX,&CFSE,&CHEL,&CISP,&CMEN,&CPRI                      01111000
         GBLC  &CREV,&CSUB,&CTSL,&CTSO,&CTSE                            01112000
*                                                              SS JUL84 01113000
*  SPF DIALOG MODE   CONDITIONAL ASSEMBLY VARS                 SS JUL84 01114000
*                                                              SS JUL84 01115000
         GBLC  &SPFSIZE,&SPFMAX,&SPFCKPT,&NMOD                 SS JUL84 01116000
         SPACE 3                                                        01117000
         COPY  PDSGEN70   ***  ESTABLISH THE PDS GLOBAL VALUES SS AUG84 01118000
         SPACE 2                                                        01119000
&CBRO    SETC  'BROWSE'   ***  SPF BROWSE SERVICE NAME                  01120000
&CEDI    SETC  'EDIT'     ***  SPF EDIT SERVICE NAME                    01121000
&CONGLBL SETC  'FSAVEOP'  ***  CONTROL NOSAVETEXT                       01122000
         SPACE 1                                                        01123000
         AIF   ('&MVSLEV' EQ 'MVS038').MVSOK                            01124000
         AIF   ('&MVSLEV' EQ 'MVS12X').MVSOK                            01125000
         AIF   ('&MVSLEV' EQ 'MVS13X').MVSOK                            01126000
         SPACE 3                                                        01127000
         MNOTE 12,'*** MVSLEV -- MVS LEVEL &MVSLEV IS INVALID ***'      01128000
         SPACE 2                                                        01129000
         AGO   .NOGEN                                                   01130000
.MVSOK   ANOP                                                           01131000
         AIF   ('&CISP' EQ '').NOSPF                                    01132000
         AIF   ('&CISP' EQ 'SPF').SMNOTE                                01133000
         AIF   ('&CISP' EQ 'ISPF').SMNOTE                               01134000
         AIF   ('&CISP' EQ 'ISPFV2').SMNOTE                             01135000
         SPACE 3                                                        01136000
         MNOTE 12,'*** CISP -- SPF CONTROL &CISP IS INVALID ***'        01137000
         SPACE 2                                                        01138000
         AGO   .NOGEN                                                   01139000
.NOSPF   ANOP                                                           01140000
&CISP    SETC  'NO SPF'                                                 01141000
&NBRO    SETC  ''          *** NULLIFY THE SPF SUBCOMMANDS -- NO SPF    01142000
&NEDI    SETC  ''          *** NULLIFY THE SPF SUBCOMMANDS -- NO SPF    01143000
&NISP    SETC  ''          *** NULLIFY THE SPF SUBCOMMANDS -- NO SPF    01144000
&NSPF    SETC  ''          *** NULLIFY THE SPF SUBCOMMANDS -- NO SPF    01145000
.SMNOTE  ANOP                                                           01146000
         SPACE 3                                                        01147000
         MNOTE *,'&CISP INTERFACE CODE WILL BE GENERATED'               01148000
         SPACE 2                                                        01149000
.NOERR   ANOP                                                           01150000
         SPACE 5                                                        01151000
*** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** 01152000
***                                                                 *** 01153000
***    HISTORICAL SECTION:                                          *** 01154000
***                                                                 *** 01155000
***                                                                 *** 01156000
***     VERSION   LAST MOD   SIZE   IN K   # SUBS   SOURCE   HELP   *** 01157000
***     =======   ========   ====   ====   ======   ======   ====   *** 01158000
***                                                                 *** 01159000
***      PDS30    1/28/80    47A0    18K     19      4851     512   *** 01160000
***                                                                 *** 01161000
***      PDS45    8/20/81    45A8    18K     22      5037     517   *** 01162000
***                                                                 *** 01163000
***      PDS52   11/08/82    6090    25K     25      6253    1123   *** 01164000
***                                                                 *** 01165000
***      PDS53    4/06/83    9610    38K     28      8978    1502   *** 01166000
***                                                                 *** 01167000
***      PDS60    9/30/83    CF28    52K     32     12068    1997   *** 01168000
***                                                                 *** 01169000
***      PDS61    2/06/84    E948    59K     34     13496    2270   *** 01170000
***                                                                 *** 01171000
***      PDS62    7/31/84   11F58    72K     39     16062    3676   *** 01172000
***                                                                 *** 01173000
***      PDS63   10/08/84   12DB0    76K     40     17122    3782   *** 01174000
***                                                                 *** 01175000
***      PDS70    1/20/85   16CD8    92K     41     18185    4112   *** 01176000
***                                                                 *** 01177000
***                                                                 *** 01178000
*** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** 01179000
         TITLE 'P D S  --  PDS PROGRAM ENTRY                   1/15/85' 01180000
PDSMAIN  ENTER                                                          01181000
         SPACE 1                                                        01182000
         LR    R6,R1                SAVE ADDR OF CPPL                   01183000
         USING WORKAREA,R7          WORK AREA DSECT                     01184000
         AIF ('&CISP' EQ 'NO SPF').MA00020                         @D01
         L     R1,0(,R1)            POINT TO PASSED PARAMETER LIST      01185000
         CLC   2(2,R1),=C'++'       SPF ADDRESS MARKER FROM PDS?        01186000
         BNE   GETMAIN              NO, NOT AN ENTRY FROM SPF           01187000
         CVB   R7,4(,R1)            WORK AREA POINTER                   01188000
         L     R0,PDSENTRY          NUMBER OF ENTRIES                   01189000
         A     R0,=F'1'                                                 01190000
         ST    R0,PDSENTRY                                              01191000
         C     R0,=F'1'             FIRST SPF ENTRY?                    01192000
         BH    RETURN2              NO, END STATEMENT                   01193000
         LA    R15,SPFMAIN          SPF REGISTER SAVE AREA              01194000
         ST    R15,8(,R13)                                              01195000
         ST    R13,4(,R15)          CHAIN TO SECONDARY SAVEAREA         01196000
         LR    R13,R15                                                  01197000
         MVI   ISPFTEXT+1,12        LENGTH OF COUNT AND "ISPF    "      01198000
         NI    FLAGSFF,FF-FSPFERR   SPF ERROR OFF                       01199000
         OI    FLAGSFF,FSPFCALL     SPF CALL ACTIVE                     01200000
         MVC   STAEPARM(4),STAELIST   RESET THE ESTAE EXIT              01201000
         ESTAE STAEEXIT,CT,PARAM=(R7),MF=(E,STAEPARM)                   01202000
         B     RESTART0             REALLOCATE THE DATA FILES           01203000
.MA00020 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS WORK AREA INITIALIZATION        1/15/85' 01204000
GETMAIN  L     R5,WORKSIZE                                              01205000
         AIF   (&MVT).MA00040                                      @D01
         LA    R0,0(,R5)                CLEAR THE TOP BYTE              01206000
         GETMAIN RU,LV=(0),SP=1,BNDRY=PAGE                              01207000
         AGO   .NA00040                                            @D01
.MA00040 ANOP  ,                                                   @D01
         GETMAIN R,LV=(R5)              Get subpool 1 work area    @D01
.NA00040 ANOP  ,                                                   @D01
         LR    R7,R1                    WORK AREA ADDRESS               01208000
         LR    R4,R1                    CLEAR WORK AREA                 01209000
         SR    R1,R1                    NULL SOURCE                     01210000
         MVCL  R4,R0                    FILL WITH PAD 0 FROM R1(0:7)    01211000
         SPACE 1                                                        01212000
         L     R1,0(,R6)                POINT TO PASSED PARAMETER LIST  01213000
         AIF ('&CISP' EQ 'NO SPF').MA00060                         @D01
         CLI   2(R1),X'40'              INVOKED AS A SPF DIALOG?        01214000
         BNH   INITADDR                 NO, BRANCH                      01215000
*                                                                       01216000
***   PDS HAS BEEN INVOKED AS A SPF DIALOG  -- TO ALLOW THE USE OF      01217000
*     NORMAL TSO SERVICES, A CPPL MUST BE BUILT.                        01218000
*     A.  GETMAIN AN AREA FOR CREATED CONTROL BLOCKS IN SUBPOOL 78      01219000
*         (THE SUBPOOL TSO USES FOR ECT I/O SERVICE AND WORK AREAS)     01220000
*     B.  COPY IN THE SYSTEM UPT AND PSCB ADDRESSES                     01221000
*     C.  CREATE A TSO COMMAND BUFFER FROM THE INPUT PARAMETERS         01222000
*     D.  CREATE AN ECT AREA                                            01223000
*         1.  THE ECT POINTS TO AN I/O SERVICE AREA                     01224000
*         2.  THE I/O SERVICE AREA POINTS TO AN I/O WORK AREA WHICH     01225000
*             IS INITIALLY 32 BYTES LONG.                               01226000
*     E.  A METHOD OF LOCATING THE ACTUAL TSO ECT HAS BEEN DEVELOPED.   01227000
*         IN A FOLLOWING RELEASE OF PDS, THE CREATED ECT AREA WILL      01228000
*         BE DELETED; FOR NOW, THE LOCATED ECT IS ACTUALLY USED.        01229000
*     F.  AT PROGRAM END, CLEAN UP THE OBTAINED AREA                    01230000
*         1.  IF THE I/O WORK AREA WAS FREED AND EXPANDED, RELEASE      01231000
*             THE NEW I/O WORK AREA.                                    01232000
*         2.  RELEASE THE OBTAINED SUBPOOL 78 CONTROL BLOCK AREA.       01233000
         SPACE 1                                                        01234000
         OI    FLAGSFF,FSPFDIAL+FSPFOPT6  SET APPROPRIATE SPF FLAGS     01235000
         MVI   SUBPDIAL,78              GETMAIN SUBPOOL                 01236000
         LA    R0,16+96+64+16+32        GETMAIN AREA SIZE               01237000
         ICM   R0,B'1000',SUBPDIAL      GETMAIN SUBPOOL                 01238000
         GETMAIN R,LV=(0)                                               01239000
         XC    0(16+96+64+16+32,R1),0(R1)                               01240000
         STCM  R1,B'0111',SUBPDIAL+1    CREATED CPPL START              01241000
         LA    R2,16(,R1)               CREATED CBUF START              01242000
         LA    R3,96(,R2)               CREATED ECT START               01243000
         LA    R4,64(,R3)               CREATED I/O SERVICE AREA        01244000
         LA    R5,16(,R4)               CREATED I/O WORK AREA           01245000
         ST    R2,CPPLCBUF-CPPL(,R1)    START OF CBUF                   01246000
         ST    R3,CPPLECT-CPPL(,R1)     START OF ECT                    01247000
         MVI   0(R5),X'80'              MARK END OF THE LIST            01248000
         ST    R5,0(,R4)                FIRST I/O WORK ELEMENT          01249000
         ST    R5,4(,R4)                LAST USED I/O WORK ELEMENT      01250000
         MVC   8(2,R4),=H'32'           INITIAL I/O WORK AREA LENGTH    01251000
         L     R5,16                    --> CVT                         01252000
         L     R5,0(,R5)                --> TCB WORDS                   01253000
         L     R5,4(,R5)                --> TCB                         01254000
         L     R5,180(,R5)              --> JSCB                        01255000
         L     R5,264(,R5)              --> PSCB                        01256000
         ST    R5,CPPLPSCB-CPPL(,R1)                                    01257000
         L     R5,52(,R5)               --> UPT                         01258000
         ST    R5,CPPLUPT-CPPL(,R1)                                     01259000
         MVC   ECTPCMD-ECT(8,R3),BLANKS CLEAR THE PRIMARY COMMAND       01260000
         MVC   ECTSCMD-ECT(8,R3),BLANKS CLEAR THE SECONDARY COMMAND     01261000
         ST    R4,ECTIOWA-ECT(,R3)      START OF THE I/O SERVICE AREA   01262000
         L     R15,0(,R6)               START OF THE PARM AREA          01263000
         LR    R6,R1                    POINT TO THE CREATED CPPL       01264000
         LH    R5,0(,R15)               PARM LENGTH                     01265000
         LA    R1,4(,R5)                                                01266000
         STH   R1,0(,R2)                CBUF STRING LENGTH              01267000
         BCTR  R5,0                     MACHINE STRING LENGTH           01268000
         MVC   4(*-*,R2),2(R15)         <<EXECUTED>>                    01269000
         EX    R5,*-6                   MOVE IN THE PARM STRING         01270000
         LA    R15,4(,R2)               PREPARE FOR STRING SCAN         01271000
         LR    R14,R15                                                  01272000
         SPACE 1                                                        01273000
         LA    R15,1(,R15)              FIND                            01274000
         CLI   0(R15),X'40'                 FIRST                       01275000
         BNE   *-8                               NON-BLANK              01276000
         SPACE 1                                                        01277000
         LR    R5,R15                                                   01278000
         SR    R5,R14                   LENGTH OF PDS PROGRAM NAME      01279000
         BCTR  R5,0                     MACHINE LENGTH                  01280000
         MVC   ECTPCMD-ECT(*-*,R3),4(R2)  <<EXECUTED>>                  01281000
         EX    R5,*-6                   MOVE IN THE PDS PROGRAM NAME    01282000
         SPACE 1                                                        01283000
         LA    R15,1(,R15)              FIND                            01284000
         CLI   0(R15),X'40'                 NEXT                        01285000
         BE    *-8                              BLANK                   01286000
         SPACE 1                                                        01287000
         SR    R15,R14                                                  01288000
         STH   R15,2(,R2)               OFFSET TO OPERANDS              01289000
         MVI   ECTSWS2-ECT(R3),ECTDEFCS DEFAULT DELETE CHARACTERS USED  01290000
         LOAD  EP=ISPLINK               ADDRESS OF SPF INTERFACE MODULE 01291000
         ST    R0,ISPLINK               SAVE ADDRESS FOR LATER          01292000
*        BAL   R2,CLEAR1                TURN OFF FULL-SCREEN MODE       01293000
         SPACE 3                                                        01294000
         NOP   INITADDR                   ZAP FOR TESTING               01295000
*        L     R2,16                   ** CHECK FOR TSO/E RELEASE 2     01296000
*        ICM   R2,B'1111',X'9C'(R2)       --> LOGON WORK AREA?          01297000
*        BZ    FECTSTD                        NO, BRANCH                01298000
*        ICM   R2,B'1111',X'20'(R2)       --> ECT?                      01299000
*        BNZ   FECTUPD                        YES, BRANCH               01300000
         SPACE 1                                                        01301000
FECTSTD  L     R2,X'21C'               ** PRE-TSO/E RELEASE 2 SYSTEM    01302000
         L     R2,X'7C'(,R2)              --> FIRST JSTCB               01303000
         L     R2,X'88'(,R2)              --> DAUGHTER TCB              01304000
         L     R2,X'50'(,R2)              --> IKJEFT01 REGISTER 8       01305000
         L     R2,X'2C'(,R2)              --> ECT                       01306000
         SPACE 1                                                        01307000
FECTUPD  L     R1,SUBPDIAL             ** UPDATE THE ECT ADDRESS        01308000
         ST    R2,CPPLECT-CPPL(,R1)       NEW ECT POINTER               01309000
         MVC   ECTPCMD-ECT(8+8,R2),ECTPCMD-ECT(R3)                      01310000
.MA00060 ANOP  ,                                                   @D01
         SPACE 3                                                        01311000
INITADDR LM    R2,R4,CPPLUPT-CPPL(R6)   INITIALIZE ADDRUPT,             01312000
         L     R5,CPPLCBUF-CPPL(R6)       ADDRPSCB, ADDRECT,            01313000
         STM   R2,R6,ADDRUPT              ADDRCBUF AND ADDRCPPL         01314000
         MVC   PDSNAME,ECTPCMD-ECT(R4)  SAVE THE PDS COMMAND NAME       01315000
         CLI   ECTSCMD-ECT(R4),X'40'      IS PDS A SUBCOMMAND?          01316000
         BE    INITADD2                   NO, BRANCH                    01317000
         CLC   ECTSCMD-ECT(3,R4),=C'GO '  GO (UNDER TEST)?              01318000
         BE    INITADD2                   YES, BRANCH                   01319000
         CLC   ECTSCMD-ECT(4,R4),=C'END ' RUN (UNDER TEST)?             01320000
         BE    INITADD2                   YES, BRANCH                   01321000
         MVC   PDSNAME,ECTSCMD-ECT(R4)    SAVE THE PDS COMMAND NAME     01322000
         SPACE 1                                                        01323000
*----------------------------------------------------------------* @D01
*        Find length of PDS command name.                          @D01
*----------------------------------------------------------------* @D01
INITADD2 DS    0H                                                  @D01
         LA    R1,L'PDSNAME-1           Initialize loop count      @D01
INITAD2A LA    R15,PDSNAME(R1)          Point to last character    @D01
         CLI   0(R15),C' '              Is it a blank?             @D01
         BNE   INITAD2B                 No, end of string found    @D01
         BCT   R1,INITAD2A              Back to look at previous   @D01
INITAD2B LA    R1,1(,R1)                Adjust for actual length   @D01
         STC   R1,PDSNAML               Save name length           @D01
         SPACE 1                                                   @D01
*  SET DEFAULTS FOR CONTROL --                                     @D01 01324000
         OI    FLAGSGG,&CONGLBL         SET DEFAULT GLOBAL VARIABLES    01325000
         OI    FLAGSJJ,&CONADEF         SET DEFAULT ALLOCATION MSG      01326000
         AIF   (&MVT).MA00080                                      @D01
         TM    ECTSWS-ECT(R4),ECTBKGRD  BACKGROUND MODE?                01327000
         BNO   INITADD3                 NO, BRANCH                      01328000
         OI    FLAGSEE,FBKGRND          YES, SET A FLAG FOR LATER       01329000
         OI    FLAGSGG,FRECVCON         YES, NO RECOVERY IS A DEFAULT   01330000
.MA00080 ANOP  ,                                                   @D01
         SPACE 1                                                        01331000
INITADD3 STM   R9,R12,BASES             SAVE BASE REGISTERS             01332000
         MVC   BLDLLIST,BLDLPARM        BLDL NUMBER OF MEMBERS & LENGTH 01333000
         ST    R7,8(,R13)               CHAIN                           01334000
         ST    R13,4(,R7)                    SAVE                       01335000
         LR    R13,R7                            AREAS                  01336000
         SPACE 1                                                        01337000
         L     R5,WORKBUFF                                              01338000
         AIF   (&MVT).MA00100                                      @D01
         LA    R0,0(,R5)                CLEAR THE TOP BYTE              01339000
         GETMAIN RU,LV=(0),SP=1,BNDRY=PAGE                              01340000
         AGO   .NA00100                                            @D01
.MA00100 ANOP  ,                                                   @D01
         GETMAIN R,LV=(R5)                                         @D01
.NA00100 ANOP  ,                                                   @D01
         L     R0,=F'32768'             MAXIMUM BLOCKSIZE               01341000
         ST    R1,IOBUFF1               INPUT BUFFER 1                  01342000
         AR    R1,R0                                                    01343000
         ST    R1,IOBUFF2               INPUT BUFFER 2                  01344000
         AR    R1,R0                                                    01345000
         ST    R1,IODIR1                FIRST DIR IOAREA                01346000
         AR    R1,R0                                                    01347000
         ST    R1,IODIR2                SECOND DIR IOAREA               01348000
         SPACE 1                                                        01349000
         LA    R1,2048(,R7)                                             01350000
         LA    R1,2048(,R1)             POINT TO DMEMAREA (MEMBER LIST) 01351000
         ST    R1,PMEMMIN               FIRST ELEMENT OF THE LIST       01352000
         LA    R0,TSMSGWRK-WORKAREA-4096(R1)  POINT TO TSMSGWRK         01353000
         SH    R1,=H'20'                                                01354000
         ST    R1,PMEMMAX               LAST ELEMENT OF THE LIST -20    01355000
         AIF   (&MVT).MA00110                                      @D01
         ST    R0,MTEXTRCT              SAVE EXTRACT ADDRESS            01356000
         MVI   MTEXTRCT,124             MAXIMUM TEXT LENGTH             01357000
.MA00110 ANOP  ,                                                   @D01
         GTSIZE
         STM   R0,R1,PAGESIZE           LINES/SCREEN                    01359000
*        ST    R1,LINESIZE              CHARACTERS/LINE                 01360000
         SPACE 1                                                        01361000
         MVC   STAEPARM(4),STAELIST     SET A ESTAE EXIT                01362000
         ESTAE STAEEXIT,CT,PARAM=(R7),MF=(E,STAEPARM)                   01363000
         SPACE 1                                                        01364000
         LA    R14,MTCSECTP            START OF MESSAGE DESCRIPTOR      01365000
         L     R15,ADDRCPPL            START OF THE CPPL                01366000
         LA    R0,ATTNECB              ECB TO USE                       01367000
         STM   R14,R0,MTPLPTR          INITIALIZE IKJEFF02 FIELDS       01368000
         AIF   (&MVT).MA00120                                      @D01
         OI    MTHIGH,X'80'            STANDARD LINKAGE                 01369000
.MA00120 ANOP  ,                                                   @D01
         OI    MTSW1,MTPUTLSW+MTJOBISW MESSAGE -- PUTLINE AND COMPRESS  01370000
         MVI   MTMSGID,C'L'            MESSAGE IDENTIFIER (FIRST BYTE)  01371000
         LA    R1,INSERT#1             ADDRESS OF INSERT 1              01372000
         ST    R1,MTADDR-1             START OF INSERT INFORMATION      01373000
         MVI   MTHIGHL,8               LENGTH OF THE STANDARD INSERT    01374000
         LA    R1,INSERT#2             ADDRESS OF INSERT 2              01375000
         ST    R1,MTADDR+4-1           START OF INSERT INFORMATION      01376000
         MVI   MTHIGHL+4,8             LENGTH OF THE STANDARD INSERT    01377000
         TITLE 'P D S  --  PDS SERVICE ROUTINE ADDRESSES       1/15/85' 01378000
*                                                                       01379000
*    LOCATE THE TSO SERVICE ROUTINES AND THE DISK ADDRESS CONVERTERS    01380000
*                                                                       01381000
         LA    R2,ADDRPUTL              FIRST SERVICE ROUTINE ADDRESS   01382000
         LA    R3,MODULEN               FIRST LOAD ADDRESS              01383000
         SPACE 1                                                        01384000
SERVLOOP DS    0H                       Init service routines      @D01
         XR    R0,R0                    Clear offset register      @D01
         ICM   R0,B'0011',0(R3)         Get CVT offset for routine @D01
         BZ    SERVLOAD                 No offset, perform load    @D01
         L     R1,CVTPTR                Get base address of CVT    @D01
         AR    R1,R0                    Build CVT address of field @D01
         ICM   R0,B'1111',0(R1)         ANY PRELOADED ADDRESS?          01387000
         BNZ   SERVCVTA                 YES, BRANCH                     01388000
SERVLOAD DS    0H                       Load service routine       @D01
***      XC    PARMLIST(12),PARMLIST    CLEAR THE PARMLIST AREA         01389000
         LOAD  EPLOC=2(R3)  ***,SF=(E,PARMLIST)                         01390000
         MVI   0(R2),X'D6'              MARK TO DELETE LATER            01391000
         SPACE 1                                                        01392000
SERVCVTA STCM  R0,B'0111',1(R2)         UPDATE THE ADDRESS              01393000
         LA    R2,4(,R2)                NEXT SERVICE ADDRESS            01394000
         LA    R3,10(,R3)               NEXT MODULES ADDRESS            01395000
         CLI   0(R3),X'FF'              END OF MODULES?                 01396000
         BNE   SERVLOOP                 NO, BRANCH                      01397000
         SPACE 2                                                        01398000
         L     R2,ADDRPSCB              ADDRESS OF THE PSCB             01399000
         MVC   PARMLIST(4),ENQSTEP      SET OPTION BITS FOR ENQ         01400000
         ENQ   (SPFUSER,PSCBUSER-PSCB(R2),E,7,STEP),RET=TEST,          X01401000
               MF=(E,PARMLIST)          CHECK FOR SPF ENQ               01402000
         SPACE 1                                                        01403000
         LTR   R15,R15                  SPF ALREADY INITIALIZED?        01404000
         BZ    PRIM00                   NO, BRANCH                      01405000
         XI    FLAGSFF,FSPFOPT6         YES, INVERT THE OPTION 6 FLAG   01406000
         TM    FLAGSFF,FSPFDIAL         DIALOG ALREADY?                 01407000
         BO    *+8                      YES, BRANCH                     01408000
         BAL   R2,CLEAR1                NO, WAKE UP SESSION MANAGER     01409000
         TITLE 'P D S  --  PDS PRIMARY SUBCOMMAND CHECK        1/15/85' 01410000
*                                                                       01411000
*     GET THE DATA SET NAME AND ANY SUBCOMMAND FROM THE COMMAND LINE    01412000
*                                                                       01413000
         SPACE 1                                                        01414000
PRIM00   L     R2,ADDRCBUF         COMMAND BUFFER                       01415000
         LH    R3,0(,R2)           TOTAL COMMAND LENGTH                 01416000
         LR    R1,R3               TOTAL COMMAND LENGTH                 01417000
         BCTR  R1,0                MACHINE LENGTH                       01418000
         LA    R14,FIRST4K         BASE FOR RECALLST                    01419000
         MVC   RECALLST-FIRST4K(*-*,R14),0(R2) <<EXECUTED>>             01420000
         EX    R1,*-6              SAVE PREVIOUS SUBCOMMAND             01421000
         XC    RECALLST-FIRST4K(2,R14),=F'0'                            01422000
         SPACE 1                                                        01423000
         LH    R4,2(,R2)           OFFSET TO OPERANDS                   01424000
         LA    R4,4(,R4)           PLUS COUNT BYTES                     01425000
         LA    R2,0(R2,R4)         START OF OPERANDS                    01426000
         SR    R3,R4               BYTES LEFT TO SCAN - ANY?            01427000
         BNP   PRIM90              NO, BRANCH                           01428000
         SPACE 1                                                        01429000
PRIM10   OI    0(R2),X'40'         UPPER-CASE THE OPERANDS              01430000
         CLI   0(R2),X'40'         BLANK?                               01431000
         BE    PRIM20              YES, BRANCH                          01432000
         LA    R2,1(,R2)           NO, TRY THE NEXT ONE                 01433000
         BCT   R3,PRIM10                                                01434000
         B     PRIM90              NOT FOUND, BRANCH                    01435000
         SPACE 1                                                        01436000
PRIM20   OI    0(R2),X'40'         UPPER-CASE THE OPERANDS              01437000
         LA    R5,PRIMOPTN-2       PDS VALID KEYWORD TABLE START -2     01438000
         CLI   0(R2),X'40'         BLANK?                               01439000
         BNE   PRIM30              NO, BRANCH                           01440000
         LA    R2,1(,R2)           YES, TRY THE NEXT ONE                01441000
         BCT   R3,PRIM20                                                01442000
         B     PRIM90              NOT FOUND, BRANCH                    01443000
         SPACE 1                                                        01444000
PRIM30   LA    R5,2(,R5)           NEXT VALID KEYWORD ENTRY             01445000
         CLI   0(R5),X'FF'         END OF KEYWORD TABLE?                01446000
         BE    PRIM40              YES, FOUND A SUBCOMMAND              01447000
         CLC   0(1,R2),0(R5)       FIRST CHARACTER MATCH?               01448000
         BNE   PRIM30              NO, CONTINUE LOOPING                 01449000
         SPACE 1                                                        01450000
         C     R3,=F'1'            ANOTHER CHARACTER?                   01451000
         BNH   PRIM90              NO, NO SUBCOMMAND ADDED              01452000
         OI    1(R2),X'40'         UPPER-CASE THE NEXT CHARACTER        01453000
         CLC   1(1,R2),1(R5)       MATCH SECOND CHARACTER TOO?          01454000
         BE    PRIM10              YES, --NOT A SUBCOMMAND--            01455000
         CLI   1(R2),X'40'         SECOND CHARACTER A BLANK?            01456000
         BE    PRIM10              YES, --NOT A SUBCOMMAND--            01457000
         CLI   1(R2),C'('          PARENTHESIS FOLLOWING V (FOR VOL)?   01458000
         BE    PRIM10              YES, --NOT A SUBCOMMAND--            01459000
         EJECT                                                          01460000
PRIM40   LA    R0,256              COUNT OF SUBCOMMAND CHARACTERS       01461000
         ICM   R0,B'1000',=X'01'   SUBPOOL 1                            01462000
         GETMAIN R,LV=(0)                                               01463000
         MVI   0(R1),X'40'         BLANK THE                            01464000
         MVC   1(255,R1),0(R1)              SUBCOMMAND STORAGE          01465000
         XC    0(4,R1),0(R1)       CLEAR THE FIRST WORD                 01466000
         MVI   0(R1),1             LENGTH=1*256                         01467000
         ST    R1,SUBCMNDP         SAVE THE STORAGE POINTER             01468000
         SPACE 1                                                        01469000
PRIM42   OC    4(1,R1),0(R2)       MOVE AND UPPER-CASE THE CHARACTER    01470000
         MVI   0(R2),X'40'         BLANK THE COMMAND LINE CHARACTER     01471000
         LA    R1,1(,R1)                                                01472000
         LA    R2,1(,R2)                                                01473000
         BCT   R3,PRIM42                                                01474000
         SPACE 3                                                        01475000
PRIM90   ICM   R1,B'1111',SUBCMNDP ADDRESS OF SUBCOMMAND?               01476000
         AIF ('&CISP' EQ 'NO SPF').MA00140                         @D01
         BZ    PRIM92              NO - ZERO, BRANCH                    01477000
         CLC   4(4,R1),$ISM        ISPMODE?                             01478000
         BE    PRIM98              YES, BRANCH                          01479000
         CLC   4(4,R1),$MML        MEMLIST?                             01480000
         BE    PRIM98              YES, BRANCH                          01481000
PRIM92   TM    FLAGSFF,FSPFDIAL    DIALOG ALREADY?                      01482000
         BNO   PRIM96              NO, DO PROGRAM IDENTIFIER            01483000
         LA    R0,=CL8'CONTROL'    FIRST PARAMETER                      01484000
         LA    R1,=CL8'DISPLAY'    SECOND PARAMETER                     01485000
         LA    R2,=CL8'SM     '    THIRD PARAMETER                      01486000
         LA    R3,=F'1'            FOURTH PARAMETER                     01487000
         STM   R0,R3,MSGTEXT2      SAVE ADDRESSES                       01488000
         OI    MSGTEXT2+12,X'80'   LAST                                 01489000
         LA    R1,MSGTEXT2             PARAMETER                        01490000
         L     R15,ISPLINK                                              01491000
         BALR  R14,R15             LET ISPF KNOW                        01492000
.MA00140 ANOP  ,                                                   @D01
         SPACE 2                                                        01493000
PRIM96   MVC   INSERT#1(8),PDSNAME                                      01494000
         MVC   MTLEN,PDSNAML       Set insert length               @D01
         TSMSG L100$1                                                   01495000
         MVI   MTLEN,8             Restore standard length         @D01
         MESSAGE MSGBLANK          ONE BLANK LINE                       01496000
         SPACE 2                                                        01497000
PRIM98   MVC   ##SUBCOM(PTW),$CHA  PCL FOR DATA SET NAME                01498000
         L     R15,=A(PARSE)       PARSE ADDRESS                        01499000
         BALR  R14,R15             CALL PARSE                           01500000
         B     EXIT12N             ERROR EXIT                           01501000
         SPACE 2                                                        01502000
         ICM   R1,B'1111',SUBCMNDP    ADDRESS OF SUBCOMMAND?            01503000
         ST    R1,ADDRCBUF                                              01504000
         BZ    PRIM99                 NO - ZERO, BRANCH                 01505000
         OI    FLAGSBB,FCMD+FONESHOT  YES, INDICATE ONE SUBCOMMAND ONLY 01506000
         B     RESTART0                    AND SKIP THE PROGRAM MESSAGE 01507000
         SPACE 1                                                        01508000
PRIM99   L     R1,$DSN+8           ALLOCATION STATUS ROUTINE            01509000
         ST    R1,##ADRCMD         EXECUTED AFTER OPEN OF DATA SET      01510000
         MVI   ##ADRCM#,CONTINUE   FLAG TO CONTINUE                     01511000
         TITLE 'P D S  --  PDS DATA SET INITIALIZATION         1/15/85' 01512000
RESTART0 DS    0H                  ** ALLOCATE OR REALLOCATE DATA SET   01513000
         SPACE 1                                                        01514000
         MVC   DSPALLOC,DSPREQST   SET INITIAL DISPOSITION SHR/OLD      01515000
         SPACE 2                                                        01516000
         L     R15,=A(ALLOCATE)    ALLOCATION ROUTINE ADDRESS           01517000
         XC    RECOVER,RECOVER     CANNOT RECOVER - NOT INITIALIZED YET 01518000
         BALR  R14,R15             ALLOCATE THE DATA SET                01519000
         B     EXIT12N             ALLOCATION UNSUCCESSFUL              01520000
         SPACE 1                                                        01521000
RESTART2 MVC   INDCB(LEXCPDCB),EXCPDCB MOVE PATTERN DCB                 01522000
         MVC   STOWDCB(LSAMDCB),SAMDCB ALSO FOR STOW OPERATIONS         01523000
         MVC   DCBDDNAM-IHADCB+INDCB,DDNAME                             01524000
         MVC   DCBDDNAM-IHADCB+STOWDCB,DDNAME                           01525000
         MVC   DCBDSORG-IHADCB+STOWDCB(1),DSORG                         01526000
         TM    DSORG,DS1DSGPO                    DSORG=PO?              01527000
         BO    *+8                               YES, BRANCH            01528000
         MVI   DCBDSORG-IHADCB+STOWDCB,DS1DSGPS  NO, USE DSORG=PS       01529000
         SPACE 2                                                        01530000
RESTART4 MVI   OPENLIST,X'00'      ** REOPEN THE DATA SET          **   01531000
         MVI   OPENLIST+4,X'80'                                         01532000
         XC    RECOVER,RECOVER     CANNOT RECOVER - NOT INITIALIZED YET 01533000
         XC    BLKSI(2),BLKSI                                           01534000
         OPEN  (STOWDCB,INPUT,INDCB,INPUT),MF=(E,OPENLIST)              01535000
         SPACE 1                                                        01536000
         MVI   OPENLIST,X'80'                                           01537000
         CLOSE (STOWDCB),MF=(E,OPENLIST)       OPENED FOR DCB EXIT ONLY 01538000
         SPACE 1                                                        01539000
         TM    DCBOFLGS-IHADCB+INDCB,DCBOFOPN  DCB OPEN?                01540000
         BNO   EXIT12O                         NO, QUIT                 01541000
         SPACE 2                                                        01542000
         NI    FLAGSCC,FF-FBLDLOK              BLDL IS INVALID NOW      01543000
         EJECT                                                          01544000
         L     R1,DCBDEBAD-IHADCB+INDCB        DEB ADDRESS              01545000
         MVC   NUMEXT+1(1),DEBNMEXT(R1)        NUMBER OF D.A. EXTENTS   01546000
         L     R4,DEBUCBAD(,R1)                ADDRESS OF FIRST UCB     01547000
         ST    R4,UCBADDR                      ADDRESS OF FIRST UCB     01548000
         MVC   BYTEUCB+1(1),UCBTYP+3(R4)       SAVE THE UCB DEVICE TYPE 01549000
         CLI   VOLALLOC,X'40'                  ANY VOLUME DISCOVERED?   01550000
         BNE   RESTART5                        YES, OBTAIN IS DONE      01551000
         MVC   VOLALLOC,UCBVOLI(R4)            SAVE VOLUME NAME USED    01552000
         L     R14,OBTAIN                      OBTAIN FLAGS             01553000
         LA    R15,DSNAME                      ADDRESS OF DSNAME        01554000
         LA    R0,VOLALLOC                     VOLUME SERIAL            01555000
         LA    R1,DS1FMTID                     OUTPUT START ADDRESS     01556000
         STM   R14,R1,PARMLIST                 SAVE CAMLIST PARAMETERS  01557000
         OBTAIN PARMLIST                       GET THE FORMAT 1 DSCB    01558000
         LTR   R15,R15                         SUCESSFUL OBTAIN?        01559000
         BZ    RESTART5                        YES, BRANCH              01560000
         SPACE 1                                                        01561000
*     IF THE DSNAME IS AN ALIAS ENTRY IN A VSAM CATALOG, A LOCATE       01562000
*     WILL PUT THE TRUE NAME IN THE DSNAME FIELD -- ISSUE A LOCATE,     01563000
*     AND TRY THE OBTAIN AGAIN.                                         01564000
         MVC   WORKTBL(44),DSNAME              COPY DSNAME              01565000
         L     R14,LOCATE                                               01566000
         LA    R15,WORKTBL                     ACTUAL DSNAME            01567000
         SR    R0,R0                           NO CVOL VALUE            01568000
         LA    R1,MSGTEXT1                     LOCATE WORK AREA         01569000
         STM   R14,R1,PARMLIST                 SAVE CAMLIST PARAMETERS  01570000
         LOCATE PARMLIST                                                01571000
         LA    R1,L830                         NO DSCB FOUND MESSAGE    01572000
         LTR   15,15                           SUCCESSFUL LOCATE?       01573000
         BNZ   EXIT12M                         NO, ERROR                01574000
         SPACE 1                                                        01575000
         L     R14,OBTAIN                      OBTAIN FLAGS             01576000
         LA    R15,WORKTBL                     ACTUAL DSNAME            01577000
         LA    R0,VOLALLOC                     VOLUME SERIAL            01578000
         LA    R1,DS1FMTID                     OUTPUT START ADDRESS     01579000
         STM   R14,R1,PARMLIST                 SAVE CAMLIST PARAMETERS  01580000
         OBTAIN PARMLIST                       GET THE FORMAT 1 DSCB    01581000
         SPACE 1                                                        01582000
         LA    R1,L830                         NO DSCB FOUND MESSAGE    01583000
         LTR   R15,R15                         SUCCESSFUL?              01584000
         BNZ   EXIT12M                         NO, QUIT                 01585000
         SPACE 2                                                        01586000
RESTART5 STM   R14,R12,12(R13)                 SAVE REGISTERS           01587000
         ICM   R0,B'0111',DS1LSTAR             DS1LSTAR --> MBBCCHHR    01588000
         SLL   R0,8                            MOVE TO HIGH POSTION     01589000
         L     R1,DCBDEBAD-IHADCB+INDCB        DEB ADDRESS              01590000
         LA    R2,LSTARMBB                     RETURN ADDRESS           01591000
         L     R15,ADDRCNVT                    CONVERSION ROUTINE       01592000
         LR    R3,R13                          SAVE R13                 01593000
         BALR  R14,R15                                                  01594000
         LR    R13,R3                          RESTORE R13              01595000
         LM    R14,R12,12(R13)                 RESTORE REGISTERS        01596000
         SPACE 2                                                        01597000
         LA    R0,IOECB                        ECB ADDRESS              01598000
         ST    R0,IOBECB                       SET INTO IOB             01599000
         LA    R0,INDCB                        DCB ADDRESSS             01600000
         ST    R0,IOBDCB                       SET INTO DCB             01601000
         MVI   IOB,X'C2'                       SET IOB FLAGS            01602000
         SPACE 2                                                        01603000
         XC    TOTUSEDX(2+2),TOTUSEDX          CLEAR TOTUSEDX/TOTALLOX  01604000
         TM    DSORG,DS1DSGPO                  PARTITIONED DATA SET?    01605000
         BNO   RESTART6                        NO, BRANCH               01606000
         SPACE 1                                                        01607000
         L     R14,=X'01080100'                R=1, K=08, DD=256        01608000
         TRKCALC FUNCTN=TRKCAP,TYPE=BYTEUCB+1,RKDD=(14),              XX01609000
               REGSAVE=YES,MF=(E,PARMLIST)                              01610000
         ST    R0,DIRTRACK                     DIRECTORY BLOCKS/TRACK   01611000
         CLC   DS1LSTAR(3),ZERO                NULL DATA SET?           01612000
         BE    RESTART6                        YES, BRANCH              01613000
         SPACE 1                                                        01614000
         STM   R14,R12,12(R13)                 SAVE REGISTERS           01615000
         LA    R0,1*256                        TTR=000001               01616000
         L     R1,DCBDEBAD-IHADCB+INDCB        DEB ADDRESS              01617000
         LA    R2,IOBSEEK                      RETURN ADDRESS           01618000
         L     R15,ADDRCNVT                    CONVERSION ROUTINE       01619000
         LR    R3,R13                          SAVE R13                 01620000
         BALR  R14,R15                                                  01621000
         LR    R13,R3                          RESTORE R13              01622000
         LM    R14,R12,12(R13)                 RESTORE REGISTERS        01623000
         SPACE 1                                                        01624000
         LA    R1,CCW0                         START OF CHANNEL PROGRAM 01625000
         ST    R1,IOBCCW                                                01626000
         MVC   CCW0(7*8),CCWDIRR               CCW'S TO READ DIRECTORY  01627000
         MVC   WORKTBL(8),IOBSEEK              INITIALIZE BOTH CCHHR'S  01628000
         MVC   WORKTBL+8(8),WORKTBL            INITIALIZE BOTH CCHHR'S  01629000
         LA    R1,WORKTBL+3                    USED CCHHR               01630000
         STCM  R1,B'0111',CCW1+1                                        01631000
         LA    R1,CCW1                         TIC TARGET 1             01632000
         STCM  R1,B'0111',CCW3+1                                        01633000
         LA    R1,WORKTBL+8+3                  TOTAL CCHHR              01634000
         STCM  R1,B'0111',CCW4+1                                        01635000
         LA    R1,CCW4                         TIC TARGET 2             01636000
         STCM  R1,B'0111',CCW6+1                                        01637000
         SPACE 2                                                        01638000
         MVI   IOECB,0                                                  01639000
         EXCP  IOB                                                      01640000
         WAIT  ECB=IOECB                                                01641000
         MVI   IOB,X'C2'                       SET IOB FLAGS            01642000
         NI    DCBIFLG-IHADCB+INDCB,X'3B'      RESET DCB ERROR FLAG     01643000
         SPACE 1                                                        01644000
         STM   R2,R12,28(R13)                  CONVERT CCHHR TO TTR     01645000
         LA    R2,WORKTBL                                               01646000
         L     R1,INDCB+(DCBDEBAD-IHADCB)                               01647000
         L     R15,ADDRRLTV                                             01648000
         LR    R3,R13                                                   01649000
         BALR  R14,R15                                                  01650000
         LR    R13,R3                                                   01651000
         LM    R2,R12,28(R13)                                           01652000
         SRDL  R0,16                           00TT RXXX                01653000
         SRL   R1,24                           00TT 000R                01654000
         MH    R0,DIRTRACK+2                                            01655000
         AR    R0,R1                                                    01656000
         STH   R0,TOTUSEDX                     USED DIR. BLOCKS         01657000
         SPACE 1                                                        01658000
         STM   R2,R12,28(R13)                  CONVERT CCHHR TO TTR     01659000
         LA    R2,WORKTBL+8                                             01660000
         L     R1,INDCB+(DCBDEBAD-IHADCB)                               01661000
         L     R15,ADDRRLTV                                             01662000
         LR    R3,R13                                                   01663000
         BALR  R14,R15                                                  01664000
         LR    R13,R3                                                   01665000
         LM    R2,R12,28(R13)                                           01666000
         SRDL  R0,16                           00TT RXXX                01667000
         SRL   R1,24                           00TT 000R                01668000
         MH    R0,DIRTRACK+2                                            01669000
         AR    R0,R1                                                    01670000
         BCTR  R0,0                                                     01671000
         STH   R0,TOTALLOX                     ALLOCATED DIR. BLOCKS    01672000
         SPACE 2                                                        01673000
RESTART6 MVC   CCWS(LCCWINIT),CCWINIT          INITIALIZE CCWS          01674000
         SPACE 1                                                        01675000
         LA    R0,IOBSEEK+3                                             01676000
         LA    R1,CCW1A                                                 01677000
         STCM  R0,B'0111',CCW1A+1              ***                      01678000
         STCM  R1,B'0111',CCW2A+1              *** -- INIT. CCW'S       01679000
         STCM  R0,B'0111',CCW3A+1              ***                      01680000
         SPACE 1                                                        01681000
         LA    R1,SNO                                                   01682000
         LA    R2,CCW1                                                  01683000
         STCM  R1,B'0111',CCW0+1               ***                      01684000
         STCM  R0,B'0111',CCW1+1               ***                      01685000
         STCM  R2,B'0111',CCW2+1               ***  -- READ CCW'S       01686000
         STCM  R0,B'0111',CCW5+1               ***                      01687000
         STCM  R1,B'0111',CCW6+1               ***                      01688000
         SPACE 2                                                        01689000
         LA    R1,CCW0                         FIRST CCW (SET SECTOR)   01690000
         ST    R1,EXCPCCWI                     SAVE FOR EXCP ROUTINE    01691000
         LH    R15,BYTEUCB                     UCBBYTE                  01692000
         MH    R15,=H'9'                       INDEX INTO UNIT TABLE    01693000
         LA    R15,UNITTBL(R15)                DEVICE UNIT TYPE         01694000
         NI    FLAGSEE,FF-FDISKTRK-FFULLTRK-FDOUBCON                    01695000
         CLI   0(R15),C'M'                     READ MULTIPLE?           01696000
         BE    SETBUFF                         YES, BRANCH              01697000
         OI    FLAGSEE,FFULLTRK                                         01698000
         CLI   0(R15),C'D'                     DOUBLE?                  01699000
         BE    SETBUFF                         YES, BRANCH              01700000
         OI    FLAGSEE,FDOUBCON                NO, MUST BE SINGLE       01701000
         SPACE 1                                                        01702000
SETBUFF  DS    0H                                                  @D01
**       CLI   UCBTYP+3(R4),X'08'              2314 DISK?          @D01
**       BNE   NOT2314                         NO, BRANCH          @D01
         TM    UCBTYP+2(R4),X'10'              DEVICE SUPPORT RPS? @D01
         BO    NOT2314                         BRANCH IF SO        @D01
         ST    R2,EXCPCCWI                     YES, DO NOT READ SECTOR  01705000
         XI    CCW5+4,X'40'                    DO NOT CHAIN CCW5        01706000
         SPACE 1                                                        01707000
NOT2314  MVI   DSORG+1,0                       CLEAR SECOND DSORG BYTE  01708000
         TM    DSORG,DS1DSGIS+DS1DSGPS+DS1DSGDA+DS1DSGPO  DSORG KNOWN?  01709000
         BM    *+10                                       YES, BRANCH   01710000
         MVC   DSORG(2),DS1DSORG                          NO, USE LABEL 01711000
         SPACE 1                                                        01712000
         MVC   MSGENTDS,PDS300A                " ENTER OPTIONS -- DSN=. 01713000
         LA    R1,MSGENTDS+25+7                WHERE TO ADD DSNAME      01714000
         MVC   0(44,R1),DSNAME                 ADD DSNAME               01715000
         AH    R1,DSNLEN                       POINT TO DSNAME END      01716000
         MVC   0(9,R1),=C',VOL=SER='           ADD ",VOL=SER="          01717000
         MVC   9(6,R1),VOLALLOC                ADD VOLUME SERIAL        01718000
         TM    DSORG,DS1DSGPO                  PARTITIONED?             01719000
         BNO   *+10                            NO, BRANCH               01720000
         MVC   9+6+2(4,R1),=C'MEM='            DEFAULT GROUP NAME  @D01 01721000
         LA    R1,9+6+2+4(,R1)                 WHERE TO ADD MEM=.. @D01 01722000
         ST    R1,MSGENTPT                     WHERE TO ADD MEM=.. @D01 01723000
         BAL   R14,DEFGROUP                    ADD DEFAULT GROUP        01724000
         SPACE 1                                                        01725000
         MVC   LABLRECL(2),LRECL               SAVE THE DCB LRECL FIELD 01726000
         TM    FLAGSCC,RECFMF                  FIXED FORMAT?            01727000
         BNO   NEWSTAX                         NO, BRANCH               01728000
         TM    RECFM,DCBRECBR                  RECFM=FB?                01729000
         BO    NEWSTAX                         YES, BRANCH              01730000
         MVC   LRECL(2),BLKSI                  RECFM=F ONLY             01731000
         SPACE 1                                                        01732000
NEWSTAX  LA    R0,NEWCMD              ABEND RECOVERY ADDRESS            01733000
         ST    R0,RECOVER                                               01734000
         L     R14,ADDRECT                                              01735000
         MVC   ECTPCMD-ECT(8,R14),PDSNAME   RESET PDS COMMAND NAME      01736000
         SPACE 1                                                        01737000
         STAX  ATTNEXIT,USADDR=(R7),REPLACE=YES,IBUF=0,OBUF=0,         X01738000
               MF=(E,STAXPARM)                                          01739000
         SPACE 1                                                        01740000
         ICM   R8,B'1111',##ADRCMD    SUBCOMMAND TO BE CONTINUED?       01741000
         BNM   NEWCMD                 NO, BRANCH                        01742000
         NI    ##ADRCM#,FF-CONTINUE           TURN OFF CALL FLAG        01743000
         BALR  R2,R8                  YES, BRANCH                       01744000
         TITLE 'P D S  --  PDS NEW SUBCOMMAND PROCESSING       1/15/85' 01745000
*                                                                       01746000
*  GET THE NEXT SUBCOMMAND                                              01747000
*                                                                       01748000
         SPACE 1                                                        01749000
NEWCMD   SR    R0,R0                                                    01750000
         ICM   R0,B'1000',SUBPOOLT     ANY TEMPORARY STORAGE?           01751000
         MVI   SUBPOOLT,0              CLEAR THE SUBPOOL CHARACTER      01752000
         BZ    NEWCMD10                NO, LINK TO THE SUBCOMMAND       01753000
         FREEMAIN R,SP=(0)             YES, RELEASE IT                  01754000
         SPACE 1                                                        01755000
NEWCMD10 MVI   STARTTR+3,0             CLEAR THE READ ADDRESS           01756000
         BAL   R2,SHUTSTOW             CLOSE STOW; RELEASE ANY ENQUEUES 01757000
         MVI   MTHIGHL,8               LENGTH OF STANDARD INSERT 1      01758000
         MVI   MTHIGHL+4,8             LENGTH OF STANDARD INSERT 2      01759000
         TM    FLAGSAA,FMEM#MEM        MEMBER GROUP IN PROGRESS?        01760000
         BO    MEMSGET                 YES, BRANCH                      01761000
         SPACE 2                                                        01762000
         TM    FLAGSEE,FMEMLIST        LIST OF MEMBER NAMES?            01763000
         BNO   NEWCMD20                NO, BRANCH                       01764000
         TM    DSORG,DS1DSGPO          PARTITIONED?                     01765000
         BNO   NEWCMD20                NO, MEMBER NAME NOT NEEDED       01766000
         TM    ##ADRPC#,@G             MEMBER GROUP ALLOWED?            01767000
         BNO   NEWCMD20                NO, BRANCH                       01768000
         L     R1,PMEMCURR             CURRENT MEMBER LIST ELEMENT      01769000
         C     R1,PMEMMAX              IN THE LIST?                     01770000
         BH    NEWCMD20                NO, BRANCH                       01771000
         NI    FLAGSAA,FOPTIONS        PRESERVE THE OPTIONS FLAG        01772000
         OC    FLAGSAA,0(R1)           RESET CONTROL FLAGS              01773000
         MVC   LMEMBER1+1(19),1(R1)    RESET MEMBER NAMES AND LENGTH    01774000
         LA    R1,20(,R1)              NEXT LIST ELEMENT                01775000
         ST    R1,PMEMCURR             SAVE FOR NEXT LIST ITERATION     01776000
         MVC   ##SUBCOM(#LSUB),#SUBHOLD  RESET SUBCOMMAND CHANGED DATA  01777000
         TM    FLAGSAA,FMEM#MEM        MEMBER GROUP REQUESTED?          01778000
         BO    CMDVER                  YES, BRANCH                      01779000
         SPACE 1                                                        01780000
         TM    ##ADRPA#,$D              DEFAULT MESSAGE SUBCOMMAND?     01781000
         BO    CMDVER                   NO, BRANCH (NO DEFAULT MESSAGE) 01782000
         MESSAGE MSGBLANK                                               01783000
         MVC   INSERT#1(8),MEMBER1                                      01784000
         TSMSG L002$1            TELL THE USER WHO IS BEING PROCESSED   01785000
         B     CMDVER                                                   01786000
         SPACE 1                                                        01787000
NEWCMD20 MVI   FLAGSAA,0               CLEAR THE MAJOR CONTROL FLAGS    01788000
         MVI   FLAGSII,0               CLEAR ALL FLAGSII FLAGS          01789000
         MVC   PMEMCURR(4),PMEMMIN     RESET THE CURRENT POINTER        01790000
         SPACE 1                                                        01791000
         TM    FLAGSBB,FCMD            COMMAND BUFFER AVAILABLE?        01792000
         BO    HAVECMD                 YES, BRANCH                      01793000
         SPACE 1                                                        01794000
         TM    FLAGSBB,FONESHOT        ONE SUBCOMMAND ONLY?             01795000
         BO    RETURN                  YES, ALL DONE                    01796000
         SPACE 1                                                        01797000
         TM    FLAGSEE,FBKGRND         BACKGROUND MODE?                 01798000
         BNO   NEWCMD30                NO, BRANCH                       01799000
         MESSAGE MSGBLANK              YES, OUTPUT A SEPARATOR LINE     01800000
         SPACE 8                                                        01801000
NEWCMD30 MVI   ATTNECB,2+1             FLAG -- CAN BE ATTENTIONED       01802000
        $PUTGET MSGENTDS,ATTN=NEWCMD40 FIRST TRY FOR A COMMAND          01803000
         B     HAVECMD                 GOT A COMMAND                    01804000
         SPACE 2                                                        01805000
NEWCMD40 MVI   ATTNECB,2+1             FLAG -- CAN BE ATTENTIONED       01806000
        $PUTGET MSGENTDS,ATTN=EXIT8N   SECOND TRY FOR A COMMAND         01807000
         B     HAVECMD                 GOT A COMMAND                    01808000
         SPACE 2                                                        01809000
NEWCMD50 BAL   R2,FREEPDL              FREE THE PARSE PDL               01810000
         TITLE 'P D S  --  PDS SUBCOMMAND INVOKE SCAN          1/15/85' 01811000
*                                                                       01812000
*        SET UP FOR SUBCOMMAND SCAN                                     01813000
*                                                                       01814000
         SPACE 1                                                        01815000
HAVECMD  NI    FLAGSBB,FF-FCMD                                          01816000
         SPACE 2                                                        01817000
         LA    R15,PARMLIST                                             01818000
         USING CSPL,R15                                                 01819000
         SPACE 1                                                        01820000
         L     R1,ADDRUPT              ADDRESS OF THE UPT               01821000
         L     R2,ADDRECT              ADDRESS OF THE ECT               01822000
         L     R14,ECTIOWA-ECT(R2)     ADDRESS OF I/O WORK AREA    @D01
         L     R14,0(,R14)             STACK ADDRESS               @D01
         ST    R14,PARMSTAK            SAVE STACK ADDRESS FOR      @D01
         LA    R3,ATTNECB              ADDRESS OF THE ATTENTION ECB     01823000
         LA    R4,ZERO                 ADDRESS OF A ZERO FLAG AREA      01824000
         LA    R5,SCANANSR             ADDRESS OF THE RESULT AREA       01825000
         L     R6,ADDRCBUF             ADDRESS OF THE SUBCOMMAND        01826000
         STM   R1,R6,CSPLUPT           SETUP CSPLUPT, CSPLECT, CSPLECB, 01827000
         DROP  R15                           CSPLFLG, CSPLOA & CSPLCBUF 01828000
         SPACE 1                                                        01829000
         LA    R14,FIRST4K                                              01830000
         MVC   MSGTEXT1(256),RECALLST-FIRST4K(R14) SAVE SUBCOMMAND      01831000
         CLC   0(2,R6),=H'4'                    NULL INPUT?             01832000
         BE    HAVECMD8                         YES, IGNORE SUBCOMMAND  01833000
         MVC   RECALLST-FIRST4K(256,R14),0(R6)  NO, RESET SUBCOMMAND    01834000
         SPACE 2                                                        01835000
         CLI   4(R6),C'?'              QUESTION ?                       01836000
         BE    HAVECMD2                YES, BRANCH                      01837000
         CLI   4(R6),C'.'              PERIOD (FOR EXTENDED HELP)?      01838000
         BNE   HAVECMD6                NO, BRANCH                       01839000
         CLI   5(R6),C'?'              QUESTION (FOR EXTENDED HELP)?    01840000
         BNE   HAVECMD6                NO, BRANCH                       01841000
         SPACE 1                                                        01842000
HAVECMD2 LA    R1,L520                 ** EXTENDED HELP IS REQUESTED    01843000
         MVC   RECALLST-FIRST4K(256,R14),MSGTEXT1  RESET SUBCOMMAND     01844000
         OC    ERRORMSG(3*5),ERRORMSG  ANY ERRORS NOTED?                01845000
         BZ    MSGNEW                  NO, "NO INFORMATION AVAILABLE"   01846000
         MVC   0(12,R6),MSGHELP        'H MS MS(' AND 4 BYTE LENGTH     01847000
         LA    R2,ERRORMSG-3           START OF ERROR MESSAGES-3        01848000
         LA    R0,3*5/3                MAXIMUM NUMBER OF MESSAGES       01849000
         LH    R4,0(,R6)               CURRENT LENGTH                   01850000
         SPACE 1                                                        01851000
HAVECMD4 LA    R3,0(R4,R6)             POINT TO CURRENT BYTE            01852000
         LA    R2,3(,R2)               NEXT MESSAGE                     01853000
         MVC   0(3,R3),PDS300A+4       'PDSNNN,' (AFTER FORMATTING)     01854000
         MVC   3(3,R3),0(R2)           MESSAGE IDENTIFICATION           01855000
         MVI   6(R3),C','              SEPARATING COMMA                 01856000
         LA    R4,7(,R4)               ADD TO LENGTH                    01857000
         STH   R4,0(,R6)               UPDATE LENGTH                    01858000
         CLI   3(R2),X'00'             ANOTHER MESSAGE?                 01859000
         BE    *+8                     NO, BRANCH                       01860000
         BCT   R0,HAVECMD4             REPEAT FOR ALL MESSAGES          01861000
         MVI   6(R3),C')'              FINAL MATCHING PARENTHESIS       01862000
**       MESSAGE (R6)                  DELETE ** FOR TESTING            01863000
         SPACE 2                                                        01864000
HAVECMD6 XC    ERRORMSG(3*5),ERRORMSG  CLEAR PREVIOUS ERROR MESSAGES    01865000
         SPACE 1                                                        01866000
HAVECMD8 MVI   ATTNECB,0               CLEAR ECB                        01867000
         LA    R1,PARMLIST             PARAMETER LIST START             01868000
         L     R15,ADDRSCAN            IKJSCAN ADDRESS                  01869000
         BALR  R14,R15                 INVOKE COMMAND SCAN              01870000
         SPACE 1                                                        01871000
         LA    R15,SCANANSR            ADDR OF RESULTS                  01872000
         USING CSOA,R15                                                 01873000
         SPACE 1                                                        01874000
         TM    CSOAFLG,CSOANOC         EMPTY BUFFER?                    01875000
         BO    NEWCMD30                YES, STILL NEED COMMAND          01876000
         SPACE 1                                                        01877000
         AIF   (&MVT).MA00160                                      @D01
         TM    CSOAFLG,CSOAEXEC        IMPLICIT EXEC?                   01878000
         BO    EXECPER                 YES, BRANCH                      01879000
.MA00160 ANOP  ,                                                   @D01
         SPACE 2                                                        01880000
         TM    CSOAFLG,CSOAVWP+CSOAVNP VALID COMMAND?                   01881000
         BNZ   HAVECMD9                YES, BRANCH                      01882000
         LA    R1,L877                 INVALID COMMAND MESSAGE          01883000
         CLI   4(R6),X'6E'             RESHOW COMMAND?                  01884000
         BNE   MSGNEW                  NO, BRANCH                       01885000
         MVI   ATTNECB,2+1             FLAG -- CAN BE ATTENTIONED       01886000
        $PUTGET MSGBLANK,ATTN=NEWCMD40 FIRST TRY FOR A COMMAND          01887000
         B     HAVECMD                 GOT A COMMAND                    01888000
         SPACE 2                                                        01889000
HAVECMD9 TM    CSOAFLG,CSOAVWP         ANY OPERAND?                     01890000
         BNO   *+8                     NO, BRANCH                       01891000
         OI    FLAGSAA,FOPTIONS        YES, NOTE FOR LATER              01892000
         TITLE 'P D S  --  PDS SUBCOMMAND TABLE SCAN           1/15/85' 01893000
*                                                                       01894000
*   COMMAND SCAN - IN THE CASE OF A POTENTIALLY AMBIGUOUS ENTRY         01895000
*                  (E.G. 'A ') THE FIRST MATCH IN THE COMMAND TABLE     01896000
*                  (ATTR IN THIS CASE) IS USED.                         01897000
*                                                                       01898000
         L     R2,CSOACNM              ADDR OF COMMAND NAME             01899000
         LH    R3,CSOALNM              LENGTH OF NAME                   01900000
         BCTR  R3,0                    MACHINE LENGTH                   01901000
         SPACE 2                                                        01902000
         LA    R1,$TBL                 START OF COMMAND SCAN            01903000
         SPACE 2                                                        01904000
         CLC   0(*-*,R1),0(R2)         <<EXECUTED>>                     01905000
CMDSCAN  EX    R3,*-6                  THIS SUBCOMMAND?                 01906000
         BNE   CMDSCAN2                NO, BRANCH                       01907000
         SPACE 1                                                        01908000
         MVC   ##SUBCOM(PTW),0(R1)     INITIALIZE ##SUBCOM, ##ADRCMD,   01909000
*                                        ##ADRPCL AND ##ADRPAR          01910000
         TM    DSORG,DS1DSGPO          PARTITIONED?                     01911000
         BO    CMDFND                  YES, BRANCH                      01912000
         TM    ##ADRPC#,@S             SUPPORTED IF NOT PARTITIONED?    01913000
         BO    CMDFND2                 YES, BRANCH                      01914000
         SPACE 1                                                        01915000
CMDSCAN2 LA    R1,PTW(R1)              NEXT ENTRY IN TABLE              01916000
         CLI   0(R1),X'FF'             END OF TABLE?                    01917000
         BNE   CMDSCAN                 NO, CONTINUE                     01918000
         SPACE 1                                                        01919000
         SR    R2,R2                                                    01920000
         L     R8,$OPT+8               OPTIONS SUBCOMMAND START         01921000
         BR    R8                                                       01922000
         SPACE 1                                                        01923000
CMDSCAN4 LA    R15,SCANANSR            INVALID SUBCOMMAND MESSAGE       01924000
         LH    R3,CSOALNM              LENGTH OF NAME                   01925000
         BCTR  R3,0                    MACHINE LENGTH                   01926000
         SR    R2,R2                                                    01927000
         L     R8,$OPT+8               OPTIONS SUBCOMMAND START         01928000
         BR    R8                                                       01929000
         DROP  R15                                                      01930000
         TITLE 'P D S  --  PDS SUBCOMMAND INITIAL PROCESSING   1/15/85' 01931000
CMDFND   NI    ##ADRPC#,FF-@S          PARTITIONED, TURN OFF OTHER FLAG 01932000
         SPACE 2                                                        01933000
CMDFND2  MVC   ##ANSWER(LISUBS),ISUBS  INITIALIZE THE PDL SAVE AREA     01934000
         L     R14,ADDRECT                                              01935000
         MVC   ECTSCMD-ECT(8,R14),##SUBCOM  RESET PDS SUBCOMMAND NAME   01936000
         AIF   (&MVT).MA00180                                      @D01
         NI    ECTSWS2-ECT(R14),FF-X'04'    PROMPT HELP IS ENABLED      01937000
.MA00180 ANOP  ,                                                   @D01
         CLC   0(8,R1),$REC            RECALL SUBCOMMAND?               01938000
         BNE   CMDCHECK                NO, BRANCH                       01939000
         LA    R14,FIRST4K                                              01940000
         MVC   RECALLST-FIRST4K(256,R14),MSGTEXT1  YES, USE PREVIOUS    01941000
         LH    R1,RECALLST-FIRST4K(R14)  LENGTH OF OLD SUBCOMMAND       01942000
         BCTR  R1,0                    MACHINE LENGTH                   01943000
         XC    MSGTEXT1(256),MSGTEXT1  CLEAR THE MESSAGE AREA           01944000
         MVC   MSGTEXT1(*-*),RECALLST-FIRST4K(R14) <<EXECUTED>>         01945000
         EX    R1,*-6                  MOVE IN MESSAGE                  01946000
         CLI   MSGTEXT1+1,79+4         A FULL LINE (80 -1)?             01947000
         BH    *+8                     YES, BRANCH                      01948000
         MVI   MSGTEXT1+1,79+4         NO, CHANGE LENGTH TO 80          01949000
         LA    R1,MSGTEXT1+1(R1)       POINT TO POSITION AFTER TEXT     01950000
         MVI   0(R1),X'40'             ADD ONE TRAILING BLANK           01951000
         MESSAGE MSGTEXT1              DISPLAY THE OLD SUBCOMMAND       01952000
         LH    R1,2(,R6)               OFFSET TO OPERANDS               01953000
         LA    R1,4(R1,R6)             POINT TO OPERANDS                01954000
         TM    FLAGSAA,FOPTIONS        ANY OPERANDS?                    01955000
         BNO   NEWCMD                  NO, BRANCH                       01956000
         OI    0(R1),X'40'             UPPER CASE THE OPERAND           01957000
         CLI   0(R1),C'E'              ENTER OPERAND?                   01958000
         BNE   NEWCMD                  NO, BRANCH                       01959000
         NI    FLAGSAA,FF-FOPTIONS     TURN OFF THE OPERAND FLAG        01960000
         LA    R14,FIRST4K                                              01961000
         MVC   PUTGETBF(256),RECALLST-FIRST4K(R14)  CHANGE TO PREVIOUS  01962000
         B     HAVECMD                 SCAN AND PARSE THIS AGAIN        01963000
         SPACE 2                                                        01964000
CMDCHECK TM    ##ADRPC#,@N       IGNORE OPTIONS?                        01965000
         BO    CMDVER            YES, BRANCH                            01966000
         SPACE 2                                                        01967000
         CLC   ##SUBCOM(8),$PAT  PATTERN SUBCOMMAND?                    01968000
         BNE   CMDCHK2           NO, BRANCH                             01969000
         TM    FLAGSAA,FOPTIONS  ANY OPERAND SPECIFIED?                 01970000
         BO    CMDPARSE          YES, USE THE SPECIFIED DATA            01971000
         CLI   MEMBERP,X'00'     ANY DEFAULT PATTERN YET?               01972000
         BE    CMDPARSE          NO, FORCE A CALL TO PARSE              01973000
         SPACE 1                                                        01974000
         MVC   LMEMBER1(2+8+8+2),MEMBERP+1  RESET DEFAULT PATTERN       01975000
         NI    FLAGSAA,FF-FMEMBER1-FMEMBER2-FMEM#MEM-FMEMRANG           01976000
         OC    FLAGSAA,MEMBERP   RESTORE THE DEFAULT FLAGS              01977000
         B     CMDVER                                                   01978000
         SPACE 2                                                        01979000
CMDCHK2  TM    ##ADRPC#,@G       MEMBER NAME DEFAULT (AND GROUP)?       01980000
         BNO   CMDREQD           NO, CHECK IF OPERANDS REQUIRED         01981000
         TM    FLAGSAA,FOPTIONS  ANY OPERAND SPECIFIED?                 01982000
         BO    CMDPARSE          YES, USE THE SPECIFIED DATA            01983000
         SPACE 2                                                        01984000
         TM    ##ADRPC#,@S       NON-PARTITIONED DATA SET?              01985000
         BO    CMDVER            YES, BRANCH                            01986000
         CLI   MEMBERD,X'00'     ANY DEFAULT MEMBER NAME YET?           01987000
         BE    CMDPARSE          NO, FORCE A CALL TO PARSE              01988000
         SPACE 1                                                        01989000
         MVC   LMEMBER1(2+8+8+2),MEMBERD+1  RESET DEFAULT MEMBER NAMES  01990000
         NI    FLAGSAA,FF-FMEMBER1-FMEMBER2-FMEM#MEM-FMEMRANG           01991000
         OC    FLAGSAA,MEMBERD   RESTORE THE DEFAULT FLAGS              01992000
         MVC   PMEMCURR(4),PMEMMIN  RESET THE FIRST MEMBER POINTER      01993000
         TM    FLAGSAA,FMEM#MEM  MEMBER GROUP REQUESTED?                01994000
         BO    CMDVER            YES, BRANCH                            01995000
         SPACE 1                                                        01996000
         TM    ##ADRPA#,$D              DEFAULT MESSAGE SUBCOMMAND?     01997000
         BO    CMDVER                   NO, BRANCH (NO DEFAULT MESSAGE) 01998000
         SPACE 1                                                        01999000
         MVC   INSERT#1(8),MEMBER1                                      02000000
         TSMSG L002$1            TELL THE USER WHO IS BEING PROCESSED   02001000
         B     CMDVER            CALL THE COMMAND                       02002000
         SPACE 3                                                        02003000
CMDREQD  TM    ##ADRPC#,@R       OPERANDS REQUIRED?                     02004000
         BO    CMDPARSE          YES, BRANCH                            02005000
         TM    FLAGSAA,FOPTIONS  ANY OPERANDS SPECIFIED?                02006000
         BZ    CMDVER            NO, BRANCH                             02007000
         SPACE 2                                                        02008000
CMDPARSE OI    FLAGSAA,FOPTIONS  NOW THERE ARE OPERANDS                 02009000
         L     R1,ADDRCBUF       START OF SUBCOMMAND BUFFER             02010000
         MVC   ##HELOFF(2),2(R1) SAVE THE OFFSET                        02011000
         L     R15,=A(PARSE)     PARSE ADDRESS                          02012000
         BALR  R14,R15           GET THE COMMAND OPERANDS               02013000
         B     NEWCMD            INVALID PARSE, IGNORE                  02014000
         L     R1,ADDRCBUF       START OF SUBCOMMAND BUFFER             02015000
         MVC   2(2,R1),##HELOFF  RESET THE OFFSET                       02016000
         SPACE 3                                                        02017000
CMDVER   ICM   R15,B'1111',=V(VSUBCMD)  VERIFY THE SUBCOMMAND?          02018000
         BZ    CALLCMD                  NO, BRANCH                      02019000
         OI    FLAGSJJ,FSUBCMD          YES, SET A ESTAE FLAG           02020000
         L     R1,ADDRCBUF              COMMAND BUFFER ADDRESS          02021000
         ST    R1,ADDRTEXT              COMMAND ADDRESS                 02022000
         MVC   MSGTEXT1(16),ADDRTEXT    MOVE ARGUMENT LIST              02023000
         LA    R1,##SUBCOM              COMMAND NAME                    02024000
         CLC   ##SUBCOM(8),$ATT         ATTRIB SUBCOMMAND?              02025000
         BNE   CMDVER2                  NO, BRANCH                      02026000
         TM    #OPTOPT,X'F0'            ATTRIBUTE CHANGES?              02027000
         BNO   CMDVER2                  NO, BRANCH                      02028000
         LA    R1,=CL8'ATTRMOD'         YES, CHANGE THE COMMAND NAME    02029000
CMDVER2  CLC   ##SUBCOM(8),$VER         VERIFY SUBCOMMAND?              02030000
         BNE   CMDVER4                  NO, BRANCH                      02031000
         TM    #VERUPDT,2               NOUPDATE?                       02032000
         BO    CMDVER4                  YES, BRANCH                     02033000
         TM    DSORG,DS1DSGPO           PARTITIONED DATA SET?           02034000
         BNO   CMDVER4                  NO, BRANCH                      02035000
         TM    FLAGSAA,FMEMBER1+FMEMBER2  ALL MEMBERS?                  02036000
         BNZ   CMDVER4                    NO, BRANCH                    02037000
         TM    FLAGSAA,FMEM#MEM           MEMBER GROUP?                 02038000
         BO    CMDVER4                    YES, BRANCH                   02039000
         LA    R1,=CL8'VERMOD'            NO, CHANGE THE COMMAND NAME   02040000
         SPACE 1                                                        02041000
CMDVER4  ST    R1,MSGTEXT1+16           FOR VERIFICATION ROUTINE        02042000
         LA    R1,DSNAME                DSNAME                          02043000
         ST    R1,MSGTEXT1+20           FOR VERIFICATION ROUTINE        02044000
         OI    MSGTEXT1+20,X'80'        MARK END OF LIST                02045000
         LA    R1,MSGTEXT1              START OF ARGUMENT LIST          02046000
         BALR  R14,R15                  CALL VERIFICATION ROUTINE       02047000
         NI    FLAGSJJ,FF-FSUBCMD       RESET THE ESTAE FLAG            02048000
         MVC   INSERT#1(8),##SUBCOM     COMMAND NAME                    02049000
         LA    R1,L920$1                ASSUME NOT AUTHORIZED           02050000
         LTR   R15,R15                  CORRECT?                        02051000
         BNZ   MSGNEWXX                 YES, BRANCH                     02052000
         SPACE 2                                                        02053000
         CLC   ##SUBCOM(8),$FIN         FIND SUBCOMMAND?                02054000
         BE    CMDVER6                  YES, BRANCH                     02055000
         CLC   ##SUBCOM(8),$IFX         IF SUBCOMMAND?                  02056000
         BNE   CALLCMD                  NO, BRANCH                      02057000
         SPACE 1                                                        02058000
CMDVER6  L     R15,=V(VSUBCMD)          VERIFY THE SUBCOMMAND           02059000
         ICM   R1,B'1111',#ACTIONT      THEN ACTION?                    02060000
         BZ    CMDVER8                  NO, BRANCH                      02061000
         OI    FLAGSJJ,FSUBCMD          YES, SET A ESTAE FLAG           02062000
         ST    R1,MSGTEXT1+16           FOR VERIFICATION ROUTINE        02063000
         LA    R1,MSGTEXT1              START OF ARGUMENT LIST          02064000
         BALR  R14,R15                  CALL VERIFICATION ROUTINE       02065000
         NI    FLAGSJJ,FF-FSUBCMD       RESET THE ESTAE FLAG            02066000
         ICM   R1,B'1111',#ACTIONT      THEN ACTION                     02067000
         MVC   INSERT#1(8),0(R1)        COMMAND NAME                    02068000
         LA    R1,L920$1                ASSUME NOT AUTHORIZED           02069000
         LTR   R15,R15                  CORRECT?                        02070000
         BNZ   MSGNEWXX                 YES, BRANCH                     02071000
         SPACE 2                                                        02072000
CMDVER8  L     R15,=V(VSUBCMD)          VERIFY THE SUBCOMMAND           02073000
         ICM   R1,B'1111',#ACTIONE      ELSE ACTION?                    02074000
         BZ    CALLCMD                  NO, BRANCH                      02075000
         OI    FLAGSJJ,FSUBCMD          YES, SET A ESTAE FLAG           02076000
         ST    R1,MSGTEXT1+16           FOR VERIFICATION ROUTINE        02077000
         LA    R1,MSGTEXT1              START OF ARGUMENT LIST          02078000
         BALR  R14,R15                  CALL VERIFICATION ROUTINE       02079000
         NI    FLAGSJJ,FF-FSUBCMD       RESET THE ESTAE FLAG            02080000
         ICM   R1,B'1111',#ACTIONE      ELSE ACTION                     02081000
         MVC   INSERT#1(8),0(R1)        COMMAND NAME                    02082000
         LA    R1,L920$1                ASSUME NOT AUTHORIZED           02083000
         LTR   R15,R15                  CORRECT?                        02084000
         BNZ   MSGNEWXX                 YES, BRANCH                     02085000
         TITLE 'P D S  --  PDS SUBCOMMAND BLDL CHECKING        1/15/85' 02086000
CALLCMD  MVC   #SUBHOLD(#LSUB),##SUBCOM   SAVE SUBCOMAND CHANGED DATA   02087000
         TM    ##ADRPC#,@S         NON-PARTITIONED DATA SET?            02088000
         BO    CALLCMD9            YES, BRANCH                          02089000
         TM    FLAGSAA,FMEM#MEM    MEMBER GROUP DESIRED?                02090000
         BO    CALLCMD8            YES, BRANCH                          02091000
         TM    ##ADRPC#,@C         CHANGE DIRECTORY AND NO BLDL?        02092000
         BNO   CALLCMD2            NO, BRANCH                           02093000
         MVC   DIRNAME,MEMBER1     GET MEMBER NAME                      02094000
         NI    FLAGSCC,FF-FBLDLOK  DIRECTORY WILL BE CHANGED            02095000
         SPACE 2                                                        02096000
CALLCMD2 TM    ##ADRPC#,@B         BLDL REQUIRED?                       02097000
         BNO   CALLCMD8            NO, BRANCH                           02098000
***      TM    FLAGSCC,FBLDLOK     BLDL STILL VALID?                    02099000
***      BNO   CALLCMD4            NO, BRANCH                           02100000
***      TM    FLAGSAA,FOPTIONS    ANY MEMBER NAME SPECIFIED?           02101000
***      BO    CALLCMD4            YES, DO A BLDL THEN                  02102000
***      CLC   DIRNAME(8),MEMBER1  STILL THIS MEMBER NAME?              02103000
***      BE    CALLCMD8            YES, NO NEED TO BLDL                 02104000
         SPACE 2                                                        02105000
CALLCMD4 XC    DIRUSER,DIRUSER     CLEAR THE USER FIELDS                02106000
         MVC   DIRNAME,MEMBER1     ORIGINAL MEMBER NAME                 02107000
         NI    FLAGSCC,FF-FBLDLOK  ASSUME MEMBER NOT FOUND              02108000
         SPACE 2                                                        02109000
         BLDL  INDCB,BLDLLIST      LOCATE DIRECTORY ENTRY               02110000
         B     *+4(R15)            PROCESS RETURN CODE                  02111000
         B     CALLCMD6              00 - SUCCESSFUL                    02112000
         B     NOMEMBER              04 - MEMBER NOT FOUND              02113000
         B     IOERROR               08 - I/O ERROR                     02114000
         SPACE 2                                                        02115000
CALLCMD6 OI    FLAGSCC,FBLDLOK     MEMBER FOUND                         02116000
         MVC   DIRFLAG(DIREND-DIRFLAG),DIRFLAG+2 BLDL ADDS THINGS       02117000
         LA    R14,DIRNAME                CURRENT MEMBER NAME ADDRESS   02118000
         ST    R14,DIRPTRS                UPDATE IF NO GROUP            02119000
         SPACE 2                                                        02120000
CALLCMD8 TM    FLAGSAA,FMEM#MEM           MEMBER GROUP TO START?        02121000
         BNO   CALLCMDZ                   NO, BRANCH                    02122000
         NI    FLAGSCC,FF-FBLDLOK         YES, FORCE A BLDL NEXT TIME   02123000
         SPACE 1                                                        02124000
         TM    FLAGSAA,FMEMBER1+FMEMBER2  ANY MEMBER NAMES?             02125000
         BNZ   MEMSINIT                   YES, BRANCH                   02126000
         TM    ##ADRPC#,@I                BROWSE, EDIT OR VERIFY?       02127000
         BNO   MEMSINIT                   NO, BRANCH                    02128000
         SPACE 2                                                        02129000
CALLCMD9 NI    FLAGSAA,FF-FMEM#MEM        TURN OFF MEMBER GROUPS        02130000
         B     CALLCMDZ                   CALL THE SUBCOMMAND           02131000
         TITLE 'P D S  --  PDS SUBCOMMAND MEMBER GROUPS        1/15/85' 02132000
MEMSINIT MVC   #SUBHOLD(#LSUB),##SUBCOM SAVE SUBCOMMAND CHANGED DATA    02133000
         XC    DIRNAME(8),DIRNAME       CLEAR THE MEMBER NAME           02134000
         OI    FLAGSII,FDIRGRP          INPUT FOR MEMBER GROUP          02135000
         TM    FLAGSAA,FMEMRANG         MEMBER RANGE?                   02136000
         BO    DISPLAY                  YES, BRANCH                     02137000
         B     PATTERN                  NO, MEMBER PATTERN              02138000
         SPACE 1                                                        02139000
MEMSGET  MVC   DIRPTRS(12),DIRPTRS2     RESTORE THE DIRPTRS             02140000
         MVC   CURMBB(8),CURDIR         RESTORE THE DIRECTORY ADDRESS   02141000
         OI    FLAGSII,FDIRGRP          INPUT FOR MEMBER GROUP          02142000
         B     DISPLAY2                 GET NEXT MEMBER                 02143000
         SPACE 1                                                        02144000
MEMSNEXT NI    FLAGSII,FF-FDIRGRP       MEMBER GROUP INPUT IS COMPLETE  02145000
         OI    FLAGSBB,FRANPAT          MEMBERS EXIST IN THIS RANGE     02146000
         MVC   DIRPTRS2(12),DIRPTRS     SAVE THE DIRPTRS                02147000
         MVC   CURDIR(8),CURMBB         SAVE THE DIRECTORY ADDRESS      02148000
         MVC   ##SUBCOM(#LSUB),#SUBHOLD RESET CHANGED INFORMATION       02149000
         L     R14,DIRPTRS              START OF CURRENT MEMBER NAME    02150000
         CLC   DIRNAME(8),0(R14)        NAME PROCESSED BEFORE?          02151000
         BNL   MEMSGET                  YES, BRANCH AND IGNORE          02152000
         XC    DIRNAME(74),DIRNAME      CLEAR THE CURRENT ENTRY         02153000
         IC    R15,MEMFLAG              DIRECTORY FLAG BYTE             02154000
         N     R15,=XL4'0000001F'       NUMBER OF HALFWORDS             02155000
         LA    R15,11(R15,R15)          MACHINE LENGTH OF ENTRY         02156000
         MVC   DIRNAME(*-*),0(R14)      <<EXECUTED>>                    02157000
         EX    R15,*-6                  MOVE IN THE CURRENT ENTRY       02158000
         SPACE 1                                                        02159000
         MVC   MSGTEXT1,MSGMEMQ         SUBCOMMAND AND MEMBER MESSAGE   02160000
         MVC   MSGTEXT1+7(8),##SUBCOM                                   02161000
         MVC   MSGTEXT1+7+8+1(8),DIRNAME                                02162000
         TR    MSGTEXT1+7+8+1(8),TRLINE                                 02163000
         TM    ##ADRPC#,@Q              HEADER DELAYED SUBCOMMAND?      02164000
         BNO   MEMSMSG                  NO, BRANCH                      02165000
         SPACE 1                                                        02166000
MEMSKIP  MVC   FINDMEMQ(38),MSGTEXT1    SAVE FOR THEN/ELSE ACTION       02167000
         OI    FLAGSAA,FINDMSG          SUBCOMMAND IS AVAILABLE         02168000
         B     CALLCMDZ                 CALL THE SUBCOMMAND             02169000
         SPACE 2                                                        02170000
MEMSMSG  MESSAGE MSGBLANK                                               02171000
         MESSAGE MSGTEXT1                                               02172000
         SPACE 3                                                        02173000
CALLCMDZ L     R8,##ADRCMD              SUBCOMMAND ROUTINE START        02174000
         LA    R2,NEWCMD                SUBCOMMAND TERMINATION ADDRESS  02175000
         BR    R8                       LINK TO THE SUBCOMMAND          02176000
         TITLE 'P D S  --  PDS DISPLAY, MEMBERS, PATTERN       1/15/85' 02177000
*********************************************************************** 02178000
***      DISPLAY SUBCOMMAND                                         *** 02179000
***                                                                 *** 02180000
***      MEMBERS SUBCOMMAND    ADDED BY BRUCE LELAND -- JULY, 1982  *** 02181000
***                                                                 *** 02182000
***      PATTERN SUBCOMMAND    ADDED BY BRUCE LELAND -- JAN, 1980   *** 02183000
*********************************************************************** 02184000
*                                                                       02185000
         SPACE 1                                                        02186000
DISPLAY  OI    FLAGSAA,FMEMRANG          **  MEMBER RANGE SELECTION     02187000
         TM    FLAGSAA,FMEMBER1+FMEMBER2 DISPLAY RANGE?                 02188000
         BNO   DISPLAYA                  NO, NO RANGE CHECK             02189000
         LH    R14,LMEMBER1                                             02190000
         CH    R14,LMEMBER2              DETERMINE MIN NAME LENGTH      02191000
         BNH   *+8                                                      02192000
         LH    R14,LMEMBER2                                             02193000
         CLC   MEMBER1(*-*),MEMBER2      <<EXECUTED>>                   02194000
         EX    R14,*-6                   VALID DISPLAY RANGE?           02195000
         LA    R1,L700                   INVALID RANGE MESSAGE          02196000
         BH    MSGNEWXX                  YES, BRANCH                    02197000
         SPACE 1                                                        02198000
PATTERN  DS    0H                        **  MEMBER PATTERN SELECTION   02199000
         SPACE 1                                                        02200000
MEMBERS  DS    0H                        **  MEMBER GROUP DISPLAY       02201000
         SPACE 1                                                        02202000
DISPLAYA LA    R1,80                     ASSUME AN ACTIVE MODE          02203000
         AIF ('&CISP' EQ 'NO SPF').MA00200                         @D01
         TM    SPFLAG0,SPFDON            ISPMODE ACTIVE?                02204000
         BO    DISPLAY0                  YES, BRANCH                    02205000
.MA00200 ANOP  ,                                                   @D01
         TM    CONTOPTN,1                ANY LOG RECORDING?             02206000
         BO    DISPLAY0                  YES, BRANCH                    02207000
         GTSIZE
         CH    R1,=H'120'                120 OR LESS BYTES?             02209000
         BL    *+8                       YES, BRANCH                    02210000
         LH    R1,=H'120'                NO, USE 120 BYTES              02211000
DISPLAY0 ST    R1,LINESIZE               CHARACTERS/LINE                02212000
         CLC   $MEM(8),##SUBCOM          MEMBERS SUBCOMMAND?            02213000
         BNE   *+8                       NO, BRANCH                     02214000
         NI    FLAGSAA,FF-FMEM#MEM       YES, TURN OFF ANY MEMBER GROUP 02215000
         NI    FLAGSBB,FF-FEXIST-FLINESET-FRANPAT                       02216000
         MVI   STARTTR+2,X'01'          TTR=000001 (START OF DIRECTORY) 02217000
         SPACE 1                                                        02218000
DISPLAY1 L     R4,LINESIZE               GET TERMINAL LINE SIZE         02219000
         LA    R4,MSGTEXT1+3-11(R4)      END OF LINE ADDRESS            02220000
         LA    R5,MSGTEXT1+4             START OF LINE                  02221000
         MVC   MSGTEXT1(136),MSGBL132    CLEAR THE DATA LINE            02222000
         SPACE 1                                                        02223000
DISPLAY2 BAL   R14,READDIR               GET NEXT DIRECTORY ENTRY       02224000
         B     DISPLAY6                  LAST MEMBER IN DIRECTORY       02225000
         SPACE 1                                                        02226000
         OI    FLAGSBB,FEXIST            MEMBER EXISTS FLAG             02227000
         TM    FLAGSAA,FMEMRANG          MEMBER NAME RANGE?             02228000
         BNO   PATTERN1                  NO, BRANCH                     02229000
         TM    FLAGSAA,FMEMBER1          START ENTRY SPECIFIED?         02230000
         BZ    DISPLAY3                  NO, BRANCH                     02231000
         LH    R15,LMEMBER1              LENGTH-1 OF MEMBER NAME        02232000
         CLC   MEMBER1(*-*),MEMNAME      <<EXECUTED>>                   02233000
         EX    R15,*-6                                                  02234000
         BH    DISPLAY2                  NOT WANTED, GET NEXT           02235000
         XI    FLAGSAA,FMEMBER1                                         02236000
         SPACE 2                                                        02237000
         AIF   ('&CONDRNG' EQ 'N').NRNG                                 02238000
         TM    FLAGSAA,FMEMBER2          LAST ENTRY SPECIFIED?          02239000
         BO    DISPLAY3                  YES, BRANCH                    02240000
         CLC   $DIS(8),##SUBCOM          DISPLAY SUBCOMMAND? ***TEST    02241000
         BNE   DISPLAY3                  NO, BRANCH          ***TEST    02242000
         STH   R15,LMEMBER2              LENGTH-1 OF SECOND NAME        02243000
         MVC   MEMBER2(*-*),MEMBER1      <<EXECUTED>>                   02244000
         EX    R15,*-6                   DUPLICATE FIRST MEMBER NAME    02245000
         OI    FLAGSAA,FMEMBER2          SET SECOND ENTRY HERE          02246000
         SPACE 2                                                        02247000
.NRNG    ANOP                                                           02248000
DISPLAY3 TM    FLAGSAA,FMEMBER2          LAST ENTRY SPECIFIED?          02249000
         BZ    DISPLAY4                  NO, BRANCH                     02250000
         SPACE 1                                                        02251000
         LH    R15,LMEMBER2                                             02252000
         CLC   MEMBER2(*-*),MEMNAME      <<EXECUTED>>                   02253000
         EX    R15,*-6                   PAST END?                      02254000
         BL    DISPLAY6                  YES, END OF DISPLAY            02255000
         B     DISPLAY4                  NO, DISPLAY THIS MEMBER NAME   02256000
         SPACE 1                                                        02257000
PATTERN1 LH    R15,LMEMBER1              LENGTH-1 OF THE PATTERN        02258000
         LA    R1,8                      MAXIMUM PATTERN LENGTH         02259000
         SR    R1,R15                    NUMBER OF COMPARE LOOPS        02260000
         LA    R14,MEMNAME               START SCAN POSITION            02261000
         CLC   0(*-*,R14),MEMBER1        <<EXECUTED>>                   02262000
PATTERN2 EX    R15,*-6                   PATTERN IN THIS MEMBER NAME?   02263000
         BE    PATTERN3                  YES, CHECK FOR ANOTHER PATTERN 02264000
         LA    R14,1(,R14)               MAYBE, CHECK AT THE NEXT BYTE  02265000
         BCT   R1,PATTERN2               CHECK ALL POSSIBLE POSITIONS   02266000
         B     DISPLAY2                  NO, IGNORE THIS ENTRY          02267000
         SPACE 1                                                        02268000
PATTERN3 TM    FLAGSAA,FMEMBER2          A SECOND PATTERN SPECIFIED?    02269000
         BZ    DISPLAY4                  NO, DISPLAY THE MEMBER NAME    02270000
         LH    R15,LMEMBER2              LENGTH-1 OF THE PATTERN        02271000
         LA    R1,8                      MAXIMUM PATTERN LENGTH         02272000
         SR    R1,R15                    NUMBER OF COMPARE LOOPS        02273000
         LA    R14,MEMNAME               START SCAN POSITION            02274000
         CLC   0(*-*,R14),MEMBER2        <<EXECUTED>>                   02275000
PATTERN4 EX    R15,*-6                   PATTERN IN THIS MEMBER NAME?   02276000
         BE    DISPLAY4                  YES, DISPLAY THE MEMBER NAME   02277000
         LA    R14,1(,R14)               MAYBE, CHECK AT THE NEXT BYTE  02278000
         BCT   R1,PATTERN4               CHECK ALL POSSIBLE POSITIONS   02279000
         B     DISPLAY2                  NO, IGNORE THIS ENTRY          02280000
         SPACE 1                                                        02281000
DISPLAYT TRT   MEMNAME(*-*),TRTMEM       <<EXECUTED>>                   02282000
DISPLAY4 TM    FLAGSAA,FMEM#MEM          MEMBER NAME GROUP DESIRED?     02283000
         BO    MEMSNEXT                  YES, FOUND A MEMBER            02284000
         LA    R1,7                      MEMBER NAME MACHINE LENGTH     02285000
         LA    R14,MEMNAME+8             END OF MEMBER NAME +1          02286000
DISPLAYB BCTR  R14,0                     SCAN                           02287000
         CLI   0(R14),X'40'                  BACKWARDS                  02288000
         BNE   *+8                                    FOR A             02289000
         BCT   R1,DISPLAYB                                 NON-BLANK    02290000
         CLI   MEMNAME,C'0'              FIRST DIGIT NUMERIC?           02291000
         BNL   *+12                      YES, FORCE A HEX DISPLAY       02292000
         EX    R1,DISPLAYT               ANY INVALID OR UNPRINTABLE?    02293000
         BZ    DISPLAY8                  NO, BRANCH                     02294000
         TM    FLAGSBB,FLINESET          LINE IN PROGRESS?              02295000
         BZ    DISPLAY9                  NO, SKIP THE PUTLINE           02296000
         MESSAGE MSGTEXT1                                               02297000
         NI    FLAGSBB,FF-FLINESET                                      02298000
         SPACE 2                                                        02299000
DISPLAY9 MVC   MSGTEXT1(136),MSGBL132    CLEAR THE DATA LINE            02300000
         UNPK  MSGTEXT1+4(9),MEMNAME(5)  FIRST HALF OF NAME             02301000
         UNPK  MSGTEXT1+12(9),MEMNAME+4(5) SECOND HALF OF NAME          02302000
         TR    MSGTEXT1+4(16),TRTABLE    FINISH TRANSLATION             02303000
         MVC   MSGTEXT1+20(8),BLANKS     CLEAN UP GARBAGE               02304000
         TM    MEMFLAG,X'80'             ALIAS?                         02305000
         BZ    *+10                      NO, SKIP -A                    02306000
         MVC   MSGTEXT1+20(2),=C'-A'     YES, SET -A                    02307000
         MVI   MSGTEXT1+24,C'*'                                         02308000
         MVC   MSGTEXT1+25(8),MEMNAME    MEMBER NAME FROM DIRECTORY     02309000
         TR    MSGTEXT1+25(8),TRLINE     TRANSLATE TO PRINTABLE         02310000
         MVI   MSGTEXT1+33,C'*'                                         02311000
         OI    FLAGSBB,FLINESET+FRANPAT  OUTPUT AND MEMBERS EXIST NOW   02312000
         B     DISPLAY5                                                 02313000
         SPACE 1                                                        02314000
DISPLAY8 MVC   0(8,R5),MEMNAME                                          02315000
         TM    MEMFLAG,X'80'             ALIAS?                         02316000
         BZ    DISPLAY7                  NO, BRANCH                     02317000
         MVC   8(2,R5),=C'-A'                                           02318000
DISPLAY7 OI    FLAGSBB,FLINESET+FRANPAT                                 02319000
         LA    R5,10+2(R5)                                              02320000
         CR    R5,R4                     LINE FULL?                     02321000
         BL    DISPLAY2                  NO, CONTINUE                   02322000
         SPACE 1                                                        02323000
DISPLAY5 MESSAGE MSGTEXT1                                               02324000
         NI    FLAGSBB,FF-FLINESET                                      02325000
         B     DISPLAY1                  RETURN                         02326000
         SPACE 2                                                        02327000
DISPLAY6 TM    FLAGSBB,FLINESET          OUTPUT LINE IN PROGRESS?       02328000
         BNO   DISPLAYZ                  NO, BRANCH                     02329000
         LA    R1,MSGTEXT1                                              02330000
         TM    FLAGSAA,FMEM#MEM          MEMBER GROUP IN PROGRESS?      02331000
         BNO   MSGNEW                    NO, BRANCH                     02332000
         SPACE 2                                                        02333000
DISPLAYZ NI    FLAGSAA,FF-FMEM#MEM       TERMINATE ANY MEMBER GROUP     02334000
         TM    FLAGSBB,FRANPAT           MEMBER IN RANGE?               02335000
         BO    NEWCMD                    YES, BRANCH                    02336000
***      CLC   $MML(8),##SUBCOM          MEMLIST SUBCOMMAND?            02337000
***      BNE   *+8                       NO, BRANCH                     02338000
***      NI    FLAGSBB,FF-FONESHOT       YES, MARK TO CONTINUE          02339000
         TM    FLAGSBB,FEXIST            NO, BUT ANY IN DIRECTORY?      02340000
         LA    R1,L400                                                  02341000
         BZ    MSGNEW                    NO, ** EMPTY DIRECTORY **      02342000
         LA    R1,L401                   ASSUME NONE IN RANGE           02343000
         TM    FLAGSAA,FMEMRANG MEMBER   CORRECT?                       02344000
         BO    MSGNEW                    YES, BRANCH                    02345000
         LA    R1,L402                   NO, NONE MATCHING PATTERN      02346000
         B     MSGNEW                                                   02347000
         TITLE 'P D S  --  PDS EXEC                            1/15/85' 02348000
*********************************************************************** 02349000
***      EXEC SUBCOMMAND       ADDED BY BRUCE LELAND -- JAN, 1980   *** 02350000
*********************************************************************** 02351000
*                                                                       02352000
         SPACE 2                                                        02353000
EXECPER  L     R2,ADDRCBUF          EXEC (%NAME -- IMPLIED FORM)        02354000
         XC    2(2,R2),2(R2)        CLEAR OFFSET                        02355000
         L     R1,ADDRECT                  ECT ADDRESS                  02356000
         OI    ECTSWS-ECT(R1),ECTNOPD      ASSUME NO OPERAND            02357000
         TM    CSOAFLG-CSOA(R15),CSOAVWP   ANY OPERAND?                 02358000
         BNO   *+8                         NO, BRANCH                   02359000
         NI    ECTSWS-ECT(R1),FF-ECTNOPD   YES, ZAP THE NO OPERAND FLAG 02360000
         SPACE 1                                                        02361000
EXEC     L     R2,ADDRCBUF          EXEC (EXEC NAME -- EXPLICIT FORM)   02362000
         AIF ('&CISP' EQ 'NO SPF').MA00220                         @D01
         LA    R1,L732              ASSUME ISPMODE IS ACTIVE            02363000
         TM    SPFLAG0,SPFDON       CORRECT?                            02364000
         BO    MSGNEWXX             YES, ERROR                          02365000
.MA00220 ANOP  ,                                                   @D01
         L     R1,ADDRCPPL                                              02366000
         ST    R2,0(,R1)                                                02367000
         SPACE 1                                                        02368000
         LA    R3,$EXE+20           TSO EXEC CLIST PROCESSOR            02369000
         BAL   R2,ATTACH            GO ATTACH IT                        02370000
         B     NEWSTAX                                                  02371000
         TITLE 'P D S  --  PDS ALIAS                           1/15/85' 02372000
*********************************************************************** 02373000
***      ALIAS SUBCOMMAND                                           *** 02374000
*********************************************************************** 02375000
*                                                                       02376000
         SPACE 1                                                        02377000
ALIAS    CSECT                                                          02378000
         USING *,R8                                                     02379000
         AIF ('&CISP' EQ 'NO SPF').MA00240                         @D01
         TM    SPFLAG2,SPFPOST            LINE COMMAND?                 02380000
         BNO   ALIAS0                     NO, BRANCH                    02381000
         LA    R1,FIRST4K                 GET ADDRESSABILITY            02382000
         MVC   MEMLNMSV-FIRST4K(8,R1),MEMBER2                           02383000
         B     ALIAS1                     NO, BRANCH                    02384000
         SPACE 2                                                        02385000
.MA00240 ANOP  ,                                                   @D01
ALIAS0   MVC   MEMBERD+1(2),LMEMBER2      CHANGE DEFAULT MEMBER LENGTH  02386000
         MVC   MEMBERD+1+2(8),MEMBER2     CHANGE DEFAULT MEMBER NAME    02387000
         MVI   MEMBERD,FMEMBER1           ONLY ONE MEMBER NAME NOW      02388000
         NI    FLAGSEE,FF-FMEMLIST        NO MEMBER LIST                02389000
         BAL   R14,DEFGROUP                    ADD DEFAULT GROUP        02390000
         SPACE 2                                                        02391000
ALIAS1   MVC   DIRNAME,MEMBER2            SET ALIAS NAME                02392000
         MVI   ENTRYPT,C'?'               ENTRY POINT NOT KNOWN YET     02393000
         TM    DIRFLAG,X'80'              MODULE A CURRENT ALIAS?       02394000
         BZ    ALIAS2                     NO, BRANCH                    02395000
         TM    FLAGSCC,RECFMU             LOAD MODULE?                  02396000
         BO    ALIAS3                     YES, BRANCH                   02397000
         B     ALIAS4                     NO, BRANCH                    02398000
         SPACE 1                                                        02399000
ALIAS2   TM    FLAGSCC,RECFMU             LOAD MODULE?                  02400000
         BZ    ALIAS4                     NO, BRANCH                    02401000
         SPACE 1                                                        02402000
         TM    DIRATTR2,DIRAOSLE+DIRAPFLG VS LKED & APF DATA PRESENT?   02403000
         BZ    ALIAS2Y                    NO, BRANCH                    02404000
         SPACE 1                                                        02405000
         LA    R2,DIRAPF                  POINT TO APF INFORMATION      02406000
         TM    DIRATTR,ATTRSCTR           SCATTER LOADED?               02407000
         BZ    *+8                        NO, BRANCH                    02408000
         LA    R2,DIRAPF3                 YES, POINT TO APF DATA        02409000
         LA    R4,11(,R2)                 POINT TO ALIAS APF DATA       02410000
         TM    DIRATTR2,DIR2SSI           SSI PRESENT?                  02411000
         BZ    ALIAS2B                    NO, BRANCH                    02412000
         SPACE 1                                                        02413000
         LA    R2,1(,R2)                  ROUND TO HALFWORD             02414000
         N     R2,=F'-2'                  FFFFFFFE MASK                 02415000
         LA    R4,1(,R4)                  ROUND TO HALFWORD             02416000
         N     R4,=F'-2'                  FFFFFFFE MASK                 02417000
         MVC   0(4,R4),0(R2)              MOVE SSI INFORMATION          02418000
         LA    R4,4(,R4)                  MOVE PAST SSI INFORMATION     02419000
         LA    R2,4(,R2)                  POINT TO APF DATA             02420000
         SPACE 1                                                        02421000
ALIAS2B  CLI   0(R2),1                    IS APF LENGTH OK?             02422000
         BE    ALIAS2D                    YES, BRANCH                   02423000
         TSMSG L710                       BAD APF INFORMATION FORMAT    02424000
         LA    R2,ZERO                    SET APF=0                     02425000
         SPACE 1                                                        02426000
ALIAS2D  MVI   0(R4),1                    SET PROPER LENGTH             02427000
         MVC   1(1,R4),1(R2)              MOVE IN APF DATA              02428000
         SPACE 3                                                        02429000
ALIAS2Y  LA    R4,DIREP                   POINT TO START OF ALIAS INFO. 02430000
         LA    R5,(DIREND2-DIRUSER+1)/2   NUMBER OF HALFWORDS           02431000
         TM    DIRATTR,ATTRSCTR           SCATTER LOADED?               02432000
         BNO   ALIAS2Z                    NO, BRANCH                    02433000
         LA    R4,DIREPSC                 POINT TO START OF ALIAS INFO. 02434000
         LA    R5,(DIREND3-DIRUSER+1)/2   NUMBER OF HALFWORDS           02435000
         SPACE 2                                                        02436000
ALIAS2Z  MVC   0(3,R4),DIREPA             MOVE IN MAIN MODULE ENTRY     02437000
         MVC   3(8,R4),MEMBER1            ADD MAIN MODULE NAME          02438000
         TM    DIRATTR2,DIR2SSI           SSI INFORMATION?              02439000
         BNO   *+8                        NO, BRANCH                    02440000
         LA    R5,2(,R5)                  YES, TWO MORE HALFWORDS       02441000
         NI    DIRFLAG,X'E0'              TURN OFF HALFWORD COUNT       02442000
         OI    DIRFLAG,*-*                <<EXECUTED>>                  02443000
         EX    R5,*-4                     MOVE IN NUMBER OF HALFWORDS   02444000
         SPACE 1                                                        02445000
ALIAS3   TM    DIRFLAG,X'80'              ALIAS ENTRY?                  02446000
         BO    ALIAS3S                    YES, BRANCH                   02447000
         NI    DIRATTR3,FF-DIRAA64-DIRAA31                         @D02
         TM    DIRATTR3,DIRAM64           AMODE 64?                @D02
         BNO   *+8                        NO, BRANCH               @D02
         OI    DIRATTR3,DIRAA64           YES, SET THE DIRECTORY   @D02
         TM    DIRATTR3,DIRAM31           AMODE 31?                @D02
         BNO   *+8                        NO, BRANCH               @D02
         OI    DIRATTR3,DIRAA31           YES, SET THE DIRECTORY   @D02
         SPACE 1                                                        02455000
ALIAS3S  L     R15,=A(READESD)            SCAN ESD FOR MEMBER NAME      02456000
         BALR  R14,R15                    MEMBER NAME IN ESD ENTRIES?   02457000
         B     ALIAS4                     NO, PSEUDO ENTRY              02458000
         SPACE 1                                                        02459000
         OI    DIRATTR+1,ATTREP0          ASSUME ENTRY POINT ZERO       02460000
         LTR   R1,R1                      CORRECT?                      02461000
         BZ    *+8                        YES, BRANCH                   02462000
         XI    DIRATTR+1,ATTREP0          NO, INSURE ATTR FLAG OFF      02463000
         STCM  R1,B'0111',DIREPA          SAVE ENTRY ADDRESS            02464000
         TM    DIRATTR,ATTRSCTR           SCATTER LOADED?               02465000
         BNO   *+8                        NO, BRANCH                    02466000
         STCM  R15,B'0011',DIRSCEP        YES, SAVE ESDID OF ENTRY PT.  02467000
         STC   R0,#ALIAESD                SAVE MODE RMODE/AMODE INFO    02468000
         TM    DIRATTR,ATTROVLY           OVERLAY ATTRIBUTES            02469000
         BO    ALIAS4                     YES, BRANCH                   02470000
         NI    DIRATTR3,FF-DIRAA64-DIRAA31                         @D02
         TM    #ALIAESD,AMODE64           AMODE 64?                @D02
         BNO   *+8                        NO, BRANCH               @D02
         OI    DIRATTR3,DIRAA64           YES, SET THE DIRECTORY   @D02
         TM    #ALIAESD,AMODE31           AMODE 31?                @D02
         BNO   *+8                        NO, BRANCH               @D02
         OI    DIRATTR3,DIRAA31           YES, SET THE DIRECTORY   @D02
         SPACE 1                                                   @D02
         TM    DIRATTR3,DIRRMANY          RMODEANY?                @D02
         BNO   ALIAS4                     NO, BRANCH               @D02
         SPACE 1                                                   @D02
         NI    DIRATTR3,FF-DIRAA64                                 @D02
         OI    DIRATTR3,DIRAA31           RESET AS AMODE31         @D02
         SPACE 1                                                        02478000
ALIAS4   OI    DIRFLAG,X'80'              SET ALIAS FLAG                02479000
         BAL   R2,OPENSTOW                OPEN STOW DCB; ENQUEUES       02480000
         B     NEWCMD                     COULD NOT OPEN -- ERROR       02481000
         STOW  STOWDCB,DIRNAME,A          ADD ALIAS TO DIRECTORY        02482000
         SPACE 1                                                        02483000
         B     *+4(R15)                PROCESS RETURN CODE              02484000
         B     ALIAS5                     00 - SUCCESSFUL               02485000
         B     MEMEXIST                   04 - MEMBER ALREADY EXISTS    02486000
         EX    0,*                        08 - SHOULD NOT HAPPEN - ADD  02487000
         B     FULLDIR                    12 - DIRECTORY IS FULL        02488000
         B     IOERROR                    16 - I/O ERROR IN DIRECTORY   02489000
         SPACE 3                                                        02490000
ALIAS5   TSMSG L010                       MSG - ALIAS ASSIGNED          02491000
         TM    FLAGSCC,RECFMU             MUST WE GIVE ENTRY POINT?     02492000
         BZ    NEWCMD                     NO, BRANCH                    02493000
         UNPK  INSERT#1(7),DIREPA(4)                                    02494000
         TR    INSERT#1(6),TRTABLE                                      02495000
         MVC   INSERT#1+6(2),BLANKS                                     02496000
         MVC   INSERT#2(8),ENTRYPT    NAME OF THE ENTRY POINT           02497000
         TR    INSERT#2(8),TRLINE     MAKE PRINTABLE                    02498000
         LA    R1,L102$1              ASSUME NONE FOUND                 02499000
         CLI   ENTRYPT,C'?'           ANY FOUND?                        02500000
         BE    *+8                    NO, BRANCH                        02501000
         LA    R1,L103$2              YES, SHOW ENTRY SYMBOL            02502000
         TSMSG (R1)                                                     02503000
         B     NEWCMD                                                   02504000
         TITLE 'P D S  --  PDS ATTRIB                          1/15/85' 02505000
*********************************************************************** 02506000
***      ATTRIB SUBCOMMAND                                          *** 02507000
*********************************************************************** 02508000
*                                                                       02509000
         SPACE 1                                                        02510000
ATTRIB   CSECT                                                          02511000
         USING *,R8                                                     02512000
         LA    R1,L530             ASSUME A NON-PARTITIONED DATA SET    02513000
         TM    DSORG,DS1DSGPO      CORRECT?                             02514000
         BZ    MSGNEW              YES, BRANCH                          02515000
         SPACE 1                                                        02516000
         TM    FLAGSCC,RECFMU      LOAD MODULE LIBRARY?                 02517000
         BO    ATTR020             YES, BRANCH                          02518000
         SPACE 1                                                        02519000
         MVC   INSERT#1(72),SPFSTATH                                    02520000
         MVI   MTHIGHL,72                                               02521000
         TM    ##ADRCM#+#LSUB,FATTRHDR  HEADER WRITTEN YET?             02522000
         BO    ATTR000                  YES, BRANCH                     02523000
         TSMSG L230$1                                                   02524000
         OI    ##ADRCM#+#LSUB,FATTRHDR  MARK FOR NEXT CALL              02525000
         SPACE 1                                                        02526000
ATTR000  MVC   INSERT#1(72),MSGBL132+4                                  02527000
         CLI   #SSIOPT,0               ANY SSI CHANGE?                  02528000
         BE    ATTR006                 NO, BRANCH                       02529000
         CLI   #SSIOPT,1               SSI(HEXDATA)?                    02530000
         BE    ATTR002                 YES, BRANCH                      02531000
         NI    DIRFLAG,FF-X'1F'        TURN OFF SSI DATA                02532000
         XC    DIRSTART(4),DIRSTART    CLEAR THE SSI FIELD              02533000
         B     ATTR006                                                  02534000
         SPACE 1                                                        02535000
ATTR002  MVC   DIRSTART(4),#SSITEXT    ADD THE CURRENT SSI DATA         02536000
         NI    DIRFLAG,FF-X'1F'        TURNS OFF ANY HALFWORDS          02537000
         OI    DIRFLAG,X'02'           ADDS IN TWO HALFWORDS            02538000
         SPACE 1                                                        02539000
ATTR006  MVC   INSERT#1+1(8),DIRNAME                                    02540000
         TM    DIRFLAG,X'80'           ALIAS MEMBER?                    02541000
         BNO   *+10                    NO, BRANCH                       02542000
         MVC   INSERT#1+1+8(2),=C'-A'  YES, ADD A FLAG                  02543000
         LA    R2,DIRUSER          LOAD START OF USER AREA (FOR SSI)    02544000
         TM    DIRFLAG,X'0F'       SPF STATISTICS PRESENT?              02545000
         BNO   ATTR010             NO, BRANCH                           02546000
         OC    DIRSPFZ(3),DIRSPFZ  RESERVED AND 00 OF 00YYDDDF ZEROS?   02547000
         BNZ   ATTR010             NO, BRANCH                           02548000
         CLI   DIRSPFCD,0          00 OF OTHER 00YYDDDF ZERO?           02549000
         BNZ   ATTR010             NO, BRANCH                           02550000
         SPACE 1                                                        02551000
         LA    R2,INSERT#1-7                                            02552000
         SR    R1,R1                                                    02553000
         IC    R1,DIRSPFR          REVISION NUMBER FIRST                02554000
         CVD   R1,DOUBLE                                                02555000
         MVC   21(4,R2),=X'40212020'                                    02556000
         ED    21(4,R2),DOUBLE+6                                        02557000
         MVI   22(R2),C'.'                                              02558000
         IC    R1,DIRSPFV          VERSION NUMBER                       02559000
         CVD   R1,DOUBLE                                                02560000
         MVC   18(4,R2),=X'40212020'                                    02561000
         ED    18(4,R2),DOUBLE+6                                        02562000
         LA    R1,DIRSPFCR+1           POINT TO YYDDDF                  02563000
         LA    R15,FULLWORD+1                                           02564000
         BAL   R14,CONVDATE            CONVERT TO MMDDYY FORMAT         02565000
         MVC   FULLWORD(1),FULLWORD+3  CONVERT TO YYMMDD                02566000
         MVC   26(L'DATEMASK,R2),DATEMASK                               02567000
         ED    26(L'DATEMASK,R2),FULLWORD                               02568000
         LA    R1,DIRSPFCD+1           POINT TO YYDDDF                  02569000
         LA    R15,FULLWORD+1                                           02570000
         BAL   R14,CONVDATE            CONVERT TO MMDDYY FORMAT         02571000
         MVC   FULLWORD(1),FULLWORD+3  CONVERT TO YYMMDD                02572000
         MVC   36(L'DATEMASK,R2),DATEMASK                               02573000
         ED    36(L'DATEMASK,R2),FULLWORD                               02574000
         MVC   45(6,R2),=X'4021207A2020'                                02575000
         ED    45(6,R2),DIRSPFCT       TIME OF LAST CHANGE              02576000
         LH    R1,DIRSPFSI                                              02577000
         CVD   R1,DOUBLE                                                02578000
         MVC   51(6,R2),=X'402020202120'                                02579000
         ED    51(6,R2),DOUBLE+5                                        02580000
         SPACE 1                                                        02581000
         LH    R1,DIRSPFIN                                              02582000
         CVD   R1,DOUBLE                                                02583000
         MVC   57(6,R2),=X'402020202120'                                02584000
         ED    57(6,R2),DOUBLE+5                                        02585000
         LH    R1,DIRSPFMD                                              02586000
         CVD   R1,DOUBLE                                                02587000
         MVC   63(6,R2),=X'402020202120'                                02588000
         ED    63(6,R2),DOUBLE+5                                        02589000
         MVC   71(8,R2),DIRSPFID                                        02590000
         B     ATTR012                 NO SSI FOR SPF-SAVED MEMBERS     02591000
         SPACE 1                                                        02592000
ATTR010  CLC   ZERO,0(R2)              ZERO?                            02593000
         BE    ATTR012                 YES, NO SSI                      02594000
         CLC   =F'-1',0(R2)            FFFFFFFF?                        02595000
         BE    ATTR012                 YES, NO SSI                      02596000
         SPACE 1                                                        02597000
         MVC   INSERT#1+2+8+3(4),=C'SSI:'                               02598000
         UNPK  INSERT#1+2+8+3+5(9),0(5,R2)                              02599000
         TR    INSERT#1+2+8+3+5(8),TRTABLE                              02600000
         MVI   INSERT#1+2+8+3+5+8,X'40'                                 02601000
         SPACE 1                                                        02602000
ATTR012  TSMSG L230$1                  OUTPUT STATISTICS                02603000
         MVI   MTHIGHL,8               RESET THE INSERT LENGTH          02604000
         CLI   #OPTOPT,FF              ANY ILLEGAL CHANGES?             02605000
         BNE   ATTR014                 NO, BRANCH                       02606000
         TSMSG L701                    NOT A LOAD MODULE                02607000
ATTR014  CLI   #OPTOPT,X'F0'           ANY SSI CHANGE?                  02608000
         BE    ATTR240                 YES, BRANCH                      02609000
         B     ATTR600                 CHECK FOR ALIAS                  02610000
         SPACE 3                                                        02611000
ATTR020  TM    FLAGSAA,FHEAD           BLANK SEPARATOR WRITTEN YET?     02612000
         BNO   ATTR022                 NO, BRANCH                       02613000
         MESSAGE MSGBLANK              NOW SEPARATORS CAN BE WRITTEN    02614000
         SPACE 1                                                        02615000
ATTR022  OI    FLAGSAA,FHEAD                                            02616000
         MVI   RLDCOUNT,X'FF'          ASSUME NO RLD/CONTROL DATA       02617000
         MVI   LKEDDATE,X'FF'          ASSUME NO LKED DATE              02618000
         CLI   #RLDERR,X'01'           "RLDFIX" OPERAND?                02619000
         BE    ATTR024                 YES, BRANCH                      02620000
         CLI   #LKEDOPT,X'02'          "NOLKEDDATE"?                    02621000
         BE    ATTR030                 YES, BRANCH                      02622000
         CLI   #LKEDOPT,X'01'          "LKEDDATE" DESIRED?              02623000
         BE    ATTR024                 YES, BRANCH                      02624000
         TM    FLAGSGG,FLKEDCON        NO LKEDDATE DEFAULT?             02625000
         BO    ATTR030                 YES, BRANCH                      02626000
ATTR024  L     R15,=A(READIDR)         FIRST RLD COUNT, LKED DATA       02627000
         BALR  R14,R15                 IDR DATA AVAILABLE?              02628000
         MVI   LKEDDATE,X'FF'          NO, ERROR                        02629000
         SPACE 1                                                        02630000
ATTR030  TM    #OPTOPT,X'F0'           ANY CHANGED ATTRIBUTES?          02631000
         BNO   ATTR250                 NO, BRANCH                       02632000
         SPACE 1                                                        02633000
         CLI   #RLDERR,X'01'           "RLDFIX"?                        02634000
         BNE   ATTR038                 NO, BRANCH                       02635000
         TM    DIRATTR2,DIRAOSLE       OS/VS LINKAGE-EDITOR?            02636000
         BNO   ATTR034                 NO, BRANCH                       02637000
         CLI   RLDCOUNT,X'FF'          ANY RLD/CONTROL DATA FOUND?      02638000
         BE    ATTR034                 NO, BRANCH                       02639000
         MVC   DIRATTR4(1),RLDCOUNT    MODIFY THE DIRECTORY ENTRY       02640000
         B     ATTR038                                                  02641000
ATTR034  TSMSG L723                    NO CHANGE IS POSSIBLE            02642000
         SPACE 2                                                        02643000
ATTR038  CLI   #AUTHOPT,X'01'          CHANGE APF PROCESSING?           02644000
         BL    ATTR060                 NO, BRANCH                       02645000
         BE    ATTR040                 YES, BRANCH                      02646000
         TM    DIRATTR2,DIRAOSLE+DIRAPFLG  NEED CHANGE APF INFORMATION? 02647000
         BNO   ATTR060                     NO, BRANCH                   02648000
         SPACE 1                                                        02649000
ATTR040  TM    DIRATTR2,DIRAOSLE+DIRAPFLG  CAN CHANGE APF INFORMATION?  02650000
         BNO   ATTR050                     NO, BRANCH                   02651000
         LA    R2,DIRAPF                   YES, POINT TO APF DATA       02652000
         TM    DIRATTR,ATTRSCTR        SCATTER LOAD?                    02653000
         BNO   *+8                     NO, BRANCH                       02654000
         LA    R2,8(,R2)               SCATTER SIZE                     02655000
         TM    DIRFLAG,X'80'           ALIAS?                           02656000
         BO    ATTR044                 YES, BRANCH                      02657000
         CLI   8(R2),0                 CONVERTED ALIAS ENTRY?           02658000
         BE    *+8                     NO, BRANCH                       02659000
ATTR044  LA    R2,11(,R2)              ADD ALIAS LENGTH                 02660000
         TM    DIRATTR2,DIR2SSI        SSI?                             02661000
         BNO   *+12                    NO, BRANCH                       02662000
         LA    R2,5(,R2)               ADD 4 AND ROUND TO HALFWORD      02663000
         N     R2,=F'-2'                                                02664000
         CLI   0(R2),1                 LENGTH RIGHT?                    02665000
         BNE   ATTR050                 NO, BRANCH                       02666000
         MVI   1(R2),1                 ASSUME TURN AUTHORIZATION ON     02667000
         CLI   #AUTHOPT,X'01'          CORRECT?                         02668000
         BE    ATTR060                 YES, BRANCH                      02669000
         MVI   1(R2),0                 NO, TURN OFF                     02670000
         B     ATTR060                                                  02671000
         SPACE 3                                                        02672000
ATTR050  TSMSG L722                        INVALID APF DATA LENGTH      02673000
         SPACE 2                                                        02674000
ATTR060  CLI   #PAGEOPT,X'01'              CHANGE PAGE ALIGNMENT?       02675000
         BL    ATTR100                     NO, BRANCH                   02676000
         BE    ATTR070                     YES, BRANCH                  02677000
         TM    DIRATTR2,DIRAOSLE+DIRAPFLG  NEED CHANGE PAGE INFO?       02678000
         BNO   ATTR100                     NO, BRANCH                   02679000
         SPACE 1                                                        02680000
ATTR070  TM    DIRATTR2,DIRAOSLE+DIRAPFLG  CAN CHANGE PAGE INFORMATION? 02681000
         BNO   ATTR080                     NO, BRANCH                   02682000
         OI    DIRATTR2,DIR2PAGA           ASSUME TURN ON PAGE BOUNDARY 02683000
         CLI   #PAGEOPT,X'01'              CORRECT?                     02684000
         BE    ATTR100                     YES, BRANCH                  02685000
         NI    DIRATTR2,FF-DIR2PAGA        NO, TURN OFF PAGE BOUNDARY   02686000
         B     ATTR100                                                  02687000
         SPACE 1                                                        02688000
ATTR080  TSMSG L726                    PAGE ALIGNMENT CANNOT BE CHANGED 02689000
         SPACE 2                                                        02690000
ATTR100  CLI   #RMODE,1                    ANY RMODE CHANGE?            02691000
         BL    ATTR120                     NO, BRANCH                   02692000
         BH    ATTR110                     YES, BRANCH                  02693000
         TM    DIRATTR2,DIRAOSLE           CAN CHANGE RMODE?            02694000
         BNO   ATTR120                     NO, BRANCH                   02695000
         SPACE 1                                                        02696000
ATTR110  LA    R1,L724                     NOT MVS LKED MESSAGE         02697000
         TM    DIRATTR2,DIRAOSLE           CAN CHANGE RMODE?            02698000
         BNO   ATTR150                     NO, BRANCH                   02699000
         NI    DIRATTR3,FF-DIRRMANY        SET RMODE=24                 02700000
         CLI   #RMODE,1                    CORRECT?                     02701000
         BE    ATTR120                     YES, BRANCH                  02702000
         OI    DIRATTR3,DIRRMANY           NO, TURN ON RMODE ANY        02703000
         SPACE 2                                                        02704000
ATTR120  CLI   #AMODE,1                    ANY AMODE CHANGE?            02705000
         BL    ATTR160                     NO, BRANCH                   02706000
         BH    ATTR130                     YES, BRANCH                  02707000
         TM    DIRATTR2,DIRAOSLE           CAN CHANGE AMODE?            02708000
         BNO   ATTR160                     NO, BRANCH                   02709000
         SPACE 1                                                        02710000
ATTR130  LA    R1,L724                     NOT MVS LKED MESSAGE         02711000
         TM    DIRATTR2,DIRAOSLE           CAN CHANGE AMODE?            02712000
         BNO   ATTR150                     NO, BRANCH                   02713000
         TM    DIRFLAG,X'80'               ALIAS ENTRY?                 02714000
         BO    ATTR140                     YES, BRANCH                  02715000
         OI    DIRATTR3,DIRAM64+DIRAM31    MAIN ENTRY              @D02
*                                           -- AMODE=64+31         @D02
         XI    DIRATTR3,DIRAM31            SET AMODE=64            @D02
         CLI   #AMODE,4                    CORRECT?                @D02
         BE    ATTR160                     YES, BRANCH             @D02
         OI    DIRATTR3,DIRAM31            NO, SET AMODE=ANY       @D02
         CLI   #AMODE,3                    CORRECT?                @D02
         BE    ATTR160                     YES, BRANCH             @D02
         XI    DIRATTR3,DIRAM64            SET AMODE=31            @D02
         CLI   #AMODE,2                    CORRECT?                @D02
         BE    ATTR160                     YES, BRANCH             @D02
         NI    DIRATTR3,FF-DIRAM64-DIRAM31 SET AMODE=24            @D02
         B     ATTR160                                                  02724000
         SPACE 1                                                        02725000
ATTR140  OI    DIRATTR3,DIRAA64+DIRAA31    ALIAS ENTRY             @D02
*                                           -- AMODE=64+31         @D02
         XI    DIRATTR3,DIRAA31            SET AMODE=64            @D02
         CLI   #AMODE,4                    CORRECT?                @D02
         BE    ATTR160                     YES, BRANCH             @D02
         OI    DIRATTR3,DIRAA31            NO, SET AMODE=ANY       @D02
         CLI   #AMODE,3                    CORRECT?                @D02
         BE    ATTR160                     YES, BRANCH             @D02
         XI    DIRATTR3,DIRAA64            SET AMODE=31            @D02
         CLI   #AMODE,2                    CORRECT?                @D02
         BE    ATTR160                     YES, BRANCH             @D02
         NI    DIRATTR3,FF-DIRAA64-DIRAA31 SET AMODE=24            @D02
         B     ATTR160                                             @D02
         SPACE 1                                                        02735000
ATTR150  TSMSG (R1)                        AMODE/RMODE MESSAGE          02736000
         SPACE 2                                                        02737000
ATTR160  OC    DIRATTR,#ATTRYES        ADD POSITIVE ATTRIBUTES          02738000
         NC    DIRATTR,#ATTRNO         REMOVE NEGATIVE ATTRIBUTES       02739000
         SPACE 1                                                        02740000
*                                                                       02741000
*   RESTRICTION: BOTH RENT AND REUS MUST BE SPECIFIED FOR REENTRANT     02742000
         TM    DIRATTR,ATTRRENT        WAS REENTRABLE SPECIFIED?        02743000
         BNO   *+8                     NO, BRANCH                       02744000
         OI    DIRATTR,ATTRREUS        YES, ALSO FORCE REUSABLE         02745000
         SPACE 1                                                        02746000
ATTR180  CLI   #SSIOPT,0               SSI(HEXDATA) OR NOSSI?           02747000
         BE    ATTR240                 NO, BRANCH                       02748000
         SR    R1,R1                   SSI INDICATOR                    02749000
         LA    R2,DIRAPF               POINT TO APF INFORMATION         02750000
         TM    DIRATTR,ATTRSCTR        SCATTER FORMAT?                  02751000
         BNO   *+8                     NO, BRANCH                       02752000
         LA    R2,8(,R2)               YES, ADD SCATTER SIZE BYTES      02753000
         SPACE 1                                                        02754000
         TM    DIRFLAG,X'80'           ALIAS?                           02755000
         BO    ATTR182                 YES, BRANCH                      02756000
         CLI   8(R2),0                 CONVERTED ALIAS ENTRY?           02757000
         BE    *+8                     NO, BRANCH                       02758000
ATTR182  LA    R2,11(,R2)              ADD ALIAS LENGTH                 02759000
         SPACE 1                                                        02760000
         LR    R3,R2                   START OF DATA BEFORE ANY SSI     02761000
         LA    R2,1(,R2)               ROUND UP TO HALFWORD             02762000
         N     R2,=F'-2'                                                02763000
         TM    DIRATTR2,DIRAOSLE       VS LINKAGE EDITOR?               02764000
         BO    ATTR184                 YES, BRANCH                      02765000
         SPACE 1                                                        02766000
         CLC   ZERO,0(R2)              ZERO?                            02767000
         BE    ATTR188                 YES, NO SSI                      02768000
         CLC   =F'-1',0(R2)            FFFFFFFF?                        02769000
         BE    ATTR188                 YES, NO SSI                      02770000
         B     ATTR186                 NO, POINT TO SSI                 02771000
         SPACE 1                                                        02772000
ATTR184  TM    DIRATTR2,DIR2SSI        SSI PRESENT?                     02773000
         BNO   ATTR188                 NO, NO SSI                       02774000
         SPACE 1                                                        02775000
ATTR186  LR    R1,R2                   POINT TO SSI                     02776000
ATTR188  LR    R15,R2                  SSI POSITION                     02777000
         SR    R15,R3                  OFFSET FROM LAST DATA TO SSI     02778000
         LA    R15,2(,R15)             ADJUSTMENT AMOUNT                02779000
         CLI   #SSIOPT,1               SSI(HEXDATA)?                    02780000
         BE    ATTR200                 YES, BRANCH                      02781000
         SPACE 1                                                        02782000
*** NOSSI                                                               02783000
         LTR   R1,R1                   ANY SSI?                         02784000
         BZ    ATTR240                 NO, DONE                         02785000
         ICM   R0,B'0011',4(R2)        APF BYTES                        02786000
         XC    0(8,R3),0(R3)           CLEAR FOLLOWING BYTES            02787000
         STCM  R0,B'0011',0(R3)        MOVE APF BEFORE THE SSI          02788000
         TM    DIRATTR2,DIRAOSLE       VS LINKAGE EDITOR?               02789000
         BNO   *+8                     NO, BRANCH                       02790000
         NI    DIRATTR2,FF-DIR2SSI     NO SSI PRESENT                   02791000
         LA    R3,2+1(,R3)             2 FOR APF AND 1 FOR ROUNDING     02792000
         B     ATTR214                                                  02793000
         SPACE 2                                                        02794000
ATTR200  LTR   R1,R1                   SSI ALREADY?                     02795000
         BZ    ATTR210                 NO, BRANCH                       02796000
*** SSI(HEXTEXT) WITH EXISTING SSI INFORMATION                          02797000
         MVC   0(4,R2),#SSITEXT        UPDATE THE SSI DATA              02798000
         B     ATTR240                                                  02799000
         SPACE 2                                                        02800000
*** SSI(HEXTEXT) WITH NO PREVIOUS SSI INFORMATION                       02801000
ATTR210  ICM   R0,B'0011',0(R3)        APF BYTES                        02802000
         MVC   0(4,R2),#SSITEXT        MOVE IN ADDED SSI DATA           02803000
         STCM  R0,B'0011',4(R2)        RESET THE APF INFORMATION        02804000
         TM    DIRATTR2,DIRAOSLE       VS LINKAGE EDITOR?               02805000
         BNO   *+8                     NO, BRANCH                       02806000
         OI    DIRATTR2,DIR2SSI        SSI PRESENT                      02807000
         LA    R3,4+2(,R2)             4 FOR SSI AND 2 FOR APF          02808000
         SPACE 1                                                        02809000
ATTR214  LA    R0,DIRSTART             FIRST BYTE AFTER DIRFLAG         02810000
         SR    R3,R0                   LENGTH OF ADDED DATA             02811000
         SRL   R3,1                    IN HALFWORDS                     02812000
         NI    DIRFLAG,FF-X'1F'        REMOVE LENGTH BITS               02813000
         IC    R0,DIRFLAG              PICK UP ALIAS FLAG, TTR COUNT    02814000
         OR    R0,R3                   ADD IN NEW LENGTH IN HALFWORDS   02815000
         STC   R0,DIRFLAG              UPDATE DIRECTORY FLAG ENTRY      02816000
         SPACE 2                                                        02817000
ATTR240  BAL   R2,OPENSTOW             OPEN STOW DCB; ENQUEUES          02818000
         B     NEWCMD                  COULD NOT OPEN -- ERROR          02819000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR                        02820000
         STOW  STOWDCB,DIRNAME,R       REPLACE OPTION                   02821000
         LR    R5,R15                  SAVE RETURN CODE                 02822000
***      BAL   R2,SHUTSTOW             *** CLOSE STOW AFTER NEWCMD      02823000
         SPACE 1                                                        02824000
         B     *+4(R5)                 PROCESS RETURN CODE              02825000
         B     ATTR250                   00 - SUCCESSFUL                02826000
         EX    0,*                       04 - SHOULD NOT OCCUR          02827000
         EX    0,*                       08 - SHOULD NOT OCCUR          02828000
         B     FULLDIR                   12 - DIRECTORY FULL            02829000
         B     IOERROR                   16 - I/O ERROR                 02830000
         SPACE 3                                                        02831000
ATTR250  TM    FLAGSCC,RECFMU          LOAD LIBRARY?                    02832000
         BNO   ATTR600                 NO, CHECK FOR ALIASES            02833000
         MVC   INSERT#1(8),DIRNAME     MEMBER NAME                      02834000
         MVC   INSERT#2(132),MSGBL132+4                                 02835000
         LA    R1,INSERT#2-1           FIRST COMMA ADDRESS (HIDDEN)     02836000
         MVC   INSERT#2+1(4),=C'NONE'  IF NO SPECIAL ATTRIBUTES         02837000
         LA    R14,TBLATTR-12          ATTRIBUTES TABLE                 02838000
         LH    R2,DIRATTR              GET MODULE ATTRIBUTES            02839000
         SPACE 2                                                        02840000
ATTR300  LA    R14,12(R14)                                              02841000
         CLI   0(R14),X'FF'            END OF TABLE?                    02842000
         BE    ATTR310                 YES, BRANCH                      02843000
         SPACE 1                                                        02844000
         LH    R15,0(R14)              GET ATTRIBUTE FLAGS              02845000
         TM    2(R14),X'80'            POSITIVE OR NEGATIVE ATTRIBUTE?  02846000
         LA    R3,X'80'                MASK FOR POS (FOR BZ INST)       02847000
         BZ    *+8                                                      02848000
         LA    R3,X'70'                MASK FOR NEG (FOR BNZ) INST      02849000
         NR    R15,R2                  CHECK FOR ATTRIBUTE PRESENT      02850000
         NOP   ATTR300                 <<BZ OR BNZ>>                    02851000
         EX    R3,*-4                  BRANCH IF NO DISPLAY ATTRIBUTE   02852000
         SPACE 1                                                        02853000
         MVC   0(6,R1),=C',     '      COMMA AND FOLLOWING BLANKS       02854000
         IC    R15,2(R14)              LENGTH-1 OF ATTRIBUTE            02855000
         LA    R3,X'7F'                MASK FOR 7 BITS                  02856000
         NR    R15,R3                                                   02857000
         MVC   2(*-*,R1),3(R14)        <<EXECUTED>>                     02858000
         EX    R15,*-6                                                  02859000
         LA    R1,3(R15,R1)            JUMP POINTER                     02860000
         B     ATTR300                                                  02861000
         SPACE 2                                                        02862000
ATTR310  MVI   MTHIGHL+4,127                                            02863000
         TSMSG L020$2                  ATTRIBUTES MSG                   02864000
         MVI   MTHIGHL+4,8                                              02865000
         SPACE 2                                                        02866000
         LA    R2,DIRAPF               POINT TO APF INFORMATION         02867000
         SPACE 1                                                        02868000
         TM    DIRATTR,ATTRSCTR        SCATTER FORMAT?                  02869000
         BNO   *+8                     NO, BRANCH                       02870000
         LA    R2,8(,R2)               YES, ADD SCATTER SIZE BYTES      02871000
         SPACE 1                                                        02872000
         TM    DIRFLAG,X'80'           ALIAS?                           02873000
         BO    ATTR314                 YES, BRANCH                      02874000
         CLI   8(R2),0                 CONVERTED ALIAS ENTRY?           02875000
         BE    *+8                     NO, BRANCH                       02876000
ATTR314  LA    R2,11(,R2)              ADD ALIAS LENGTH                 02877000
         SPACE 1                                                        02878000
         TM    DIRATTR2,DIRAOSLE       VS LINKAGE EDITOR?               02879000
         BO    ATTR330                 YES, BRANCH                      02880000
         TSMSG L022                    NON-VS LINKAGE EDITOR MESSAGE    02881000
         B     ATTR340                                                  02882000
         SPACE 1                                                        02883000
ATTR330  TM    DIRATTR2,DIR2SSI        SSI PRESENT?                     02884000
         BNO   ATTR360                 NO, SKIP SSI PROCESSING          02885000
         SPACE 1                                                        02886000
ATTR340  LA    R2,1(,R2)               ROUND UP TO HALFWORD             02887000
         N     R2,=F'-2'                                                02888000
         SPACE 1                                                        02889000
         CLC   ZERO,0(R2)              ZERO?                            02890000
         BE    ATTR360                 YES, NO SSI                      02891000
         CLC   =F'-1',0(R2)            FFFFFFFF?                        02892000
         BE    ATTR360                 YES, NO SSI                      02893000
         SPACE 1                                                        02894000
         UNPK  INSERT#1(9),0(5,R2)                                      02895000
         TR    INSERT#1(8),TRTABLE                                      02896000
         TSMSG L025$1                                                   02897000
         LA    R2,4(,R2)               ADD SSI SIZE                     02898000
         SPACE 2                                                        02899000
ATTR360  TM    FLAGSCC,RECFMU          LOAD MODULE LIB?                 02900000
         BZ    ATTR600                 NO, BRANCH                       02901000
         SPACE 1                                                        02902000
         MVI   MODESAVE,0                                               02903000
         TM    DIRATTR2,DIRAOSLE           VS LINKAGE EDITOR?           02904000
         BZ    ATTR540                     NO, CANNOT BE AUTHORIZED     02905000
         SR    R1,R1                                                    02906000
         IC    R1,DIRATTR3                 AMODE BITS                   02907000
         TM    DIRFLAG,X'80'               ALIAS?                       02908000
         BNO   *+8                         NO, BRANCH                   02909000
         SRL   R1,2                        YES, SHIFT AMODE BITS        02910000
         STC   R1,MODESAVE                 SAVE CURRENT AMODE           02911000
         TM    DIRATTR3,DIRRMANY           RMODE ANY?                   02912000
         BNO   *+8                         NO, BRANCH                   02913000
         OI    MODESAVE,DIRRMANY           YES, SET RMODE AGAIN         02914000
         SPACE 1                                                        02915000
         TM    MODESAVE,DIRRMANY+DIRAM31+DIRAM64 UNUSUAL           @D02
*                                                RMODE/AMODE?      @D02
         BZ    ATTR400                     NO, BRANCH              @D02
         MVC   INSERT#1(8),BLANKS          RMODE FILLER            @D02
         MVC   INSERT#2(8),BLANKS          AMODE FILLER            @D02
         MVC   INSERT#1(3),=C'24 '         MOVE IN THE RMODE TEXT  @D02
         MVI   MTLEN,2                     Set RMODE insert length @D02
         TM    MODESAVE,DIRRMANY           RMODE ANY?              @D02
         BZ    ATTR363                     NO, BRANCH              @D02
         MVC   INSERT#1(3),=C'ANY'         MOVE IN THE RMODE TEXT  @D02
         MVI   MTLEN,3                     Set RMODE insert length @D02
ATTR363  DS    0H                                                  @D02
         MVC   INSERT#2(3),=C'24 '         Assume AMODE=24         @D02
         MVI   MTLEN+4,2                   Set AMODE insert length @D02
         TM    MODESAVE,DIRAM64+DIRAM31    AMODE anything other    @D02
*                                           than 24?               @D02
         BZ    ATTR365                     No, display AMODE=24    @D02
         MVC   INSERT#2(3),=C'ANY'         Assume AMODE=ANY        @D02
         MVI   MTLEN+4,3                   Set AMODE insert length @D02
         BO    ATTR365                     Yes, display AMODE=ANY  @D02
         MVC   INSERT#2(3),=C'64 '         Assume AMODE=64         @D02
         MVI   MTLEN+4,2                   Set AMODE insert length @D02
         TM    MODESAVE,DIRAM31            AMODE 31?               @D02
         BZ    ATTR365                     No, display amode=64    @D02
         MVC   INSERT#2(3),=C'31 '         Else AMODE must be 31   @D02
ATTR365  DS    0H                                                  @D02
         TSMSG L120$2                                                   02931000
         MVI   MTLEN+4,8                   Restore standard length @D02
         TM    MODESAVE,DIRRMANY           RMODE ANY?              @D02
         BZ    ATTR400                     NO, BRANCH              @D02
         LA    R1,=C'ANY'                  ASSUME AMODE IS ANY     @D02
         MVI   MTLEN,3                     Set insert length       @D02
         TM    MODESAVE,DIRAM64+DIRAM31    AMODE ANY?              @D02
         BO    ATTR370                     YES, INVALID            @D02
         TM    MODESAVE,DIRAM31            AMODE 31?               @D02
         BO    ATTR400                     YES, BRANCH             @D02
         TM    MODESAVE,DIRAM64            AMODE 64?               @D02
         BO    ATTR400                     YES, BRANCH             @D02
         LA    R1,=C'24 '                  AMODE IS 24             @D02
         MVI   MTLEN,2                     Set insert length       @D02
ATTR370  MVC   INSERT#1(8),BLANKS                                       02940000
         MVC   INSERT#1(3),0(R1)           MOVE IN THE AMODE TEXT       02941000
         TSMSG L880$1                      RMODE ANY/AMODE CONFLICT     02942000
         SPACE 2                                                        02943000
ATTR400  MVI   MTLEN,8                     Restore standard length @D02
         CLI   RLDCOUNT,X'FF'          ANY DATA TO CHECK?               02944000
         BE    ATTR500                 NO, BRANCH                       02945000
         CLC   RLDCOUNT(1),DIRATTR4    RLD/CONTROL AMOUNTS AGREE?       02946000
         BE    ATTR500                 YES, BRANCH                      02947000
         TSMSG L826                                                     02948000
         SPACE 2                                                        02949000
ATTR500  TM    DIRATTR2,DIR2PAGA       PAGE ALIGNMENT REQUIRED?         02950000
         BNO   ATTR510                 NO, BRANCH                       02951000
         TSMSG L024                    PAGE ALIGNMENT REQUIRED          02952000
         SPACE 2                                                        02953000
ATTR510  LA    R1,L720                 ASSUME NO APF DATA               02954000
         TM    DIRATTR2,DIRAPFLG       APF DATA PRESENT AND VALID?      02955000
         BNO   ATTR530                 NO, BRANCH                       02956000
         SPACE 1                                                        02957000
         LA    R1,L721                 ASSUME APF LENGTH INCORRECT      02958000
         CLI   0(R2),1                 APF DATA LENGTH OK?              02959000
         BNE   ATTR530                 NO, BRANCH                       02960000
         SPACE 3                                                        02961000
         LA    R1,L021                 ASSUME AUTHORIZED                02962000
         CLI   1(R2),1                 AUTHORIZED?                      02963000
         BE    ATTR530                 YES, BRANCH                      02964000
         BL    ATTR540                 NO, APF=0 (NO MESSAGE NEEDED)    02965000
         LA    R1,L023                 APF DATA IS TOO LARGE            02966000
         SPACE 1                                                        02967000
ATTR530  TSMSG (R1)                                                     02968000
         SPACE 2                                                        02969000
ATTR540  TM    DIRATTR,ATTROVLY                OVERLAY DEFINED?         02970000
         BNO   ATTR550                         NO, BRANCH               02971000
         MVC   INSERT#1(8),BLANKS              BLANK FILL               02972000
         MVC   INSERT#1(4),REUSTXT+3           OVERLAY AND REENTRANT    02973000
         TM    DIRATTR,ATTRRENT                CORRECT?                 02974000
         BNO   ATTR542                         NO, BRANCH               02975000
         TSMSG L884$1                          YES, ERROR               02976000
ATTR542  MVC   INSERT#1(4),REUSTXT+3           OVERLAY AND REUSABLE     02977000
         TM    DIRATTR,ATTRREUS                CORRECT?                 02978000
         BNO   ATTR543                         NO, BRANCH               02979000
         TSMSG L884$1                          YES, ERROR               02980000
ATTR543  MVC   INSERT#1(4),REFRTXT+3           OVERLAY AND REFRESHABLE  02981000
         TM    DIRATTR+1,ATTRREFR              CORRECT?                 02982000
         BNO   ATTR544                         NO, BRANCH               02983000
         TSMSG L884$1                          YES, ERROR               02984000
ATTR544  MVC   INSERT#1(4),SCTRTXT+3           OVERLAY AND SCATTER      02985000
         TM    DIRATTR,ATTRSCTR                CORRECT?                 02986000
         BNO   ATTR545                         NO, BRANCH               02987000
         TSMSG L884$1                          YES, ERROR               02988000
ATTR545  TM    DIRATTR2,DIRAOSLE               MVS LINKAGE-EDITOR?      02989000
         BNO   ATTR550                         NO, BRANCH               02990000
         MVC   INSERT#1(5),=C'RMODE'                                    02991000
         MVC   INSERT#1+6(3),=C'ANY'           RMODE ANY                02992000
         TM    MODESAVE,DIRRMANY               CORRECT?                 02993000
         BNO   ATTR546                         NO, BRANCH               02994000
         TSMSG L884$1                          YES, ERROR               02995000
ATTR546  MVI   INSERT#1,C'A'                   AMODE ANY                02996000
         TM    MODESAVE,DIRAM31+DIRAM64        AMODE ANY?          @D02
         BO    ATTR548                         YES, ERROR          @D02
         MVC   INSERT#1+6(3),=C'31 '           AMODE 31            @D02
         TM    MODESAVE,DIRAM31                AMODE 31?           @D02
         BO    ATTR548                         YES, ERROR          @D02
         MVC   INSERT#1+6(3),=C'64 '           AMODE 64            @D02
         TM    MODESAVE,DIRAM64                AMODE 64?           @D02
         BO    ATTR548                         YES, ERROR          @D02
         B     ATTR550                         NO, BRANCH          @D02
ATTR548  DS    0H                                                  @D02
         TSMSG L884$1                          YES, ERROR               03002000
         SPACE 1                                                        03003000
ATTR550  TM    DIRATTR+1,ATTRSYMS+ATTRNE       TEST AND NOT EDIT?       03004000
         BNO   ATTR560                         NO, BRANCH               03005000
         TSMSG L882                            YES, ERROR               03006000
         SPACE 1                                                        03007000
ATTR560  TM    DIRATTR,ATTRRENT                REENTRANT?               03008000
         BNO   ATTR570                         NO, BRANCH               03009000
         TM    DIRATTR,ATTRREUS                REUSABLE?                03010000
         BO    ATTR570                         YES, BRANCH              03011000
         TSMSG L881                            ERROR MESSAGE            03012000
         SPACE 1                                                        03013000
ATTR570  TM    DIRATTR,ATTRREUS+ATTRSCTR       REUSABLE AND SCATTER?    03014000
         BNO   ATTR590                         NO, BRANCH               03015000
         TSMSG L883                            YES, ERROR               03016000
         SPACE 2                                                        03017000
ATTR590  UNPK  INSERT#1(7),DIREPA(4)                                    03018000
         TR    INSERT#1(6),TRTABLE                                      03019000
         MVC   INSERT#1+6(2),BLANKS                                     03020000
         TSMSG L102$1                 NO ENTRY POINT MESSAGE            03021000
         SPACE 1                                                        03022000
         UNPK  INSERT#1(7),DIRSTORE(4)                                  03023000
         TR    INSERT#1(6),TRTABLE                                      03024000
         MVC   INSERT#1+6(2),BLANKS                                     03025000
         ICM   R1,B'0111',DIRSTORE    ACTUAL MODULE LENGTH              03026000
         LA    R1,1023(,R1)           NEXT HIGHER                       03027000
         SRL   R1,10                             1K VALUE               03028000
         CVD   R1,DOUBLE                                                03029000
         MVC   INSERT#2(8),=X'402020202120D2404040'                     03030000
         ED    INSERT#2(6),DOUBLE+5                                     03031000
         TSMSG L104$2                                                   03032000
         SPACE 2                                                        03033000
         CLI   LKEDDATE,X'FF'          ANY DATA TO OUTPUT?              03034000
         BE    ATTR600                 NO, BRANCH                       03035000
         CLI   #LKEDOPT,X'02'          "NOLKEDDATE" DESIRED?            03036000
         BE    ATTR600                 YES, BRANCH                      03037000
         CLI   #LKEDOPT,X'01'          "LKEDDATE" DESIRED?              03038000
         BE    *+12                    YES, BRANCH                      03039000
         TM    FLAGSGG,FLKEDCON        NO LKEDDATE DEFAULT?             03040000
         BO    ATTR600                 YES, BRANCH                      03041000
         SPACE 1                                                        03042000
         MVC   INSERT#1-1(9),DATEMASK                                   03043000
         ED    INSERT#1-1(9),LKEDDATE                                   03044000
         SPACE 1                                                   @D01
         MVI   MTLEN+4,18+14                      Insert length    @D01
         MVC   INSERT#2(10),LKEDNAME              LKED name        @D01
         MVC   INSERT#2+10(2),=CL2' V'            Constant "V"     @D01
         UNPK  INSERT#2+10+2(3),LKEDVVMM(2)       Version          @D01
         MVC   INSERT#2+10+2+2(2),=CL2' M'        Constant "M"     @D01
         UNPK  INSERT#2+10+2+2+2(3),LKEDVVMM+1(2) Level            @D01
         SPACE 1                                                   @D01
**       TSMSG L106$1                                              @D01 03045000
         TSMSG L064$2                                              @D01
         SPACE 3                                                        03046000
ATTR600  TM    DIRFLAG,X'80'           ALIAS?                           03047000
         BO    ATTR630                 YES, BRANCH                      03048000
         OC    #RMODE(2),#RMODE        ANY RMODE/AMODE CHANGE?          03049000
         BZ    ATTR630                 NO, BRANCH                       03050000
         TM    FLAGSCC,RECFMU          RECFM=U?                         03051000
         BNO   ATTR630                 NO, BRANCH                       03052000
         NI    MODESAVE,DIRRMANY+DIRAM31+DIRAM64                   @D02
         MVC   MSGTEXT2(DIREND-DIRNAME),DIRNAME  SAVE MAIN ENTRY        03054000
         MVI   STARTTR+2,X'01'         TTR=000001 (START OF DIRECTORY)  03055000
         SPACE 1                                                        03056000
ATTR610  MVC   DIRNAME(DIREND-DIRNAME),MSGTEXT2  RESTORE MAIN ENTRY     03057000
         BAL   R14,READDIR             GET NEXT DIRECTORY MEMBER        03058000
         B     ATTR630                 LAST MEMBER PROCESSED            03059000
         SPACE 2                                                        03060000
         CLC   DIRTTR,MEMTTR           TTR'S MATCH?                     03061000
         BNE   ATTR610                 NO, BRANCH                       03062000
         TM    MEMFLAG,X'80'           ALIAS ENTRY?                     03063000
         BNO   ATTR610                 NO, CONTINUE SEARCHING           03064000
         SPACE 2                                                        03065000
         L     R14,DIRPTRS             CURRENT DIRECTORY ENTRY          03066000
         MVC   DIRNAME(DIREND-DIRNAME),0(R14)                           03067000
         SPACE 1                                                        03068000
         MVC   DOUBLE(1),DIRATTR3                                       03069000
         NI    DOUBLE,DIRRMANY+DIRAM31+DIRAM64                     @D02
         CLC   MODESAVE(1),DOUBLE      RMODE/AMODE ENTRIES EQUAL?       03071000
         BE    ATTR610                 YES, BRANCH                      03072000
         NI    DIRATTR3,FF-DIRRMANY-DIRAM31-DIRAM64                @D02
         OC    DIRATTR3(1),MODESAVE    CHANGE THE RMODE/AMODE ENTRY     03074000
         SPACE 1                                                        03075000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   03076000
         STOW  STOWDCB,DIRNAME,R       REPLACE THIS MEMBER ENTRY        03077000
         SPACE 1                                                        03078000
         LR    R5,R15                  SAVE RETURN CODE                 03079000
         MVC   INSERT#1(8),DIRNAME     MEMBER NAME                      03080000
         TSMSG L065$1                                                   03081000
         LTR   R15,R5                  SUCCESSFUL?                      03082000
         BNZ   IOERROR                 NO, I/O ERROR                    03083000
         B     ATTR610                 CONTINUE FOR ALL ALIASES         03084000
         SPACE 2                                                        03085000
ATTR630  NI    FLAGSBB,FF-FLINESET                                      03086000
         CLI   #ALIAOPT,X'01'          "ALIASINFO" DESIRED?             03087000
         BE    ATTR640                 YES, BRANCH                      03088000
         BH    NEWCMD                  "NOALIASINFO", DONE              03089000
         TM    FLAGSGG,FALINCON        NO ALIAS INFORMATION DEFAULT?    03090000
         BO    NEWCMD                  YES, BRANCH                      03091000
         TM    FLAGSCC,RECFMU          RECFM=U?                         03092000
         BO    ATTR640                 YES, BRANCH                      03093000
         TM    DIRFLAG,X'80'           MODULE AN ALIAS?                 03094000
         BNO   NEWCMD                  NO, DONE                         03095000
         SPACE 1                                                        03096000
ATTR640  MVI   STARTTR+2,X'01'         TTR=000001 (START OF DIRECTORY)  03097000
         TM    DIRFLAG,X'80'           MODULE AN ALIAS?                 03098000
         BNO   ATTR900                 NO, FIND ALL ALIASES             03099000
         XC    INSERT#1(8),INSERT#1    NO MAIN(S) FOUND                 03100000
         SPACE 2                                                        03101000
*  LIST ANY CORRESPONDING MAIN MODULE NAMES                             03102000
         SPACE 1                                                        03103000
ATTR800  BAL   R14,READDIR        GET NEXT DIRECTORY MEMBER             03104000
         B     ATTR810            LAST MEMBER PROCESSED                 03105000
         SPACE 1                                                        03106000
         TM    MEMFLAG,X'80'      THIS MODULE AN ALIAS?                 03107000
         BO    ATTR800            YES, IGNORE                           03108000
         CLC   DIRTTR,MEMTTR      TTR MATCH?                            03109000
         BNE   ATTR800            NO, BRANCH                            03110000
         MVC   INSERT#1(8),MEMNAME                                      03111000
         TSMSG L066$1                                                   03112000
         B     ATTR800                                                  03113000
         SPACE 1                                                        03114000
ATTR810  OC    INSERT#1(8),INSERT#1  ANY MAIN(S) FOUND?                 03115000
         BNZ   NEWCMD                YES, BRANCH                        03116000
         TSMSG L860                                                     03117000
         TM    FLAGSCC,RECFMU     LOAD MODULE?                          03118000
         BNO   NEWCMD             NO, BRANCH                            03119000
         MVC   INSERT#1(8),DIRREAL                                      03120000
         SPACE 1                                                        03121000
         TM    DIRATTR,ATTRSCTR   SCATTER LOADED?                       03122000
         BNO   *+10               NO, BRANCH                            03123000
         MVC   INSERT#1(8),DIRREALS                                     03124000
         LA    R1,L861$1                                                03125000
         B     MSGNEW                                                   03126000
         SPACE 2                                                        03127000
*  LIST ANY ALIASES FOR THE MODULE                                      03128000
         SPACE 1                                                        03129000
ATTR900  BAL   R14,READDIR          GET NEXT DIRECTORY MEMBER           03130000
         B     ATTR940              LAST MEMBER PROCESSED               03131000
         SPACE 1                                                        03132000
         CLC   DIRTTR,MEMTTR        TTR MATCH?                          03133000
         BNE   ATTR900              NO, BRANCH                          03134000
         TM    MEMFLAG,X'80'        AN ALIAS?                           03135000
         BO    ATTR910              YES, BRANCH                         03136000
         CLC   DIRNAME(8),MEMNAME   DID I FIND MYSELF?                  03137000
         BE    ATTR900              YES, BRANCH                         03138000
         MVC   INSERT#1(8),MEMNAME                                      03139000
         TSMSG L864$1               THIS IS AN APPARENT ALIAS MEMBER    03140000
         B     ATTR900                                                  03141000
         SPACE 1                                                        03142000
ATTR910  LA    R2,MEMNAME+7                                             03143000
         TM    FLAGSBB,FLINESET     LINE IN PROGRESS?                   03144000
         BO    ATTR920              YES, BRANCH                         03145000
         OI    FLAGSBB,FLINESET     LINE NOW IN PROGRESS                03146000
         LA    R1,80                ASSUME AN ACTIVE MODE               03147000
         AIF ('&CISP' EQ 'NO SPF').MA00260                         @D01
         TM    SPFLAG0,SPFDON       ISPMODE ACTIVE?                     03148000
         BO    ATTR912              YES, BRANCH                         03149000
.MA00260 ANOP  ,                                                   @D01
         TM    CONTOPTN,1           ANY LOG RECORDING?                  03150000
         BO    ATTR912              YES, BRANCH                         03151000
         GTSIZE
         CH    R1,=H'120'           120 OR LESS BYTES?                  03153000
         BL    *+8                  YES, BRANCH                         03154000
         LH    R1,=H'120'           NO, USE 120 BYTES                   03155000
ATTR912  SH    R1,=H'7'             LESS SEVEN FOR PREFIX               03156000
         ST    R1,LINESIZE          CHARACTERS/LINE                     03157000
         MVC   MSGLINE+4(L'MSGALIAS),MSGALIAS                           03158000
         LA    R5,MSGLINE+4+L'MSGALIAS                                  03159000
         MVC   FULLWORD(3),L160$1   MESSAGE IDENTIFIER                  03160000
         SPACE 1                                                        03161000
ATTR920  CLI   0(R2),X'40'          SCAN FOR                            03162000
         BNE   *+8                          LAST                        03163000
         BCT   R2,ATTR920                       NON-BLANK               03164000
         SPACE 1                                                        03165000
         LA    R0,MEMNAME                                               03166000
         SR    R2,R0                                                    03167000
         BNM   *+6                                                      03168000
         SR    R2,R2                                                    03169000
         LA    R15,2(R5,R2)                                             03170000
         LA    R1,MSGLINE                                               03171000
         SR    R15,R1                                                   03172000
         C     R15,LINESIZE                                             03173000
         BNH   ATTR930                                                  03174000
         LA    R1,MSGLINE+4                                             03175000
         SR    R5,R1                                                    03176000
         STC   R5,MTHIGHL                                               03177000
         MVC   INSERT#1(127),MSGLINE+4                                  03178000
         LA    R1,FULLWORD                                              03179000
         TSMSG (R1)                                                     03180000
         MVI   MTHIGHL,8                                                03181000
         MVI   FULLWORD+2,C'9'                                          03182000
         LA    R5,MSGLINE+3         INDENT FOR BLANKS                   03183000
         SPACE 1                                                        03184000
ATTR930  MVI   0(R5),X'40'                                              03185000
         MVC   1(8,R5),MEMNAME                                          03186000
         TR    1(8,R5),TRLINE                                           03187000
         LA    R1,2(R2,R5)                                              03188000
         MVI   0(R1),C','                                               03189000
         LA    R5,3(R2,R5)                                              03190000
         B     ATTR900                                                  03191000
         SPACE 2                                                        03192000
ATTR940  TM    FLAGSBB,FLINESET     LINE IN PROGRESS?                   03193000
         BZ    NEWCMD               NO, EXIT                            03194000
         LA    R1,MSGLINE+5                                             03195000
         SR    R5,R1                                                    03196000
         STC   R5,MTHIGHL                                               03197000
         MVC   INSERT#1(127),MSGLINE+4                                  03198000
         LA    R1,FULLWORD                                              03199000
         TSMSG (R1)                                                     03200000
         MVI   MTHIGHL,8                                                03201000
         B     NEWCMD                                                   03202000
         SPACE 2                                                        03203000
         AIF ('&CISP' EQ 'NO SPF').MA00280                         @D01
         TITLE 'P D S -- PDS BROWSE/EDIT/ISPF/ISPMODE/MEMLIST  1/15/85' 03204000
*********************************************************************** 03205000
***     BROWSE SUBCOMMAND      ADDED BY BRUCE LELAND -- JULY, 1982  *** 03206000
***                                                                 *** 03207000
***     EDIT SUBCOMMAND        ADDED BY BRUCE LELAND -- JULY, 1982  *** 03208000
***                                                                 *** 03209000
***     ISPF SUBCOMMAND        ADDED BY STEVE SMITH  -- MAY,  1984  *** 03210000
***                                                                 *** 03211000
***     ISPMODE SUBCOMMAND     ADDED BY STEVE SMITH  -- AUG., 1984  *** 03212000
***                                                                 *** 03213000
***     MEMLIST SUBCOMMAND     ADDED BY STEVE SMITH  -- SEPT, 1984  *** 03214000
*********************************************************************** 03215000
*                                                                       03216000
         SPACE 1                                                        03217000
BROWSE   CSECT                                                          03218000
         USING *,R8                                                     03219000
         LA    R1,L730                  ASSUME ALREADY UNDER SPF        03220000
         TM    FLAGSFF,FSPFOPT6         CORRECT?                        03221000
         BO    MSGNEWXX                 YES, BRANCH                     03222000
         OI    ##ADRPA#,$A+$D           SET TO CANCEL STAX EXIT         03223000
         LA    R1,L731                  ASSUME SPF DID NOT INITIALIZE   03224000
         TM    FLAGSFF,FSPFERR          CORRECT?                        03225000
         BO    MSGNEWXX                 YES, BRANCH                     03226000
         MVC   MSGTEXT1(8),##SUBCAL     SPF SERVICE REQUESTED           03227000
         CLI   #SPFOLD,X'01'            "NEW" SPECIFIED?                03228000
         BNE   SPFMEMOK                 NO, BRANCH                      03229000
         TM    DSORG,DS1DSGPO           NON-PARTITIONED DATA SET?       03230000
         BZ    SPFMEMOK                 YES, BRANCH                     03231000
         BLDL  INDCB,BLDLLIST           INSURE IT DOES NOT EXIST        03232000
         B     *+4(R15)                 PROCESS RETURN CODE             03233000
         B     MEMEXIST                   00 - MEMBER IS NOT NEW        03234000
         B     SPFMEMOK                   04 - MEMBER DOES NOT EXIST    03235000
         B     IOERROR                    08 - I/O ERROR IN DIRECTORY   03236000
         SPACE 1                                                        03237000
SPFMEMOK TM    ##ADRPC#,@I             BROWSE OR EDIT?                  03238000
         BNO   SPFINIT                 NO, ALLOW IT                     03239000
         LA    R1,DIRNAME-1            START OF MEMBER NAME             03240000
         LA    R0,8                    MAXIMUM MEMBER NAME              03241000
         SPACE 1                                                        03242000
SPFMEM2  LA    R1,1(,R1)               SCAN                             03243000
         CLI   0(R1),C'.'                  FOR                          03244000
         BE    BADMEMB                        FIRST                     03245000
         BCT   R0,SPFMEM2                          PERIOD               03246000
         CLI   DIRNAME,X'EF'           NUMERIC FIRST CHARACTER?         03247000
         BH    BADMEMB                 YES, INVALID                     03248000
         SPACE 1                                                        03249000
SPFMEM4  CLC   ##SUBCOM(8),$EDI        EDIT SUBCOMMAND?                 03250000
         BE    SPFMEM5                 YES, BRANCH                      03251000
         CLC   ##SUBCOM(8),$SPF        SPFEDIT SUBCOMMAND?              03252000
         BNE   SPFINIT                 NO, ALLOW IT                     03253000
SPFMEM5  MVC   DSNMEMQ(8),DIRNAME      MEMBER NAME TO TEST              03254000
         BAL   R2,ENQMTEST             MEMBER IN USE?                   03255000
         B     NEWCMD                  YES, ERROR                       03256000
         SPACE 1                                                        03257000
         LA    R1,L702                 ASSUME THIS IS A LOAD LIBRARY    03258000
         TM    FLAGSCC,RECFMU          CORRECT?                         03259000
         BO    MSGNEWXX                YES, BRANCH                      03260000
         SPACE 2                                                        03261000
SPFINIT  TM    FLAGSFF,FSPFCALL+FSPFDIAL  SPF ENVIRONMENT INITIALIZED?  03262000
         BM    SPFLINK                    YES, CALL SPF EDIT/BROWSE     03263000
         BAL   R2,SPFRECUR                NO, INVOKE PDS AS A DIALOG    03264000
         SPACE 3                                                        03265000
SPFLINK  ICM   R15,B'1111',ISPLINK      ISPLINK ADDRESS KNOWN?          03266000
         BNZ   SPFINTRF                 YES, BRANCH                     03267000
         OI    FLAGSFF,FSPFERR          SPF ERROR                       03268000
         MVI   ##ADRCM#,CONTINUE+EDITOR+FABEND                          03269000
         LOAD  EP=ISPLINK               ADDRESS OF SPF INTERFACE MODULE 03270000
         ST    R0,ISPLINK               SAVE ADDRESS FOR LATER          03271000
         XI    FLAGSFF,FSPFERR          NOT AN SPF ERROR NOW            03272000
         MVI   ##ADRCM#,0                                               03273000
SPFINTRF DS    0H                                              SS JUL84 03274000
         STFSMODE ON,INITIAL=YES       ENTER FULLSCREEN MODE            03275000
         CLC   ##SUBCOM(8),$ISM        ISPF DISPLAY MODE SUBCD SS JUL84 03276000
         BE    SPFSETM                 YES, ALLOW IT           SS JUL84 03277000
         CLC   ##SUBCOM(8),$MML        MEMLIST SUBCOMMAND?    ABL OCT84 03278000
         BE    MEMLIST                 YES, ALLOW IT          ABL OCT84 03279000
         BAL   R2,CLOSEIT                 CLOSE THE INPUT DATA SS JUL84 03280000
         SPACE 2                                                        03281000
         XC    RECOVER,RECOVER            NO ESTAE RECOVER ATTEMPTED    03282000
         LA    R0,=CL8'CONTROL'           FIRST PARAMETER               03283000
         LA    R1,=CL8'DISPLAY'           SECOND PARAMETER              03284000
         LA    R2,=CL8'REFRESH'           THIRD PARAMETER               03285000
         STM   R0,R2,MSGTEXT2             SAVE ADDRESSES                03286000
         OI    MSGTEXT2+8,X'80'           LAST                          03287000
         LA    R1,MSGTEXT2                    PARAMETER                 03288000
         L     R15,ISPLINK                                              03289000
         BALR  R14,R15                    LET SPF KNOW                  03290000
         SPACE 1                                                        03291000
         TM    ##ADRPA#,$P                SELECT PANEL SUPPORT SS NOV84 03292000
         BO    SPFP1                      GO PROCESS           SS NOV84 03293000
         BAL   R2,CLOSEIT                 CLOSE THE INPUT DATA SS NOV84 03294000
         CLC   ##SUBCOM(8),$ISP           ISPF SUBCOMMAND?              03295000
         BNE   SPFNOMEN                   NO, BRANCH                    03296000
         LA    R0,=CL8'SELECT'            FIRST PARAMETER               03297000
         LA    R1,29                      16 CHARACTERS                 03298000
         ST    R1,FULLWORD                                              03299000
         LA    R1,FULLWORD                SECOND PARAMETER              03300000
         LA    R2,MSGTEXT1                START OF STRING BYTES         03301000
         STM   R0,R2,MSGTEXT2             SAVE ADDRESSES                03302000
         OI    MSGTEXT2+8,X'80'           MARK END OF LIST (THIRD ITEM) 03303000
         MVC   0(33,R2),ISPPANEL          ADD PANEL(ISR@PRIM) ...       03304000
         OC    #COMMDSZ(2),#COMMDSZ       ANY PARM DATA?                03305000
         BZ    SPFCALL                    NO, BRANCH                    03306000
         MVC   33(80,R2),MSGLINE          ADD THE PARM DATA             03307000
         LA    R1,34                      LENGTH OF PARAMETER STRING    03308000
         AH    R1,#COMMDSZ                LENGTH OF PARAMETER STRING    03309000
         ST    R1,FULLWORD                UPDATE THE PARAMETER LENGTH   03310000
         AR    R2,R1                      POINT TO LAST BYTE +1         03311000
         BCTR  R2,0                       POINT TO LAST BYTE            03312000
         MVI   0(R2),C')'                 LAST PAREN                    03313000
         B     SPFCALL                                                  03314000
         SPACE 2                                                        03315000
SPFNOMEN MVI   MSGTEXT1+8,C''''           ADD A QUOTE                   03316000
         MVC   MSGTEXT1+8+1(44),DSNAME    ADD THE DATA SET NAME         03317000
         LH    R15,DSNLEN                 DSNAME ACTUAL LENGTH          03318000
         LA    R2,MSGTEXT1+8(R15)         POINT TO CURRENT BYTE         03319000
         TM    DSORG,DS1DSGPO             NON-PARTITIONED DATA SET?     03320000
         BZ    SPFALLM                    YES, BRANCH                   03321000
         TM    FLAGSAA,FMEMBER1+FMEMBER2  ALL MEMBERS DESIRED?          03322000
         BNZ   SPFMEMBR                   NO, BRANCH                    03323000
         TM    FLAGSAA,FMEM#MEM           MEMBER GROUP IN PROGRESS?     03324000
         BNO   SPFALLM                    NO, BRANCH                    03325000
         SPACE 1                                                        03326000
SPFMEMBR MVI   1(R2),C'('               MEMBER NAME PARENTHESIS         03327000
         MVC   2(8,R2),DIRNAME          ADD MEMBER NAME                 03328000
         MVI   10(R2),X'40'             INSURE SCAN STOPS               03329000
         LA    R2,1(,R2)                SCAN                            03330000
         CLI   0(R2),X'40'                  FOR FIRST                   03331000
         BNE   *-8                                   BLANK              03332000
         MVI   0(R2),C')'               ADD FINAL PARENTHESIS           03333000
         SPACE 2                                                        03334000
SPFALLM  MVI   1(R2),C''''              ADD FINAL QUOTE                 03335000
         MVI   2(R2),X'40'              ADD FINAL BLANK                 03336000
         LA    R0,MSGTEXT1              FIRST PARAMETER                 03337000
         LA    R1,MSGTEXT1+8            SECOND PARAMETER                03338000
         LA    R2,VOLUME                THIRD PARAMETER                 03339000
         LA    R3,PASSWORD              FOURTH PARAMETER                03340000
         STM   R0,R3,MSGTEXT2           SAVE PARAMETER ADDRESSES        03341000
         MVI   MSGTEXT2+12,X'80'        MARK END OF LIST (FOUR ITEMS)   03342000
         CLI   #SPFMACR,0               ANY MACRO NAME?                 03343000
         BE    SPFCALL                  NO, BRANCH                      03344000
         SR    R4,R4                    FIFTH PARAMETER                 03345000
         LA    R5,#SPFMACR              SIXTH PARAMETER                 03346000
         STM   R0,R5,MSGTEXT2           SAVE PARAMETER ADDRESSES        03347000
         MVI   MSGTEXT2+20,X'80'        MARK END OF LIST (SIX ITEMS)    03348000
         SPACE 1                                                        03349000
SPFCALL  LA    R1,MSGTEXT2              PARAMETER LIST                  03350000
         L     R15,ISPLINK                                              03351000
         BALR  R14,R15                  SPF INTERFACE ROUTINE           03352000
         AIF ('&RETURNX' EQ 'NO').RETURNX                               03353000
         CLI   FLAGSSS,0                ANY RETURN TRAP SET?            03354000
         BE    SPFRET30                 NO, BRANCH                      03355000
         CLC   ##SUBCOM(8),$ISP         ISPF SUBCOMMAND?                03356000
         BNE   SPFRET20                 NO, BRANCH                      03357000
         MVI   FLAGSSS,0                YES, TRAP IS RESET              03358000
         B     SPFRET30                                                 03359000
         SPACE 1                                                        03360000
SPFRET20 CLC   ##SUBCOM(1),FLAGSSS      THIS SERVICE AGAIN?             03361000
         MVI   FLAGSSS,0                                                03362000
         BNE   SPFCALL                  NO, CALL IT AGAIN               03363000
         SPACE 1                                                        03364000
SPFRET30 TM    SPFLAG0,SPFDON           ISPF DIALOG TABLES?             03365000
         BNO   SPFRET35                 NO, BRANCH                      03366000
         CLI   PDSENTRY+3,0             ENTRY TO PDS AS A DIALOG?       03367000
         BE    SPFRET60                 YES, DO NOT RE-INVOKE           03368000
SPFRET35 CLC   ##SUBCOM(8),$ISP         ISPF SUBCOMMAND?                03369000
         BNE   SPFRET40                 NO, BRANCH                      03370000
         CH    R15,=H'4'                YES, RETURN OR EXIT OPTION?     03371000
         BNE   SPFRET60                      NO, BRANCH                 03372000
         MVI   FLAGSSS,C'Z'                  YES, SET RE-INVOKE TRAP    03373000
         B     SPFRET80                                                 03374000
         SPACE 1                                                        03375000
SPFRET40 LA    R1,SPFVDEF               VDEF                            03376000
         LA    R2,SPFZVERB              ZVERB                           03377000
         LA    R3,MSGTEXT2+50           WHERE TO PLACE OUTPUT           03378000
         LA    R4,SPFCHAR               MOVE FUNCTION                   03379000
         L     R15,SPFL8                LENGTH 8                        03380000
         ST    R15,FULLWORD                                             03381000
         LA    R5,FULLWORD              USE AS PARM                     03382000
         STM   R1,R5,MSGTEXT2+20        PARAMETER LIST                  03383000
         OI    MSGTEXT2+20+16,X'80'     END OF LIST                     03384000
         LA    R1,MSGTEXT2+20           START OF PARAMETER LIST         03385000
         L     R15,ISPLINK                                              03386000
         BALR  R14,R15                                                  03387000
         LTR   R15,R15                  DOES ZVERB EXIST?               03388000
         BNZ   SPFRET50                 NO, BRANCH                      03389000
         SPACE 1                                                        03390000
         LA    R1,SPFVGET               VGET                            03391000
         LA    R2,SPFZVERB              ZVERB                           03392000
         LA    R3,SPFSHARE              SHARED                          03393000
         STM   R1,R3,MSGTEXT2+20        PARAMETER LIST                  03394000
         OI    MSGTEXT2+20+8,X'80'      END OF LIST                     03395000
         LA    R1,MSGTEXT2+20           START OF PARAMETER LIST         03396000
         L     R15,ISPLINK                                              03397000
         BALR  R14,R15                                                  03398000
         LTR   R15,R15                  DOES ZVERB EXIST?               03399000
         BNZ   SPFRET50                 NO, BRANCH                      03400000
         SPACE 1                                                        03401000
         CLC   MSGTEXT2+50(3),=C'RET'   RETURN KEY?                     03402000
         BNE   SPFRET50                 NO, BRANCH                      03403000
         MVC   FLAGSSS(1),##SUBCOM      SET THE TRAP CHARACTER          03404000
SPFRET50 LA    R2,SPFVDEL               VDELETE                         03405000
         LA    R3,SPFZVERB              ZVERB                           03406000
         STM   R2,R3,MSGTEXT2+20        PARAMETER LIST                  03407000
         OI    MSGTEXT2+20+4,X'80'      END OF LIST                     03408000
         LA    R1,MSGTEXT2+20           START OF PARAMETER LIST         03409000
         L     R15,ISPLINK                                              03410000
         BALR  R14,R15                                                  03411000
         B     SPFRET80                                                 03412000
SPFVDEF  DC    CL8'VDEFINE'                                             03413000
SPFVDEL  DC    CL8'VDELETE'                                             03414000
SPFZVERB DC    CL8'(ZVERB)'                                             03415000
SPFL8    DC    F'8'                                                     03416000
SPFCHAR  DC    CL8'CHAR'                                                03417000
SPFVGET  DC    CL8'VGET'                                                03418000
SPFSHARE DC    CL8'SHARED'                                              03419000
         SPACE 1                                                        03420000
SPFRET60 MVI   FLAGSSS,0                RESET THE TRAP CHARACTER        03421000
         SPACE 1                                                        03422000
SPFRET80 DS    0H                                                       03423000
.RETURNX ANOP                                                           03424000
         LA    R0,=CL8'CONTROL'           FIRST PARAMETER               03425000
         LA    R1,=CL8'DISPLAY'           SECOND PARAMETER              03426000
         LA    R2,=CL8'SM     '           THIRD PARAMETER               03427000
         LA    R3,=F'1'                   FOURTH PARAMETER              03428000
         STM   R0,R3,MSGTEXT2             SAVE ADDRESSES                03429000
         OI    MSGTEXT2+12,X'80'          LAST                          03430000
         LA    R1,MSGTEXT2                    PARAMETER                 03431000
         L     R15,ISPLINK                                              03432000
         BALR  R14,R15                    LET SPF KNOW                  03433000
*        BAL   R2,CLEAR                 TURN OFF FULL SCREEN MODE       03434000
         NI    ##ADRPA#,FF-$A-$D        DO NOT IGNORE ATTENTION NOW     03435000
         SPACE 1                                                        03436000
         ESTAE 0                        CANCEL THE ESTAE ADDRESS        03437000
         MVC   STAEPARM(4),STAELIST     RESET THE ESTAE ADDRESS         03438000
         ESTAE STAEEXIT,CT,PARAM=(R7),MF=(E,STAEPARM)                   03439000
         MVI   VOLALLOC,X'40'           READ THE DSCB AGAIN             03440000
         SPACE 1                                                        03441000
         MVI   ##ADRCM#,EDITOR          NO REPEATED WARNING MESSAGE     03442000
         L     R1,X'21C'                --> CURRENT TCB                 03443000
         L     R1,X'00C'(,R1)           --> TIOT                        03444000
         LA    R1,24(,R1)               TIOENTRY                        03445000
SPFNTIOT CLI   0(R1),0                  END OF TIOT?                    03446000
         BE    RESTART0                 YES, REALLOCATE AND OPEN AGAIN  03447000
         CLC   4(8,R1),DDNAME           THIS DDNAME?                    03448000
         BE    RESTART4                 YES, JUST OPEN AGAIN            03449000
         SR    R15,R15                                                  03450000
         IC    R15,0(,R1)                                               03451000
         LA    R1,0(R15,R1)                                             03452000
         B     SPFNTIOT                                                 03453000
SPFSETM  DS    0H                       DO FUNCTION            SS JUL84 03454000
         TM    SPFLAG0,SPFDON           ISPMODE ACTIVE?       ABL OCT84 03455000
         BO    SPFSETMM                 YES, BRANCH           ABL OCT84 03456000
         OI    SPFLAG0,SPFDON           ISPMODE ACTIVE NOW     SS JUL84 03457000
         NI    FLAGSBB,FF-FONESHOT      ALWAYS CONTINUE       ABL OCT84 03458000
         TM    SPFLAG0,SPFDSUSP         ISPMODE SUSPENDED?    ABL OCT84 03459000
         BO    SPFSETMM                 YES, BRANCH           ABL OCT84 03460000
         NI    SPFLAG0,255-SPFDSUSP     NO LONGER SUSPENDED   ABL OCT84 03461000
         OI    SPFLAG3,SPFCHN           FORCE MSG TO BE LOGGED SS SEP84 03462000
         MVC   INSERT#1(8),PDSNAME                            ABL OCT84 03463000
         MVC   MTLEN,PDSNAML       Set insert length               @D01
         TSMSG L100$1                                         ABL OCT84 03464000
         MVI   MTLEN,8             Restore standard length         @D01
         MESSAGE MSGBLANK               ONE BLANK LINE        ABL OCT84 03465000
         L     R15,$DSN+8               DO A "DSN" SUBCOMMAND ABL OCT84 03466000
         BR    R15                                            ABL OCT84 03467000
         SPACE 3                                                        03468000
SPFSETMM NI    SPFLAG0,255-SPFDSUSP     SET SUSPEND MODE OFF   SS JUL84 03469000
         NI    SPFLAG3,255-SPFCLIST     END CLIST INTERCEPT    SS NOV84 03470000
         B     NEWCMD                                         ABL OCT84 03471000
         SPACE 3                                                        03472000
*                                                              SS NOV84 03473000
*    SELECT PANEL SUPPORT INTERFACE                            SS NOV84 03474000
*                                                              SS NOV84 03475000
SPFP1    DS    0H                                              SS NOV84 03476000
         ST    R6,SPFSAV6                                      SS NOV84 03477000
         LA    R6,FIRST4K                                      SS NOV84 03478000
         USING FIRST4K,R6                                      SS NOV84 03479000
         TM    ##ADRPA#,$J                MEMBERS PRESENT      SS NOV84 03480000
         BO    SPFP10                     PROCESS WITHOUT      SS NOV84 03481000
         TM    DSORG,DS1DSGPO             NON-PARTITIONED DATA SET?     03482000
         BZ    SPFP10                     YES, BRANCH                   03483000
         TM    FLAGSAA,FMEMBER1+FMEMBER2  ALL MEMBERS DESIRED?          03484000
         BNZ   SPFP5                      NO, BRANCH                    03485000
         TM    FLAGSAA,FMEM#MEM           MEMBER GROUP IN PROGRESS?     03486000
         BNO   SPFP10                     NO, BRANCH                    03487000
SPFP5    MVC   SPFMEMB,DIRNAME            SET CURRENT MEMBER   SS NOV84 03488000
         B     SPFP20                                          SS NOV84 03489000
SPFP10   MVI   SPFMEMB,C' '                                    SS NOV84 03490000
         MVC   SPFMEMB+1(7),SPFMEMB       BLANK                SS NOV84 03491000
SPFP20   DS    0H                                              SS NOV84 03492000
         LH    R1,#COMMDSZ                GET ADDED DATA LEN   SS NOV84 03493000
         STH   R1,SPFZLEN                 SAVE LEN (EVEN ZERO) SS NOV84 03494000
         LTR   R1,R1                      IS IT ZERO           SS NOV84 03495000
         BZ    SPFP22                     NO DATA              SS NOV84 03496000
         LA    R1,MSGLINE                 GET ADDR             SS NOV84 03497000
         ST    R1,SPFZDATA                SAVE ADDR ZCMD DATA  SS NOV84 03498000
SPFP22   DS    0H                                              SS NOV84 03499000
         MVC   SPFPSTK2,##SUBCAL          COPY PANEL ID        SS NOV84 03500000
         L     R6,SPFSAV6                                      SS NOV84 03501000
         DROP  R6                                              SS NOV84 03502000
         MVI   SPFLAG1,SPFPAND            CODE                 SS NOV84 03503000
         L     R15,=V(ISPDSPY)                                 SS NOV84 03504000
         BALR  R14,R15                                         SS NOV84 03505000
         NOP   0                                               SS NOV84 03506000
         CLC   0(4,R1),SPFP0END           END KEY              SS NOV84 03507000
         BE    SPFP30                     YES, BRANCH         ABL DEC84 03508000
         LR    R2,R1                      3RD PARAMETER        SS NOV84 03509000
         LA    R0,=CL8'SELECT'            FIRST PARAMETER      SS NOV84 03510000
         LA    R1,250                     BUFFER 250 CHARS     SS NOV84 03511000
         ST    R1,FULLWORD                                     SS NOV84 03512000
         LA    R1,FULLWORD                SECOND PARAMETER     SS NOV84 03513000
         STM   R0,R2,MSGTEXT2             SAVE ADDRESSES       SS NOV84 03514000
         OI    MSGTEXT2+8,X'80'           MARK END OF LIST     SS NOV84 03515000
SPFP30   BAL   R2,CLOSEIT                 CLOSE THE INPUT DATA SS NOV84 03516000
         B     SPFCALL                                         SS NOV84 03517000
SPFP0END DC    C'END '                                         SS NOV84 03518000
         SPACE 3                                               SS NOV84 03519000
         COPY  MEML70                   INCLUDE MEMLIST CODE   SS NOV84 03520000
.MA00280 ANOP  ,                                                   @D01
         AIF ('&NCAR' EQ  '').MA00300                              @D01
         TITLE 'P D S  --  PDS COMPARE                        1/15/85'  03521000
*********************************************************************** 03522000
***      COMPARE SUBCOMMAND    ADDED BY BRUCE LELAND --  MAY, 1984  *** 03523000
*********************************************************************** 03524000
*                                                                       03525000
         SPACE 1                                                        03526000
COMPARE  CSECT                                                          03527000
         USING *,R8                                                     03528000
         SPACE 1                                                        03529000
         AIF ('&CISP' EQ 'NO SPF').MA00320                         @D01
         TM    SPFLAG2,SPFPOST            LINE COMMAND?                 03530000
         BO    COMPA6                     YES, BRANCH                   03531000
         SPACE 1                                                        03532000
.MA00320 ANOP  ,                                                   @D01
         MVC   MEMBERD+1(2),LMEMBER2   CHANGE DEFAULT MEMBER LENGTH     03533000
         MVC   MEMBERD+1+2(8),MEMBER2  CHANGE DEFAULT MEMBER NAME       03534000
         MVI   MEMBERD,FMEMBER1        ONLY ONE MEMBER NAME NOW         03535000
         NI    FLAGSEE,FF-FMEMLIST     NO MEMBER LIST                   03536000
         BAL   R14,DEFGROUP                    ADD DEFAULT GROUP        03537000
         SPACE 1                                                        03538000
COMPA6   XC    DIRUSER,DIRUSER         CLEAR THE USER FIELDS            03539000
         MVC   DIRNAME,MEMBER2         SECOND MEMBER NAME               03540000
         SPACE 2                                                        03541000
         BLDL  INDCB,BLDLLIST          LOCATE DIRECTORY ENTRY           03542000
         B     *+4(R15)                PROCESS RETURN CODE              03543000
         B     COMPA10                   00 - SUCCESSFUL                03544000
         B     NOMEMBER                  04 - MEMBER NOT FOUND          03545000
         B     IOERROR                   08 - I/O ERROR                 03546000
         SPACE 2                                                        03547000
COMPA10  MVC   DIRNAME(8),MEMBER1      FIRST MEMBER NAME                03548000
         MVC   MSGTEXT1+4(8),##SUBCAL  PROCESSOR TO ATTACH              03549000
         MVI   MSGTEXT1+12,X'40'       ADD A BLANK                      03550000
         MVI   MSGTEXT1+13,C''''       ADD A QUOTE                      03551000
         MVC   MSGTEXT1+14(44),DSNAME  ADD THE DATA SET NAME            03552000
         LH    R15,DSNLEN              DSNAME ACTUAL LENGTH             03553000
         LA    R4,14(,R15)             LENGTH OF "COMPARE '"            03554000
         LA    R3,MSGTEXT1+13(R15)     POINT TO CURRENT BYTE -1         03555000
         SPACE 1                                                        03556000
         MVI   1(R3),C'('              MEMBER NAME PARENTHESIS          03557000
         MVC   2(8,R3),DIRNAME         MEMBER NAME                      03558000
         LA    R3,2+8(,R3)             END OF MEMBER +1                 03559000
         LA    R4,2+8(,R4)             LENGTH OF MEMBER +1              03560000
         LA    R2,8                    MAXIMUM MACHINE LENGTH+1         03561000
         SPACE 1                                                        03562000
COMPA20  BCTR  R3,0                    SCAN                             03563000
         BCTR  R4,0                        BACKWARDS                    03564000
         CLI   0(R3),X'40'                          FOR                 03565000
         BNE   *+8                                     FIRST            03566000
         BCT   R2,COMPA20                                   NON-BLANK   03567000
         SPACE 1                                                        03568000
         BCTR  R2,0                    MACHINE LENGTH                   03569000
         TRT   DIRNAME(*-*),TRTMEM     <<EXECUTED>>                     03570000
         EX    R2,*-6                  VALID MEMBER NAME?               03571000
         BNZ   BADMEMB                 NO, ERROR                        03572000
         CLI   DIRNAME,C'0'            VALID FIRST CHARACTER?           03573000
         BNL   BADMEMB                 NO, BRANCH                       03574000
         LA    R3,1(,R3)               POINT TO TERMINATOR              03575000
         MVI   0(R3),C')'              ADD A CLOSING PARENTHESIS        03576000
         SPACE 1                                                        03577000
         MVI   1(R3),C''''             ADD A QUOTE                      03578000
         MVI   2(R3),X'40'             ADD A BLANK                      03579000
         LA    R4,3(,R4)               ACCOUNT FOR ")' "                03580000
         LA    R3,3(,R3)               ACCOUNT FOR ")' "                03581000
         SPACE 2                                                        03582000
         MVC   DIRNAME(8),MEMBER2      SECOND MEMBER NAME               03583000
         MVI   0(R3),C''''             ADD A QUOTE                      03584000
         MVC   1(44,R3),DSNAME         ADD THE DATA SET NAME            03585000
         LH    R15,DSNLEN              DSNAME ACTUAL LENGTH             03586000
         LA    R4,01(R4,R15)           LENGTH SO FAR                    03587000
         LA    R3,MSGTEXT1-1(R4)       POINT TO CURRENT BYTE -1         03588000
         SPACE 1                                                        03589000
         MVI   1(R3),C'('              MEMBER NAME PARENTHESIS          03590000
         MVC   2(8,R3),DIRNAME         MEMBER NAME                      03591000
         LA    R3,2+8(,R3)             END OF MEMBER +1                 03592000
         LA    R4,2+8(,R4)             LENGTH OF MEMBER +1              03593000
         LA    R2,8                    MAXIMUM MACHINE LENGTH+1         03594000
         SPACE 1                                                        03595000
COMPA30  BCTR  R3,0                    SCAN                             03596000
         BCTR  R4,0                        BACKWARDS                    03597000
         CLI   0(R3),X'40'                          FOR                 03598000
         BNE   *+8                                     FIRST            03599000
         BCT   R2,COMPA30                                   NON-BLANK   03600000
         SPACE 1                                                        03601000
         BCTR  R2,0                    MACHINE LENGTH                   03602000
         TRT   DIRNAME(*-*),TRTMEM     <<EXECUTED>>                     03603000
         EX    R2,*-6                  VALID MEMBER NAME?               03604000
         BNZ   BADMEMB                 NO, ERROR                        03605000
         CLI   DIRNAME,C'0'            VALID FIRST CHARACTER?           03606000
         BNL   BADMEMB                 NO, BRANCH                       03607000
         LA    R3,1(,R3)               POINT TO TERMINATOR              03608000
         MVI   0(R3),C')'              ADD A CLOSING PARENTHESIS        03609000
         SPACE 1                                                        03610000
         MVI   1(R3),C''''             ADD A QUOTE                      03611000
         MVI   2(R3),X'40'             ADD A BLANK                      03612000
         LA    R4,3(,R4)               ACCOUNT FOR ")' "                03613000
         SPACE 1                                                        03614000
         TM    FLAGSGG,FSAVEOP         SAVE TEXT MODE?                  03615000
         BNZ   COMPA36                 NO, BRANCH                       03616000
         LA    R15,FIRST4K                                              03617000
         LA    R15,SAVECOMP-FIRST4K(,R15)  SAVE TEXT AREA               03618000
         CLI   #COMMDSZ+1,0            ANY OPERAND?                     03619000
         BE    COMPA34                 NO, BRANCH                       03620000
         MVC   0(40,R15),MSGLINE       YES, SAVE NEW DEFAULT TEXT       03621000
         B     COMPA36                                                  03622000
COMPA34  MVC   MSGLINE(40),0(R15)      USE THE DEFAULT OPERAND          03623000
         CLI   0(R15),0                ANY DEFAULT?                     03624000
         BE    COMPA36                 NO, BRANCH                       03625000
         MVI   #COMMDSZ+1,40           YES, USE A 40 CHARACTER LENGTH   03626000
         SPACE 1                                                        03627000
COMPA36  AH    R4,#COMMDSZ             ADD LENGTH OF KEYWORD DATA       03628000
         MVC   3(40,R3),MSGLINE        ADD ANY KEYWORD DATA             03629000
         SPACE 2                                                        03630000
         LA    R2,MSGTEXT1             START OF COMMAND TEXT            03631000
         SLL   R4,16                   CLEAR BOTTOM TWO BYTES           03632000
         STCM  R4,B'1111',0(R2)        SAVE STRING TOTAL LENGTH         03633000
*        MESSAGE (R2)                  DELETE * TO OUTPUT COMMAND       03634000
         ST    R2,ADDRTEXT             COMMAND ADDRESS                  03635000
         ST    R2,ADDRCBUF             COMMAND ADDRESS                  03636000
         LA    R1,ADDRTEXT             COMMAND ADDRESS                  03637000
         CLI   ##SUBCAL,C'%'           CLIST CALL?                      03638000
         BE    EXEC                    YES, IMPLIED CLIST               03639000
         MVI   3(R2),9                 OPERAND OFFSET                   03640000
         SPACE 1                                                        03641000
         LA    R3,##SUBCAL             PROCESSOR TO ATTACH              03642000
         AIF ('&C296' EQ 'YES').YES296                                  03643000
COMPAZAP NOP   COMPA39                 DO NOT LINK TO COMPARE           03644000
         AGO   .NOT296                                                  03645000
.YES296  ANOP                                                           03646000
COMPAZAP B     COMPA39                 LINK TO COMPARE                  03647000
.NOT296  ANOP                                                           03648000
***  THE FOLLOWING INTERFACE IS FOR COMPARE FROM THE CBT TAPE, FILE 300 03649000
         BAL   R2,ATTACH               ATTACH THIS COMMAND PROCESSOR    03650000
         B     NEWCMD                                                   03651000
         SPACE 1                                                        03652000
***  EITHER THE ABOVE OR THE FOLLOWING INTERFACE MAY BE                 03653000
***  USED BY THE COMPARE COMMAND FROM THE CBT TAPE, FILE 296            03654000
COMPA39  LA    R15,MSGLINE           ***  START OF PARAMETER LIST       03655000
         MVC   0(12,R15),COMPA40     ***  SAVE RE-ENTRY CODE            03656000
         LA    R0,COMPA50            ***  START OF WRITE SUBROUTINE     03657000
         ST    R0,12(,R15)           ***  OPERAND OFFSET                03658000
         ST    R7,16(,R15)           ***  SAVE GETMAIN ADDRESS          03659000
         MVC   4(4,R2),=C'****'      ***  SET COMPARE FLAGS             03660000
         ST    R15,8(,R2)            ***  SAVE REENTRY LIST ADDRESS     03661000
         LA    R0,NEWSTAX            ***  ABEND RECOVERY                03662000
         ST    R0,RECOVER            ***                                03663000
         SPACE 2                                                        03664000
         MVC   PARMLIST(COMPA66),COMPA60  *** INITIALIZE LINK LIST      03665000
         LINK  EPLOC=((3)),SF=(E,PARMLIST)                              03666000
         B     NEWCMD                                                   03667000
         SPACE 1                                                        03668000
COMPA40  ST    R1,20(,R15)           ***  SAVE PARAMETER ADDRESS        03669000
         L     R15,12(,R15)          ***  RE-ENTRY POINT                03670000
         BAL   R1,0(,R15)            ***  LINK TO SUBROUTINE            03671000
         SPACE 3                                                        03672000
COMPA50  SAVE  (14,12)               ***                                03673000
         LR    R8,R15                ***  BASE REGISTER ADDRESS         03674000
         USING COMPA50,R8            ***  BASE REGISTER NOTIFICATION    03675000
         L     R7,4(,R1)             ***  WORK AREA ADDRESS             03676000
         L     R1,8(,R1)             ***  OUTPUT MESSAGE START          03677000
         LM    R9,R12,BASES          ***  RESTORE BASE REGISTERS        03678000
         LA    R15,VALSAVE           ***  SAVE AREA FOR THIS ROUTINE    03679000
         ST    R13,4(,R15)           ***                                03680000
         ST    R15,8(,R13)           ***  CHAIN SAVE AREAS              03681000
         LR    R13,R15               ***                                03682000
         MVC   MSGTEXT2+4(80),1(R1)  ***                                03683000
         LA    R1,79+4               ***  LENGTH                        03684000
         SLL   R1,16                 ***  CLEAR OUT OTHER BYTES         03685000
         ST    R1,MSGTEXT2           ***  SET IN THE MESSAGE            03686000
         LA    R1,MSGTEXT2           ***  MESSAGE ADDRESS               03687000
        $PUTLINE (R1),ATTN=COMPA58   ***  OUTPUT THIS MESSAGE           03688000
         SR    R15,R15               ***  SUCCESSFUL OUTPUT             03689000
         B     COMPA59               ***  RETURN                        03690000
COMPA58  LA    R15,4                 ***  SET REGISTER R15              03691000
COMPA59  L     R13,4(,R13)           ***  UNCHAIN SAVE AREAS            03692000
         ST    R15,16(R13)           ***  SAVE RETURN CODE              03693000
         RETURN (14,12)              ***  RETURN                        03694000
         SPACE 3                                                        03695000
COMPA60  LINK  EPLOC=$CAR,SF=L                                          03696000
COMPA66  EQU   *-COMPA60                                                03697000
.MA00300 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS COMPRESS                        1/15/85' 03698000
*********************************************************************** 03699000
***      COMPRESS SUBCOMMAND   ADDED BY BRUCE LELAND -- APR., 1984  *** 03700000
*********************************************************************** 03701000
*                                                                       03702000
         SPACE 1                                                        03703000
COMPRESS CSECT                                                          03704000
         USING *,R8                                                     03705000
         SPACE 1                                                        03706000
         MVI   VOLALLOC,X'40'             READ THE DSCB AGAIN           03707000
         CLI   DSPALLOC,ALLOOLD           EXCLUSIVE USE ALREADY?        03708000
         BE    CMXSYSDD                   YES, BRANCH                   03709000
*  ALLOCATE THE DATA SET TO COMPRESS AS "OLD"                           03710000
         BAL   R2,CLOSEIT                 CLOSE THE DATA SET            03711000
         BAL   R2,DEALLDCB                UNALLOCATE THE DATA SET       03712000
         LA    R0,RESTART0                ABEND RECOVERY                03713000
         ST    R0,RECOVER                               RESTART ADDRESS 03714000
         MVI   DSPALLOC,ALLOOLD           WANT EXCLUSIVE USE NOW        03715000
         L     R15,=A(ALLOCATE)           ALLOCATION ROUTINE ADDRESS    03716000
         BALR  R14,R15                    ALLOCATE THE DATA SET?        03717000
         B     RESTART0                   NO, ERROR                     03718000
         SPACE 1                                                        03719000
         L     R8,##ADRCMD                REESTABLISH THE BASE REGISTER 03720000
         CLI   DSPALLOC,ALLOOLD           OLD ALLOCATION NOW?           03721000
         BE    CMXSYSDD                   YES, BRANCH                   03722000
         CLI   #CMXSHR,1                  SHR COMPRESS DESIRED?         03723000
         BNE   RESTART2                   NO, QUIT                      03724000
         SPACE 2                                                        03725000
         AIF   (&MVT).MA00340                                      @D01
*  ALLOCATE COMPRESS SYSIN FILE                                         03726000
CMXSYSDD XC    M99RBPTR(40),M99RBPTR      CLEAR THE WORK AREA           03727000
         LA    R1,M99RBPTR                DYNAMIC ALLOCATION            03728000
         USING S99RBP,R1                                                03729000
         SPACE 1                                                        03730000
         LA    R4,M99RB                                                 03731000
         USING S99RB,R4                                                 03732000
         ST    R4,S99RBPTR                                              03733000
         OI    S99RBPTR,S99RBPND          MARK END OF LIST              03734000
         SPACE 1                                                        03735000
         LA    R5,M99TUPL                                               03736000
         USING S99TUPL,R5                                               03737000
         MVI   S99RBLN,20                 LENGTH 20                     03738000
         MVI   S99VERB,S99VRBAL           ALLOCATE                      03739000
         ST    R5,S99TXTPP                POINT TO TEXT POINTERS        03740000
         SPACE 1                                                        03741000
         MVC   #CMXSYSI(14),CMXDDNAM      REQUEST DDNAME FEEDBACK       03742000
         LA    R3,#CMXSYSI                FIRST TEXT POINTER            03743000
         USING S99TUNIT,R3                                              03744000
         ST    R3,S99TUPTR                POINT TO FIRST TEXT UNITS     03745000
         MVC   S99TUPTR+4(20),CMXSYSIN    ADD OTHER LIST ELEMENTS       03746000
         SPACE 1                                                        03747000
         DYNALLOC                                                       03748000
         MVC   #CMXSYSI(8),#CMXSYSI+6     MOVE DOWN THE DATA SET NAME   03749000
         SPACE 2                                                        03750000
         DROP  R1,R3,R4,R5                                              03751000
         LTR   R15,R15                    SUCCESSFUL?                   03752000
         BNZ   CMXERROR                   NO, BRANCH                    03753000
         SPACE 3                                                        03754000
*  ALLOCATE COMPRESS SYSPRINT DATA SET                                  03755000
         SPACE 1                                                        03756000
         XC    M99RBPTR(40),M99RBPTR      CLEAR THE WORK AREA           03757000
         LA    R1,M99RBPTR                DYNAMIC ALLOCATION            03758000
         USING S99RBP,R1                                                03759000
         SPACE 1                                                        03760000
         LA    R4,M99RB                                                 03761000
         USING S99RB,R4                                                 03762000
         ST    R4,S99RBPTR                                              03763000
         OI    S99RBPTR,S99RBPND          MARK END OF LIST              03764000
         SPACE 1                                                        03765000
         LA    R5,M99TUPL                                               03766000
         USING S99TUPL,R5                                               03767000
         MVI   S99RBLN,20                 LENGTH 20                     03768000
         MVI   S99VERB,S99VRBAL           ALLOCATE                      03769000
         ST    R5,S99TXTPP                POINT TO TEXT POINTERS        03770000
         SPACE 1                                                        03771000
         MVC   #CMXSYSP(14),CMXDDNAM      REQUEST DDNAME FEEDBACK       03772000
         LA    R3,#CMXSYSP                FIRST TEXT POINTER            03773000
         USING S99TUNIT,R3                                              03774000
         ST    R3,S99TUPTR                POINT TO FIRST TEXT UNITS     03775000
         MVC   S99TUPTR+4(4),CMXSYSIN     ASSUME DUMMY TEXT IS DESIRED  03776000
         CLI   #CMXFLAG,3                 NOLIST?                       03777000
         BNE   *+8                        NO, BRANCH                    03778000
         LA    R5,4(,R5)                  YES, USE THE DUMMY TEXT       03779000
         MVC   S99TUPTR+4(36),CMXSYSPR    ADD OTHER LIST ELEMENTS       03780000
         MVC   MSGTEXT2(9+9),CMXPRTFI     ADD PRIMARY, SECONDARY        03781000
         LA    R0,MSGTEXT2                START OF PRIMARY AMOUNT       03782000
         ST    R0,S99TUPTR+4              CHANGE ADDRESS POINTER        03783000
         LA    R0,MSGTEXT2+9              START OF SECONDARY AMOUNT     03784000
         ST    R0,S99TUPTR+4+4            CHANGE ADDRESS POINTER        03785000
         LH    R15,TOTUSEDX               NUMBER OF USED MEMBER BLOCKS  03786000
         MH    R15,=H'21'                 MAXIMUM MEMBERS               03787000
         AR    R15,R15                    MAXIMUM MEMBERS*2             03788000
         SR    R14,R14                                                  03789000
         D     R14,=F'50'                 50 MEMBERS/PAGE               03790000
         SRL   R15,4                      DIVIDED BY 16                 03791000
         LA    R15,2(,R15)                ADD 2                         03792000
         STCM  R15,B'0111',MSGTEXT2+6     UPDATE IN PRIMARY SPACE       03793000
         STCM  R15,B'0111',MSGTEXT2+9+6   UPDATE IN SECONDARY SPACE     03794000
         SPACE 1                                                        03795000
         DYNALLOC                                                       03796000
         SPACE 2                                                        03797000
         MVC   #CMXSYSP(8),#CMXSYSP+6     MOVE DOWN THE DDNAME          03798000
         DROP  R1,R3,R4,R5                                              03799000
         LTR   R15,R15                    SUCCESSFUL?                   03800000
         BNZ   CMXERROR                   NO, BRANCH                    03801000
         SPACE 2                                                        03802000
*  ALLOCATE COMPRESS SYSUT3 DATA SET                                    03803000
         SPACE 1                                                        03804000
         XC    M99RBPTR(40),M99RBPTR      CLEAR THE WORK AREA           03805000
         LA    R1,M99RBPTR                DYNAMIC ALLOCATION            03806000
         USING S99RBP,R1                                                03807000
         SPACE 1                                                        03808000
         LA    R4,M99RB                                                 03809000
         USING S99RB,R4                                                 03810000
         ST    R4,S99RBPTR                                              03811000
         OI    S99RBPTR,S99RBPND          MARK END OF LIST              03812000
         SPACE 1                                                        03813000
         LA    R5,M99TUPL                                               03814000
         USING S99TUPL,R5                                               03815000
         MVI   S99RBLN,20                 LENGTH 20                     03816000
         MVI   S99VERB,S99VRBAL           ALLOCATE                      03817000
         ST    R5,S99TXTPP                POINT TO TEXT POINTERS        03818000
         SPACE 1                                                        03819000
         MVC   #CMXSYS3(14),CMXDDNAM      REQUEST DDNAME FEEDBACK       03820000
         LA    R3,#CMXSYS3                FIRST TEXT POINTER            03821000
         USING S99TUNIT,R3                                              03822000
         ST    R3,S99TUPTR                POINT TO FIRST TEXT UNITS     03823000
         MVC   S99TUPTR+4(24),CMXSYSUT    ADD OTHER LIST ELEMENTS       03824000
         MVC   MSGTEXT2(9+9),CMXPRTFI     ADD PRIMARY, SECONDARY        03825000
         LA    R0,MSGTEXT2                START OF PRIMARY AMOUNT       03826000
         ST    R0,S99TUPTR+4              CHANGE ADDRESS POINTER        03827000
         LA    R0,MSGTEXT2+9              START OF SECONDARY AMOUNT     03828000
         ST    R0,S99TUPTR+4+4            CHANGE ADDRESS POINTER        03829000
         LH    R15,TOTUSEDX               NUMBER OF USED MEMBER BLOCKS  03830000
         MH    R15,=H'21'                 MAXIMUM MEMBERS               03831000
         MH    R15,=H'105'                                              03832000
         SR    R14,R14                                                  03833000
         D     R14,=F'100'                TOTAL SPACE IN BLOCKS         03834000
         SRL   R15,4                      DIVIDED BY 16                 03835000
         LA    R15,2(,R15)                ADD 2                         03836000
         STCM  R15,B'0111',MSGTEXT2+6     UPDATE IN PRIMARY SPACE       03837000
         STCM  R15,B'0111',MSGTEXT2+9+6   UPDATE IN SECONDARY SPACE     03838000
         SPACE 1                                                        03839000
         DYNALLOC                                                       03840000
         SPACE 2                                                        03841000
         MVC   #CMXSYS3(8),#CMXSYS3+6     MOVE DOWN THE DDNAME          03842000
         DROP  R1,R3,R4,R5                                              03843000
         LTR   R15,R15                    SUCCESSFUL?                   03844000
         BZ    CMXSTAX                    YES, BRANCH                   03845000
         SPACE 2                                                        03846000
CMXERROR ST    R15,DAIRRC                 SAVE RETURN CODE              03847000
         BAL   R2,CLOSEIT                 CLOSE THE DATA SET            03848000
         BAL   R2,DEALLDCB                UNALLOCATE THE DATA SET       03849000
         LA    R0,RESTART0                ABEND RECOVERY                03850000
         ST    R0,RECOVER                               RESTART ADDRESS 03851000
         LA    R14,M99RB                  POINTER TO SVC 99 BLOCK       03852000
         LA    R15,DAIRRC                 POINTER TO RETURN CODE        03853000
         LA    R0,ADDRFF02                POINTER TO A(IKJEFF02)        03854000
         LA    R1,=AL2(DFSVC99)           POINTER TO INVOCATION TYPE    03855000
         L     R2,ADDRCPPL                POINTER TO THE CPPL           03856000
         STM   R14,R2,DFDAPLP             INITIALIZE DFDAPLP, DFDRCP,   03857000
*                                           DFJEFF02, DFIDP AND DFCPPLP 03858000
         SPACE 1                                                        03859000
         AGO   .NA00340                                            @D01
.MA00340 ANOP  ,                                                   @D01
*----------------------------------------------------------------* @D01
*        Allocate compress SYSIN file using DAIR.                * @D01
*----------------------------------------------------------------* @D01
CMXSYSDD MVC   #CMXSYSI(8),BLANKS  Assume no SYSIN allocation      @D01
         LA    R1,PARMLIST         Point to DAPL                   @D01
         USING DAPL,R1             Addressability for DAPL         @D01
         XC    DAIR08,DAIR08       Zero DAIR X'08' parm block      @D01
         LA    R5,DAIR08           Point to parm block             @D01
         USING DAPB08,R5           Address parm block              @D01
         ST    R5,DAPLDAPB         Set parm block address in DAPL  @D01
         MVC   DA08CD,=XL2'0008'   Set entry code = allocate       @D01
         XC    DA08PDSN,DA08PDSN   No DSN                          @D01
         MVC   DA08PSWD,BLANKS     No password                     @D01
         MVC   DA08DDN,BLANKS      Return DD name                  @D01
         MVC   DA08SER,BLANKS      No volume                       @D01
         MVC   DA08MNM,BLANKS      No member name                  @D01
         MVC   DA08UNIT,BLANKS     No unit                         @D01
         MVI   DA08CTL,DA08DMMY    Set DUMMY flag                  @D01
         MVI   DA08DSP1,DA08NEW    DISP=(NEW,...,...)              @D01
         MVI   DA08DPS2,DA08DEL    DISP=(...,DELETE,...)           @D01
         MVI   DA08DPS3,DA08DELE   DISP=(...,...,DELETE)           @D01
         XC    ATTNECB,ATTNECB     Clear the ECB                   @D01
         L     R15,ADDRDAIR        Get address of DAIR             @D01
         BALR  R14,R15             Go to DAIR                      @D01
         DROP  R1                  End DAPL addressability         @D01
         LTR   R15,R15             Allocation successful?          @D01
         BNZ   CMXERROR            No, branch to error routine     @D01
         MVC   #CMXSYSI(8),DA08DDN Save returned SYSIN DD name     @D01
         DROP  R5                  End parm block addressability   @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        Allocate compress SYSPRINT file using DAIR.             * @D01
*----------------------------------------------------------------* @D01
         MVC   #CMXSYSP(8),BLANKS  Assume no SYSPRINT allocation   @D01
         LA    R1,PARMLIST         Point to DAPL                   @D01
         USING DAPL,R1             Addressability for DAPL         @D01
         XC    DAIR08,DAIR08       Zero DAIR X'08' parm block      @D01
         LA    R5,DAIR08           Point to parm block             @D01
         USING DAPB08,R5           Address parm block              @D01
         ST    R5,DAPLDAPB         Set parm block address in DAPL  @D01
         MVC   DA08CD,=XL2'0008'   Set entry code = allocate       @D01
         XC    DA08PDSN,DA08PDSN   No DSN                          @D01
         MVC   DA08PSWD,BLANKS     No password                     @D01
         MVC   DA08DDN,BLANKS      Return DD name                  @D01
         MVC   DA08SER,BLANKS      No volume                       @D01
         MVC   DA08MNM,BLANKS      No member name                  @D01
         MVC   DA08UNIT,=CL8'&DAUNIT'    Unit                      @D01
         MVI   DA08CTL,DA08DMMY    Set DUMMY flag                  @D01
         MVI   DA08DSP1,DA08NEW    DISP=(NEW,...,...)              @D01
         MVI   DA08DPS2,DA08DEL    DISP=(...,DELETE,...)           @D01
         MVI   DA08DPS3,DA08DELE   DISP=(...,...,DELETE)           @D01
         CLI   #CMXFLAG,3          User specify NOLIST?            @D01
         BE    CMXSYSP2            Yes, done with SYSPRINT parms   @D01
         MVC   DAIRDSNT(7),=C'&&&&PRINT'  Set data set name        @D01
         MVC   DAIRDSNL,=AL2(7)           Set data set name length @D01
         LA    R15,DAIRDSN         Point to DSN key                @D01
         ST    R15,DA08PDSN        Set DSN pointer in parm block   @D01
         MVI   DA08CTL,DA08ABKL    Set BLOCKS indicator            @D01
         MVC   DA08BLK,=AL4(6171)  Set block size for allocation   @D01
         LH    R15,TOTUSEDX        Get count of used dir blocks    @D01
         MH    R15,=H'21'          Calculate maximum members       @D01
         AR    R15,R15             Maximum members * 2             @D01
         SR    R14,R14             Divide by                       @D01
         D     R14,=F'50'           50 members per page            @D01
         SRL   R15,4               Divided by 16 extents           @D01
         LA    R15,2(,R15)         Add 2                           @D01
         ST    R15,DA08PQTY        Set as primary quantity         @D01
         ST    R15,DA08SQTY        Set as secondary quantity       @D01
CMXSYSP2 XC    ATTNECB,ATTNECB     Clear the ECB                   @D01
         L     R15,ADDRDAIR        Get address of DAIR             @D01
         BALR  R14,R15             Go to DAIR                      @D01
         DROP  R1                  End DAPL addressability         @D01
         LTR   R15,R15             Allocation successful?          @D01
         BNZ   CMXERROR            No, branch to error routine     @D01
         MVC   #CMXSYSP(8),DA08DDN Save returned SYSPRINT DD name  @D01
         DROP  R5                  End parm block addressability   @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        Allocate compress SYSUT3 file using DAIR.               * @D01
*----------------------------------------------------------------* @D01
         MVC   #CMXSYS3(8),BLANKS  Assume no SYSUT3 allocation     @D01
         LA    R1,PARMLIST         Point to DAPL                   @D01
         USING DAPL,R1             Addressability for DAPL         @D01
         XC    DAIR08,DAIR08       Zero DAIR X'08' parm block      @D01
         LA    R5,DAIR08           Point to parm block             @D01
         USING DAPB08,R5           Address parm block              @D01
         ST    R5,DAPLDAPB         Set parm block address in DAPL  @D01
         MVC   DA08CD,=XL2'0008'   Set entry code = allocate       @D01
         MVC   DA08PSWD,BLANKS     No password                     @D01
         MVC   DA08DDN,BLANKS      Return DD name                  @D01
         MVC   DA08SER,BLANKS      No volume                       @D01
         MVC   DA08MNM,BLANKS      No member name                  @D01
         MVC   DA08UNIT,=CL8'&DAUNIT'    Unit                      @D01
         MVI   DA08DSP1,DA08NEW    DISP=(NEW,...,...)              @D01
         MVI   DA08DPS2,DA08DEL    DISP=(...,DELETE,...)           @D01
         MVI   DA08DPS3,DA08DELE   DISP=(...,...,DELETE)           @D01
         MVC   DAIRDSNT(8),=C'&&&&SYSUT3' Set data set name        @D01
         MVC   DAIRDSNL,=AL2(8)           Set data set name length @D01
         LA    R15,DAIRDSN         Point to DSN key                @D01
         ST    R15,DA08PDSN        Set DSN pointer in parm block   @D01
         MVI   DA08CTL,DA08ABKL    Set BLOCKS indicator            @D01
         MVC   DA08BLK,=AL4(80)    Set block size for allocation   @D01
         LH    R15,TOTUSEDX        Get count of used dir blocks    @D01
         MH    R15,=H'21'          Calculate maximum members       @D01
         MH    R15,=H'105'         Times                           @D01
         SR    R14,R14              1.05                           @D01
         D     R14,=F'100'           per member                    @D01
         SRL   R15,4               Divided by 16 extents           @D01
         LA    R15,2(,R15)         Add 2                           @D01
         ST    R15,DA08PQTY        Set as primary quantity         @D01
         ST    R15,DA08SQTY        Set as secondary quantity       @D01
         XC    ATTNECB,ATTNECB     Clear the ECB                   @D01
         L     R15,ADDRDAIR        Get address of DAIR             @D01
         BALR  R14,R15             Go to DAIR                      @D01
         DROP  R1                  End DAPL addressability         @D01
         LTR   R15,R15             Allocation successful?          @D01
         BNZ   CMXERROR            No, branch to error routine     @D01
         MVC   #CMXSYS3(8),DA08DDN Save returned SYSUT3 DD name    @D01
         DROP  R5                  End parm block addressability   @D01
         B     CMXSTAX             Allocation successful, continue @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        An allocation failed, call DAIRFAIL.                    * @D01
*----------------------------------------------------------------* @D01
CMXERROR ST    R15,DAIRRC          Save DAIR return code           @D01
         BAL   R2,CLOSEIT          Close data set                  @D01
         BAL   R2,DEALLDCB         Unallocate the data set         @D01
         LA    R0,RESTART0         Set restart adddress            @D01
         ST    R0,RECOVER           for abend recovery             @D01
         LA    R14,PARMLIST        Pointer to DAIR parm list       @D01
         LA    R15,DAIRRC          Pointer to RETURN CODE          @D01
         LA    R0,ADDRFF02         Pointer to A(IKJEFF02)          @D01
         LA    R1,=AL2(DFDAIR)     Pointer to invocation type      @D01
         L     R2,ADDRCPPL         Pointer to the CPPL             @D01
         STM   R14,R2,DFDAPLP      Initialize DFDAPLP, DFDRCP,     @D01
*                                             DFJEFF02, DFIDP      @D01
*                                             and DFCPPLP          @D01
.NA00340 ANOP  ,                                                   @D01
         LINK  EP=IKJEFF18,MF=(E,DFPARMS)                               03860000
         LTR   R15,R15                    PROBLEM WITH IKJEFF18?        03861000
         BZ    CMXRETRN                   NO, BRANCH                    03862000
         SPACE 1                                                        03863000
         CVD   R15,DOUBLE                                               03864000
         MVI   MTHIGHL,4                                                03865000
         MVC   INSERT#1(4),=X'40202120'                                 03866000
         ED    INSERT#1(4),DOUBLE+6                                     03867000
         MVI   INSERT#1,C'='                                            03868000
         TSMSG L835$1                                                   03869000
         B     CMXRETRN                                                 03870000
         SPACE 3                                                        03871000
CMXSTAX  TSMSG L480                       COMPRESS IN PROGRESS MESSAGE  03872000
         OI    ##ADRPA#,$A                DEFER ALL ATTENTIONS          03873000
         SPACE 1                                                        03874000
         XC    WORKTBL,WORKTBL            CLEAR THE TEMPORARY TABLE     03875000
         STAX  ATTNNULL,USADDR=(R7),REPLACE=NO,IBUF=0,                 X03876000
               OBUF=(PDS480W,PDS480WL),MF=(E,WORKTBL)                   03877000
         LA    R1,ZERO                    NO FIRST PARAMETER            03878000
         ST    R1,#CMXLIST                                              03879000
         LA    R1,#CMXDDNA                SECOND PARAMETER              03880000
         ST    R1,#CMXLIST+4                                            03881000
         OI    #CMXLIST+4,X'80'           MARK END OF LIST              03882000
         XC    #CMXDDNA(82),#CMXDDNA      SYSIN DDNAME                  03883000
         MVI   #CMXDDNA+1,80              LENGTH OF DDNAME LIST         03884000
         MVC   #CMXDDIN,#CMXSYSI          SYSIN DDNAME                  03885000
         MVC   #CMXDDPR,#CMXSYSP          SYSPRINT DDNAME               03886000
         MVC   #CMXDDT1,DDNAME            SYSUT1 DDNAME                 03887000
         MVC   #CMXDDT2,DDNAME            SYSUT2 DDNAME                 03888000
         MVC   #CMXDDT3,#CMXSYS3          SYSUT3 DDNAME                 03889000
         BAL   R6,RESERVE                 RESERVE DEVICE IF REQUIRED    03890000
         SPACE 1                                                        03891000
COMPRZAP LA    R0,3239  **TO BE ZAPPED    PASSWORD                      03892000
         SVC   247      **TO BE ZAPPED    GET AUTHORIZED                03893000
         ORG   *-2      -- NOTE --        OVERLAY THE SVC CALL          03894000
         NOPR  0        **TO BE ZAPPED    OVERLAY THE SVC CALL          03895000
         LA    R3,##SUBCAL                WHO TO ATTACH                 03896000
         LA    R1,#CMXLIST                PARAMETERS TO PASS            03897000
         BAL   R2,ATTACH                  SPFCOPY/IEBCOPY/$PDSFAST      03898000
         SR    R0,R0                      UNAUTHORIZATION CODE          03899000
         SVC   247      **TO BE ZAPPED    GET UNAUTHORIZED              03900000
         ORG   *-2      -- NOTE --        OVERLAY THE SVC CALL          03901000
         NOPR  0        **TO BE ZAPPED    OVERLAY THE SVC CALL          03902000
         SPACE 1                                                        03903000
         SPACE 3                                                        03904000
         BAL   R2,DEQ                     RELEASE ANY RESERVES          03905000
         BAL   R2,CLOSEIT                 CLOSE THE DATA SET            03906000
         BAL   R2,DEALLDCB                UNALLOCATE THE DATA SET       03907000
         LA    R0,RESTART0                ABEND RECOVERY                03908000
         ST    R0,RECOVER                               RESTART ADDRESS 03909000
         STAX  ,                                                        03910000
         NI    ##ADRPA#,FF-$A             ALLOW ATTENTIONS AGAIN        03911000
         MVI   ATTNECB,0                  CLEAR THE ATTENTION ECB       03912000
         CLI   SUBSECB+3,12               RETURN CODE > 12?             03913000
         BH    CMXNOPEN                   YES, BRANCH                   03914000
         CLI   #CMXFLAG,3                 NOLIST REQUESTED?             03915000
         BNE   CMXOPEN                    NO, BRANCH                    03916000
CMXNOPEN MVI   MTHIGHL,3                                                03917000
         SR    R15,R15                                                  03918000
         ICM   R15,B'0001',SUBSECB+3                                    03919000
         CVD   R15,DOUBLE                                               03920000
         MVC   INSERT#1-1(4),=X'40202120'                               03921000
         ED    INSERT#1-1(4),DOUBLE+6                                   03922000
         MVI   INSERT#1,C'='                                            03923000
         TSMSG L171$1                                                   03924000
         B     CMXRETRN                                                 03925000
         SPACE 3                                                        03926000
CMXOPEN  MVC   STOWDCB(CMXDL),CMXDCB      GET MODEL DCB                 03927000
         MVC   DCBDDNAM-IHADCB+STOWDCB(8),#CMXSYSP                      03928000
         MVI   OPENLIST,X'80'                                           03929000
         OPEN  (STOWDCB),MF=(E,OPENLIST)      OPEN SYSPRINT             03930000
         TM    DCBOFLGS-IHADCB+STOWDCB,X'10'  SUCCESSFUL OPEN?          03931000
         BO    CMXMSGIN                       YES, BRANCH               03932000
         TSMSG L865                           NO STATUS AVAILABLE       03933000
         B     CMXRETRN                       EXIT                      03934000
         SPACE 3                                                        03935000
*  PROCESS SYSPRINT RECORDS                                             03936000
         SPACE 1                                                        03937000
CMXMSGIN GET   STOWDCB                    GET LIST RECORD               03938000
         CLI   1(R1),X'40'                HEADER LINE?                  03939000
         BE    CMXMSGIN                   YES, IGNORE                   03940000
         CLI   #CMXFLAG,2                 FULL LIST REQUESTED?          03941000
         BE    CMXMSGON                   YES, OUTPUT                   03942000
         LA    R3,CMXEXCL-6               START OF EXCLUSION TABLE -6   03943000
CMXMSGCK LA    R3,6(,R3)                  NEXT MESSAGE ID               03944000
         CLC   1(6,R1),0(R3)              MESSAGE ID TO BE EXCLUDED?    03945000
         BE    CMXMSGIN                   YES, IGNORE                   03946000
         CLI   0(R3),FF                   END OF TABLE?                 03947000
         BNE   CMXMSGCK                   NO, LOOP                      03948000
         SPACE 3                                                        03949000
CMXMSGON MVC   MSGTEXT1(136),MSGBL132     BLANK THE MESSAGE LINE        03950000
         CLC   1(6,R1),CMXIEB14           UNUSED TRACKS MESSAGE?        03951000
         BNE   *+8                        NO, BRANCH                    03952000
         MVI   MSGTEXT1+1,64              YES, TRUNCATE THE MESSAGE     03953000
         MVC   MSGTEXT1+4(120),1(R1)      ADD THE IEBCOPY MESSAGE       03954000
         MESSAGE MSGTEXT1                 OUTPUT THE MESSAGE            03955000
         B     CMXMSGIN                                                 03956000
         SPACE 3                                                        03957000
CMXEXCL  DC    C'IEB152'           IEB152I MEMBERNAME COMPRESSED-WAS AL 03958000
         DC    C'IEB154'           IEB154I MEMBERNAME HAS BEEN SUCCESSF 03959000
         DC    C'IEB167'           IEB167I FOLLOWING MEMBER(S) COPIED F 03960000
         DC    C'IEB161'           IEB161I COMPRESS TO BE DONE USING IN 03961000
         DC    C'PDSFAS'           PDSFAST   ... HEADER LINE            03962000
         DC    C'PDF00 '           PDF00  START EXECUTION               03963000
         DC    C'PDF06 '           PDF06   INPUT DATASET:  ...          03964000
         DC    C'PDF09 '           PDF09  MEMBER ........ - MOVED ...   03965000
         DC    X'FF'                                                    03966000
         SPACE 2                                                        03967000
*** THE FOLLOWING MESSAGES ARE ALSO CANDIDATES FOR SUPPRESSION:         03968000
CMXIEB14 DC    C'IEB144'           IEB144I THERE ARE XXXXXXX UNUSED TRA 03969000
***      DC    C'IEB147'           IEB147I END OF JOB X WAS HIGHEST RET 03970000
***      DC    C'IEB149'           IEB149I THERE ARE XXXXXXX UNUSED DIR 03971000
***      DC    C'IEB153'           IEB153I ALL MEMBERS COMPRESSED-ALL W 03972000
         DC    X'FF'                                                    03973000
         SPACE 2                                                        03974000
CMXMDONE DS    0H                                                       03975000
         MVI   OPENLIST,X'80'                                           03976000
         CLOSE (STOWDCB),MF=(E,OPENLIST)  CLOSE THE SYSPRINT FILE.      03977000
         SPACE 2                                                        03978000
CMXRETRN MESSAGE MSGBLANK                                               03979000
         AIF   (&MVT).MA00360                                      @D01
         CLI   #CMXSYSI,X'41'             ANY SYSIN DDNAME?             03980000
         BL    CMXFREEP                   NO, BRANCH                    03981000
         SPACE 1                                                        03982000
         XC    M99RBPTR(40),M99RBPTR      CLEAR THE WORK AREA           03983000
         LA    R1,M99RBPTR                DYNAMIC ALLOCATION            03984000
         USING S99RBP,R1                                                03985000
         SPACE 1                                                        03986000
         LA    R4,M99RB                                                 03987000
         USING S99RB,R4                                                 03988000
         ST    R4,S99RBPTR                                              03989000
         OI    S99RBPTR,S99RBPND          MARK END OF LIST              03990000
         SPACE 1                                                        03991000
         LA    R5,M99TUPL                                               03992000
         USING S99TUPL,R5                                               03993000
         MVI   S99RBLN,20                 LENGTH 20                     03994000
         MVI   S99VERB,S99VRBUN           UNALLOCATE                    03995000
         ST    R5,S99TXTPP                POINT TO TEXT POINTER         03996000
         SPACE 1                                                        03997000
         LA    R3,#CMXSYSI-6              TEXT POINTER                  03998000
         USING S99TUNIT,R3                                              03999000
         MVC   S99TUKEY(6),CMXDDNAM       ADD TEXT KEYS                 04000000
         ST    R3,S99TUPTR                POINT TO TEXT UNIT            04001000
         OI    S99TUPTR,X'80'             MARK END OF THE TEXT LIST     04002000
         MVI   S99TUKEY+1,1               CONVERT DDNAME REQUEST        04003000
         SPACE 1                                                        04004000
         DYNALLOC                                                       04005000
         SPACE 1                                                        04006000
         DROP  R1,R3,R4,R5                                              04007000
         SPACE 2                                                        04008000
CMXFREEP CLI   #CMXSYSP,X'41'             ANY SYSPRINT ALLOCATED?       04009000
         BL    CMXFREE3                   NO, BRANCH                    04010000
         SPACE 1                                                        04011000
         XC    M99RBPTR(40),M99RBPTR      CLEAR THE WORK AREA           04012000
         LA    R1,M99RBPTR                DYNAMIC ALLOCATION            04013000
         USING S99RBP,R1                                                04014000
         SPACE 1                                                        04015000
         LA    R4,M99RB                                                 04016000
         USING S99RB,R4                                                 04017000
         ST    R4,S99RBPTR                                              04018000
         OI    S99RBPTR,S99RBPND          MARK END OF LIST              04019000
         SPACE 1                                                        04020000
         LA    R5,M99TUPL                                               04021000
         USING S99TUPL,R5                                               04022000
         MVI   S99RBLN,20                 LENGTH 20                     04023000
         MVI   S99VERB,S99VRBUN           UNALLOCATE                    04024000
         ST    R5,S99TXTPP                POINT TO TEXT POINTER         04025000
         SPACE 1                                                        04026000
         LA    R3,#CMXSYSP-6              TEXT POINTER                  04027000
         USING S99TUNIT,R3                                              04028000
         MVC   S99TUKEY(6),CMXDDNAM       ADD TEXT KEYS                 04029000
         ST    R3,S99TUPTR                POINT TO TEXT UNIT            04030000
         OI    S99TUPTR,X'80'             MARK END OF THE TEXT LIST     04031000
         MVI   S99TUKEY+1,1               CONVERT DDNAME REQUEST        04032000
         SPACE 1                                                        04033000
         DYNALLOC                                                       04034000
         SPACE 1                                                        04035000
         DROP  R1,R3,R4,R5                                              04036000
         SPACE 2                                                        04037000
CMXFREE3 CLI   #CMXSYSP,X'41'             ANY SYSUT3 ALLOCATED?         04038000
         BL    RESTART0                   NO, BRANCH                    04039000
         SPACE 1                                                        04040000
         XC    M99RBPTR(40),M99RBPTR      CLEAR THE WORK AREA           04041000
         LA    R1,M99RBPTR                DYNAMIC ALLOCATION            04042000
         USING S99RBP,R1                                                04043000
         SPACE 1                                                        04044000
         LA    R4,M99RB                                                 04045000
         USING S99RB,R4                                                 04046000
         ST    R4,S99RBPTR                                              04047000
         OI    S99RBPTR,S99RBPND          MARK END OF LIST              04048000
         SPACE 1                                                        04049000
         LA    R5,M99TUPL                                               04050000
         USING S99TUPL,R5                                               04051000
         MVI   S99RBLN,20                 LENGTH 20                     04052000
         MVI   S99VERB,S99VRBUN           UNALLOCATE                    04053000
         ST    R5,S99TXTPP                POINT TO TEXT POINTER         04054000
         SPACE 1                                                        04055000
         LA    R3,#CMXSYS3-6              TEXT POINTER                  04056000
         USING S99TUNIT,R3                                              04057000
         MVC   S99TUKEY(6),CMXDDNAM       ADD TEXT KEYS                 04058000
         ST    R3,S99TUPTR                POINT TO TEXT UNIT            04059000
         OI    S99TUPTR,X'80'             MARK END OF THE TEXT LIST     04060000
         MVI   S99TUKEY+1,1               CONVERT DDNAME REQUEST        04061000
         SPACE 1                                                        04062000
         DYNALLOC                                                       04063000
         SPACE 1                                                        04064000
         DROP  R1,R3,R4,R5                                              04065000
         AGO   .NA00360
.MA00360 ANOP  ,                                                   @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        Unallocate SYSIN using DAIR.                            * @D01
*----------------------------------------------------------------* @D01
         CLI   #CMXSYSI,X'41'      Was SYSIN allocated?            @D01
         BL    CMXFREEP            No, skip unallocate             @D01
         XC    DAIR18,DAIR18       Clear parm block to zeroes      @D01
         LA    R5,DAIR18           Point to unallocate parm block  @D01
         USING DAPB18,R5           Address unallocate parm block   @D01
         MVI   DA18CD+1,X'18'      Entry code = unallocate         @D01
         MVC   DA18DDN,#CMXSYSI    Set SYSIN DD name               @D01
         LA    R14,PARMLIST        Point to DAPL                   @D01
         USING DAPL,R14            Addressability for DAPL         @D01
         L     R1,ADDRUPT          Get UPT address                 @D01
         L     R2,ADDRECT          Get ECT address                 @D01
         LA    R3,ATTNECB          Get address of ECB              @D01
         L     R4,ADDRPSCB         Get PSCB address                @D01
***      LA    R5,DAIR18           Get DAIR parm block address     @D01
         STM   R1,R5,DAPLUPT       Set DAPLUPT, DAPLECT, DAPLECB,  @D01
*                                      DAPLPSCB and DAPLDAPB       @D01
         DROP  R5                  End parm block addressability   @D01
         LR    R1,R14              Set DAPL address for DAIR       @D01
         DROP  R14                 End DAPL addressability         @D01
         L     R15,ADDRDAIR        Get DAIR address                @D01
         BALR  R14,R15             Link to DAIR to free the file   @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        Unallocate SYSPRINT using DAIR.                         * @D01
*----------------------------------------------------------------* @D01
CMXFREEP CLI   #CMXSYSP,X'41'      Was SYSPRINT allocated?         @D01
         BL    CMXFREE3            No, skip unallocate             @D01
         XC    DAIR18,DAIR18       Clear parm block to zeroes      @D01
         LA    R5,DAIR18           Point to unallocate parm block  @D01
         USING DAPB18,R5           Address unallocate parm block   @D01
         MVI   DA18CD+1,X'18'      Entry code = unallocate         @D01
         MVC   DA18DDN,#CMXSYSP    Set SYSPRINT DD name            @D01
         LA    R14,PARMLIST        Point to DAPL                   @D01
         USING DAPL,R14            Addressability for DAPL         @D01
         L     R1,ADDRUPT          Get UPT address                 @D01
         L     R2,ADDRECT          Get ECT address                 @D01
         LA    R3,ATTNECB          Get address of ECB              @D01
         L     R4,ADDRPSCB         Get PSCB address                @D01
***      LA    R5,DAIR18           Get DAIR parm block address     @D01
         STM   R1,R5,DAPLUPT       Set DAPLUPT, DAPLECT, DAPLECB,  @D01
*                                      DAPLPSCB and DAPLDAPB       @D01
         DROP  R5                  End parm block addressability   @D01
         LR    R1,R14              Set DAPL address for DAIR       @D01
         DROP  R14                 End DAPL addressability         @D01
         L     R15,ADDRDAIR        Get DAIR address                @D01
         BALR  R14,R15             Link to DAIR to free the file   @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        Unallocate SYSUT3 using DAIR.                           * @D01
*----------------------------------------------------------------* @D01
CMXFREE3 CLI   #CMXSYS3,X'41'      Was SYSUT3 allocated?           @D01
         BL    RESTART0            No, skip unallocate             @D01
         XC    DAIR18,DAIR18       Clear parm block to zeroes      @D01
         LA    R5,DAIR18           Point to unallocate parm block  @D01
         USING DAPB18,R5           Address unallocate parm block   @D01
         MVI   DA18CD+1,X'18'      Entry code = unallocate         @D01
         MVC   DA18DDN,#CMXSYS3    Set SYSUT3 DD name              @D01
         LA    R14,PARMLIST        Point to DAPL                   @D01
         USING DAPL,R14            Addressability for DAPL         @D01
         L     R1,ADDRUPT          Get UPT address                 @D01
         L     R2,ADDRECT          Get ECT address                 @D01
         LA    R3,ATTNECB          Get address of ECB              @D01
         L     R4,ADDRPSCB         Get PSCB address                @D01
***      LA    R5,DAIR18           Get DAIR parm block address     @D01
         STM   R1,R5,DAPLUPT       Set DAPLUPT, DAPLECT, DAPLECB,  @D01
*                                      DAPLPSCB and DAPLDAPB       @D01
         DROP  R5                  End parm block addressability   @D01
         LR    R1,R14              Set DAPL address for DAIR       @D01
         DROP  R14                 End DAPL addressability         @D01
         L     R15,ADDRDAIR        Get DAIR address                @D01
         BALR  R14,R15             Link to DAIR to free the file   @D01
.NA00360 ANOP  ,                                                   @D01
         B     RESTART0                                                 04066000
         SPACE 3                                                        04067000
*  COMPRESS CONSTANTS                                                   04068000
         PRINT NOGEN                                                    04069000
CMXDCB   DCB   DSORG=PS,DDNAME=CMX,MACRF=GL,EODAD=CMXMDONE              04070000
CMXDL    EQU   *-CMXDCB                                                 04071000
         AIF   (&MVT).MA00380                                      @D01
         PRINT GEN                                                      04072000
         SPACE 2                                                        04073000
CMXDDNAM DC    X'0055000100084040404040404040'                          04074000
CMXDUMMY DC    X'00240000'                       DUMMY DATA SET         04075000
CMXBLKSI DC    X'0030000100020050'               DCB=BLKSIZE=80         04076000
CMXNEW   DC    X'00040001000104'                 DISP=(NEW)             04077000
CMXDEL   DC    X'00050001000104'                 DISP=(,DELETE)         04078000
CMXCDEL  DC    X'00060001000104'                 DISP=(,,DELETE)        04079000
         SPACE 2                                                        04080000
         SPACE 2                                                        04081000
CMXPRTFI DC    X'000A00010003',AL3(*-*)          SPACE=(,NNN)           04082000
CMXPRTSE DC    X'000B00010003',AL3(*-*)          SPACE=(,(,NNN))        04083000
CMXPRTIN DC    X'00090001000300181B'             SPACE=(6171)           04084000
CMXUT3IN DC    X'000900010003000050'             SPACE=(80)             04085000
         SPACE 1                                                        04086000
CMXPRTRE DC    X'004900010001',XL1'94'           DCB=RECFM=FBA          04087000
CMXPRTLR DC    X'004200010002',AL2(121)          DCB=LRECL=121          04088000
CMXPRTBL DC    X'003000010002',AL2(6171)         DCB=BLKSIZE=6171       04089000
         SPACE 2                                                        04090000
CMXSYSIN DC    A(CMXDUMMY,CMXBLKSI,CMXNEW,CMXDEL),X'80',AL3(CMXCDEL)    04091000
CMXSYSUT DC    A(CMXPRTFI,CMXPRTSE,CMXUT3IN)                            04092000
         DC    A(CMXNEW,CMXDEL),X'80',AL3(CMXCDEL)                      04093000
CMXSYSPR DC    A(CMXPRTFI,CMXPRTSE,CMXPRTIN)                            04094000
         DC    A(CMXPRTRE,CMXPRTLR,CMXPRTBL)                            04095000
         DC    A(CMXNEW,CMXDEL),X'80',AL3(CMXCDEL)                      04096000
.MA00380 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS CONTROL                         1/15/85' 04097000
*********************************************************************** 04098000
***      CONTROL SUBCOMMAND    ADDED BY BRUCE LELAND -- OCT., 1983  *** 04099000
*********************************************************************** 04100000
*                                                                       04101000
         SPACE 1                                                        04102000
CONTROL  CSECT                                                          04103000
         USING *,R8                                                     04104000
         AIF ('&CISP' EQ 'NO SPF').NSPF200                              04105000
         TM    FLAGSEE,FBKGRND               BACKGROUND MODE?           04106000
         BO    CONT004                       YES, BRANCH                04107000
         TM    FLAGSFF,FSPFOPT6+FSPFERR+FSPFCALL+FSPFDIAL  CHANGE SPF?  04108000
         BNZ   CONT004                                     NO, BRANCH   04109000
         TM    #OUT+10,X'01'                 SYSOUT/DSNAME?             04110000
         BNO   CONT004                       NO, BRANCH                 04111000
         BAL   R2,SPFRECUR                   INVOKE PDS AS A DIALOG     04112000
         SPACE 1                                                        04113000
.NSPF200 ANOP                                                           04114000
         SPACE 2                                                        04115000
CONT004  CLI   #OUT+10,0                     SYSOUT/NOSYSOUT/DSN/NODSN? 04116000
         BE    CONT010                       NO, BRANCH                 04117000
         TM    DCBOFLGS-IHADCB+LOGDCB,X'10'  OPEN?                      04118000
         BZ    CONT010                       NO, BRANCH                 04119000
*** CLOSE THE SYSOUT/DSNAME DATA SET                                    04120000
         NI    FLAGSFF,FF-FLOGWRT         TURN OFF RECORD FLAG          04121000
         MVI   OPENLIST,X'80'                                           04122000
         CLOSE (LOGDCB),MF=(E,OPENLIST)                                 04123000
         AIF   (NOT &MVT).MA00400                                  @D01
*----------------------------------------------------------------* @D01
*        Free the old log file using DAIR.                       * @D01
*----------------------------------------------------------------* @D01
         XC    DAIR18,DAIR18       Clear parm block to zeroes      @D01
         LA    R5,DAIR18           Point to unallocate parm block  @D01
         USING DAPB18,R5           Address unallocate parm block   @D01
         MVI   DA18CD+1,X'18'      Entry code = unallocate         @D01
         MVC   DA18DDN,LOGDDN      Set DD name to free             @D01
         DROP  R5                  End parm block addresability    @D01
         LA    R14,PARMLIST        Point to DAPL                   @D01
         USING DAPL,R14            Addressability for DAPL         @D01
         L     R1,ADDRUPT          Get UPT address                 @D01
         L     R2,ADDRECT          Get ECT address                 @D01
         LA    R3,ATTNECB          Get address of ECB              @D01
         L     R4,ADDRPSCB         Get PSCB address                @D01
***      LA    R5,DAIR18           Get DAIR parm block address     @D01
         STM   R1,R5,DAPLUPT       Set DAPLUPT, DAPLECT, DAPLECB,  @D01
*                                      DAPLPSCB and DAPLDAPB       @D01
         LR    R1,R14              Set DAPL address for DAIR       @D01
         DROP  R14                 End DAPL addressability         @D01
         L     R15,ADDRDAIR        Get DAIR address                @D01
         BALR  R14,R15             Link to DAIR to free the file   @D01
.MA00400 ANOP  ,                                                   @D01
         TSMSG L081                                                     04124000
         SPACE 2                                                        04125000
         CLI   CONTOPTN,X'03'             DISK LOG OPEN?                04126000
         BNE   CONT010                    NO, BRANCH                    04127000
         LH    R1,DSNLEN                  DSNAME LENGTH                 04128000
         BCTR  R1,0                       MACHINE LENGTH                04129000
         LA    R15,FIRST4K                                              04130000
         CLC   DSNAME(*-*),CONTDSN-FIRST4K(R15)                         04131000
         EX    R1,*-6                     THIS DATA SET?                04132000
         BNE   CONT010                    NO, BRANCH                    04133000
         SPACE 1                                                        04134000
         MVI   ##ADRCM#,CONTINUE          FLAG TO CONTINUE              04135000
         MVI   VOLALLOC,X'40'             READ THE DSCB AGAIN           04136000
         BAL   R2,CLOSEIT                 CLOSE THE DCB                 04137000
         B     RESTART4                   OPEN THE DATA SET AGAIN       04138000
         SPACE 2                                                        04139000
CONT010  MESSAGE MSGBLANK          ONE BLANK LINE                       04140000
         MVC   INSERT#1(8),PDSNAME                                      04141000
         MVC   MTLEN,PDSNAML       Set insert length               @D01
         TSMSG L100$1                                                   04142000
         MVI   MTLEN,8             Restore standard length         @D01
         MESSAGE MSGBLANK          ONE BLANK LINE                       04143000
         SPACE 1                                                        04144000
         CLI   #OUT+0,1            ANY CONTROL OPERAND?                 04145000
         BL    CONT020             NO, BRANCH                           04146000
         BH    CONT012             YES, THE NO FORM                     04147000
         NI    FLAGSGG,FF-FALINCON YES FORM                             04148000
         B     CONT020                                                  04149000
CONT012  OI    FLAGSGG,FALINCON    NO FORM                              04150000
         SPACE 1                                                        04151000
CONT020  CLI   #OUT+1,1            ANY CONTROL OPERAND?                 04152000
         BL    CONT030             NO, BRANCH                           04153000
         BH    CONT022             YES, THE NO FORM                     04154000
**       NI    FLAGSGG,FF-FSAVEOP  YES FORM                        @D05 04155000
         NI    FLAGSGG,FF-FTRANCON YES FORM                        @D05
         B     CONT030                                                  04156000
**CONT022  OI    FLAGSGG,FSAVEOP     NO FORM                       @D05 04157000
CONT022  OI    FLAGSGG,FTRANCON    NO FORM                         @D05
         SPACE 1                                                        04158000
CONT030  CLI   #OUT+2,1            ANY CONTROL OPERAND?                 04159000
         BL    CONT040             NO, BRANCH                           04160000
         BH    CONT032             YES, THE NO FORM                     04161000
         NI    FLAGSGG,FF-FLKEDCON YES FORM                             04162000
         B     CONT040                                                  04163000
CONT032  OI    FLAGSGG,FLKEDCON    NO FORM                              04164000
         SPACE 1                                                        04165000
CONT040  CLI   #OUT+3,1            ANY CONTROL OPERAND?                 04166000
         BL    CONT050             NO, BRANCH                           04167000
         BH    CONT042             YES, THE NO FORM                     04168000
         NI    FLAGSGG,FF-FPROMCON YES FORM                             04169000
         B     CONT050                                                  04170000
CONT042  OI    FLAGSGG,FPROMCON    NO FORM                              04171000
         SPACE 1                                                        04172000
CONT050  CLI   #OUT+4,1            ANY CONTROL OPERAND?                 04173000
         BL    CONT060             NO, BRANCH                           04174000
         BH    CONT052             YES, THE NO FORM                     04175000
         NI    FLAGSGG,FF-FRECVCON YES FORM                             04176000
         B     CONT060                                                  04177000
CONT052  OI    FLAGSGG,FRECVCON    NO FORM                              04178000
         SPACE 1                                                        04179000
CONT060  CLI   #OUT+5,1            ANY CONTROL OPERAND?                 04180000
         BL    CONT100             NO, BRANCH                           04181000
         CLI   #OUT+5,2            ANY CONTROL OPERAND?                 04182000
         BE    CONT062             YES, THE NO FORM                     04183000
         NI    FLAGSEE,FF-FDOUBCON-FFULLTRK  YES FORM                   04184000
         XI    FLAGSEE,FDOUBCON    DOUBLE BUFFER FORM                   04185000
         CLI   #OUT+5,1            CONTROL DOUBLE?                      04186000
         BE    CONT100             YES, BRANCH                          04187000
         XI    FLAGSEE,FDOUBCON    NO, FULLTRACK REQUEST                04188000
         B     CONT100                                                  04189000
CONT062  OI    FLAGSEE,FDOUBCON+FFULLTRK     NO FORM                    04190000
         SPACE 2                                                        04191000
CONT100  MVI   MTHIGHL,100                                              04192000
         MVC   INSERT#1(132),MSGBL132+4                                 04193000
         LA    R1,INSERT#1-2       START OF GLOBAL TEXT                 04194000
         SPACE 1                                                        04195000
         TM    FLAGSGG,FALINCON    CONTROL NO FORM?                     04196000
         BNO   *+14                NO, BRANCH                           04197000
         MVC   2(L'CALINCON,R1),CALINCON                                04198000
         LA    R1,L'CALINCON(R1)                                        04199000
         SPACE 1                                                        04200000
         TM    FLAGSGG,FLKEDCON    CONTROL NO FORM?                     04201000
         BNO   *+14                NO, BRANCH                           04202000
         MVC   2(L'CLKEDCON,R1),CLKEDCON                                04203000
         LA    R1,L'CLKEDCON(R1)                                        04204000
         SPACE 1                                                        04205000
         TM    FLAGSGG,FPROMCON    CONTROL NO FORM?                     04206000
         BNO   *+14                NO, BRANCH                           04207000
         MVC   2(L'CPROMCON,R1),CPROMCON                                04208000
         LA    R1,L'CPROMCON(R1)                                        04209000
         SPACE 1                                                        04210000
         TM    FLAGSGG,FRECVCON    CONTROL NO FORM?                     04211000
         BNO   *+14                NO, BRANCH                           04212000
         MVC   2(L'CRECVCON,R1),CRECVCON                                04213000
         LA    R1,L'CRECVCON(R1)                                        04214000
         SPACE 1                                                   @D05
         TM    FLAGSGG,FTRANCON    CONTROL NO FORM?                @D05
         BNO   *+14                NO, BRANCH                      @D05
         MVC   2(L'CTRANCON,R1),CTRANCON                           @D05
         LA    R1,L'CTRANCON(R1)                                   @D05
         SPACE 1                                                        04215000
***TEST  TM    FLAGSGG,FSAVEOP     CONTROL NO FORM?                     04216000
***TEST  BNO   *+14                NO, BRANCH                           04217000
***TEST  MVC   2(L'CSAVECON,R1),CSAVECON                                04218000
***TEST  LA    R1,L'CSAVECON(R1)                                        04219000
         SPACE 2                                                        04220000
         TM    FLAGSGG,FALINCON    CONTROL YES FORM?                    04221000
         BNZ   *+14                NO, BRANCH                           04222000
         MVC   2(L'CALINCON-2,R1),CALINCON+2                            04223000
         LA    R1,L'CALINCON-2(R1)                                      04224000
         SPACE 1                                                        04225000
         TM    FLAGSGG,FLKEDCON    CONTROL YES FORM?                    04226000
         BNZ   *+14                NO, BRANCH                           04227000
         MVC   2(L'CLKEDCON-2,R1),CLKEDCON+2                            04228000
         LA    R1,L'CLKEDCON-2(R1)                                      04229000
         SPACE 1                                                        04230000
         TM    FLAGSGG,FPROMCON    CONTROL YES FORM?                    04231000
         BNZ   *+14                NO, BRANCH                           04232000
         MVC   2(L'CPROMCON-2,R1),CPROMCON+2                            04233000
         LA    R1,L'CPROMCON-2(R1)                                      04234000
         SPACE 1                                                        04235000
         TM    FLAGSGG,FRECVCON    CONTROL YES FORM?                    04236000
         BNZ   *+14                NO, BRANCH                           04237000
         MVC   2(L'CRECVCON-2,R1),CRECVCON+2                            04238000
         LA    R1,L'CRECVCON-2(R1)                                      04239000
         SPACE 1                                                   @D05
         TM    FLAGSGG,FTRANCON    CONTROL YES FORM?               @D05
         BNZ   *+14                NO, BRANCH                      @D05
         MVC   2(L'CTRANCON-2,R1),CTRANCON+2                       @D05
         LA    R1,L'CTRANCON-2(R1)                                 @D05
         SPACE 1                                                        04240000
**       TM    FLAGSGG,FSAVEOP     CONTROL YES FORM?               @D05 04241000
**       BNZ   *+14                NO, BRANCH                      @D05 04242000
**       MVC   2(L'CSAVECON-2,R1),CSAVECON+2                       @D05 04243000
**       LA    R1,L'CSAVECON-2(R1)                                 @D05 04244000
         SPACE 1                                                        04245000
         MVC   0(8,R1),BLANKS      DELETE THE LAST COMMA                04246000
         TSMSG L030$1                                                   04247000
         SPACE 2                                                        04248000
         MVC   INSERT#1(120),MSGBL132+4                                 04249000
         AIF   (&MVT).MA00420                                      @D01
         CLI   #OUT+13,X'02'              NODEST?                       04250000
         BE    *+12                       YES, BRANCH                   04251000
         CLI   #OUT+15,0                  ANY DEST?                     04252000
         BE    CONT112                    NO, BRANCH                    04253000
         MVC   CONTDEST(2),#OUT+14        DEST LENGTH                   04254000
         MVC   CONTDEST+2(8),#OUT+30      DEST                          04255000
         SPACE 1                                                        04256000
CONT112  CLI   #OUT+12,X'02'              NOFORM?                       04257000
         BE    *+12                       YES, BRANCH                   04258000
         CLI   #OUT+17,0                  ANY FORM?                     04259000
         BE    CONT114                    NO, BRANCH                    04260000
         MVC   CONTFORM(2),#OUT+16        DEST LENGTH                   04261000
         MVC   CONTFORM+2(4),#OUT+38      DEST                          04262000
         SPACE 1                                                        04263000
.MA00420 ANOP  ,                                                   @D01
CONT114  CLI   #OUT+10,0                  ANY SWITCHED LOG?             04264000
         BE    CONT116                    NO, BRANCH                    04265000
         MVC   CONTOPTN(1),#OUT+10        CURRENT OPTION                04266000
         AIF   (&MVT).MA00440                                      @D01
         CLI   CONTOPTN,X'02'             NOSYSOUT?                     04267000
         BNE   *+8                        NO, BRANCH                    04268000
         MVI   CONTOPTN,0                 YES, CONVERT TO NULL          04269000
.MA00440 ANOP  ,                                                   @D01
         CLI   CONTOPTN,X'04'             NODSNAME?                     04270000
         BNE   *+8                        NO, BRANCH                    04271000
         MVI   CONTOPTN,0                 YES, CONVERT TO NULL          04272000
         SPACE 2                                                        04273000
CONT116  CLI   CONTOPTN,X'03'             DSNAME?                       04274000
         BNE   CONT124                    NO, BRANCH                    04275000
         LA    R14,FIRST4K                BASE REGISTER                 04276000
         LA    R14,CONTDSN-FIRST4K(,R14)  POINT TO THE CONTDSN          04277000
         CLI   #OUT+19,0                  ANY DSNAME?                   04278000
         BE    CONT120                    NO, USE PREVIOUS              04279000
         MVC   0(60,R14),MSGBL132+4       BLANK CONTDSN                 04280000
         MVC   0(44,R14),#OUT+44          DSNAME                        04281000
         LH    R1,#OUT+18                 DSNAME LENGTH                 04282000
         LA    R15,0(R1,R14)              POINT TO START OF MEMBER      04283000
         CLI   #OUT+21,0                  ANY MEMBER?                   04284000
         BE    CONT118                    NO, BRANCH                    04285000
         MVI   0(R15),C'('                BEGINNING (                   04286000
         MVC   1(8,R15),#OUT+88           MEMBER NAME                   04287000
         AH    R15,#OUT+20                MEMBER LENGTH                 04288000
         MVI   1(R15),C')'                ENDING )                      04289000
         LA    R15,2(,R15)                CURRENT LENGTH OF NAME        04290000
         SPACE 1                                                        04291000
CONT118  MVI   0(R15),C')'                TO MATCH DSN( ...             04292000
         MVC   2(3,R15),CLOGSHR           SHR                           04293000
         CLI   #OUT+11,X'02'              CORRECT?                      04294000
         BE    CONT120                    YES, BRANCH                   04295000
         MVC   2(3,R15),CLOGMOD           MOD                           04296000
         CLI   #OUT+11,X'03'              CORRECT?                      04297000
         BE    CONT120                    YES, BRANCH                   04298000
         MVC   2(3,R15),CLOGNEW           NEW                           04299000
         CLI   #OUT+11,X'04'              CORRECT?                      04300000
         BE    CONT120                    YES, BRANCH                   04301000
         MVC   2(3,R15),CLOGOLD           OLD                           04302000
         SPACE 1                                                        04303000
CONT120  MVC   INSERT#1(7),CLOGDSN        DSNAME KEYWORD                04304000
         MVC   INSERT#1+7(60),0(R14)                                    04305000
         B     CONT129                                                  04306000
         SPACE 2                                                        04307000
CONT124  LA    R15,INSERT#1                                             04308000
         CLI   CONTOPTN,0                 ANY CURRENT OPTIONS?          04309000
         BH    CONT126                    YES, BRANCH                   04310000
         AIF   (&MVT).MA00480                                      @D01
         MVC   0(9,R15),CLOGNDSN          ADD NODSNAME,                 04311000
         LA    R15,10(,R15)                                             04312000
         MVC   0(9,R15),CLOGNSYS          ADD NOSYSOUT,                 04313000
         LA    R15,10(,R15)                                             04314000
         B     CONT127                                                  04315000
         AGO   .NA00480                                            @D01
.MA00480 ANOP  ,                                                   @D01
         MVC   0(8,R15),CLOGNDSN          ADD NODSNAME,            @D01
         LA    R15,8(,R15)                                         @D01
.NA00480 ANOP  ,                                                   @D01
         SPACE 1                                                        04316000
CONT126  DS    0H                                                  @D01
         AIF   (&MVT).MA00500                                      @D01
         MVC   0(7,R15),CLOGSYS           ADD SYSOUT(              @D01 04317000
         MVC   7(1,R15),CONTSYS           ADD SYSOUT CLASS              04318000
         MVC   8(2,R15),CLOGCOMM          ADD ),                        04319000
         LA    R15,11(,R15)                                             04320000
         SPACE 1                                                        04321000
CONT127  DS    0H                                                  @D01
         MVC   0(7,R15),CLOGNFOR          ADD NOFORM,              @D01 04322000
         CLI   CONTFORM+1,0               ANY FORM?                     04323000
         BNE   *+12                       YES, BRANCH                   04324000
         LA    R15,8(,R15)                                              04325000
         B     CONT128                                                  04326000
         MVC   0(5,R15),CLOGFOR           ADD FORM(                     04327000
         MVC   5(4,R15),CONTFORM+2        ADD FORM NAME                 04328000
         LH    R1,CONTFORM                LENGTH                        04329000
         LA    R15,5(R1,R15)                                            04330000
         MVC   0(2,R15),CLOGCOMM          ADD ),                        04331000
         LA    R15,3(R15)                                               04332000
         SPACE 1                                                        04333000
CONT128  MVC   0(6,R15),CLOGNDES          ADD NODEST,                   04334000
         CLI   CONTDEST+1,0               ANY DEST?                     04335000
         BE    CONT129                    NO, BRANCH                    04336000
         MVC   0(5,R15),CLOGDES           ADD DEST(                     04337000
         MVC   5(8,R15),CONTDEST+2        ADD DEST NAME                 04338000
         LH    R1,CONTDEST                LENGTH                        04339000
         LA    R15,5(R1,R15)                                            04340000
         MVI   0(R15),C')'                ADD )                         04341000
.MA00500 ANOP  ,                                                   @D01
         SPACE 2                                                        04342000
CONT129  DS    0H                                                       04343000
         TSMSG L030$1                                                   04344000
         MVC   INSERT#1(120),MSGBL132+4                                 04345000
         MVC   INSERT#1(8),CSINGCON       ASSUME SINGLE BUFFERING       04346000
         TM    FLAGSEE,FDOUBCON+FFULLTRK  CONTROL SINGLE?               04347000
         BO    CONT130                    YES, BRANCH                   04348000
         MVC   INSERT#1(8),CDOUBCON       ASSUME DOUBLE BUFFERING       04349000
         TM    FLAGSEE,FDOUBCON+FFULLTRK  CONTROL DOUBLE?               04350000
         BM    CONT130                    YES, BRANCH                   04351000
         MVC   INSERT#1(8),CMULTCON       READ MULTIPLE                 04352000
         SPACE 2                                                        04353000
CONT130  MVI   MTHIGHL,8                                                04354000
         TSMSG L031$1                                                   04355000
         MESSAGE MSGBLANK                 ONE BLANK LINE                04356000
         SPACE 2                                                        04357000
CONT134  TM    CONTOPTN,1                    ANY LOG RECORDING?         04358000
         BNO   CONT200                       NO, BRANCH                 04359000
         TM    DCBOFLGS-IHADCB+LOGDCB,X'10'  OPEN ALREADY               04360000
         BO    CONT200                       YES, BRANCH                04361000
***  ALLOCATE THE SYSOUT/DATA SET                                       04362000
         NI    FLAGSFF,FF-FLOGWRT            TURN OFF RECORD FLAG       04363000
         SPACE 1                                                        04364000
         AIF   (&MVT).MA00520                                      @D01
         XC    M99RBPTR(40),M99RBPTR    CLEAR THE WORK AREA             04365000
         LA    R1,M99RBPTR              DYNAMIC ALLOCATION              04366000
         USING S99RBP,R1                                                04367000
         SPACE 1                                                        04368000
         LA    R4,M99RB                                                 04369000
         USING S99RB,R4                                                 04370000
         ST    R4,S99RBPTR                                              04371000
         OI    S99RBPTR,S99RBPND        MARK END OF LIST                04372000
         SPACE 1                                                        04373000
         LA    R5,M99TUPL                                               04374000
         USING S99TUPL,R5                                               04375000
         MVI   S99RBLN,20               LENGTH 20                       04376000
         MVI   S99VERB,S99VRBAL         ALLOCATE                        04377000
         ST    R5,S99TXTPP              POINT TO TEXT POINTERS          04378000
         LA    R3,WORKTBL                        START OF TEXT          04379000
         SPACE 1                                                        04380000
         MVC   0(L'CONDDNAM,R3),CONDDNAM         SPECIFY DDNAME TEXT    04381000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04382000
         LA    R3,L'CONDDNAM(,R3)                START OF NEXT TEXT     04383000
         SPACE 1                                                        04384000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04385000
         MVC   0(L'CONDSORG,R3),CONDSORG         SPECIFY DSORG TEXT     04386000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04387000
         LA    R3,L'CONDSORG(,R3)                START OF NEXT TEXT     04388000
         SPACE 1                                                        04389000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04390000
         MVC   0(L'CONFREE,R3),CONFREE           SPECIFY FREE TEXT      04391000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04392000
         LA    R3,L'CONFREE(,R3)                 START OF NEXT TEXT     04393000
         SPACE 1                                                        04394000
CONT140  CLI   CONTOPTN,X'03'                    DSNAME ALLOCATION?     04395000
         BNE   CONT150                           NO, BRANCH             04396000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04397000
         MVC   0(L'CONDSNAM,R3),CONDSNAM         SPECIFY DSNAME TEXT    04398000
         MVC   6(44,R3),#OUT+44                  SPECIFY DSNAME         04399000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04400000
         LA    R3,L'CONDSNAM+44(,R3)             START OF NEXT TEXT     04401000
         SPACE 1                                                        04402000
         CLI   #OUT+88,X'41'                     ANY MEMBER?            04403000
         BL    CONT141                           NO, BRANCH             04404000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04405000
         MVC   0(L'CONMEMBR,R3),CONMEMBR         SPECIFY MEMBER TEXT    04406000
         MVC   6(8,R3),#OUT+88                   SPECIFY MEMBER         04407000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04408000
         LA    R3,L'CONMEMBR(,R3)                START OF NEXT TEXT     04409000
         SPACE 1                                                        04410000
CONT141  CLI   #OUT+96,X'41'                     ANY PASSWORD?          04411000
         BL    CONT142                           NO, BRANCH             04412000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04413000
         MVC   0(L'CONPASSW,R3),CONPASSW         SPECIFY PASSWORD TEXT  04414000
         MVC   6(8,R3),#OUT+96                   SPECIFY PASSWORD       04415000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04416000
         LA    R3,L'CONPASSW(,R3)                START OF NEXT TEXT     04417000
         SPACE 1                                                        04418000
CONT142  LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04419000
         MVC   0(L'CONALLOC,R3),CONALLOC         SPECIFY DISP TEXT      04420000
         CLI   #OUT+11,2                         SHR?                   04421000
         BNE   *+8                               NO, BRANCH             04422000
         MVI   6(R3),CONOSHR                     SPECIFY DISPOSITION    04423000
         CLI   #OUT+11,3                         MOD?                   04424000
         BNE   *+8                               NO, BRANCH             04425000
         MVI   6(R3),CONOMOD                     SPECIFY DISPOSITION    04426000
         CLI   #OUT+11,4                         NEW?                   04427000
         BNE   *+8                               NO, BRANCH             04428000
         MVI   6(R3),CONONEW                     SPECIFY DISPOSITION    04429000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04430000
         LA    R3,L'CONALLOC(,R3)                START OF NEXT TEXT     04431000
         SPACE 1                                                        04432000
         CLI   #OUT+11,3                         MOD OR NEW?            04433000
         BL    CONT149                           NO, BRANCH             04434000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04435000
         MVC   0(L'CONFIRST,R3),CONFIRST         SPECIFY PRIMARY        04436000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04437000
         LA    R3,L'CONFIRST(,R3)                START OF NEXT TEXT     04438000
         SPACE 1                                                        04439000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04440000
         MVC   0(L'CONSECON,R3),CONSECON         SPECIFY SECONDARY      04441000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04442000
         LA    R3,L'CONSECON(,R3)                START OF NEXT TEXT     04443000
         SPACE 1                                                        04444000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04445000
         MVC   0(L'CONTRK,R3),CONTRK             SPECIFY TRACK ALLOC    04446000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04447000
         LA    R3,L'CONTRK(,R3)                  START OF NEXT TEXT     04448000
         SPACE 1                                                        04449000
         CLI   #OUT+88,X'41'                     ANY MEMBER NAME?       04450000
         BL    CONT149                           NO, BRANCH             04451000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04452000
         MVC   0(L'CONDIR,R3),CONDIR             SPECIFY DIRECTORY BLKS 04453000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04454000
         LA    R3,L'CONDIR(,R3)                  START OF NEXT TEXT     04455000
         SPACE 1                                                        04456000
CONT149  LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04457000
         MVC   0(L'CONNORM,R3),CONNORM           SPECIFY DISP=(,CATLG)  04458000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04459000
         LA    R3,L'CONNORM(,R3)                 START OF NEXT TEXT     04460000
         SPACE 1                                                        04461000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04462000
         MVC   0(L'CONANORM,R3),CONANORM         SPECIFY DISP=(,,KEEP)  04463000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04464000
         B     CONT159                                                  04465000
         SPACE 1                                                        04466000
CONT150  CLI   CONTFORM+1,0                      ANY FORM?              04467000
         BZ    CONT152                           NO, BRANCH             04468000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04469000
         MVC   0(L'CONFORMS,R3),CONFORMS         SPECIFY FORMS TEXT     04470000
         MVC   6(4,R3),CONTFORM+2                SPECIFY FORM NAME      04471000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04472000
         LA    R3,L'CONFORMS(,R3)                START OF NEXT TEXT     04473000
         SPACE 1                                                        04474000
CONT152  CLI   CONTDEST+1,0                      ANY DEST?              04475000
         BZ    CONT154                           NO, BRANCH             04476000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04477000
         MVC   0(L'CONDESTS,R3),CONDESTS         SPECIFY DEST TEXT      04478000
         MVC   6(8,R3),CONTDEST+2                SPECIFY DESTINATION    04479000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04480000
         LA    R3,L'CONDESTS(,R3)                START OF NEXT TEXT     04481000
         SPACE 1                                                        04482000
CONT154  LA    R5,4(,R5)                         NEXT POINTER ELEMENT   04483000
         MVC   0(L'CONSYSOU,R3),CONSYSOU         SPECIFY SYSOUT TEXT    04484000
         MVC   6(1,R3),CONTSYS                   SPECIFY SYSOUT CLASS   04485000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     04486000
         SPACE 1                                                        04487000
CONT159  OI    S99TUPTR,X'80'                    MARK END OF LIST       04488000
         DYNALLOC                                                       04489000
         SPACE 2                                                        04490000
         DROP  R1,R4,R5                                                 04491000
         MVC   DDNAMEH,WORKTBL+6        SAVE DDNAME                     04492000
         LTR   R15,R15                  SUCCESSFUL?                     04493000
         BZ    CONT164                  YES, BRANCH                     04494000
         SPACE 2                                                        04495000
         LA    R14,M99RB                POINTER TO SVC 99 BLOCK         04496000
         ST    R15,DAIRRC               RETURN CODE                     04497000
         LA    R15,DAIRRC               POINTER TO RETURN CODE          04498000
         LA    R0,ADDRFF02              POINTER TO A(IKJEFF02)          04499000
         LA    R1,=AL2(DFSVC99)         POINTER TO INVOCATION TYPE      04500000
         L     R2,ADDRCPPL              POINTER TO THE CPPL             04501000
         STM   R14,R2,DFDAPLP           INITIALIZE DFDAPLP, DFDRCP,     04502000
*                                         DFJEFF02, DFIDP AND DFCPPLP   04503000
         AGO   .NA00520                                            @D01
.MA00520 ANOP  ,                                                   @D01
*----------------------------------------------------------------* @D01
*        Allocate the log file using DAIR.  The log file must    * @D01
*        be a disk data set; logging to SYSOUT is not supported  * @D01
*        in MVT.                                                 * @D01
*----------------------------------------------------------------* @D01
         XC    DAIR08,DAIR08       Zero DAIR X'08' parm block      @D01
         LA    R5,DAIR08           Point to parm block             @D01
         USING DAPB08,R5           Addressability for parm block   @D01
         MVC   DA08CD,=XL2'0008'   Set entry code = allocate       @D01
         MVC   DA08DDN,BLANKS      Blank DD name                   @D01
         MVC   DA08MNM,BLANKS      Assume no member name           @D01
         MVC   DA08PSWD,BLANKS     Assume no password              @D01
         MVC   DA08UNIT,BLANKS     Assume no unit                  @D01
         MVC   DA08SER,BLANKS      Assume no volser                @D01
         MVC   DAIRDSNT,#OUT+44    Copy data set name              @D01
         MVC   DAIRDSNL,=AL2(44)   Set data set name length        @D01
         LA    R3,DAIRDSN          Point to DSN key                @D01
         ST    R3,DA08PDSN         Set DSN pointer in parm block   @D01
         CLI   #OUT+88,X'41'       Any member name?                @D01
         BL    CONT141             Branch if no member             @D01
         MVC   DA08MNM,#OUT+88     Else put member in parm block   @D01
CONT141  CLI   #OUT+96,X'41'       Was password provided?          @D01
         BL    CONT142             Branch if no password           @D01
         MVC   DA08PSWD,#OUT+96    Else set password               @D01
CONT142  MVI   DA08DSP1,DA08OLD    Assume DISP=OLD                 @D01
         MVI   DA08DPS2,DA08KEEP   Assume normal disp KEEP         @D01
         MVI   DA08DPS3,DA08KEP    Assume conditional disp KEEP    @D01
         CLI   #OUT+11,2           DISP=SHR?                       @D01
         BNE   CONT143             Branch if not SHR               @D01
         MVI   DA08DSP1,DA08SHR    Else set DISP=SHR               @D01
         B     CONT146             Continue                        @D01
CONT143  CLI   #OUT+11,3           DISP=MOD?                       @D01
         BNE   CONT144             Branch if not MOD               @D01
         MVI   DA08DSP1,DA08MOD    Else set DISP=MOD               @D01
         MVI   DA08DPS2,DA08CAT    Set normal disp CATLG           @D01
         B     CONT146             Continue                        @D01
CONT144  CLI   #OUT+11,4           DISP=NEW?                       @D01
         BNE   CONT146             Branch if not NEW               @D01
         MVI   DA08DSP1,DA08NEW    Else set DISP=NEW               @D01
         MVI   DA08DPS2,DA08CAT    Set normal disp CATLG           @D01
CONT146  CLI   #OUT+11,3           Is disposition NEW or MOD?      @D01
         BL    CONT149             No, branch                      @D01
         LA    R3,DAIRDSN          Point to DSN key                @D01
         OI    DA08CTL,DA08TRKS    Show to allocate in tracks      @D01
         MVC   DA08PQTY,=AL4(1)    Primary allocation 1 track      @D01
         MVC   DA08SQTY,=AL4(4)    Secondary allocation 4 tracks   @D01
         CLI   #OUT+88,X'41'       Was member name provided?       @D01
         BL    CONT149             No, continue                    @D01
         MVC   DA08DQTY,=AL4(5)    Else specify 5 directory blocks @D01
CONT149  DS    0H                                                  @D01
         B     CONT159             Continue                        @D01
CONT159  DS    0H                                                  @D01
         LA    R1,PARMLIST         Point to DAIR parameter list    @D01
         USING DAPL,R1             Address of DAIR parameter list  @D01
         MVC   DAPLUPT,ADDRUPT     Set UPT address in parm list    @D01
         MVC   DAPLECT,ADDRECT     Set ECT address in parm list    @D01
         MVC   DAPLECB,ATTNECB     Set ECB address in parm list    @D01
         MVC   DAPLPSCB,ADDRPSCB   Set PSCB address in parm list   @D01
         XC    ATTNECB,ATTNECB     Clear ECB                       @D01
         ST    R5,DAPLDAPB         Set parm block address in plist @D01
         L     R15,ADDRDAIR        Get address of DAIR             @D01
         BALR  R14,R15             Go to DAIR                      @D01
         DROP  R1                  End parm list addressability    @D01
         MVC   DDNAMEH,DA08DDN     Save DD name                    @D01
         MVC   LOGDDN,DA08DDN      Save DD name for unallocated    @D01
         MVC   WORKTBL+14+6(1),DA08DSO  Save returned DSORG        @D01
         LTR   R15,R15             Was DAIR successful?            @D01
         BZ    CONT164             Branch if successful            @D01
         XC    DFPARM,DFPARM       Else zero DAIRFAIL parm list    @D01
         ST    R15,DAIRRC          Save DAIR return code           @D01
         LA    R15,PARMLIST        Point to DAIR parameter list    @D01
         ST    R15,DFDAPLP         Set DAPL address for DAIRFAIL   @D01
         LA    R15,DAIRRC          Point to address of return code @D01
         ST    R15,DFRCP           Set RC address for DAIRFAIL     @D01
         LA    R15,ADDRFF02        Point to address of IKJEFF02    @D01
         ST    R15,DFJEFF02        Put in DAIRFAIL parm list       @D01
         LA    R15,=AL2(DFDAIR)    Point to DAIRFAIL caller ID     @D01
         ST    R15,DFIDP           Set ID pointer for DAIRFAIL     @D01
         L     R15,ADDRCPPL        Get address of CPPL             @D01
         ST    R15,DFCPPLP         Set CPPL address for DAIRFAIL   @D01
         DROP  R5                  End parm block addressability   @D01
.NA00520 ANOP  ,                                                   @D01
         SPACE 1                                                        04504000
         LINK  EP=IKJEFF18,MF=(E,DFPARMS)                               04505000
         LTR   R15,R15                  PROBLEM WITH IKJEFF18?          04506000
         BZ    CONT162                  NO, BRANCH                      04507000
         SPACE 2                                                        04508000
         CVD   R15,DOUBLE                                               04509000
         MVI   MTHIGHL,4                                                04510000
         MVC   INSERT#1(4),=X'40202120'                                 04511000
         ED    INSERT#1(4),DOUBLE+6                                     04512000
         MVI   INSERT#1,C'='                                            04513000
         TSMSG L835$1                                                   04514000
         SPACE 1                                                        04515000
CONT162  MVI   CONTOPTN,0               TURN OFF LOGGING                04516000
         NI    FLAGSFF,FF-FLOGWRT       TURN OFF LOGGING                04517000
         B     CONT200                                                  04518000
         SPACE 2                                                        04519000
CONT164  CLI   CONTOPTN,X'03'           DSNAME ALLOCATION?              04520000
         BNE   CONT180                  NO, BRANCH                      04521000
         LA    R1,L781$1                ASSUME A LOGICAL ERROR          04522000
         CLI   WORKTBL+14+6,DS1DSGPO    PARTITIONED?                    04523000
         BNE   CONT166                  NO, BRANCH                      04524000
         CLI   #OUT+88,X'41'            ANY MEMBER NAME?                04525000
         BL    CONT190                  NO, ERROR                       04526000
         B     CONT180                                                  04527000
         SPACE 1                                                        04528000
CONT166  CLI   WORKTBL+14+6,DS1DSGPS    SEQUENTIAL?                     04529000
         BNE   CONT190                  NO, ERROR                       04530000
         CLI   #OUT+88,X'40'            ANY MEMBER NAME?                04531000
         BH    CONT190                  YES, ERROR                      04532000
         SPACE 2                                                        04533000
*** OPEN THE SYSOUT/DATA SET                                            04534000
CONT180  MVC   LOGDCB(LLOGDCB),LOGSDCB       CONSTRUCT A DCB            04535000
         MVC   DCBDDNAM-IHADCB+LOGDCB(8),DDNAMEH                        04536000
         MVI   OPENLIST,X'80'                                           04537000
         OPEN  (LOGDCB,(OUTPUT)),MF=(E,OPENLIST)                        04538000
         LA    R1,L780$1                                                04539000
         TM    DCBOFLGS-IHADCB+LOGDCB,X'10'  OPEN ALREADY               04540000
         BNO   CONT190                       NO, ERROR                  04541000
         TM    FLAGSFF,FLOGWRT               OPEN WITH GOOD VALUES?     04542000
         BO    CONT200                       YES, BRANCH                04543000
         MVI   OPENLIST,X'80'                                           04544000
         CLOSE (LOGDCB),MF=(E,OPENLIST)                                 04545000
         LA    R1,L781$1                     ERROR MESSAGE              04546000
CONT190  MVI   CONTOPTN,0                    TURN OFF ANY LOGGING       04547000
         MVC   INSERT#1(8),CTEXTLOG          LOGCOPY                    04548000
         B     MSGNEW                                                   04549000
         SPACE 2                                                        04550000
CONT200  CLI   #OUT+7,1            CPULOOP?                             04551000
         BNE   CONT300             NO, BRANCH                           04552000
         TSMSG L032                YES, LOOP MESSAGE                    04553000
         B     *                   LOOP                                 04554000
         SPACE 1                                                        04555000
CONT300  CLI   #OUT+7,2            ABEND?                               04556000
         BNE   CONT400             NO, BRANCH                           04557000
         TSMSG L033                YES, ABEND MESSAGE                   04558000
         DC    H'0'                LOOP                                 04559000
         SPACE 1                                                        04560000
CONT400  CLI   #OUT+7,3            OUTLOOP?                             04561000
         BNE   CONT500             NO, BRANCH                           04562000
         TSMSG L034                YES, LOOP MESSAGE                    04563000
         B     CONT400             LOOP                                 04564000
         SPACE 1                                                        04565000
CONT500  CLI   #OUT+7,4            MESSAGES?                            04566000
         BNE   CONT600             NO, BRANCH                           04567000
         MVC   INSERT#1(8),CTEXTP1                                      04568000
         MVC   INSERT#2(8),CTEXTP2                                      04569000
         LA    R4,L000             FIRST INFORMATIONAL MESSAGE          04570000
CONT510  LR    R1,R4               POINT TO IT                          04571000
         TSMSG (R1)                OUTPUT IT                            04572000
         LA    R4,3(,R4)           NEXT MESSAGE                         04573000
         CLI   0(R4),C'3'          DONE?                                04574000
         BNH   CONT510             NO, BRANCH                           04575000
         LA    R5,CONLIST          FIRST ACTION MESSAGE                 04576000
CONT520  L     R1,0(,R5)           POINT TO IT                          04577000
         MESSAGE (R1)              OUTPUT IT                            04578000
         LA    R5,4(,R5)           NEXT MESSAGE                         04579000
         CLI   0(R5),X'FF'         DONE?                                04580000
         BNE   CONT520             NO, BRANCH                           04581000
CONT530  LR    R1,R4               NEXT WARNING/ERROR MESSAGE           04582000
         TSMSG (R1)                OUTPUT IT                            04583000
         LA    R4,3(,R4)           NEXT MESSAGE                         04584000
         CLI   0(R4),C'9'          DONE?                                04585000
         BNH   CONT530             NO, BRANCH                           04586000
         SPACE 1                                                        04587000
CONT600  CLI   #OUT+7,5            IOSTATS DESIRED?                     04588000
         BNE   CONT700             NO, BRANCH                           04589000
         LH    R1,IODONE           ** INPUT ROUTINE ENTRIES             04590000
         LA    R14,MSGCOA1                                              04591000
         BAL   R2,CONT900                                               04592000
         LH    R1,IODONEW          ** NUMBER OF TTR CHANGES             04593000
         LA    R14,MSGCOA2                                              04594000
         BAL   R2,CONT900                                               04595000
         LH    R1,IOLOGUSE         ** LOGICAL INPUTS PERFORMED          04596000
         LA    R14,MSGCOA3                                              04597000
         BAL   R2,CONT900                                               04598000
         LH    R1,IOPHYTRK         ** PHYSICAL TRACKS READ              04599000
         LA    R14,MSGCOA4                                              04600000
         BAL   R2,CONT900                                               04601000
         XC    IODONE(8),IODONE                                         04602000
         SPACE 1                                                        04603000
CONT700  CLI   #OUT+7,6            TESTREAD?                            04604000
         BNE   NEWCMD              NO, BRANCH                           04605000
         MVC   #OUT+20(1),FLAGSEE         SAVE THE INPUT FLAGS          04606000
         MESSAGE MSGBLANK                 ONE BLANK LINE                04607000
         MVC   INSERT#1(8),CSINGCON       SINGLE BUFFERING              04608000
         TSMSG L031$1                                                   04609000
         OI    FLAGSEE,FDOUBCON+FFULLTRK  CONTROL SINGLE                04610000
         BAL   R2,CONT710                 READ THE FIRST RECORD         04611000
         SPACE 1                                                        04612000
         MVC   INSERT#1(8),CDOUBCON       DOUBLE BUFFERING              04613000
         TSMSG L031$1                                                   04614000
         XI    FLAGSEE,FDOUBCON           CONTROL DOUBLE                04615000
         BAL   R2,CONT710                 READ THE FIRST RECORD         04616000
         SPACE 1                                                        04617000
         MVC   INSERT#1(8),CMULTCON       DOUBLE BUFFERING              04618000
         TSMSG L031$1                                                   04619000
         NI    FLAGSEE,FF-FDISKTRK-FFULLTRK-FDOUBCON                    04620000
         BAL   R2,CONT710                 READ THE FIRST RECORD         04621000
         MVC   FLAGSEE(1),#OUT+20         RESET THE INPUT FLAGS         04622000
         B     NEWCMD                                                   04623000
         SPACE 2                                                        04624000
CONT710  MVI   STARTTR+2,1                SET TTR TO 1                  04625000
         L     R15,=A(EXCP)               INPUT IT                      04626000
         BALR  R14,R15                                                  04627000
         CVD   R15,DOUBLE                 CONVERT RETURN CODE           04628000
         MVC   INSERT#1(8),BLANKS                                       04629000
         MVC   INSERT#1-2(4),=X'40212020' EDIT CHARACTERS               04630000
         ED    INSERT#1-2(4),DOUBLE+6     CONVERT TO DISPLAY            04631000
         STM   R2,R12,28(R13)             CONVERT CCHHR TO TTR          04632000
         LA    R2,IOBSEEK                 NEXT MBBCCHHR                 04633000
         L     R1,INDCB+(DCBDEBAD-IHADCB)                               04634000
         L     R15,ADDRRLTV                                             04635000
         LR    R3,R13                                                   04636000
         BALR  R14,R15                                                  04637000
         LR    R13,R3                                                   04638000
         LM    R2,R12,28(R13)                                           04639000
         ST    R0,FULLWORD                TTR OF CURRENT DIRECTORY EOF  04640000
         UNPK  INSERT#2(7),FULLWORD(4)                                  04641000
         TR    INSERT#2(6),TRTABLE                                      04642000
         MVC   INSERT#2+6(2),BLANKS                                     04643000
         TSMSG L035$2                                                   04644000
         MESSAGE MSGBLANK                 ONE BLANK LINE                04645000
         BR    R2                                                       04646000
         SPACE 2                                                        04647000
CONT900  MVC   MSGTEXT1,0(R14)                                          04648000
         MVC   MSGTEXT1+4(7),MSGCOAM                                    04649000
         LTR   R1,R1                                                    04650000
         BZR   R2                                                       04651000
         CVD   R1,DOUBLE                                                04652000
         ED    MSGTEXT1+4(7),DOUBLE+5                                   04653000
         MESSAGE MSGTEXT1                                               04654000
         BR    R2                                                       04655000
         SPACE 4                                                        04656000
         USING IHADCB,R1                                                04657000
*** DCB OPEN EXIT                                                       04658000
CONT980  CLC   DCBDSORG(2),ZERO              ANY DSORG?                 04659000
         BNE   *+8                           YES, BRANCH                04660000
         OI    DCBDSORG,DS1DSGPS             NO, USE DSORG=PS           04661000
         TM    DCBDSORG,DS1DSGPS             DSORG=PS?                  04662000
         BNOR  R14                           NO, ERROR                  04663000
         CLI   DCBRECFM,0                    ANY RECFM?                 04664000
         BNE   *+8                           YES, BRANCH                04665000
         MVI   DCBRECFM,DCBRECF+DCBRECBR     NO, USE RECFM=FB           04666000
         TM    DCBRECFM,DCBRECF+DCBRECV      RECFM=F. OR RECFM=V.?      04667000
         BNMR  R14                           NO, ERROR                  04668000
         LA    R0,80                         DEFAULT LRECL              04669000
         TM    DCBRECFM,DCBRECV              RECFM=V.?                  04670000
         BNO   *+8                           NO, BRANCH                 04671000
         LA    R0,255                        DEFAULT LRECL FOR VARIABLE 04672000
         CLC   DCBLRECL(2),ZERO              ANY LRECL?                 04673000
         BNE   *+8                           YES, BRANCH                04674000
         STH   R0,DCBLRECL                   NO, USE LRECL=80           04675000
         TM    DCBRECFM,DCBRECV              RECFM=V.?                  04676000
         BO    CONT988                       YES, BRANCH                04677000
         CH    R0,DCBLRECL                   LRECL=80?                  04678000
         BNER  R14                           NO, ERROR                  04679000
CONT988  LA    R0,3120                       DEFAULT BLKSIZE            04680000
         CLC   DCBBLKSI(2),ZERO              ANY BLKSIZE?               04681000
         BNE   *+8                           YES, BRANCH                04682000
         STH   R0,DCBBLKSI                   NO, USE BLKSIZE=3120       04683000
         OI    FLAGSFF,FLOGWRT               ALL ATTRIBUTES ARE CORRECT 04684000
         BR    R14                                                      04685000
         DROP  R1                                                       04686000
         SPACE 2                                                        04687000
         PRINT NOGEN                                                    04688000
LOGSDCB  DCB   DSORG=PS,DDNAME=PDSLOG,MACRF=(PM),EXLST=CONT990          04689000
LLOGDCB  EQU   *-LOGSDCB                                                04690000
         PRINT GEN                                                      04691000
         SPACE 2                                                        04692000
CONT990  DC    0F'0',X'85',AL3(CONT980)      OPEN EXIT ONLY             04693000
         PRINT NOGEN                                                    04694000
MSGCOA1  MSG   ' 12,345 INPUT ROUTINE ENTRIES'                          04695000
         ORG   MSGCOA1+4                                                04696000
MSGCOAM  DC    X'4020206B202120'                                        04697000
         ORG   ,                                                        04698000
MSGCOA2  MSG   ' 12,345 TTR CHANGES'                                    04699000
MSGCOA3  MSG   ' 12,345 LOGICAL INPUTS PERFORMED'                       04700000
MSGCOA4  MSG   ' 12,345 PHYSICAL TRACKS READ'                           04701000
         PRINT GEN                                                      04702000
CALINCON DC    C'NOALIASINFO, '                                         04703000
CLKEDCON DC    C'NOLKEDDATE, '                                          04704000
CPROMCON DC    C'NOPROMPT, '                                            04705000
CRECVCON DC    C'NORECOVER, '                                           04706000
CTRANCON DC    C'NOTRANSLATOR, '                                   @D05
CSAVECON DC    C'NOSAVETEXT, '                                          04707000
CSINGCON DC    CL8'SINGLE'                                              04708000
CDOUBCON DC    CL8'DOUBLE'                                              04709000
CMULTCON DC    CL8'MULTIPLE'                                            04710000
CTEXTP1  DC    CL8'<PARM#1>'                                            04711000
CTEXTP2  DC    CL8'<PARM#2>'                                            04712000
CTEXTLOG DC    CL8'LOGCOPY'                                             04713000
CLOGOLD  DC    CL3'OLD'                                                 04714000
CLOGMOD  DC    CL3'MOD'                                                 04715000
CLOGSHR  DC    CL3'SHR'                                                 04716000
CLOGNEW  DC    CL3'NEW'                                                 04717000
CLOGDSN  DC    CL7'DSNAME('                                             04718000
CLOGNDSN DC    CL9'NODSNAME,'                                           04719000
CLOGSYS  DC    CL7'SYSOUT('                                             04720000
CLOGNSYS DC    CL9'NOSYSOUT,'                                           04721000
CLOGFOR  DC    CL5'FORM('                                               04722000
CLOGNFOR DC    CL7'NOFORM,'                                             04723000
CLOGDES  DC    CL5'DEST('                                               04724000
CLOGNDES DC    CL6'NODEST'                                              04725000
CLOGCOMM DC    CL2'),'                                                  04726000
CONLIST  DC    A(PDS300A)                                               04727000
         DC    A(PDS380A,PDS381A,PDS382A,PDS383A,PDS384A,PDS385A)       04728000
         DC    A(PDS390A,PDS391A,PDS392A,PDS393A,PDS394A),X'FF'         04729000
         SPACE 2                                                        04730000
         AIF   (&MVT).MA00540                                      @D01
CONDDNAM DC    X'0055000100084040404040404040'     RETURN DDNAME        04731000
CONDSORG DC    X'0057000100024040'                 RETURN DSORG         04732000
CONFREE  DC    X'001C0000'                         FREE=CLOSE           04733000
CONMEMBR DC    X'0003000100084040404040404040'     DSNAME               04734000
CONPASSW DC    X'0050000100084040404040404040'     PASSWORD             04735000
CONDSNAM DC    X'00020001002C'                     DSNAME               04736000
CONALLOC DC    X'00040001000101'                   DISP=(_)             04737000
CONNORM  DC    X'00050001000102'                   DISP=(,CATLG)        04738000
CONANORM DC    X'00060001000108'                   DISP=(,,KEEP)        04739000
CONTRK   DC    X'00070000'                         SPACE=(TRK,          04740000
CONFIRST DC    X'000A00010003000001'               SPACE=(,1            04741000
CONSECON DC    X'000B00010003000004'               SPACE=(,,4           04742000
CONDIR   DC    X'000C00010003000005'               SPACE=(,,,5)         04743000
.MA00540 ANOP  ,                                                   @D01
CONOOLD  EQU   X'01'                                                    04744000
CONOMOD  EQU   X'02'                                                    04745000
CONONEW  EQU   X'04'                                                    04746000
CONOSHR  EQU   X'08'                                                    04747000
         AIF   (&MVT).MA00560                                      @D01
CONSYSOU DC    X'001800010001C1'                   SYSOUT=A             04748000
CONFORMS DC    X'001A00010004C4F1F0F1'             SYSOUT=(,,D101)      04749000
CONDESTS DC    X'005800010008D5F1F3F040404040'     DEST=R130            04750000
.MA00560 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS DELETE                          1/15/85' 04751000
*********************************************************************** 04752000
***    DELETE SUBCOMMAND    MODIFIED BY BRUCE LELAND -- OCT., 1983  *** 04753000
*********************************************************************** 04754000
*                                                                       04755000
         SPACE 1                                                        04756000
DELETE   CSECT                                                          04757000
         USING *,R8                                                     04758000
         LA    R1,L530             ASSUME A NON-PARTITIONED DATA SET    04759000
         TM    DSORG,DS1DSGPO            CORRECT?                       04760000
         BZ    MSGNEW                    YES, BRANCH                    04761000
         SPACE 2                                                        04762000
         NI    FLAGSCC,FF-FBLDLOK        BLDL IS INVALIDATED            04763000
         TM    FLAGSII,FSINGLE           IF OR FIND THEN(DELETE)?       04764000
         BNO   DELE010                   NO, BRANCH                     04765000
         MVC   IODIR1+4+12+00(8),CURDIR  RESET READ ADDRESS             04766000
         MVI   IODIR1+4+12+08,X'08'      RESET KEY LENGTH               04767000
         MVC   IODIR1+4+12+09(2),=H'256' RESET DATA LENGTH              04768000
         MVI   IODIR1+4+12+11,0          RESET SECTOR ADDRESS TO ZERO   04769000
         MVI   IOECB,X'7F'               LAST READ WAS OK               04770000
         B     DELE100                   PROMPT BY DEFAULT              04771000
         SPACE 1                                                        04772000
DELE010  TM    FLAGSAA,FMEM#MEM      MEMBER GROUP?                      04773000
         BO    DELE200               YES, BRANCH                        04774000
         MVC   MEMNAME(12),DIRNAME   ENSURE MEMBER NAME IS PRESENT      04775000
         OI    #DELFLAG,#DELONE      ONLY A SINGLE MEMBER               04776000
         TM    #DELFLAG,#DELASS2     DELETE ASSOCIATES TOO?             04777000
         BO    DELE200               YES, BRANCH                        04778000
         SPACE 1                                                        04779000
         TM    FLAGSAA,FMEMSTAR      ASTERISK NOTATION?                 04780000
         BO    DELE110               YES, NO PROMPTING                  04781000
         TM    FLAGSAA,FOPTIONS      ANY MEMBER NAME?                   04782000
         BO    DELE110               YES, NO PROMPTING                  04783000
         SPACE 2                                                        04784000
DELE100  LA    R1,PDS393A            DELETE SINGLE MEMBER               04785000
         BAL   R2,YESNO              PROMPT FOR YES OR NO               04786000
         B     NEWCMD                NO -- DONE                         04787000
         SPACE 1                                                        04788000
DELE110  LA    R4,DIRNAME            DUMMY ARRAY ENTRY                  04789000
         ST    R4,#MEMPTR                                               04790000
         LA    R4,16(,R4)            POSITION FOR ONE ENTRY             04791000
         MVC   DSNMEMQ(8),DIRNAME    MEMBER NAME                        04792000
         BAL   R2,ENQMTEST           MEMBER IN USE?                     04793000
         B     NEWCMD                YES, IGNORE THE COMMAND            04794000
         B     DELE900               NO, DELETE IT                      04795000
         SPACE 3                                                        04796000
DELE200  OI    FLAGSII,FDIRGRP       SIMULATE MEMBER GROUP INPUT        04797000
         NI    FLAGSAA,FF-FMEM#MEM   TURN OFF MEMBER GROUPS NOW         04798000
         OI    FLAGSBB,FLINESET      LINE NOW IN PROGRESS               04799000
         LA    R1,80                 ASSUME AN ACTIVE MODE              04800000
         AIF ('&CISP' EQ 'NO SPF').MA00580                         @D01
         TM    SPFLAG0,SPFDON        ISPMODE ACTIVE?                    04801000
         BO    DELE202               YES, BRANCH                        04802000
.MA00580 ANOP  ,                                                   @D01
         TM    CONTOPTN,1            ANY LOG RECORDING?                 04803000
         BO    DELE202               YES, BRANCH                        04804000
         GTSIZE
         CH    R1,=H'120'            120 OR LESS BYTES?                 04806000
         BL    *+8                   YES, BRANCH                        04807000
         LH    R1,=H'120'            NO, USE 120 BYTES                  04808000
DELE202  SH    R1,=H'7'              LESS SEVEN FOR PREFIX              04809000
         ST    R1,LINESIZE           CHARACTERS/LINE                    04810000
         MVC   MSGLINE+4(L'MSGDELET),MSGDELET                           04811000
         LA    R6,MSGLINE+4+L'MSGDELET                                  04812000
         MVC   FULLWORD(3),L162$1    MEMBERS TO BE DELETED              04813000
         NI    FLAGSBB,FF-FLINESET   NO LINE IN PROGRESS                04814000
         MVI   SUBPOOLT,21           SUBPOOL 21 DATA                    04815000
         LA    R5,256/2              256 MEMBERS INITIALLY              04816000
         SPACE 1                                                        04817000
DELE210  SLL   R5,1                  MEMBERS*2 FOR EACH LOOP            04818000
         LR    R3,R5                                                    04819000
         LR    R0,R5                                                    04820000
         SLL   R0,4                  TABLE SIZE=MEMBERS*16              04821000
         ICM   R0,B'1000',SUBPOOLT                                      04822000
         GETMAIN R,LV=(0)                                               04823000
         LR    R4,R1                 NEW TABLE ADDRESS                  04824000
         ICM   R0,B'1111',#MEMPTR    ANY PREVIOUS MEMBERS?              04825000
         BNZ   DELE220               YES, BRANCH                        04826000
         ST    R4,#MEMPTR            INITIALIZE MEMBER BASE             04827000
         B     DELE500                                                  04828000
         SPACE 1                                                        04829000
DELE220  SRL   R3,1                  SECOND HALF OF TABLE (# MEMBERS)   04830000
         LR    R14,R4                NEW TABLE START ADDRESS            04831000
         LR    R15,R5                                                   04832000
         SLL   R15,3                 OLD TABLE SIZE=MEMBERS*8           04833000
         LR    R2,R15                START OF NEW PART                  04834000
         LR    R1,R15                                                   04835000
         MVCL  R14,R0                PRESERVE THE OLD TABLE             04836000
         L     R1,#MEMPTR                                               04837000
         LR    R0,R2                 LENGTH TO FREE                     04838000
         ICM   R0,B'1000',SUBPOOLT   SUBPOOL TO FREE                    04839000
         FREEMAIN R,LV=(0),A=(1)                                        04840000
         ST    R4,#MEMPTR            START OF NEW TABLE                 04841000
         AR    R4,R2                 WHERE TO ADD MEMBERS               04842000
         SPACE 3                                                        04843000
DELE300  BAL   R14,READDIR           GET NEXT DIRECTORY ENTRY           04844000
         B     DELE600               END OF MEMBERS -- BRANCH           04845000
         SPACE 1                                                        04846000
         TM    #DELFLAG,#DELASSP     ASSOCIATES PHASE?                  04847000
         BO    DELE400               YES, BRANCH                        04848000
         SPACE 1                                                        04849000
         TM    FLAGSAA,FMEMRANG      MEMBER NAME RANGE?                 04850000
         BNO   DELE340               NO, BRANCH                         04851000
         TM    FLAGSAA,FMEMBER1      START ENTRY SPECIFIED?             04852000
         BNO   DELE330               NO, BRANCH                         04853000
         SPACE 1                                                        04854000
         LH    R15,LMEMBER1          MACHINE LENGTH OF THE MEMBER NAME  04855000
         CLC   MEMBER1(*-*),MEMNAME  <<EXECUTED>>                       04856000
         EX    R15,*-6               ABOVE THIS VALUE?                  04857000
         BH    DELE300               YES, BRANCH                        04858000
         XI    FLAGSAA,FMEMBER1      FIRST NAME IS SATISFIED            04859000
         SPACE 2                                                        04860000
DELE330  TM    FLAGSAA,FMEMBER2      END ENTRY SPECIFIED?               04861000
         BNO   DELE500               NO, BRANCH                         04862000
         SPACE 1                                                        04863000
         LH    R15,LMEMBER2          MACHINE LENGTH OF THE MEMBER NAME  04864000
         CLC   MEMBER2(*-*),MEMNAME  <<EXECUTED>>                       04865000
         EX    R15,*-6               BELOW THIS VALUE?                  04866000
         BL    DELE600               YES, BRANCH                        04867000
         B     DELE500                                                  04868000
         SPACE 3                                                        04869000
DELE340  LH    R15,LMEMBER1          MACHINE LENGTH OF THIS PATTERN     04870000
         LA    R1,8                  MAXIMUM PATTERN LENGTH             04871000
         SR    R1,R15                COMPARE LENGTH                     04872000
         LA    R14,MEMNAME           POSITION IN MEMBER NAME            04873000
         CLC   0(*-*,R14),MEMBER1    <<EXECUTED>>                       04874000
DELE350  EX    R15,*-6               IN THIS MEMBER NAME?               04875000
         BE    DELE360               YES, BRANCH                        04876000
         LA    R14,1(,R14)                                              04877000
         BCT   R1,DELE350            MAYBE, CHECK ALL OTHER POSITIONS   04878000
         B     DELE300               NO, IGNORE THIS ENTRY              04879000
         SPACE 2                                                        04880000
DELE360  TM    FLAGSAA,FMEMBER2      A SECOND PATTERN TOO?              04881000
         BNO   DELE500               NO, USE THIS ENTRY                 04882000
         LH    R15,LMEMBER2          MACHINE LENGTH OF THIS PATTERN     04883000
         LA    R1,8                  MAXIMUM PATTERN LENGTH             04884000
         SR    R1,R15                COMPARE LENGTH                     04885000
         LA    R14,MEMNAME           POSITION IN MEMBER NAME            04886000
         CLC   0(*-*,R14),MEMBER2    <<EXECUTED>>                       04887000
DELE370  EX    R15,*-6               IN THIS MEMBER NAME?               04888000
         BE    DELE500               YES, BRANCH                        04889000
         LA    R14,1(,R14)                                              04890000
         BCT   R1,DELE370            MAYBE, CHECK ALL OTHER POSITIONS   04891000
         B     DELE300               NO, IGNORE THIS ENTRY              04892000
         SPACE 3                                                        04893000
DELE400  L     R1,#MEMPTR            START OF MEMBER LIST               04894000
         B     DELE410+4             SKIP FIRST ADD                     04895000
DELE410  LA    R1,16(,R1)            NEXT TABLE ENTRY                   04896000
         CR    R1,R4                 END OF TABLE?                      04897000
         BNL   DELE300               YES, IGNORE THIS ENTRY             04898000
         CLC   8(3,R1),MEMTTR        MATCHING TTR?                      04899000
         BNE   DELE410               NO, BRANCH                         04900000
         SPACE 3                                                        04901000
         L     R1,#MEMPTR            START OF MEMBER LIST               04902000
         B     DELE430+4             SKIP FIRST ADD                     04903000
DELE430  LA    R1,16(,R1)            NEXT TABLE ENTRY                   04904000
         CR    R1,R4                 END OF TABLE?                      04905000
         BNL   DELE500               YES, ADD THIS ENTRY                04906000
         CLC   0(8,R1),MEMNAME       FIND MYSELF?                       04907000
         BE    DELE300               YES, IGNORE THIS ENTRY             04908000
         B     DELE430               NO, CONTINUE SEARCHING             04909000
         SPACE 3                                                        04910000
DELE500  MVC   DSNMEMQ(8),MEMNAME                                       04911000
         BAL   R2,ENQMTEST           MEMBER IN USE?                     04912000
         OI    #DELFLAG,#DELENQ      YES, MARK TO EXIT LATER            04913000
         SPACE 1                                                        04914000
         LA    R2,MEMNAME+7                                             04915000
         TM    FLAGSBB,FLINESET      LINE IN PROGRESS?                  04916000
         BO    DELE510               YES, BRANCH                        04917000
         OI    FLAGSBB,FLINESET      LINE NOW IN PROGRESS               04918000
DELE510  CLI   0(R2),X'40'           SCAN                               04919000
         BNE   *+8                       FOR LAST                       04920000
         BCT   R2,DELE510                        NON-BLANK              04921000
         LA    R0,MEMNAME                                               04922000
         SR    R2,R0                                                    04923000
         BNM   *+6                                                      04924000
         SR    R2,R2                                                    04925000
         LA    R15,2(R6,R2)                                             04926000
         LA    R1,MSGLINE                                               04927000
         SR    R15,R1                                                   04928000
         C     R15,LINESIZE          FIT ON THIS OUTPUT LINE?           04929000
         BNH   DELE520               YES, BRANCH                        04930000
         LA    R1,MSGLINE+4                                             04931000
         SR    R6,R1                                                    04932000
         STC   R6,MTHIGHL                                               04933000
         MVC   INSERT#1(127),MSGLINE+4                                  04934000
         LA    R1,FULLWORD                                              04935000
         TSMSG (R1)                                                     04936000
         MVI   MTHIGHL,8                                                04937000
         MVI   FULLWORD+2,C'9'                                          04938000
         LA    R6,MSGLINE+3          INDENT FOR BLANKS                  04939000
         SPACE 1                                                        04940000
DELE520  MVI   0(R6),X'40'                                              04941000
         MVC   1(8,R6),MEMNAME                                          04942000
         TR    1(8,R6),TRLINE        MAKE PRINTABLE                     04943000
         LA    R1,2(R2,R6)                                              04944000
         MVI   0(R1),C','            ADD A COMMA                        04945000
         LA    R6,3(R2,R6)                                              04946000
         MVC   0(16,R4),MEMNAME      ADD TO THE TABLE                   04947000
         LA    R4,16(,R4)            NEXT MEMBER POSITION               04948000
         S     R3,=F'1'              ANY MORE FIT?                      04949000
         BNP   DELE210               NO, BRANCH                         04950000
         TM    #DELFLAG,#DELONE      A SINGLE MEMBER?                   04951000
         BNO   DELE300               NO, BRANCH                         04952000
         SPACE 3                                                        04953000
DELE600  TM    FLAGSBB,FLINESET      ANY MEMBERS FOUND?                 04954000
         BNO   DELE610               NO, BRANCH                         04955000
         LA    R1,MSGLINE+5                                             04956000
         SR    R6,R1                                                    04957000
         STC   R6,MTHIGHL                                               04958000
         MVC   INSERT#1(127),MSGLINE+4                                  04959000
         LA    R1,FULLWORD                                              04960000
         TSMSG (R1)                                                     04961000
         MVI   MTHIGHL,8                                                04962000
         MESSAGE MSGBLANK                                               04963000
         SPACE 1                                                        04964000
DELE610  TM    #DELFLAG,#DELASSP     ASSOCIATES PHASE STARTED?          04965000
         BO    DELE700               YES, BRANCH                        04966000
         TM    #DELFLAG,#DELASS2     DELETE ASSOCIATE MEMBERS TOO?      04967000
         BNO   DELE700               NO, BRANCH                         04968000
         OI    #DELFLAG,#DELASSP     YES, ASSOCIATES PHASE STARTED      04969000
         NI    #DELFLAG,FF-#DELONE   WANT ALL ASSOCIATED MEMBERS        04970000
         NI    FLAGSII,FF-FDIRGRP    NORMAL INPUT NOW                   04971000
         NI    FLAGSBB,FF-FLINESET   NEW OUTPUT LINE                    04972000
         MVC   MSGLINE+4(L'MSGDELAS),MSGDELAS                           04973000
         LA    R6,MSGLINE+4+L'MSGDELAS                                  04974000
         MVC   FULLWORD(3),L163$1    MEMBERS TO BE DELETED              04975000
         MVI   STARTTR+2,X'01'       TTR=000001 (START OF DIRECTORY)    04976000
         B     DELE300               DO ANY ASSOCIATED MEMBERS          04977000
         SPACE 3                                                        04978000
DELE700  NI    FLAGSII,FF-FDIRGRP    NORMAL INPUT NOW                   04979000
         TM    #DELFLAG,#DELENQ      ANY MEMBERS IN USE?                04980000
         BO    NEWCMD                YES, BRANCH                        04981000
         SPACE 1                                                        04982000
         LA    R1,PDS394A            DELETE PROMPT MESSAGE              04983000
         BAL   R2,YESNO              PROMPT FOR YES OR NO               04984000
         B     NEWCMD                NO, QUIT                           04985000
         SPACE 2                                                        04986000
DELE900  BAL   R2,OPENSTOW           OPEN STOW DCB; ENQUEUE             04987000
         B     NEWCMD                NO OPEN -- QUIT                    04988000
         SPACE 1                                                        04989000
         L     R3,#MEMPTR            START OF MEMBER LIST               04990000
         B     DELE910+4             SKIP FIRST ADD                     04991000
DELE910  LA    R3,16(,R3)                                               04992000
         CR    R3,R4                                                    04993000
         BNL   DELE980                                                  04994000
         STOW  STOWDCB,0(R3),D       ISSUE STOW WITH DELETE OPTION      04995000
         SPACE 1                                                        04996000
         B     *+4(R15)              PROCESS RETURN CODE                04997000
         B     DELE940                 00 - SUCCESSFUL                  04998000
         EX    0,*                     04 - SHOULD NOT OCCUR            04999000
         B     DELE960                 08 - MEMBER NOT FOUND            05000000
         B     IOERROR                 12 - I/O ERROR IN DIRECTORY      05001000
         SPACE 1                                                        05002000
DELE940  MVC   INSERT#1(8),0(R3)                                        05003000
         TSMSG L040$1                                                   05004000
         B     DELE910                                                  05005000
         SPACE 1                                                        05006000
DELE960  MVC   INSERT#1(8),0(R3)                                        05007000
         TSMSG L853$1                                                   05008000
         B     DELE910                                                  05009000
         SPACE 1                                                        05010000
DELE980  BAL   R2,SHUTSTOW            CLOSE FOR: IF * THEN(DELETE)      05011000
         B     NEWCMD                                                   05012000
         SPACE 2                                                        05013000
#DELASSP EQU     X'80'            DELETE: ASSOCIATES PHASE OF DELETE    05014000
#DELONE  EQU     X'10'            DELETE: DELETE A SINGLE MEMBER        05015000
#DELENQ  EQU     X'08'            DELETE: A DELETE MEMBER IS "IN USE"   05016000
#DELASS2 EQU     X'01'            DELETE: DELETE ASSOCIATES TOO         05017000
         TITLE 'P D S  --  PDS DSNAME                          1/15/85' 05018000
*********************************************************************** 05019000
***      DSNAME  SUBCOMMAND                                         *** 05020000
*********************************************************************** 05021000
*                                                                       05022000
         SPACE 1                                                        05023000
DSNAMES  CSECT                                                          05024000
         BALR  R6,0                                                     05025000
         USING *,R6                                                     05026000
         MVC   INSERT#1(80),MSGBL132+4  BLANK THE FIRST LINE            05027000
         MVI   MTHIGHL,80               80 CHARACTER MESSAGE            05028000
         TM    FLAGSJJ,FDSNMSG          MSG ALLOCATION?                 05029000
         BO    DSNMSG                   YES, BRANCH                     05030000
         TM    FLAGSJJ,FDSNTSO          TSO ALLOCATION?                 05031000
         BO    DSNTSO                   YES, BRANCH                     05032000
         SPACE 1                                                        05033000
DSNJCL   MVC   INSERT#1(20),DSNJDSN     ADD "//12345678  DD  DSN="      05034000
         MVC   INSERT#1+2(8),DDNAME     MOVE IN THE DDNAME              05035000
         LA    R1,INSERT#1+20           DSNAME START POSITION           05036000
         MVC   0(44,R1),DSNAME          MOVE IN THE DSNAME              05037000
         AH    R1,DSNLEN                LENGTH OF THE DSNAME            05038000
         MVC   0(15,R1),DSNJDSND        ADD ",DISP=SHR,UNIT="           05039000
         CLI   DSPALLOC,ALLOSHR         DISP=SHR?                       05040000
         BE    *+10                     YES, BRANCH                     05041000
         MVC   6(3,R1),=C'OLD'          NO, DISP=OLD                    05042000
         LH    R15,BYTEUCB              UCBBYTE                         05043000
         MH    R15,=H'9'                INDEX INTO THE UNIT TABLE       05044000
         LA    R15,UNITTBL(R15)         DEVICE UNIT TYPE                05045000
         LA    R1,15(,R1)               START OF UNIT DATA              05046000
         MVC   0(8,R1),1(R15)           ADD TO THE MESSAGE              05047000
         MVI   8(R1),X'40'              ADD A TERMINATOR                05048000
         LA    R1,1(,R1)                SCAN                            05049000
         CLI   0(R1),X'40'                  FOR FIRST                   05050000
         BNE   *-8                                   BLANK              05051000
         MVI   0(R1),C','               ADD A TERMINATOR AND CONTINUE   05052000
         TSMSG L220$1                                                   05053000
         MVC   INSERT#1(80),MSGBL132+4  BLANK THE SECOND LINE           05054000
         MVC   INSERT#1(20),DSNJDCT     "// DCB=(RECFM=, ..."           05055000
         IC    R5,FLAGSCC               RECFM BITS                      05056000
         SLL   R5,29                    DROP TOP BITS                   05057000
         SRL   R5,29                    REPOSITION                      05058000
         IC    R5,RECFMTYP(R5)          RECORD FORMAT                   05059000
         STC   R5,INSERT#1+15           MOVE INTO MESSAGE               05060000
         LA    R1,INSERT#1+16                                           05061000
         TM    RECFM,DCBRECBR           RECFM=.B?                       05062000
         BNO   *+12                     NO, BRANCH                      05063000
         MVI   0(R1),C'B'                                               05064000
         LA    R1,1(R1)                                                 05065000
         TM    RECFM,DCBRECSB           RECFM=.S?                       05066000
         BNO   *+12                     NO, BRANCH                      05067000
         MVI   0(R1),C'S'                                               05068000
         LA    R1,1(R1)                                                 05069000
         TM    RECFM,DCBRECTO           RECFM=.T?                       05070000
         BNO   *+12                     NO, BRANCH                      05071000
         MVI   0(R1),C'T'                                               05072000
         LA    R1,1(R1)                                                 05073000
         TM    RECFM,DCBRECCA           RECFM=.A?                       05074000
         BNO   *+12                     NO, BRANCH                      05075000
         MVI   0(R1),C'A'                                               05076000
         LA    R1,1(R1)                                                 05077000
         TM    RECFM,DCBRECCM           RECFM=.M?                       05078000
         BNO   *+12                     NO, BRANCH                      05079000
         MVI   0(R1),C'M'                                               05080000
         LA    R1,1(R1)                                                 05081000
         TM    FLAGSCC,RECFMU           RECFM=U?                        05082000
         BO    DSN010                   YES, NO LRECL                   05083000
         MVC   0(7,R1),DSNJDCTL         MOVE IN LRECL TEXT              05084000
         LA    R1,7(R1)                                                 05085000
         LH    R4,LABLRECL                                              05086000
         BAL   R14,DSNCONV                                              05087000
         SPACE 1                                                        05088000
DSN010   MVC   0(9,R1),DSNJDCTB                                         05089000
         LA    R1,9(R1)                                                 05090000
         LH    R4,BLKSI                                                 05091000
         BAL   R14,DSNCONV                                              05092000
         SPACE 1                                                        05093000
         SR    R4,R4                                                    05094000
         ICM   R4,B'0001',DS1KEYL       ANY KEY LENGTH?                 05095000
         BZ    DSN020                   NO, BRANCH                      05096000
         MVC   0(8,R1),DSNJDCTK         ADD ,KEYLEN=                    05097000
         LA    R1,8(R1)                                                 05098000
         BAL   R14,DSNCONV                                              05099000
         SPACE 1                                                        05100000
         MVC   0(5,R1),DSNJDCTR         ADD ,RKP=                       05101000
         LA    R1,5(R1)                                                 05102000
         SR    R4,R4                                                    05103000
         ICM   R4,B'0011',DS1RKP        RELATIVE KEY POSITION           05104000
         BAL   R14,DSNCONV                                              05105000
         SPACE 1                                                        05106000
DSN020   TM    DSORG,DS1DSGPO           PARTITIONED?                    05107000
         BO    DSN030                   NO, BRANCH                      05108000
         MVC   0(7,R1),DSNJDCTD         ADD ,DSORG=                     05109000
         IC    R5,DSORG                 DSORG BITS                      05110000
         SLL   R5,24                    DROP TOP BITS                   05111000
         SRL   R5,28                    REPOSITION BITS *2              05112000
         LA    R5,DSORGTYP(R5)          DSORG                           05113000
         MVC   7(2,R1),0(R5)            MOVE INTO MESSAGE               05114000
         TM    DSORG+1,DS1ACBM          VSAM DATA SET?                  05115000
         BNO   *+10                     YES, BRANCH                     05116000
         MVC   7(2,R1),=C'VS'                                           05117000
         LA    R1,9(,R1)                SKIP OVER DSORG TEXT            05118000
         TM    DS1DSORG,DS1DSGU         UNMOVEABLE?                     05119000
         BNO   DSN030                   NO, BRANCH                      05120000
         MVI   0(R1),C'U'               ADD U                           05121000
         LA    R1,1(,R1)                SKIP OVER U                     05122000
         SPACE 1                                                        05123000
DSN030   MVC   0(10,R1),DSNJDCTV        ADD ),VOL=SER=                  05124000
         MVC   10(6,R1),VOLALLOC        ADD THE SERIAL NUMBER           05125000
         MVI   10+6(R1),C','                                            05126000
         TSMSG L220$1                                                   05127000
         SPACE 1                                                        05128000
         MVC   INSERT#1(80),DSNJSPA     //  SPACE= ...                  05129000
         L     R1,DCBDEBAD-IHADCB+INDCB GET DEB ADDRESS                 05130000
         LH    R14,NUMEXT               NUMBER OF EXTENTS               05131000
         SR    R0,R0                                                    05132000
         AH    R0,32+14(,R1)            ADD NUMBER OF TRACKS IN EXTENT  05133000
         LA    R1,16(,R1)               NEXT EXTENT                     05134000
         BCT   R14,*-8                  BRANCH FOR ALL EXTENTS          05135000
         STH   R0,DSNTOTAL              SAVE TOTAL D.S. SIZE IN TRACKS  05136000
         LH    R1,DS1LSTAR              GET TT OF LAST TRACK            05137000
         CLC   DS1LSTAR(3),ZERO         ANY ALLOCATION?                 05138000
         BE    *+8                      NO, BRANCH                      05139000
         LA    R1,1(,R1)                JUMP FOR COMPUTATION            05140000
         SR    R0,R1                                                    05141000
         STH   R0,DSNEMPTY              TOTAL FREE SPACE                05142000
         SPACE 1                                                        05143000
         LA    R1,INSERT#1+DSNJSPAP     PRIMARY SPACE                   05144000
         LH    R4,DSNTOTAL              TOTAL FREE SPACE                05145000
         TM    DS1SCALO,X'C0'           CYLINDER ALLOCATION?            05146000
         BNO   DSN050                   NO, BRANCH                      05147000
         MVC   INSERT#1+11(3),=C'CYL'   YES, MARK AS CYLINDER ALLOC.    05148000
         LH    R0,DEVTTRKS              TRACKS/CYLINDER                 05149000
         LR    R5,R0                                                    05150000
         BCTR  R5,0                     TRACKS/CYLINDER -1              05151000
         AR    R5,R4                    TOTAL+TRK/CYL -1                05152000
         SR    R4,R4                                                    05153000
         DR    R4,R0                    CEIL(TOTAL+TRK/CYL-1) / TRK/CYL 05154000
         LR    R4,R5                    RESULTING QUOTIENT              05155000
DSN050   BAL   R14,DSNCONV                                              05156000
         SPACE 1                                                        05157000
         SR    R4,R4                                                    05158000
         ICM   R4,B'0111',DS1SCALO+1    SECONDARY ALLOCATION?           05159000
         BZ    DSN070                   NO, BRANCH                      05160000
         TM    DS1SCALO,X'80'           TRACK OR CYLINDER ALLOCATION?   05161000
         BO    DSN060                   YES, BRANCH                     05162000
         TM    DS1SCALO,X'40'           AVERAGE BLOCK ALLOCATION?       05163000
         BNO   DSN060                   NO, BRANCH                      05164000
         LH    R14,BLKSI                BLOCKSIZE                       05165000
         ICM   R14,B'1000',=X'01'       R=1, K=0, DD=BLKSIZE            05166000
         TRKCALC FUNCTN=TRKCAP,TYPE=BYTEUCB+1,RKDD=(14),               X05167000
               REGSAVE=YES,MF=(E,PARMLIST)                              05168000
         LR    R5,R0                                                    05169000
         BCTR  R5,0                                                     05170000
         AR    R5,R4                                                    05171000
         SR    R4,R4                                                    05172000
         DR    R4,R0                    CEIL((BUFFERS+#/TRK-1)/(#/TRK)) 05173000
         LR    R4,R5                    RESULTING QUOTIENT              05174000
DSN060   MVI   0(R1),C','               SEPARATOR                       05175000
         LA    R1,1(,R1)                                                05176000
         BAL   R14,DSNCONV                                              05177000
         SPACE 1                                                        05178000
DSN070   TM    DSORG,DS1DSGPO           PARTITIONED DATA SET?           05179000
         BNO   DSN080                   NO, BRANCH                      05180000
         MVI   0(R1),C','               SEPARATOR                       05181000
         CLC   DS1SCALO+1(3),ZERO       SECONDARY ALLOCATION?           05182000
         BNE   *+8                      YES, BRANCH                     05183000
         LA    R1,1(,R1)                NO, ADD ANOTHER COMMA           05184000
         MVI   0(R1),C','               SEPARATOR                       05185000
         LA    R1,1(,R1)                                                05186000
         LH    R4,TOTALLOX              TOTAL DIRECTORY BLOCKS          05187000
         BAL   R14,DSNCONV                                              05188000
         SPACE 2                                                        05189000
DSN080   MVI   0(R1),C')'               PAIRED PARENTHESIS 1            05190000
         MVI   1(R1),C')'               PAIRED PARENTHESIS 2            05191000
         TM    DS1SCALO,X'01'           CYLINDER ROUNDING?              05192000
         BNO   *+10                     NO, BRANCH                      05193000
         MVC   1(8,R1),=C',,ROUND)'     YES, MARK IT                    05194000
         SPACE 1                                                        05195000
         LA    R1,INSERT#1+DSNJSPAT     WHERE TO STORE NUMBER FREE      05196000
         LH    R4,DSNEMPTY              TOTAL FREE TRACKS               05197000
         BAL   R14,DSNCONV                                              05198000
         SPACE 1                                                        05199000
         TM    DSORG,DS1DSGPO           PARTITIONED?                    05200000
         BNO   DSN090                   NO, BRANCH                      05201000
         MVC   0(10,R1),=C',FREE DIR='  FREE DIRECTORY BLOCKS           05202000
         LA    R1,10(,R1)               WHERE TO STORE NUMBER FREE      05203000
         LH    R4,TOTALLOX              TOTAL DIRECTORY BLOCKS          05204000
         SH    R4,TOTUSEDX              FREE DIRECTORY BLOCKS           05205000
         BAL   R14,DSNCONV                                              05206000
DSN090   MVI   0(R1),C'*'               TERMINATOR                      05207000
         MVI   1(R1),C'/'                         CHARACTERS            05208000
         TSMSG L220$1                                                   05209000
         MVI   MTHIGHL,8                RESET THE INSERT LENGTH         05210000
         MESSAGE MSGBLANK               ONE BLANK LINE                  05211000
         BR    R2                                                       05212000
         SPACE 3                                                        05213000
DSNTSO   MVC   INSERT#1(22),DSNTDSN     ADD "ALLOC F(1234567)  DA('"    05214000
         MVC   INSERT#1+8(8),DDNAME     MOVE IN THE DDNAME              05215000
         LA    R1,INSERT#1+8            DDNAME START POSITION           05216000
         LA    R1,1(,R1)                SCAN                            05217000
         CLI   0(R1),X'40'                  FOR FIRST                   05218000
         BNE   *-8                                   BLANK              05219000
         MVI   0(R1),C')'               ADD TERMINATOR                  05220000
         LA    R1,INSERT#1+22           DSNAME START POSITION           05221000
         MVC   0(44,R1),DSNAME          MOVE IN THE DSNAME              05222000
         AH    R1,DSNLEN                LENGTH OF THE DSNAME            05223000
         MVC   0(12,R1),DSNTDSND        ADD "') SHR UNIT("              05224000
         CLI   DSPALLOC,ALLOSHR         DISP=SHR?                       05225000
         BE    *+10                     YES, BRANCH                     05226000
         MVC   3(3,R1),=C'OLD'          NO, DISP=OLD                    05227000
         LH    R15,BYTEUCB              UCBBYTE                         05228000
         MH    R15,=H'9'                INDEX INTO THE UNIT TABLE       05229000
         LA    R15,UNITTBL(R15)         DEVICE UNIT TYPE                05230000
         LA    R1,12(,R1)               START OF UNIT DATA              05231000
         MVC   0(8,R1),1(R15)           ADD TO THE MESSAGE              05232000
         MVI   8(R1),X'40'              ADD A TERMINATOR                05233000
         LA    R1,1(,R1)                SCAN                            05234000
         CLI   0(R1),X'40'                  FOR FIRST                   05235000
         BNE   *-8                                   BLANK              05236000
         MVC   0(3,R1),=C') -'          ADD A TERMINATOR AND CONTINUE   05237000
         TSMSG L210$1                                                   05238000
         MVC   INSERT#1(80),MSGBL132+4  BLANK THE SECOND LINE           05239000
         MVC   INSERT#1(08),DSNTDCT     "  RECFM("                      05240000
         IC    R5,FLAGSCC               RECFM BITS                      05241000
         SLL   R5,29                    DROP TOP BITS                   05242000
         SRL   R5,29                    REPOSITION                      05243000
         IC    R5,RECFMTYP(R5)          RECORD FORMAT                   05244000
         STC   R5,INSERT#1+8            MOVE INTO MESSAGE               05245000
         LA    R1,INSERT#1+9                                            05246000
         TM    RECFM,DCBRECBR           RECFM=.B?                       05247000
         BNO   *+12                     NO, BRANCH                      05248000
         MVI   1(R1),C'B'                                               05249000
         LA    R1,2(R1)                                                 05250000
         TM    RECFM,DCBRECSB           RECFM=.S?                       05251000
         BNO   *+12                     NO, BRANCH                      05252000
         MVI   1(R1),C'S'                                               05253000
         LA    R1,2(R1)                                                 05254000
         TM    RECFM,DCBRECTO           RECFM=.T?                       05255000
         BNO   *+12                     NO, BRANCH                      05256000
         MVI   1(R1),C'T'                                               05257000
         LA    R1,2(R1)                                                 05258000
         TM    RECFM,DCBRECCA           RECFM=.A?                       05259000
         BNO   *+12                     NO, BRANCH                      05260000
         MVI   1(R1),C'A'                                               05261000
         LA    R1,2(R1)                                                 05262000
         TM    RECFM,DCBRECCM           RECFM=.M?                       05263000
         BNO   *+12                     NO, BRANCH                      05264000
         MVI   1(R1),C'M'                                               05265000
         LA    R1,2(R1)                                                 05266000
         TM    FLAGSCC,RECFMU           RECFM=U?                        05267000
         BO    DSN310                   YES, NO LRECL                   05268000
         MVC   0(8,R1),DSNTDCTL         MOVE IN LRECL TEXT              05269000
         LA    R1,8(R1)                                                 05270000
         LH    R4,LABLRECL                                              05271000
         BAL   R14,DSNCONV                                              05272000
         SPACE 1                                                        05273000
DSN310   MVC   0(10,R1),DSNTDCTB                                        05274000
         LA    R1,10(R1)                                                05275000
         LH    R4,BLKSI                                                 05276000
         BAL   R14,DSNCONV                                              05277000
         SPACE 1                                                        05278000
         SR    R4,R4                                                    05279000
         ICM   R4,B'0001',DS1KEYL       ANY KEY LENGTH?                 05280000
         BZ    DSN320                   NO, BRANCH                      05281000
         MVC   0(9,R1),DSNTDCTK         ADD ,KEYLEN=                    05282000
         LA    R1,9(R1)                                                 05283000
         BAL   R14,DSNCONV                                              05284000
         SPACE 1                                                        05285000
         MVC   0(6,R1),DSNTDCTR         ADD ,RKP=                       05286000
         LA    R1,6(R1)                                                 05287000
         SR    R4,R4                                                    05288000
         ICM   R4,B'0011',DS1RKP        RELATIVE KEY POSITION           05289000
         BAL   R14,DSNCONV                                              05290000
         SPACE 1                                                        05291000
DSN320   TM    DSORG,DS1DSGPO           PARTITIONED?                    05292000
         BO    DSN330                   NO, BRANCH                      05293000
         MVC   0(8,R1),DSNTDCTD         ADD ) DSORG(                    05294000
         IC    R5,DSORG                 DSORG BITS                      05295000
         SLL   R5,24                    DROP TOP BITS                   05296000
         SRL   R5,28                    REPOSITION BITS *2              05297000
         LA    R5,DSORGTYP(R5)          DSORG                           05298000
         MVC   8(2,R1),0(R5)            MOVE INTO MESSAGE               05299000
         TM    DSORG+1,DS1ACBM          VSAM DATA SET?                  05300000
         BNO   *+10                     YES, BRANCH                     05301000
         MVC   8(2,R1),=C'VS'                                           05302000
         LA    R1,10(,R1)               SKIP OVER DSORG TEXT            05303000
         TM    DS1DSORG,DS1DSGU         UNMOVEABLE?                     05304000
         BNO   DSN330                   NO, BRANCH                      05305000
         MVI   0(R1),C'U'               ADD U                           05306000
         LA    R1,1(,R1)                SKIP OVER U                     05307000
         SPACE 1                                                        05308000
DSN330   MVC   0(9,R1),DSNTDCTV         ADD ) VOLUME(                   05309000
         LA    R1,9(,R1)                START OF UNIT DATA              05310000
         MVC   0(6,R1),VOLALLOC         ADD THE SERIAL NUMBER           05311000
         MVI   6(R1),X'40'              ADD A TERMINATOR                05312000
         LA    R1,1(,R1)                SCAN                            05313000
         CLI   0(R1),X'40'                  FOR FIRST                   05314000
         BNE   *-8                                   BLANK              05315000
         MVC   0(3,R1),=C') -'          ADD A TERMINATOR AND CONTINUE   05316000
         TSMSG L210$1                                                   05317000
         SPACE 1                                                        05318000
         MVC   INSERT#1(80),DSNTSPA     "  TRK SPACE(N ..."             05319000
         L     R1,DCBDEBAD-IHADCB+INDCB GET DEB ADDRESS                 05320000
         LH    R14,NUMEXT               NUMBER OF EXTENTS               05321000
         SR    R0,R0                                                    05322000
         AH    R0,32+14(,R1)            ADD NUMBER OF TRACKS IN EXTENT  05323000
         LA    R1,16(,R1)               NEXT EXTENT                     05324000
         BCT   R14,*-8                  BRANCH FOR ALL EXTENTS          05325000
         STH   R0,DSNTOTAL              SAVE TOTAL D.S. SIZE IN TRACKS  05326000
         LH    R1,DS1LSTAR              GET TT OF LAST TRACK            05327000
         CLC   DS1LSTAR(3),ZERO         ANY ALLOCATION?                 05328000
         BE    *+8                      NO, BRANCH                      05329000
         LA    R1,1(,R1)                JUMP FOR COMPUTATION            05330000
         SR    R0,R1                                                    05331000
         STH   R0,DSNEMPTY              TOTAL FREE SPACE                05332000
         SPACE 1                                                        05333000
         LA    R1,INSERT#1+DSNTSPAP     PRIMARY SPACE                   05334000
         LH    R4,DSNTOTAL              TOTAL FREE SPACE                05335000
         TM    DS1SCALO,X'C0'           CYLINDER ALLOCATION?            05336000
         BNO   DSN350                   NO, BRANCH                      05337000
         MVC   INSERT#1+2(3),=C'CYL'    YES, MARK AS CYLINDER ALLOC.    05338000
         LH    R0,DEVTTRKS              TRACKS/CYLINDER                 05339000
         LR    R5,R0                                                    05340000
         BCTR  R5,0                     TRACKS/CYLINDER -1              05341000
         AR    R5,R4                    TOTAL+TRK/CYL -1                05342000
         SR    R4,R4                                                    05343000
         DR    R4,R0                    CEIL(TOTAL+TRK/CYL-1) / TRK/CYL 05344000
         LR    R4,R5                    RESULTING QUOTIENT              05345000
DSN350   BAL   R14,DSNCONV                                              05346000
         SPACE 1                                                        05347000
         SR    R4,R4                                                    05348000
         ICM   R4,B'0111',DS1SCALO+1    SECONDARY ALLOCATION?           05349000
         BZ    DSN370                   NO, BRANCH                      05350000
         TM    DS1SCALO,X'80'           TRACK OR CYLINDER ALLOCATION?   05351000
         BO    DSN360                   YES, BRANCH                     05352000
         TM    DS1SCALO,X'40'           AVERAGE BLOCK ALLOCATION?       05353000
         BNO   DSN360                   NO, BRANCH                      05354000
         LH    R14,BLKSI                BLOCKSIZE                       05355000
         ICM   R14,B'1000',=X'01'       R=1, K=0, DD=BLKSIZE            05356000
         TRKCALC FUNCTN=TRKCAP,TYPE=BYTEUCB+1,RKDD=(14),               X05357000
               REGSAVE=YES,MF=(E,PARMLIST)                              05358000
         LR    R5,R0                                                    05359000
         BCTR  R5,0                                                     05360000
         AR    R5,R4                                                    05361000
         SR    R4,R4                                                    05362000
         DR    R4,R0                    CEIL((BUFFERS+#/TRK-1)/(#/TRK)) 05363000
         LR    R4,R5                    RESULTING QUOTIENT              05364000
DSN360   MVI   0(R1),C','               SEPARATOR                       05365000
         LA    R1,1(,R1)                                                05366000
         BAL   R14,DSNCONV                                              05367000
         SPACE 1                                                        05368000
DSN370   MVI   0(R1),C')'               PAIRED PARENTHESIS 1            05369000
         LA    R1,1(,R1)                                                05370000
         TM    DSORG,DS1DSGPO           PARTITIONED DATA SET?           05371000
         BNO   DSN380                   NO, BRANCH                      05372000
         MVC   1(4,R1),=C'DIR('         SEPARATOR                       05373000
         LA    R1,5(,R1)                                                05374000
         LH    R4,TOTALLOX              TOTAL DIRECTORY BLOCKS          05375000
         BAL   R14,DSNCONV                                              05376000
         MVI   0(R1),C')'               FINAL PARENTHESIS               05377000
         SPACE 2                                                        05378000
DSN380   LA    R1,INSERT#1+DSNTSPAT     WHERE TO STORE NUMBER FREE      05379000
         LH    R4,DSNEMPTY              TOTAL FREE TRACKS               05380000
         BAL   R14,DSNCONV                                              05381000
         SPACE 1                                                        05382000
         TM    DSORG,DS1DSGPO           PARTITIONED?                    05383000
         BNO   DSN390                   NO, BRANCH                      05384000
         MVC   0(10,R1),=C',FREE DIR='  FREE DIRECTORY BLOCKS           05385000
         LA    R1,10(,R1)               WHERE TO STORE NUMBER FREE      05386000
         LH    R4,TOTALLOX              TOTAL DIRECTORY BLOCKS          05387000
         SH    R4,TOTUSEDX              FREE DIRECTORY BLOCKS           05388000
         BAL   R14,DSNCONV                                              05389000
DSN390   MVI   0(R1),C'*'               TERMINATOR                      05390000
         MVI   1(R1),C'/'                         CHARACTERS            05391000
         TSMSG L210$1                                                   05392000
         MVI   MTHIGHL,8                RESET THE INSERT LENGTH         05393000
         MESSAGE MSGBLANK               ONE BLANK LINE                  05394000
         BR    R2                                                       05395000
         SPACE 3                                                        05396000
DSNMSG   MVC   INSERT#1(80),DSNM200H       ADD HEADER                   05397000
         TM    DSORG,DS1DSGPO              PARTITIONED?                 05398000
         BO    *+10                        YES, BRANCH                  05399000
         MVC   INSERT#1+63(7),=CL7'DSORG'  NO, CHANGE THE HEADER        05400000
         TSMSG L200$1                                                   05401000
         MVC   INSERT#1(80),DSNM200E    ADD DATA LINE                   05402000
         CLI   DSPALLOC,ALLOSHR         DISP=SHR?                       05403000
         BE    *+10                     YES, BRANCH                     05404000
         MVC   INSERT#1+0(3),=C'OLD'    NO, DISP=OLD                    05405000
         LH    R15,BYTEUCB              UCBBYTE                         05406000
         MH    R15,=H'9'                INDEX INTO THE UNIT TABLE       05407000
         LA    R15,UNITTBL(R15)         DEVICE UNIT TYPE                05408000
         MVC   INSERT#1+05(8),1(R15)    DEVICE TYPE TEXT                05409000
         IC    R5,FLAGSCC               RECFM BITS                      05410000
         SLL   R5,29                    DROP TOP BITS                   05411000
         SRL   R5,29                    REPOSITION                      05412000
         IC    R5,RECFMTYP(R5)          RECORD FORMAT                   05413000
         STC   R5,INSERT#1+14           MOVE INTO MESSAGE               05414000
         LA    R1,INSERT#1+15                                           05415000
         TM    RECFM,DCBRECBR           RECFM=.B?                       05416000
         BNO   *+12                     NO, BRANCH                      05417000
         MVI   0(R1),C'B'                                               05418000
         LA    R1,1(R1)                                                 05419000
         TM    RECFM,DCBRECSB           RECFM=.S?                       05420000
         BNO   *+12                     NO, BRANCH                      05421000
         MVI   0(R1),C'S'                                               05422000
         LA    R1,1(R1)                                                 05423000
         TM    RECFM,DCBRECTO           RECFM=.T?                       05424000
         BNO   *+12                     NO, BRANCH                      05425000
         MVI   0(R1),C'T'                                               05426000
         LA    R1,1(R1)                                                 05427000
         TM    RECFM,DCBRECCA           RECFM=.A?                       05428000
         BNO   *+12                     NO, BRANCH                      05429000
         MVI   0(R1),C'A'                                               05430000
         LA    R1,1(R1)                                                 05431000
         TM    RECFM,DCBRECCM           RECFM=.M?                       05432000
         BNO   *+12                     NO, BRANCH                      05433000
         MVI   0(R1),C'M'                                               05434000
         LA    R1,1(R1)                                                 05435000
         LH    R4,LABLRECL                                              05436000
         TM    FLAGSCC,RECFMU           RECFM=U?                        05437000
         BNO   *+6                      NO, BRANCH                      05438000
         SR    R4,R4                    YES, LRECL IS ZERO              05439000
         CVD   R4,DOUBLE                CONVERT TO DECIMAL              05440000
         ED    INSERT#1+19(6),DOUBLE+5  CONVERT TO DISPLAY              05441000
         LH    R4,BLKSI                                                 05442000
         CVD   R4,DOUBLE                CONVERT TO DECIMAL              05443000
         ED    INSERT#1+27(6),DOUBLE+5  CONVERT TO DISPLAY              05444000
         SPACE 1                                                        05445000
         LH    R14,NUMEXT               NUMBER OF EXTENTS               05446000
         CVD   R14,DOUBLE                                               05447000
         ED    INSERT#1+33(4),DOUBLE+6  CONVERT TO DISPLAY              05448000
         L     R1,DCBDEBAD-IHADCB+INDCB GET DEB ADDRESS                 05449000
         SR    R0,R0                                                    05450000
         AH    R0,32+14(,R1)            ADD NUMBER OF TRACKS IN EXTENT  05451000
         LA    R1,16(,R1)               NEXT EXTENT                     05452000
         BCT   R14,*-8                  BRANCH FOR ALL EXTENTS          05453000
         STH   R0,DSNTOTAL              SAVE TOTAL D.S. SIZE IN TRACKS  05454000
         CVD   R0,DOUBLE                                                05455000
         ED    INSERT#1+38(6),DOUBLE+5  CONVERT TO DISPLAY              05456000
         LH    R1,DS1LSTAR              GET TT OF LAST TRACK            05457000
         CLC   DS1LSTAR(3),ZERO         ANY ALLOCATION?                 05458000
         BE    *+8                      NO, BRANCH                      05459000
         LA    R1,1(,R1)                JUMP FOR COMPUTATION            05460000
         SR    R0,R1                                                    05461000
         STH   R0,DSNEMPTY              TOTAL FREE SPACE                05462000
         SPACE 1                                                        05463000
         CVD   R0,DOUBLE                                                05464000
         ED    INSERT#1+46(6),DOUBLE+5  CONVERT TO DISPLAY              05465000
         SPACE 1                                                        05466000
         SR    R4,R4                                                    05467000
         ICM   R4,B'0111',DS1SCALO+1    SECONDARY ALLOCATION?           05468000
         BZ    DSN660                   NO, BRANCH                      05469000
         TM    DS1SCALO,X'80'           TRACK OR CYLINDER ALLOCATION?   05470000
         BO    DSN660                   YES, BRANCH                     05471000
         TM    DS1SCALO,X'40'           AVERAGE BLOCK ALLOCATION?       05472000
         BNO   DSN660                   NO, BRANCH                      05473000
         LH    R14,BLKSI                BLOCKSIZE                       05474000
         ICM   R14,B'1000',=X'01'       R=1, K=0, DD=BLKSIZE            05475000
         TRKCALC FUNCTN=TRKCAP,TYPE=BYTEUCB+1,RKDD=(14),               X05476000
               REGSAVE=YES,MF=(E,PARMLIST)                              05477000
         LR    R5,R0                                                    05478000
         BCTR  R5,0                                                     05479000
         AR    R5,R4                                                    05480000
         SR    R4,R4                                                    05481000
         DR    R4,R0                    CEIL((BUFFERS+#/TRK-1)/(#/TRK)) 05482000
         LR    R4,R5                    RESULTING QUOTIENT              05483000
DSN660   CVD   R4,DOUBLE                                                05484000
         ED    INSERT#1+52(6),DOUBLE+5  CONVERT TO DISPLAY              05485000
         SPACE 1                                                        05486000
         TM    DS1SCALO,X'C0'           CYLINDER ALLOCATION?            05487000
         BNO   *+10                     NO, BRANCH                      05488000
         MVC   INSERT#1+59(3),=C'CYL'   YES, MARK AS CYLINDER ALLOC.    05489000
         SPACE 1                                                        05490000
         TM    DSORG,DS1DSGPO           PARTITIONED?                    05491000
         BO    DSN680                   NO, BRANCH                      05492000
         LA    R1,INSERT#1+63           WHERE TO ADD DSORG DATA         05493000
         MVC   0(8,R1),BLANKS           BLANK THE EDIT DATA             05494000
         IC    R5,DSORG                 DSORG BITS                      05495000
         SLL   R5,24                    DROP TOP BITS                   05496000
         SRL   R5,28                    REPOSITION BITS *2              05497000
         LA    R5,DSORGTYP(R5)          DSORG                           05498000
         MVC   0(2,R1),0(R5)            MOVE INTO MESSAGE               05499000
         TM    DSORG+1,DS1ACBM          VSAM DATA SET?                  05500000
         BNO   *+10                     YES, BRANCH                     05501000
         MVC   0(2,R1),=C'VS'                                           05502000
         TM    DS1DSORG,DS1DSGU         UNMOVEABLE?                     05503000
         BNO   DSN690                   NO, BRANCH                      05504000
         MVI   2(R1),C'U'               ADD U                           05505000
         B     DSN690                                                   05506000
         SPACE 1                                                        05507000
DSN680   LH    R4,TOTALLOX              TOTAL DIRECTORY BLOCKS          05508000
         SH    R4,TOTUSEDX              FREE DIRECTORY BLOCKS           05509000
         CVD   R4,DOUBLE                                                05510000
         ED    INSERT#1+64(6),DOUBLE+5  CONVERT TO DISPLAY              05511000
         SPACE 1                                                        05512000
DSN690   TSMSG L200$1                                                   05513000
         MVI   MTHIGHL,8                RESET THE INSERT LENGTH         05514000
         MESSAGE MSGBLANK               ONE BLANK LINE                  05515000
         BR    R2                                                       05516000
         SPACE 3                                                        05517000
DSNCONV  CVD   R4,DOUBLE                                                05518000
         UNPK  DOUBLE(5),DOUBLE+5(3)                                    05519000
         LA    R4,DOUBLE-1                                              05520000
         LA    R4,1(R4)                                                 05521000
         CLI   0(R4),C'0'                                               05522000
         BE    *-8                                                      05523000
         OI    DOUBLE+4,X'F0'                                           05524000
DSNMOVE  MVC   0(1,R1),0(R4)                                            05525000
         LA    R1,1(R1)                                                 05526000
         TM    1(R4),X'F0'                                              05527000
         LA    R4,1(R4)                                                 05528000
         BO    DSNMOVE                                                  05529000
         BR    R14                                                      05530000
         SPACE 1                                                        05531000
DSNTDSN  DC    C'ALLOC F(1234567)  DA('''') SHR UNIT('                  05532000
DSNTDSND EQU   DSNTDSN+22,12                                            05533000
         SPACE 1                                                        05534000
DSNTDCT  DC    C'  RECFM() LRECL() BLKSIZE() DSORG(**) KEYLEN() RKP() VX05535000
               OLUME('                                                  05536000
DSNTDCTL EQU   DSNTDCT+8,8                                              05537000
DSNTDCTB EQU   DSNTDCT+8+8,10                                           05538000
DSNTDCTD EQU   DSNTDCT+8+8+10,10                                        05539000
DSNTDCTK EQU   DSNTDCT+8+8+10+10,9                                      05540000
DSNTDCTR EQU   DSNTDCT+8+8+10+10+9,6                                    05541000
DSNTDCTV EQU   DSNTDCT+8+8+10+10+9+6,9                                  05542000
         SPACE 1                                                        05543000
DSNTSPA  DC    CL80'  TRK SPACE(N                            /*FREE TRKX05544000
               =N'                                                      05545000
DSNTSPAP EQU   12,4                                                     05546000
DSNTSPAT EQU   52,7                                                     05547000
         SPACE 2                                                        05548000
DSNJDSN  DC    C'//12345678  DD  DSN=,DISP=SHR,UNIT='                   05549000
DSNJDSND EQU   DSNJDSN+20,15                                            05550000
         SPACE 1                                                        05551000
DSNJDCT  DC    C'//  DCB=(RECFM=,LRECL=,BLKSIZE=,DSORG=**,KEYLEN=,RKP=)X05552000
               ,VOL=SER='                                               05553000
DSNJDCTL EQU   DSNJDCT+15,7                                             05554000
DSNJDCTB EQU   DSNJDCT+15+7,9                                           05555000
DSNJDCTD EQU   DSNJDCT+15+7+9,9                                         05556000
DSNJDCTK EQU   DSNJDCT+15+7+9+9,8                                       05557000
DSNJDCTR EQU   DSNJDCT+15+7+9+9+8,5                                     05558000
DSNJDCTV EQU   DSNJDCT+15+7+9+9+8+5,10                                  05559000
         SPACE 1                                                        05560000
DSNJSPA  DC    CL80'//  SPACE=(TRK,(N                        /*FREE TRKX05561000
               =N'                                                      05562000
DSNJSPAP EQU   16,4                                                     05563000
DSNJSPAT EQU   52,7                                                     05564000
         SPACE 2                                                        05565000
DSNM200H DC    CL80'DISP UNIT     RECFM LRECL BLKSIZE   ALLOCTRK FREETRX05566000
               K SECONDARY FREEDIR'                   123X 12345        05567000
DSNM200E DC    CL80'SHR                                  X             X05568000
                       TRK        '                                     05569000
         ORG   DSNM200E+19                                              05570000
         DC    X'402020202120'                                          05571000
         ORG   DSNM200E+27                                              05572000
         DC    X'402020202120'                                          05573000
         ORG   DSNM200E+33                                              05574000
         DC    X'40202120'                                              05575000
         ORG   DSNM200E+38                                              05576000
         DC    X'402020202120'                                          05577000
         ORG   DSNM200E+46                                              05578000
         DC    X'402020202120'                                          05579000
         ORG   DSNM200E+52                                              05580000
         DC    X'402020202120'                                          05581000
         ORG   DSNM200E+64                                              05582000
         DC    X'402020202120'                                          05583000
         ORG   ,                                                        05584000
         DROP  R6                                                       05585000
         TITLE 'P D S  --  PDS FIXPDS                          1/15/85' 05586000
*********************************************************************** 05587000
***      FIXPDS SUBCOMMAND     ADDED BY BRUCE LELAND -- NOV., 1982  *** 05588000
*********************************************************************** 05589000
*                                                                       05590000
         SPACE 1                                                        05591000
FIXPDS   CSECT                                                          05592000
         USING *,R8                                                     05593000
         SPACE 1                                                        05594000
         ICM   R1,B'1111',#RECFM       NEW DCB=RECFM SPECIFIED?         05595000
         BP    *+10                    YES, BRANCH                      05596000
         MVC   #RECFM+3(1),RECFM       NO, USE PREVIOUS RECFM           05597000
         ICM   R2,B'1111',#LRECL       NEW DCB=LRECL SPECIFIED?         05598000
         BP    *+10                    YES, BRANCH                      05599000
         MVC   #LRECL+2(2),LABLRECL    NO, USE THE LRECL FROM THE DCB   05600000
         TM    #RECFM+3,X'C0'          RECFM=U..?                       05601000
         BNO   *+10                    NO, BRANCH                       05602000
         XC    #LRECL,#LRECL           YES, USE LRECL=0                 05603000
         ICM   R3,B'1111',#BLKSI       NEW DCB=BLKSIZE SPECIFIED?       05604000
         BP    *+10                    YES, BRANCH                      05605000
         MVC   #BLKSI+2(2),BLKSI       NO, USE PREVIOUS BLOCKSIZE       05606000
         SPACE 2                                                        05607000
         TM    #RECFM+3,DCBRECF        RECFM=F OR RECFM=U?              05608000
         BNO   FIXPDS10                NO, BRANCH                       05609000
         TM    #RECFM+3,DCBRECV        RECFM=U?                         05610000
         BO    FIXPDS10                YES, BRANCH                      05611000
         SPACE 1                                                        05612000
         L     R15,#BLKSI              REQUESTED BLOCKSIZE              05613000
         SR    R14,R14                                                  05614000
         ICM   R4,B'1111',#LRECL       ANY LRECL?                       05615000
         BZ    FIXPDS10                NO, AVOID DIVIDE ERROR           05616000
         DR    R14,R4                  CHECK LRECL'S PER BLOCK          05617000
         LTR   R14,R14                 INTEGRAL NUMBER?                 05618000
         BZ    FIXPDS10                YES, BRANCH                      05619000
         TSMSG L482                    NO, DIVIDE ERROR MESSAGE         05620000
         SPACE 2                                                        05621000
FIXPDS10 TM    DSORG,DS1DSGPO          PARTITIONED?                     05622000
         BNO   FIXPDS50                NO, BRANCH                       05623000
         CLI   #FIXOPT,X'02'           DCB?                             05624000
         BL    FIXPDS50                YES, BRANCH                      05625000
         SPACE 1                                                        05626000
         MVC   ##SUBCOM(8),$USA        TEMPORARY SUBCOMMAND IDENTIFIER  05627000
         MVI   STARTTR+2,X'01'         TTR=000001 (START OF DIRECTORY)  05628000
         BAL   R14,READDIR             NUMBER OF DIRECTORY BLOCKS       05629000
         MVC   ##SUBCOM(8),$FIX        RESET THE SUBCOMMAND NAME        05630000
         SPACE 1                                                        05631000
         ICM   R3,B'1111',TOTMEMR      REAL (2 BYTES) AND ALIASES (2)   05632000
         LH    R6,TOTBLOCK             NUMBER OF DIRECTORY BLOCKS       05633000
         LTR   R6,R6                   ANY CURRENT DIRECTORY BLOCKS?    05634000
         BP    FIXPDS20                YES, BRANCH                      05635000
         LA    R1,L752                 ASSUME RESET OR EXPAND & NOCOUNT 05636000
         CLC   #NEWDIR,ZERO            CORRECT?                         05637000
         BE    MSGNEW                  YES, ERROR EXIT                  05638000
         SPACE 1                                                        05639000
FIXPDS20 CLI   #FIXOPT,X'02'           EXPANDDIR?                       05640000
         BE    FIXPDS30                YES, BRANCH                      05641000
         ICM   R1,B'1111',#NEWDIR      ANY DIRECTORY BLOCKS SPECIFIED?  05642000
         BP    *+8                     YES, BRANCH                      05643000
         ST    R6,#NEWDIR              NO, USE CURRENT NUMBER           05644000
         SR    R6,R6                   CLEAR CURRENT DIRECTORY NUMBER   05645000
         LTR   R3,R3                   ANY MAIN OR ALIAS MEMBERS?       05646000
         BZ    FIXPDS30                NO, A WARNING IS NOT NEEDED      05647000
         TSMSG L451                    YES, ALL MEMBERS WILL BE LOST    05648000
         SPACE 1                                                        05649000
FIXPDS30 STM   R2,R12,28(R13)          CONVERT CCHHR TO TTR             05650000
         LA    R2,CURMBB                                                05651000
         L     R1,INDCB+(DCBDEBAD-IHADCB)                               05652000
         L     R15,ADDRRLTV                                             05653000
         LR    R3,R13                                                   05654000
         BALR  R14,R15                                                  05655000
         LR    R13,R3                                                   05656000
         LM    R2,R12,28(R13)                                           05657000
         ST    R0,#EOF1TTR             TTR OF CURRENT DIRECTORY EOF     05658000
         SPACE 1                                                        05659000
         ICM   R4,B'1111',#NEWDIR      ANY DIRECTORY BLOCKS SPECIFIED?  05660000
         BP    *+8                     YES, BRANCH                      05661000
         LA    R4,50                   NO, ADD 50 TO THE CURRENT NUMBER 05662000
         AR    R4,R6                   DESIRED + CURRENT DIR. BLOCKS    05663000
         ST    R4,#NEWDIR              UPDATE (NOW TOTAL # OF BLOCKS)   05664000
         LTR   R3,R3                   ANY MAIN OR ALIAS MEMBERS?       05665000
         BNZ   *+6                     YES, BRANCH                      05666000
         SR    R6,R6                   NO, CLEAR DIRECTORY COUNT        05667000
         SPACE 1                                                        05668000
         LR    R1,R4                                                    05669000
         SR    R1,R6                   NUMBER OF BLOCKS TO ADD          05670000
         ST    R1,#NEWDIR              UPDATE (NOW NUMBER TO ADD)       05671000
         SPACE 1                                                        05672000
         L     R14,=X'01080100'        R=1, K=08, DD=256 BYTES          05673000
         TRKCALC FUNCTN=TRKCAP,TYPE=BYTEUCB+1,RKDD=(14),              XX05674000
               REGSAVE=YES,MF=(E,PARMLIST)                              05675000
         ST    R0,#DIRBTRK             SAVE DIRECTORY BLOCKS PER TRACK  05676000
         SRDA  R4,32                   TOTAL BLOCKS                     05677000
         DR    R4,R0                   TOTAL / ENTRIES PER TRACK        05678000
         STH   R5,#EOF2TT              TRACK OF NEW DIRECTORY EOF       05679000
         L     R2,DCBDEBAD-IHADCB+INDCB  DEB ADDRESS                    05680000
         LA    R1,L870                 ASSUME MULTI-EXTENT DIRECTORY    05681000
         CLC   32+14(2,R2),ZERO        NULL DATA SET?                   05682000
         BE    FIXPDS31                YES, ALLOW THE ALLOCATION        05683000
         CH    R5,32+14(,R2)           CORRECT?                         05684000
         BNL   MSGNEW                  YES, ERROR                       05685000
         SPACE 1                                                        05686000
FIXPDS31 LTR   R4,R4                   PARTIAL TRACK USED?              05687000
         BP    FIXPDS32                YES, BRANCH                      05688000
         TSMSG L450                    NO, WARNING MESSAGE              05689000
         L     R1,#NEWDIR              ONE ADDITIONAL                   05690000
         A     R1,=F'1'                       DIRECTORY                 05691000
         ST    R1,#NEWDIR                           BLOCK USED          05692000
         SPACE 2                                                        05693000
FIXPDS32 LA    R3,#MEMPTR              BASE FOR THE MEMBER LIST         05694000
         USING DIRLINK,R3              NO, BRANCH                       05695000
         MVI   STARTTR+2,X'01'         TTR=000001 (START OF DIRECTORY)  05696000
FIXPDS40 BAL   R14,READDIR             GET THE NEXT MEMBER              05697000
         B     FIXPDS50                LAST MEMBER, BRANCH              05698000
         SPACE 1                                                        05699000
         CLI   #FIXOPT,X'03'           RESET DIRECTORY?                 05700000
         BE    FIXPDS42                YES, BRANCH                      05701000
         CLC   #EOF2TT(2),MEMTTR       IN THE NEW DIRECTORY AREA?       05702000
         BL    FIXPDS40                NO, BRANCH                       05703000
         MVI   SUBPOOLT,21             MARK TEMPORARY SUBPOOL IN USE    05704000
         LA    R0,DIREND-DIRLINK       GET ANOTHER DIRECTORY ENTRY      05705000
         ICM   R0,B'1000',SUBPOOLT                                      05706000
         GETMAIN R,LV=(0)                                               05707000
         XC    0(DIREND-DIRLINK,R1),0(R1)                               05708000
         ST    R1,DIRLINK              CHAIN TO THE                     05709000
         LR    R3,R1                               NEXT ENTRY           05710000
         L     R14,DIRPTRS             ACTUAL DIRECTORY ENTRY           05711000
         MVC   DIRNAME(74),0(R14)      ADD THE DIRECTORY INFORMATION    05712000
         MVC   INSERT#1(8),DIRNAME                                      05713000
         TSMSG L050$1                                                   05714000
         SPACE 2                                                        05715000
FIXPDS42 MVC   DSNMEMQ(8),MEMNAME      MEMBER NAME TO CHECK             05716000
         BAL   R2,ENQMTEST             MEMBER IN USE?                   05717000
         B     FIXPDS40                YES, OUTPUT WARNING MESSAGE ONLY 05718000
         B     FIXPDS40                REPEAT FOR ALL MEMBERS           05719000
         SPACE 2                                                        05720000
FIXPDS50 MESSAGE MSGBLANK              ONE SPACING LINE                 05721000
         L     R15,$DSN+8                                               05722000
         BALR  R2,R15                  DISPLAY ALLOCATION STATUS        05723000
         LA    R1,PDS392A              CORRECT DATA SET                 05724000
         BAL   R2,YESNO                RESPONSE "YES" OR "NO"?          05725000
         B     NEWCMD                  "NO", QUIT                       05726000
         SPACE 1                                                        05727000
         TM    DSORG,DS1DSGPO          PARTITIONED?                     05728000
         BNO   FIXDCB                  NO, BRANCH                       05729000
         MVI   #DIRFIX,X'F9'           HIGH IN COLLATING SEQUENCE       05730000
         MVC   #DIRFIX+1(7),=C'FIXPDS' TEMPORARY STOW AND DELETE NAME   05731000
         BAL   R6,RESERVE              RESERVE/ENQUE AS REQUIRED        05732000
         L     R4,#NEWDIR              DIRECTORY BLOCKS DESIRED         05733000
         CLI   #FIXOPT,X'02'           WHICH PROCESSING MODE?           05734000
         BL    FIXDCB                    DCB       -- CHANGE DCB ONLY   05735000
***      BE    EXPAND                    EXPANDDIR -- ADD TO DIRECTORY  05736000
         BH    FIXRES                    RESETDIR  -- REWRITE DIRECTORY 05737000
         SPACE 3                                                        05738000
EXPAND   ICM   R1,B'1111',TOTMEMR      ANY MAIN OR ALIAS MEMBERS?       05739000
         BZ    FIXRES                  NO, USE RESETDIR INSTEAD         05740000
         SPACE 1                                                        05741000
         MVI   SUBPOOLT,21             MARK TEMPORARY STORAGE OBTAINED  05742000
         LA    R0,1024*3               STORAGE FOR THREE NOTELISTS      05743000
         ICM   R0,B'1000',SUBPOOLT     SUBPOOL                          05744000
         GETMAIN R,LV=(0)                                               05745000
         ST    R1,#NOTEPTR             POINTER TO NOTELIST WORK AREA    05746000
         BAL   R2,OPENSTOW             OPEN OUTPUT DCB; RESERVE IS DONE 05747000
         B     NEWCMD                  COULD NOT OPEN -- ERROR          05748000
         CLC   #MEMPTR(4),ZERO         ANY MEMBERS TO MOVE?             05749000
         BE    EXPAND80                NO, BRANCH                       05750000
         LA    R0,80                   FIRST RECORD IS 80 BYTES LONG    05751000
         SPACE 2                                                        05752000
*  ONE OR MORE MEMBERS MUST BE MOVED                                    05753000
*    WRITE GARBAGE RECORDS TO OCCUPY SPACE UP TO THE NEW DIRECTORY EOF  05754000
EXPAND02 STH   R0,STOWDCB+DCBBLKSI-IHADCB  UPDATE IN THE DCB            05755000
         L     R2,IOBUFF1              START OF DATA                    05756000
         WRITE FIXPDSD,SF,STOWDCB,(2),'S',MF=E                          05757000
         CHECK FIXPDSD                                                  05758000
         NOTE  STOWDCB                 OUTPUT TTR                       05759000
         LH    R0,BLKSI                MAXIMUM OUTPUT RECORD LENGTH     05760000
         CLM   R1,B'1100',#EOF2TT      PAST THE NEW DIRECTORY EOF?      05761000
         BNH   EXPAND02                NO, BRANCH                       05762000
         ST    R1,#FIXTTRO             HIGHEST OUTPUT TTR               05763000
         LA    R3,#MEMPTR                                               05764000
         SPACE 1                                                        05765000
EXPAND12 ICM   R3,B'0111',DIRLINK+1    NEXT MEMBER ENTRY                05766000
         BZ    EXPAND20                END OF LIST, BRANCH              05767000
         MVI   DIRLINK,X'80'           ASSUME THE MEMBER IS TO BE MOVED 05768000
         TM    DIRFLAG,DIRALIAS        ALIAS ENTRY?                     05769000
         BNO   EXPAND18                NO, BRANCH                       05770000
         LA    R2,#MEMPTR                                               05771000
         SPACE 1                                                        05772000
EXPAND14 ICM   R2,B'0111',1(R2)              MORE IN THE LIST?          05773000
         BZ    EXPAND18                      NO, THIS ITEM WILL MOVE    05774000
         CR    R2,R3                         SAME ITEM?                 05775000
         BE    EXPAND14                      YES, TRY AGAIN             05776000
         CLC   DIRTTR(3),DIRTTR-DIRLINK(R2)  SAME TTR?                  05777000
         BNE   EXPAND14                      NO, BRANCH                 05778000
         TM    DIRLINK-DIRLINK(R2),X'80'     OTHER ITEM TO BE MOVED?    05779000
         BO    EXPAND16                      YES, TRUE ALIAS            05780000
         TM    DIRFLAG-DIRLINK(R2),DIRALIAS  OTHER ITEM AN ALIAS?       05781000
         BO    EXPAND14                      YES, BRANCH                05782000
         SPACE 1                                                        05783000
EXPAND16 MVI   DIRLINK,0                     DO NOT MOVE THIS ENTRY     05784000
EXPAND18 TM    DIRFLAG,DIR1TTR+DIR2TTR       ANY USER TTR'S?            05785000
         BZ    EXPAND12                      NO, BRANCH                 05786000
         SPACE 1                                                        05787000
         OI    DIRLINK,X'01'                 AT LEAST ONE TTR           05788000
         TM    DIRFLAG,DIR2TTR               TWO OR MORE TTR'S?         05789000
         BNO   *+8                           NO, BRANCH                 05790000
         OI    DIRLINK,X'02'                 AT LEAST TWO TTR'S         05791000
         TM    DIRFLAG,DIR1TTR+DIR2TTR       THREE TTR'S?               05792000
         BNO   *+8                           NO, BRANCH                 05793000
         OI    DIRLINK,X'04'                 THREE TTR'S                05794000
         B     EXPAND12                                                 05795000
         SPACE 3                                                        05796000
EXPAND20 LA    R3,#MEMPTR                                               05797000
EXPAND22 ICM   R3,B'0111',DIRLINK+1    ANY MORE MEMBERS IN THE LIST?    05798000
         BZ    EXPAND80                NO, BRANCH                       05799000
         MVC   INSERT#1(8),DIRNAME     MEMBER NAME                      05800000
         TSMSG L051$1                                                   05801000
         TM    DIRLINK,X'80'           MEMBER TO BE MOVED?              05802000
         BNO   EXPAND22                NO, BRANCH                       05803000
         LA    R2,DIRSTART             FIRST USER TTR                   05804000
         L     R4,#NOTEPTR             START OF NOTELIST STORAGE        05805000
         LA    R5,X'10'+X'01'          MASK BITS FOR TESTING            05806000
         LA    R6,3                    LOOP CONTROL                     05807000
         SPACE 1                                                        05808000
*  INPUT THE OVERLAY NOTELIST TABLE                                     05809000
         TM    DIRLINK,*-*             <<EXECUTED>>                     05810000
EXPAND24 EX    R5,*-4                  ANOTHER TTR?                     05811000
         BZ    EXPAND30                NO, BRANCH                       05812000
         CLI   3(R2),0                 NOTELIST COUNT?                  05813000
         BZ    EXPAND26                NO, BRANCH                       05814000
         OI    DIRLINK,*-*             <<EXECUTED>>                     05815000
         EX    R5,*-4                  MARK FOR NOTELIST PROCESSING     05816000
         MVC   STARTTR(3),0(R2)        NOTELIST TTR ADDRESS             05817000
         L     R15,=A(EXCP)            INPUT IT                         05818000
         BALR  R14,R15                                                  05819000
         LA    R1,L751                 ASSUME AN INPUT PROBLEM          05820000
         LTR   R15,R15                 CORRECT?                         05821000
         BP    MSGNEW                  YES, BRANCH                      05822000
         LR    R14,R0                  INPUT ADDRESS                    05823000
         SR    R15,R15                                                  05824000
         IC    R15,3(,R2)              NUMBER OF NOTELIST ENTRIES       05825000
         SLL   R15,2                   SIZE OF NOTELIST AREA            05826000
         LR    R0,R4                   START OF THIS NOTELIST AREA      05827000
         LR    R1,R15                  SAVE AREA MOVE LENGTH            05828000
         MVCL  R0,R14                  SAVE THE NOTELIST DATA           05829000
         SPACE 1                                                        05830000
EXPAND26 LA    R2,4(,R2)               NEXT POTENTIAL USER TTR          05831000
         LA    R4,1024(,R4)            NEXT POTENTIAL NOTELIST AREA     05832000
         SLL   R5,1                    NEXT MASK BITS                   05833000
         BCT   R6,EXPAND24                                              05834000
         SPACE 3                                                        05835000
*  READ EACH RECORD OF THE MEMBER                                       05836000
EXPAND30 MVC   STARTTR(3),DIRTTR       FIRST TTR OF THE MEMBER          05837000
         MVC   #FINDTTR(3),DIRTTR      SAVE THE FIRST TTR FOR LATER     05838000
         SPACE 2                                                        05839000
EXPAND32 L     R15,=A(EXCP)                                             05840000
         BALR  R14,R15                                                  05841000
         B     *+4(R15)                PROCESS RETURN CODE              05842000
         B     EXPAND34                  00 - GOOD READ                 05843000
         B     EXPAND60                  04 - END OF MEMBER             05844000
         B     EXPAND60                  08 - END OF DATA SET           05845000
         B     NEWCMD                    12 - I/O ERROR                 05846000
         SPACE 1                                                        05847000
EXPAND34 STM   R2,R12,28(R13)          CONVERT CCHHR TO TTR             05848000
         LA    R2,CURMBB                                                05849000
         L     R1,INDCB+(DCBDEBAD-IHADCB)                               05850000
         L     R15,ADDRRLTV                                             05851000
         LR    R3,R13                                                   05852000
         BALR  R14,R15                                                  05853000
         LR    R13,R3                                                   05854000
         LM    R2,R12,28(R13)                                           05855000
         ST    R0,#FIXTTRI             SAVE CURRENT INPUT TTR           05856000
         TM    DIRLINK,X'77'           ANY PENDING TTR UPDATES?         05857000
         BZ    EXPAND50                NO, BRANCH                       05858000
         LA    R2,DIRSTART             FIRST USER TTR                   05859000
         L     R4,#NOTEPTR             START OF NOTELIST STORAGE        05860000
         LA    R5,X'10'                MASK                             05861000
         LA    R6,3                    LOOP CONTROL                     05862000
         SPACE 1                                                        05863000
         TM    DIRLINK,*-*             <<EXECUTED>>                     05864000
EXPAND36 EX    R5,*-4                  ANY NOTELIST FOR THIS ENTRY?     05865000
         BZ    EXPAND38                NO, BRANCH                       05866000
         CLM   R0,B'1110',0(R2)        IS THIS THE NOTELIST ENTRY?      05867000
         BE    EXPAND40                YES, BRANCH                      05868000
EXPAND38 LA    R2,4(,R2)               NEXT USER TTR                    05869000
         LA    R4,1024(,R4)            NEXT NOTELIST ENTRY              05870000
         SLL   R5,1                    NEXT MASK                        05871000
         BCT   R6,EXPAND36                                              05872000
         B     EXPAND50                NOT THIS RECORD, BRANCH          05873000
         SPACE 2                                                        05874000
EXPAND40 SR    R0,R0                                                    05875000
         IC    R0,3(R2)                NUMBER OF NOTELIST ENTRIES       05876000
         LA    R1,L750                 ERROR MESSAGE FOR A PROBLEM      05877000
         XI    DIRLINK,*-*             <<EXECUTED>>                     05878000
         EX    R5,*-4                  TURN OFF THIS NOTELIST ENTRY     05879000
         L     R5,EXCPBUFF             OUTPUT START ADDRESS             05880000
EXPAND42 TM    3(R4),X'80'             NOTELIST TTR PREVIOUSLY UPDATED? 05881000
         BNO   MSGNEW                  NO, ERROR                        05882000
         MVC   0(3,R5),0(R4)           REPLACE THE BUFFER TTR           05883000
         LA    R4,4(,R4)               NEXT STORAGE ADDRESS             05884000
         LA    R5,4(,R5)               NEXT BUFFER ADDRESS              05885000
         BCT   R0,EXPAND42             MOVE AND CHECK ALL ENTRIES       05886000
         SPACE 3                                                        05887000
*  OUTPUT EACH RECORD AND CHANGE TTR POINTERS AS NECESSARY              05888000
EXPAND50 L     R0,LS                   RECORD LENGTH                    05889000
         STH   R0,STOWDCB+DCBBLKSI-IHADCB  UPDATE IN THE DCB            05890000
         L     R2,EXCPBUFF             START OF DATA                    05891000
         WRITE FIXPDSD,SF,STOWDCB,(2),'S',MF=E                          05892000
         CHECK FIXPDSD                                                  05893000
         NOTE  STOWDCB                 OUTPUT TTR                       05894000
         ST    R1,#FIXTTRO                                              05895000
         SPACE 1                                                        05896000
         CLC   DIRTTR(3),#FINDTTR      FIRST MEMBER RECORD?             05897000
         BNE   *+10                    NO, BRANCH                       05898000
         MVC   DIRTTR(3),#FIXTTRO      YES, UPDATE THE TTR              05899000
         SPACE 1                                                        05900000
         TM    DIRLINK,X'77'           ANY PENDING TTR UPDATES?         05901000
         BZ    EXPAND32                NO, BRANCH                       05902000
         LA    R2,DIRSTART             FIRST USER TTR                   05903000
         L     R4,#NOTEPTR             START OF NOTELIST                05904000
         LA    R5,X'10'                NOTELIST MASK                    05905000
         LA    R6,3                    LOOP CONTROL                     05906000
         LA    R14,X'01'               TTR MASK                         05907000
         SPACE 1                                                        05908000
         TM    DIRLINK,*-*             <<EXECUTED>>                     05909000
EXPAND52 EX    R14,*-4                 TTR IN THIS POSITION?            05910000
         BNO   EXPAND54                NO, BRANCH                       05911000
         CLC   #FIXTTRI(3),0(R2)       THIS INPUT TTR?                  05912000
         BNE   EXPAND54                NO, BRANCH                       05913000
         STCM  R1,B'1110',0(R2)        YES, UPDATE THE TTR              05914000
         XI    DIRLINK,*-*             <<EXECUTED>>                     05915000
         EX    R14,*-4                 TURN OFF THE TTR INDICATOR       05916000
         SPACE 1                                                        05917000
         TM    DIRLINK,*-*             <<EXECUTED>>                     05918000
EXPAND54 EX    R5,*-4                  NOTELIST FOR THIS ENTRY?         05919000
         BNO   EXPAND58                NO, BRANCH                       05920000
         LR    R15,R4                  START OF NOTELIST                05921000
         SR    R0,R0                                                    05922000
         IC    R0,3(R2)                NUMBER OF NOTELIST ENTRIES       05923000
EXPAND56 CLC   0(3,R15),#FIXTTRI       THIS TTR?                        05924000
         BNE   *+12                    NO, BRANCH                       05925000
         STCM  R1,B'1110',0(R15)       YES, UPDATE THE TTR              05926000
         OI    3(R15),X'80'                 AND MARK AS UPDATED         05927000
         LA    R15,4(,R15)             NEXT NOTELIST ENTRY              05928000
         BCT   R0,EXPAND56                                              05929000
EXPAND58 LA    R2,4(,R2)               NEXT USER TTR                    05930000
         LA    R4,1024(,R4)            NEXT NOTELIST STORAGE            05931000
         SLL   R5,1                    NEXT NOTELIST BIT MASK           05932000
         SLL   R14,1                   NEXT TTR BIT MASK                05933000
         BCT   R6,EXPAND52                                              05934000
         B     EXPAND32               MOVE ALL MEMBERS                  05935000
         SPACE 3                                                        05936000
*  VERIFY THAT THE MEMBER WAS CORRECTLY PROCESSED                       05937000
EXPAND60 LA    R1,L871                 ASSUME A TTR WAS NOT UPDATED     05938000
         TM    DIRLINK,X'77'           CORRECT?                         05939000
         BNZ   MSGNEW                  YES, BRANCH                      05940000
         SPACE 1                                                        05941000
         CLC   DIRTTR(3),#FINDTTR      A NULL MEMBER?                   05942000
         BNE   EXPAND62                NO, BRANCH                       05943000
         SPACE 1                                                        05944000
* UPDATE TTR BY TWO AND STOW AGAIN FOR NULL MEMBERS                     05945000
         STOW  STOWDCB,DIRNAME,D                                        05946000
         LA    R1,L833                                                  05947000
         LTR   R15,R15                                                  05948000
         BP    EXIT8M                                                   05949000
         SPACE 1                                                        05950000
         ICM   R1,B'0111',#FIXTTRO                 HIGHEST OUTPUT TTR   05951000
         LA    R1,2(,R1)                                                05952000
         STCM  R1,B'0111',DCBRELAD-IHADCB+STOWDCB  HIGHEST OUTPUT TTR+2 05953000
         STOW  STOWDCB,DIRNAME,A                                        05954000
         LA    R1,L832                                                  05955000
         LTR   R15,R15                                                  05956000
         BP    EXIT8M                                                   05957000
         SPACE 1                                                        05958000
         SR    R1,R1                               YES, CHANGE THE TTR  05959000
         ICM   R1,B'0111',DCBRELAD-IHADCB+STOWDCB  TTR OF LAST EOF      05960000
         S     R1,=F'1'                            TTR OF NULL DATA     05961000
         STCM  R1,B'0111',DIRTTR                   TTR OF NULL DATA     05962000
         STCM  R1,B'0111',#FIXTTRO                 HIGHEST OUTPUT TTR   05963000
         SPACE 2                                                        05964000
EXPAND62 TM    DIRFLAG,DIRALIAS        ALIAS (WITH NO MAIN)?            05965000
         BNO   EXPAND70                NO, BRANCH                       05966000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   05967000
         XI    DIRFLAG,DIRALIAS        TEMPORARILY TURN OFF ALIAS BIT   05968000
         STOW  STOWDCB,DIRNAME,R       REPLACE THIS MEMBER ENTRY        05969000
         OI    DIRFLAG,DIRALIAS        RESET THE ALIAS BIT              05970000
         SPACE 1                                                        05971000
         B     *+4(R15)                PROCESS RETURN CODE              05972000
         B     EXPAND70                  00 - REPLACED                  05973000
         EX    0,*                       04 - SHOULD NOT OCCUR          05974000
         EX    0,*                       08 - SHOULD NOT OCCUR          05975000
         B     FULLDIR                   12 - DIRECTORY FULL            05976000
         B     IOERROR                   16 - I/O ERROR                 05977000
         SPACE 3                                                        05978000
*  UPDATE THIS MEMBER AND ALL OF ITS ALIASES                            05979000
EXPAND70 LA    R2,#MEMPTR                                               05980000
         LR    R4,R3                                                    05981000
         SPACE 1                                                        05982000
EXPAND72 MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR-DIRLINK(R4)  TTR       05983000
         STOW  STOWDCB,4(R4),R         REPLACE THIS MEMBER ENTRY        05984000
         SPACE 1                                                        05985000
         B     *+4(R15)                PROCESS RETURN CODE              05986000
         B     EXPAND74                  00 - REPLACED                  05987000
         EX    0,*                       04 - SHOULD NOT OCCUR          05988000
         EX    0,*                       08 - SHOULD NOT OCCUR          05989000
         B     FULLDIR                   12 - DIRECTORY FULL            05990000
         B     IOERROR                   16 - I/O ERROR                 05991000
         SPACE 1                                                        05992000
EXPAND74 ICM   R2,B'0111',1(R2)               NEXT MEMBER ENTRY         05993000
         BZ    EXPAND22                       END OF LIST, BRANCH       05994000
         CLC   #FINDTTR(3),DIRTTR-DIRLINK(R2) THIS TTR TOO?             05995000
         BNE   EXPAND74                       NO, BRANCH                05996000
         CR    R2,R3                          SAME ENTRY?               05997000
         BE    EXPAND74                       YES, BRANCH               05998000
         LR    R4,R2                                                    05999000
         NI    DIRLINK-DIRLINK(R2),FF-X'80'   DO NOT MOVE THIS MEMBER   06000000
         MVC   DIRTTR-DIRLINK(3,R2),DIRTTR    NEW PRIMARY TTR           06001000
         LA    R14,DIRSTART-DIRLINK(,R2)      FIRST ALIAS USER TTR      06002000
         LA    R15,DIRSTART                   FIRST MOVED USER TTR      06003000
         LA    R5,X'01'                       MASK BIT                  06004000
         LA    R6,3                           LOOP CONTROL              06005000
         SPACE 1                                                        06006000
         TM    DIRLINK-DIRLINK(R2),*-*        <<EXECUTED>>              06007000
EXPAND76 EX    R5,*-4                         A TTR AT THIS ENTRY?      06008000
         BNO   EXPAND72                       NO, BRANCH                06009000
         MVC   0(3,R14),0(R15)                YES, UPDATE THE TTR ENTRY 06010000
         LA    R14,4(,R14)                    NEXT ALIAS TTR            06011000
         LA    R15,4(,R15)                    NEXT MOVED TTR            06012000
         SLL   R5,1                           NEXT MASK BIT             06013000
         BCT   R6,EXPAND76                                              06014000
         B     EXPAND72                                                 06015000
         DROP  R3                                                       06016000
         SPACE 3                                                        06017000
*  WRITE THE ADDED DIRECTORY RECORDS                                    06018000
EXPAND80 L     R6,#NEWDIR                     DIRECTORY BLOCKS TO ADD   06019000
         LA    R0,CCW1                        FIRST CCW                 06020000
         ST    R0,IOBCCW                               TO USE           06021000
         MVI   CCW3,X'1D'                     COMMAND FOR WRITE C,K,D   06022000
         LA    R0,MSGTEXT1+3                  STORAGE FOR               06023000
         STCM  R0,B'0111',CCW3+1                         WRITE ADDRESS  06024000
         NI    CCW3+4,FF-X'40'                LAST CCW IN CHAIN         06025000
         MVC   CCW3+6(2),=H'8'                DATA LENGTH IS EIGHT      06026000
         XC    MSGTEXT1(20),MSGTEXT1          CLEAR THE WRITE ADDRESS   06027000
         MVI   MSGTEXT1+8,8                   KEY IS EIGHT BYTES        06028000
         MVI   MSGTEXT1+9,1                   DATA IS 1*256 BYTES       06029000
         MVI   OPENLIST,X'80'                                           06030000
         CLOSE (INDCB),MF=(E,OPENLIST)                                  06031000
         OPEN  (INDCB,UPDAT),MF=(E,OPENLIST)                            06032000
         SPACE 2                                                        06033000
EXPAND82 L     R0,#EOF1TTR                    POINT TO LAST RECORD      06034000
         STM   R15,R12,12+4(R13)              CONVERT TTR TO MBBCCHHR   06035000
         L     R1,INDCB+(DCBDEBAD-IHADCB)     DEB ADDRESS               06036000
         LA    R2,MSGTEXT1                    RETURN CCHHR              06037000
         L     R15,ADDRCNVT                   TTR TO MBBCCHHR CONVERT   06038000
         LR    R3,R13                         SAVE AREA ADDRESS         06039000
         BALR  R14,R15                                                  06040000
         LR    R13,R3                         SAVE AREA ADDRESS         06041000
         LM    R15,R12,12+4(R13)              RESTORE REGISTERS         06042000
         MVC   IOBSEEK(8),MSGTEXT1                                      06043000
         SR    R1,R1                                                    06044000
         IC    R1,IOBSEEK+7                                             06045000
         S     R1,=F'1'                       REDUCE INITIAL TTR        06046000
         STC   R1,IOBSEEK+7                                             06047000
         MVI   IOECB,0                                                  06048000
         EXCP  IOB                            WRITE THIS RECORD         06049000
         WAIT  ECB=IOECB                      WAIT FOR I/O COMPLETION   06050000
         LA    R1,L836                        I/O ERROR IN DIRECTORY    06051000
         CLI   IOECB,X'7F'                    SUCCESSFUL WRITE?         06052000
         BNE   EXIT8M                         NO, ERROR                 06053000
         SR    R1,R1                                                    06054000
         IC    R1,#EOF1TTR+2                  INCREMENT                 06055000
         A     R1,=F'1'                                R OF             06056000
         STC   R1,#EOF1TTR+2                               TTR          06057000
         C     R1,#DIRBTRK                    FIT ON THIS TRACK?        06058000
         BNH   EXPAND84                       YES, BRANCH               06059000
         LH    R1,#EOF1TTR                    INCREMENT                 06060000
         A     R1,=F'1'                                TT OF            06061000
         STH   R1,#EOF1TTR                                  TTR         06062000
         MVI   #EOF1TTR+2,1                   RESET R OF TTR            06063000
         SPACE 1                                                        06064000
EXPAND84 S     R6,=F'1'                       MORE BLOCKS?              06065000
         BP    EXPAND82                       YES, BRANCH               06066000
         SPACE 2                                                        06067000
*  WRITE THE DATA SET END-OF-FILE MARKER                                06068000
         OC    MSGTEXT1+8(3),MSGTEXT1+8       END-OF-FILE WRITTEN?      06069000
         BZ    FIXDCB                         YES, BRANCH               06070000
         XC    MSGTEXT1+8(3),MSGTEXT1+8       SET KEY, DATA LENGTH TO 0 06071000
         B     EXPAND82                       ONE MORE LOOP             06072000
         SPACE 3                                                        06073000
FIXRES   BAL   R2,CLOSEIT                        CLOSE INPUT DATA SET   06074000
         LA    R0,CHANGE2                        ABEND RECOVERY ADDRESS 06075000
         ST    R0,RECOVER                                               06076000
         MVC   BAMDCB(LDIRDCB),DIRDCB            COPY PROTTYPE DCB      06077000
         MVC   DCBDDNAM-IHADCB+BAMDCB,DDNAME     CURRENT DDNAME         06078000
         MVI   OPENLIST,X'80'                    END OF LIST MARKER     06079000
         OPEN  (BAMDCB,(OUTPUT)),MF=(E,OPENLIST)                        06080000
         TM    DCBOFLGS-IHADCB+BAMDCB,X'10'  DIRECTORY OPEN?            06081000
         BNO   EXIT12O                       NO, QUIT                   06082000
         MVC   MSGTEXT1(18),KEYDATA          MOVE IN THE KEY AND DATA   06083000
         XC    MSGTEXT1+18(256),MSGTEXT1+18  FOLLOWED BY ZEROES         06084000
         SPACE 1                                                        06085000
FIXRES30 WRITE FIXPDSD,SF,BAMDCB,MSGTEXT1,'S',MF=E                      06086000
         CHECK FIXPDSD                 CHECK THIS OUTPUT OPERATION      06087000
         XC    MSGTEXT1(18),MSGTEXT1   ZERO THE KEY AND DATA PORTION    06088000
         S     R4,=F'1'                SUFFICIENT BLOCKS WRITTEN?       06089000
         BP    FIXRES30                NO, BRANCH                       06090000
         CLOSE (BAMDCB),MF=(E,OPENLIST)                                 06091000
         SPACE 3                                                        06092000
         MVI   OPENLIST,X'80'          END OF LIST MARKER               06093000
         MVC   STOWDCB(LSAMDCB),SAMDCB                                  06094000
         MVC   DCBDDNAM-IHADCB+STOWDCB,DDNAME                           06095000
         MVI   ##ADRCM#,FIXOPEN        MARK FOR DCB OPEN EXIT USE       06096000
         SPACE 2                                                        06097000
         OPEN  (STOWDCB,(OUTPUT)),MF=(E,OPENLIST)                       06098000
         TM    DCBOFLGS-IHADCB+STOWDCB,X'10'  OUT OPEN?                 06099000
         BNO   EXIT12O                        NO, QUIT                  06100000
         SPACE 1                                                        06101000
         STOW  STOWDCB,#DIRFIX,A       ADD A NULL MEMBER                06102000
         LA    R1,L832                 NOT ADDED MESSAGE                06103000
         LTR   R15,R15                 ADDED?                           06104000
         BP    EXIT8M                  NO, QUIT                         06105000
         STOW  STOWDCB,#DIRFIX,D       DELETE THE DUMMY MEMBER          06106000
         LA    R1,L833                 NOT DELETED MESSAGE              06107000
         LTR   R15,R15                 DELETED?                         06108000
         BP    EXIT8M                  NO, QUIT                         06109000
         B     FIXDCB20                YES, CLOSE AND END               06110000
         SPACE 3                                                        06111000
FIXDCB   BAL   R2,CLOSEIT              CLOSE THE INPUT DCB              06112000
         TM    DSORG,DS1DSGPO          PARTITIONED DATA SET?            06113000
         BO    FIXDCB10                YES, BRANCH                      06114000
         LA    R0,RESTART0             ABEND RECOVERY ADDRESS           06115000
         ST    R0,RECOVER                                               06116000
         BAL   R2,DEALLDCB             FREE THE DATA SET                06117000
         MVI   DSPALLOC,CONOMOD        ASSUME MOD -- NO CHANGE          06118000
         CLI   #FIXOPT,X'03'           CORRECT?                         06119000
         BNE   *+8                     NO, BRANCH                       06120000
         MVI   DSPALLOC,CONOOLD        YES, OPEN FOR RESET PROCESSING   06121000
         MVI   ##ADRCM#,EDITOR         NO REPEATED WARNING MESSAGE      06122000
         L     R15,=A(ALLOCATE)        ALLOCATION ROUTINE               06123000
         BALR  R14,R15                 GOOD ALLOCATION?                 06124000
         B     RESTART0                NO, ERROR                        06125000
         SPACE 1                                                        06126000
         L     R8,##ADRCMD             REESTABLISH THE BASE REGISTER    06127000
         CLI   DSPALLOC,CONOSHR        REQUESTED ALLOCATION?            06128000
         BE    RESTART2                NO, OLD ALLOCATION FAILED        06129000
         SPACE 1                                                        06130000
         LA    R0,CHANGE2              ABEND RECOVERY ADDRESS           06131000
         ST    R0,RECOVER                                               06132000
         MVI   OPENLIST,X'80'          END OF LIST MARKER               06133000
         MVC   STOWDCB(LSAMDCB),SAMDCB                                  06134000
         MVI   DCBDSORG-IHADCB+STOWDCB,DS1DSGPS  SET FOR SEQUENTIAL     06135000
         MVC   DCBDDNAM-IHADCB+STOWDCB,DDNAME                           06136000
         MVI   ##ADRCM#,FIXOPEN                  MARK FOR DCB OPEN EXIT 06137000
         SPACE 1                                                        06138000
         OPEN  (STOWDCB,(OUTPUT)),MF=(E,OPENLIST)                       06139000
         TM    DCBOFLGS-IHADCB+STOWDCB,X'10'  OUT OPEN?                 06140000
         BNO   EXIT12O                        NO, QUIT                  06141000
         B     FIXDCB20                                                 06142000
         SPACE 1                                                        06143000
FIXDCB10 LA    R0,CHANGE2              ABEND RECOVERY ADDRESS           06144000
         ST    R0,RECOVER                                               06145000
         MVI   OPENLIST,X'80'          END OF LIST MARKER               06146000
         MVC   STOWDCB(LSAMDCB),SAMDCB                                  06147000
         MVC   DCBDDNAM-IHADCB+STOWDCB,DDNAME                           06148000
         MVI   ##ADRCM#,FIXOPEN                  MARK FOR DCB OPEN EXIT 06149000
         SPACE 1                                                        06150000
         OPEN  (STOWDCB,(OUTPUT)),MF=(E,OPENLIST)                       06151000
         BAL   R6,RESERVE                                               06152000
         TM    DCBOFLGS-IHADCB+STOWDCB,X'10'  OUT OPEN?                 06153000
         BNO   EXIT12O                        NO, QUIT                  06154000
         SPACE 2                                                        06155000
FIXDCB20 CLI   #FIXOPT2,4                      MAXSPACE?                06156000
         BNE   FIXDCB30                        NO, BRANCH               06157000
         L     R1,DCBDEBAD-IHADCB+STOWDCB      GET DEB ADDRESS          06158000
         LH    R14,NUMEXT                      NUMBER OF EXTENTS        06159000
         SR    R0,R0                                                    06160000
         AH    R0,32+14(,R1)                   ADD TRACKS IN EXTENT     06161000
         LA    R1,16(,R1)                      NEXT EXTENT              06162000
         BCT   R14,*-8                         BRANCH FOR ALL EXTENTS   06163000
         S     R0,=F'1'                        MAX 00TT OF TTR VALID?   06164000
         BM    FIXDCB30                        NO, BRANCH               06165000
         SLL   R0,8                            0TTX                     06166000
         A     R0,=F'1'                        0TT1 (R OF TTR IS 1)     06167000
         SLL   R0,8                            TT10 -- NEW DS1LSTAR     06168000
         STM   R14,R12,12(R13)                 SAVE REGISTERS           06169000
         L     R1,DCBDEBAD-IHADCB+STOWDCB      DEB ADDRESS              06170000
         LA    R2,DCBFDAD-IHADCB+STOWDCB       RETURN ADDRESS           06171000
         L     R15,ADDRCNVT                    CONVERSION ROUTINE       06172000
         LR    R3,R13                          SAVE R13                 06173000
         BALR  R14,R15                                                  06174000
         LR    R13,R3                          RESTORE R13              06175000
         LM    R14,R12,12(R13)                 RESTORE REGISTERS        06176000
         XC    DCBTRBAL-IHADCB+STOWDCB(2),DCBTRBAL-IHADCB+STOWDCB       06177000
         SPACE 2                                                        06178000
FIXDCB30 CLOSE (STOWDCB),MF=(E,OPENLIST)                                06179000
         MESSAGE MSGBLANK              ONE SPACING LINE                 06180000
         L     R1,$DSN+8               ALLOCATION STATUS ROUTINE        06181000
         ST    R1,##ADRCMD             EXECUTED AFTER OPEN OF DATA SET  06182000
         MVI   ##ADRCM#,CONTINUE+EDITOR  CONTINUE AND NO WARNING        06183000
         CLI   #FIXOPT2,0              RELEASE/RELSAVE/RELEXT/MAXSPACE? 06184000
         BE    FIXDCB90                NO, BRANCH                       06185000
         CLI   #FIXOPT2,4              MAXSPACE?                        06186000
         BE    FIXDCB90                YES, BRANCH                      06187000
         MVC   MSGTEXT1+4(8),##SUBCAL  RELEASE COMMAND NAME             06188000
         MVI   MSGTEXT1+12,X'40'       ADD A BLANK                      06189000
         MVI   MSGTEXT1+13,C''''       ADD A QUOTE                      06190000
         MVC   MSGTEXT1+14(44),DSNAME  ADD THE DSNAME                   06191000
         LH    R15,DSNLEN              LENGTH OF DSNAME                 06192000
         LA    R3,MSGTEXT1+14(R15)     WHERE ADDITIONAL TEXT STARTS     06193000
         MVC   0(12,R3),MSGBL132+4     BLANK IT FIRST                   06194000
         MVI   0(R3),C''''             ADD A FINAL QUOTE                06195000
         LA    R4,14+12(,R15)          LENGTH OF COMMAND BUFFER         06196000
         SLL   R4,16                                                    06197000
         ST    R4,MSGTEXT1             UPDATE LENGTH FIELD              06198000
         SPACE 1                                                        06199000
         CLI   #FIXOPT2,1              RELEASE ALL?                     06200000
         BE    FIXDCB80                YES, BRANCH                      06201000
         MVC   2(3,R3),=C'EXT'         ADD EXT FOR EXTENTS              06202000
         CLI   #FIXOPT2,3              RELEASE EXTENTS ONLY?            06203000
         BE    FIXDCB80                YES, BRANCH                      06204000
         MVC   2(4,R3),=C'SPA('        ADD SPA( FOR SPACE(              06205000
         L     R1,#FIXRES              TRACKS TO RESERVE                06206000
         CVD   R1,DOUBLE                                                06207000
         OI    DOUBLE+7,X'0F'          CONVERT SIGN                     06208000
         UNPK  2+4(5,R3),DOUBLE+5(3)   CONVERT TO PRINTABLE             06209000
         MVI   2+4+5(R3),C')'          ENDING )                         06210000
         SPACE 1                                                        06211000
FIXDCB80 LA    R1,MSGTEXT1             START OF COMMAND BUFFER          06212000
         ST    R1,ADDRTEXT             COMMAND ADDRESS                  06213000
         MVI   3(R1),9                 OFFSET TO OPERANDS               06214000
         LA    R1,ADDRTEXT             COMMAND ADDRESS                  06215000
         LA    R3,##SUBCAL             RELEASE COMMAND PROCESSOR        06216000
         BAL   R2,ATTACH               CALL THE COMMAND                 06217000
         SPACE 2                                                        06218000
FIXDCB90 BAL   R2,DEALLDCB             FREE THE DATA SET                06219000
         B     RESTART0                REALLOCATE AND START OVER        06220000
         TITLE 'P D S  --  PDS HELP                            1/15/85' 06221000
*********************************************************************** 06222000
***      HELP  SUBCOMMAND      ADDED BY BRUCE LELAND -- JAN, 1980   *** 06223000
*********************************************************************** 06224000
*                                                                       06225000
         SPACE 2                                                        06226000
HELP     CSECT                                                          06227000
         USING *,R8                                                     06228000
         MVC   DDNAMEH,DDNAME        SAVE ACTUAL DDNAME                 06229000
         MVC   DDNAME,SYSHELP        DDNAME TO FREE                     06230000
         BAL   R2,DEALLOCZ           FORCE A FREE OF SYSHELP            06231000
         MVC   DDNAME,DDNAMEH        RESTORE ACTUAL DDNAME              06232000
         L     R14,ADDRECT                                              06233000
         MVC   ECTSCMD-ECT(8,R14),=CL8'HELP' SET PDS SUBCOMMAND NAME    06234000
         AIF ('&CISP' EQ 'NO SPF').MA00600                         @D01
         TM    SPFLAG0,SPFDON           ISPMODE ACTIVE?                 06235000
         BNO   *+8                      NO, BRANCH                      06236000
         MVI   ECTSCMD-ECT+4(R14),C'X'  YES, HELPX (FOR NO LINE MODE)   06237000
.MA00600 ANOP  ,                                                   @D01
         L     R2,ADDRCBUF           INPUT BUFFER ADDRESS               06238000
         L     R1,ADDRCPPL                                              06239000
         USING CPPL,R1               ACTUAL ADDRESS                     06240000
         ST    R2,CPPLCBUF           SET COMMAND ADDRESS                06241000
         DROP  R1                                                       06242000
         LA    R3,##SUBCAL           TSO HELP COMMAND                   06243000
         BAL   R2,ATTACH             GO ATTACH IT                       06244000
         B     NEWSTAX               NEXT COMMAND                       06245000
         SPACE 2                                                        06246000
*  NOTE: THE SYSHELP FILE IS FREED BEFORE THE HELP                      06247000
*        CALL IN CASE A PCF EXIT ALREADY REQUESTED HELP.                06248000
         TITLE 'P D S  --  PDS HISTORY                         1/15/85' 06249000
*********************************************************************** 06250000
***      HISTORY SUBCOMMAND                                         *** 06251000
*********************************************************************** 06252000
*                                                                       06253000
         SPACE 1                                                        06254000
HISTORY  CSECT                                                          06255000
         USING *,R8                                                     06256000
         LA    R1,L530             ASSUME A NON-PARTITIONED DATA SET    06257000
         TM    DSORG,DS1DSGPO      CORRECT?                             06258000
         BZ    MSGNEW              YES, BRANCH                          06259000
         SPACE 1                                                        06260000
         TM    FLAGSCC,RECFMU      LOAD MODULE LIBRARY?                 06261000
         BO    HIST020             YES, BRANCH                          06262000
         SPACE 1                                                        06263000
         MVC   INSERT#1(72),SPFSTATH                                    06264000
         MVI   MTHIGHL,72                                               06265000
         TM    FLAGSAA,FHEAD       HEADER WRITTEN YET?                  06266000
         BO    HIST000             YES, BRANCH                          06267000
         TSMSG L230$1                                                   06268000
         OI    FLAGSAA,FHEAD       NOW IT HAS BEEN WRITTEN              06269000
         SPACE 1                                                        06270000
HIST000  MVC   INSERT#1(72),MSGBL132+4                                  06271000
         MVC   INSERT#1+1(8),DIRNAME                                    06272000
         TM    DIRFLAG,X'80'           ALIAS MEMBER?                    06273000
         BNO   *+10                    NO, BRANCH                       06274000
         MVC   INSERT#1+1+8(2),=C'-A'  YES, ADD A FLAG                  06275000
         LA    R2,DIRUSER          LOAD START OF USER AREA (FOR SSI)    06276000
         TM    DIRFLAG,X'0F'       SPF STATISTICS PRESENT?              06277000
         BNO   HIST010             NO, BRANCH                           06278000
         OC    DIRSPFZ(3),DIRSPFZ  RESERVED AND 00 OF 00YYDDDF ZEROS?   06279000
         BNZ   HIST010             NO, BRANCH                           06280000
         CLI   DIRSPFCD,0          00 OF OTHER 00YYDDDF ZERO?           06281000
         BNZ   HIST010             NO, BRANCH                           06282000
         SPACE 1                                                        06283000
         LA    R2,INSERT#1-7                                            06284000
         SR    R1,R1                                                    06285000
         IC    R1,DIRSPFR          REVISION NUMBER FIRST                06286000
         CVD   R1,DOUBLE                                                06287000
         MVC   21(4,R2),=X'40212020'                                    06288000
         ED    21(4,R2),DOUBLE+6                                        06289000
         MVI   22(R2),C'.'                                              06290000
         IC    R1,DIRSPFV          VERSION NUMBER                       06291000
         CVD   R1,DOUBLE                                                06292000
         MVC   18(4,R2),=X'40212020'                                    06293000
         ED    18(4,R2),DOUBLE+6                                        06294000
         LA    R1,DIRSPFCR+1           POINT TO YYDDDF                  06295000
         LA    R15,FULLWORD+1                                           06296000
         BAL   R14,CONVDATE            CONVERT TO MMDDYY FORMAT         06297000
         MVC   FULLWORD(1),FULLWORD+3  CONVERT TO YYMMDD                06298000
         MVC   26(L'DATEMASK,R2),DATEMASK                               06299000
         ED    26(L'DATEMASK,R2),FULLWORD                               06300000
         LA    R1,DIRSPFCD+1           POINT TO YYDDDF                  06301000
         LA    R15,FULLWORD+1                                           06302000
         BAL   R14,CONVDATE            CONVERT TO MMDDYY FORMAT         06303000
         MVC   FULLWORD(1),FULLWORD+3  CONVERT TO YYMMDD                06304000
         MVC   36(L'DATEMASK,R2),DATEMASK                               06305000
         ED    36(L'DATEMASK,R2),FULLWORD                               06306000
         MVC   45(6,R2),=X'4021207A2020'                                06307000
         ED    45(6,R2),DIRSPFCT       TIME OF LAST CHANGE              06308000
         LH    R1,DIRSPFSI                                              06309000
         CVD   R1,DOUBLE                                                06310000
         MVC   51(6,R2),=X'402020202120'                                06311000
         ED    51(6,R2),DOUBLE+5                                        06312000
         SPACE 1                                                        06313000
         LH    R1,DIRSPFIN                                              06314000
         CVD   R1,DOUBLE                                                06315000
         MVC   57(6,R2),=X'402020202120'                                06316000
         ED    57(6,R2),DOUBLE+5                                        06317000
         LH    R1,DIRSPFMD                                              06318000
         CVD   R1,DOUBLE                                                06319000
         MVC   63(6,R2),=X'402020202120'                                06320000
         ED    63(6,R2),DOUBLE+5                                        06321000
         MVC   71(8,R2),DIRSPFID                                        06322000
         LA    R1,L230$1                                                06323000
         B     MSGNEW                  NO SSI FOR SPF-SAVED MEMBERS     06324000
         SPACE 1                                                        06325000
HIST010  LA    R1,L230$1                                                06326000
         CLC   ZERO,0(R2)              ZERO?                            06327000
         BE    MSGNEW                  YES, NO SSI                      06328000
         CLC   =F'-1',0(R2)            FFFFFFFF?                        06329000
         BE    MSGNEW                  YES, NO SSI                      06330000
         SPACE 1                                                        06331000
         MVC   INSERT#1+2+8+3(4),=C'SSI:'                               06332000
         UNPK  INSERT#1+2+8+3+5(9),0(5,R2)                              06333000
         TR    INSERT#1+2+8+3+5(8),TRTABLE                              06334000
         MVI   INSERT#1+2+8+3+5+8,X'40'                                 06335000
         B     MSGNEW                                                   06336000
         SPACE 3                                                        06337000
HIST020  OC    #ZAPOPT(4),#ZAPOPT      ANY ZAP, USER, TRAN OR LKED?     06338000
         BNZ   *+10                    YES, BRANCH                      06339000
         OC    #ZAPOPT(4),=X'01010101' NO, DEFAULT TO DO THEM ALL       06340000
         TM    FLAGSGG,FTRANCON          TRANSLATOR DATA OFF?      @D05
         BZ    HIST021                   NO, BRANCH                @D05
         MVI   #TRANOPT,X'02'            YES, NO TRANSLATOR DATA   @D05
         SPACE 1                                                        06341000
HIST021  DS    0H                                                  @D05
         L     R15,=A(READESD)     FORMAT THE ESD DATA                  06342000
         BALR  R14,R15             ANY ESD DATA?                        06343000
         NOP   0                   NO, CONTINUE ANYWAY                  06344000
         SPACE 2                                                        06345000
         L     R15,=A(READIDR)     FORMAT THE IDR DATA                  06346000
         BALR  R14,R15             IS IDR DATA AVAILABLE?               06347000
         B     NOHIST              NO, MESSAGE AND QUIT                 06348000
         B     HISTTRN$            YES, CONTINUE                        06349000
         SPACE 1                                                        06350000
NOHIST   SR    R6,R6                                                    06351000
         BAL   R4,HISTHDR                                               06352000
         LA    R1,L460             NO HISTORY AVAILABLE                 06353000
         B     MSGNEW                                                   06354000
         SPACE 3                                                        06355000
HISTHDR  TM    FLAGSAA,FINDMSG     NEED A GROUP HEADER?                 06356000
         BNO   HISTHDR2            NO, BRANCH                           06357000
         NI    FLAGSAA,FF-FINDMSG                                       06358000
         MESSAGE MSGBLANK                                               06359000
         MESSAGE FINDMEMQ                                               06360000
HISTHDR2 TM    FLAGSCC,F1IDR       FIRST IDR RECORD?                    06361000
         BZR   R4                  NO, RETURN                           06362000
         NI    FLAGSCC,FF-F1IDR                                         06363000
         LTR   R1,R6               ANY SECOND HEADER?                   06364000
         BZR   R4                  NO, RETURN                           06365000
         TSMSG (R1)                INDIVIDUAL HISTORY TITLE             06366000
         BR    R4                                                       06367000
         EJECT                                                          06368000
*                                                                       06369000
*        FORMAT TRANSLATOR IDR DATA ENTRIES                             06370000
*                                                                       06371000
HISTTRN$ LA    R3,#IDRPTR          SCAN IDR CHAIN                       06372000
         USING IDRENTRY,R3                                              06373000
         OI    FLAGSCC,F1IDR                                            06374000
         CLI   #TRANOPT,X'02'      NO TRANSLATOR DATA?             @D05
         BE    HISTZAP$            YES, BRANCH                     @D05
         SPACE 2                                                        06375000
HISTTRN  ICM   R3,B'1111',IDRLINK  END OF ESD CHAIN?                    06376000
         BZ    HISTZAP$            YES, BRANCH                          06377000
         CLI   IDRTYPE,IDRTRAN     TRANSLATOR ENTRY?                    06378000
         BNE   HISTTRN             NO, BRANCH                           06379000
         SPACE 2                                                        06380000
         LA    R2,#ESDPTR          START OF ESD CHAIN                   06381000
         USING ESDENTRY,R2                                              06382000
HISTTRN1 ICM   R2,B'1111',ESDLINK  END OF ESD CHAIN?                    06383000
         BZ    HISTTRN             YES, BRANCH                          06384000
         CLI   ESDTYPE,CODESD      CSECT ENTRY?                         06385000
         BNE   HISTTRN1            NO, SKIP THIS                        06386000
         CLC   ESDID,IDRESDID      REQUESTED IDR RECORD?                06387000
         BNE   HISTTRN1            NO, BRANCH                           06388000
         SPACE 1                                                        06389000
         LA    R6,L060                                                  06390000
         BAL   R4,HISTHDR                                               06391000
         MVC   MSGTEXT1(136),MSGBL132                                   06392000
         SPACE 1                                                        06393000
         MVC   MSGTEXT1+4(8),ESDNAME                                    06394000
         MVC   MSGTEXT1+12(9),DATEMASK                                  06395000
         ED    MSGTEXT1+12(9),IDRDATE                                   06396000
         MVC   MSGTEXT1+24(10),IDRTDATA   TRANSLATOR 1                  06397000
         UNPK  DOUBLE(5),IDRTDATA+10(3)   VVMM PACKED                   06398000
         MVI   MSGTEXT1+36,C'V'                                         06399000
         MVC   MSGTEXT1+36+1(2),DOUBLE    VV                            06400000
         MVI   MSGTEXT1+40,C'M'                                         06401000
         MVC   MSGTEXT1+40+1(2),DOUBLE+2  MM                            06402000
         CLI   IDRLDATA,15                TWO TRANSLATORS?              06403000
         BL    HISTTRN3                   NO, BRANCH                    06404000
         SPACE 1                                                        06405000
         OI    IDRTDATA+27+2,X'0F'        FIX THE SIGN FIELD            06406000
         LA    R15,FULLWORD               OUTPUT LOCATION               06407000
         LA    R1,IDRTDATA+27             SECOND YYDDD                  06408000
         BAL   R14,CONVDATE               CONVERT TO MMDDYY FORMAT      06409000
         MVC   MSGTEXT1+48(9),DATEMASK                                  06410000
         ED    MSGTEXT1+48(9),FULLWORD                                  06411000
         MVC   MSGTEXT1+60(10),IDRTDATA+15  TRANSLATOR 2                06412000
         UNPK  DOUBLE(5),IDRTDATA+25(3)     VVMM PACKED                 06413000
         MVI   MSGTEXT1+72,C'V'                                         06414000
         MVC   MSGTEXT1+72+1(2),DOUBLE      VV                          06415000
         MVI   MSGTEXT1+76,C'M'                                         06416000
         MVC   MSGTEXT1+76+1(2),DOUBLE+2    MM                          06417000
         SPACE 1                                                        06418000
HISTTRN3 MESSAGE MSGTEXT1                                               06419000
         B     HISTTRN1            NEXT IDR DATA RECORD THIS ESD ENTRY  06420000
         SPACE 3                                                        06421000
*                                                                       06422000
*        FORMAT AMASPZAP IDR DATA ENTRIES                               06423000
*                                                                       06424000
HISTZAP$ LA    R3,#IDRPTR          SCAN IDR CHAIN                       06425000
         USING IDRENTRY,R3                                              06426000
         OI    FLAGSCC,F1IDR                                            06427000
         SPACE 1                                                        06428000
HISTZAP  ICM   R3,B'1111',IDRLINK  END OF ESD CHAIN?                    06429000
         BZ    HISTUSR$            YES, BRANCH                          06430000
         CLI   IDRTYPE,IDRZAP      AMASPZAP ENTRY?                      06431000
         BNE   HISTZAP             NO, BRANCH                           06432000
         SPACE 1                                                        06433000
         LA    R2,#ESDPTR          START OF ESD CHAIN                   06434000
         USING ESDENTRY,R2                                              06435000
         SPACE 1                                                        06436000
HISTZAP1 ICM   R2,B'1111',ESDLINK  END OF ESD CHAIN?                    06437000
         BZ    HISTZAP             YES, BRANCH                          06438000
         SPACE 1                                                        06439000
         CLI   ESDTYPE,CODESD      CSECT ENTRY?                         06440000
         BNE   HISTZAP1            NO, SKIP THIS                        06441000
         SPACE 1                                                        06442000
         CLC   ESDID,IDRESDID      REQUESTED IDR RECORD?                06443000
         BNE   HISTZAP1            NO, BRANCH                           06444000
         SPACE 1                                                        06445000
         LA    R6,L061                                                  06446000
         BAL   R4,HISTHDR                                               06447000
         MVC   MSGTEXT1(136),MSGBL132                                   06448000
         SPACE 1                                                        06449000
         MVC   MSGTEXT1+4(L'ESDNAME),ESDNAME                            06450000
         MVC   MSGTEXT1+8+L'ESDNAME(L'DATEMASK),DATEMASK                06451000
         ED    MSGTEXT1+8+L'ESDNAME(L'DATEMASK),IDRDATE                 06452000
         MVC   MSGTEXT1+12+L'ESDNAME+L'DATEMASK(L'IDRZDATA),IDRZDATA    06453000
         MESSAGE MSGTEXT1                                               06454000
         B     HISTZAP1            NEXT IDR DATA RECORD THIS ESD ENTRY  06455000
         EJECT                                                          06456000
*                                                                       06457000
*        FORMAT THE USER-SUPPLIED IDR DATA RECORDS                      06458000
*                                                                       06459000
         SPACE 1                                                        06460000
HISTUSR$ LA    R3,#IDRPTR                                               06461000
         OI    FLAGSCC,F1IDR                                            06462000
         SPACE 1                                                        06463000
HISTUSR  ICM   R3,B'1111',IDRLINK  END OF IDR CHAIN?                    06464000
         BZ    HISTLKD$            YES, BRANCH                          06465000
         CLI   IDRTYPE,IDRUSER     USER IDR DATA RECORD?                06466000
         BNE   HISTUSR             NO, BRANCH                           06467000
         SPACE 1                                                        06468000
         LA    R2,#ESDPTR          ADDRESS OF ESD CHAIN                 06469000
         SPACE 1                                                        06470000
HISTUSR1 ICM   R2,B'1111',ESDLINK  END OF ESD CHAIN?                    06471000
         BZ    HISTUSR             YES, BRANCH                          06472000
         SPACE 1                                                        06473000
         CLI   ESDTYPE,CODESD      CSECT ENTRY?                         06474000
         BNE   HISTUSR1            NO, BRANCH                           06475000
         CLC   ESDID,IDRESDID      WANTED ESD RECORD?                   06476000
         BNE   HISTUSR1            NO, BRANCH                           06477000
         SPACE 1                                                        06478000
         LA    R6,L062                                                  06479000
         BAL   R4,HISTHDR                                               06480000
         MVC   MSGTEXT1(136),MSGBL132                                   06481000
         MVC   MSGTEXT1+4(L'ESDNAME),ESDNAME                            06482000
         MVC   MSGTEXT1+8+L'ESDNAME(L'DATEMASK),DATEMASK                06483000
         ED    MSGTEXT1+8+L'ESDNAME(L'DATEMASK),IDRDATE                 06484000
         SR    R1,R1                                                    06485000
         ICM   R1,B'0001',IDRLDATA ZERO BYTES?                          06486000
         BZ    HISTUSRS            YES, SKIP THE MOVE (LENGTH ZERO)     06487000
         SPACE 1                                                        06488000
         MVC   MSGTEXT1+12+L'ESDNAME+L'DATEMASK(*-*),IDRDATA  <<EXEC>>  06489000
         EX    R1,*-6                                                   06490000
         SPACE 1                                                        06491000
HISTUSRS MESSAGE MSGTEXT1                                               06492000
         B     HISTUSR1                                                 06493000
         DROP  R2,R3                                                    06494000
         EJECT                                                          06495000
*                                                                       06496000
*        FORMAT THE LINKAGE-EDITOR IDR DATA RECORD                      06497000
*                                                                       06498000
HISTLKD$ CLI   #LKEDOPT,X'01'           "LKED" REQUESTED?               06499000
         BNE   NEWCMD                   NO, BRANCH                      06500000
         SR    R1,R1                                                    06501000
         ICM   R1,B'0001',#LKEDLEN      ANY LKED NAME CHECK?            06502000
         BZ    HISTLKDG                 NO, BRANCH                      06503000
         BCTR  R1,0                     MACHINE LENGTH                  06504000
         CLC   #LKEDTXT(*-*),LKEDNAME   <<EXECUTED>>                    06505000
         EX    R1,*-6                   THIS LINKAGE EDITOR?            06506000
         BNE   NEWCMD                   NO, BRANCH                      06507000
HISTLKDG SR    R6,R6                                                    06508000
         BAL   R4,HISTHDR                                               06509000
         MVC   INSERT#1-1(9),DATEMASK                                   06510000
         ED    INSERT#1-1(9),LKEDDATE                                   06511000
         MVI   MTHIGHL+4,18                   LENGTH OF THIS INSERT     06512000
         MVC   INSERT#2(10),LKEDNAME                                    06513000
         MVC   INSERT#2+10(2),=C' V'                                    06514000
         UNPK  INSERT#2+10+2(3),LKEDVVMM(2)                             06515000
         MVC   INSERT#2+10+2+2(2),=C' M'                                06516000
         UNPK  INSERT#2+10+2+2+2(3),LKEDVVMM+1(2)                       06517000
         SPACE 1                                                        06518000
         TSMSG L064$2                         LINKAGE EDIT MESSAGE      06519000
         MVI   MTHIGHL+4,8                    LENGTH OF STANDARD INSERT 06520000
         B     NEWCMD                                                   06521000
         TITLE 'P D S  --  PDS HISTORY IDR SCAN SUBROUTINE     1/15/85' 06522000
*                                                                       06523000
*        IDR SCAN SUBROUTINE                                            06524000
*                                                                       06525000
         SPACE 3                                                        06526000
READIDR  STM   R14,R12,ESDIDRSV    SAVE REGISTERS                       06527000
         LR    R8,R15              BASE FOR THIS SUBROUTINE             06528000
         USING READIDR,R8                                               06529000
         NI    FLAGSCC,255-FIDR    IDR DATA DOES NOT EXIST YET          06530000
         LA    R6,IDRNORML         BRANCH ADDRESS IF NOT CONTINUED      06531000
         LA    R2,#IDRPTR          BASE FOR IDR LIST                    06532000
         USING IDRENTRY,R2                                              06533000
         MVC   STARTTR(3),DIRTTR   FIRST TTR                            06534000
         SPACE 2                                                        06535000
IDREXCP  L     R15,=A(EXCP)                                             06536000
         BALR  R14,R15                                                  06537000
         B     *+4(R15)            PROCESS RETURN CODE                  06538000
         B     IDREXCP1              00 - GOOD READ                     06539000
         B     LASTIDR               04 - END OF MEMBER                 06540000
         B     LASTIDR               08 - END OF DATA SET               06541000
         B     NEWCMD                12 - I/O ERROR                     06542000
         SPACE 1                                                        06543000
IDREXCP1 LR    R15,R0              START OF RECORD                      06544000
         TM    0(R15),X'50'        TEST SYM OR SCATTER RECORD?          06545000
         BM    IDREXCP             YES, SKIP IT                         06546000
         SPACE 1                                                        06547000
         CLI   0(R15),X'20'        CESD RECORD?                         06548000
         BE    IDREXCP             YES, SKIP                            06549000
         SPACE 1                                                        06550000
         CLI   0(R15),X'80'        IDR RECORD?                          06551000
         BNE   LASTIDR             NO, BRANCH                           06552000
         SPACE 1                                                        06553000
         LA    R3,3(,R15)          START OF IDR DATA                    06554000
         SR    R5,R5                                                    06555000
         IC    R5,1(,R15)          BYTE COUNT THIS RECORD               06556000
         LA    R5,0(R5,R15)        END OF BUFFER ADDRESS                06557000
         BR    R6                  BRANCH TO IDRNORML OR AS CONTINUED   06558000
         SPACE 2                                                        06559000
IDRNORML TM    2(R15),IDRLKED      LINKAGE EDITOR IDR RECORD?           06560000
         BO    LKEDIDR             YES, BRANCH                          06561000
         TM    2(R15),IDRTRAN      TRANSLATOR IDR RECORD?               06562000
         BO    TRANIDR             YES, BRANCH                          06563000
         TM    2(R15),IDRZAP       AMASPZAP IDR RECORD?                 06564000
         BO    ZAPIDR              YES, BRANCH                          06565000
         TM    2(R15),IDRUSER      USER-SUPPLIED IDR RECORD?            06566000
         BNO   NEXTIDR             NO, NEXT RECORD                      06567000
         EJECT                                                          06568000
*  USER-SUPPLIED IDR RECORDS:                                           06569000
* --  -- --+ --  --  --  -- -+ --  --  --  -- + --  --  --  --  -- ---* 06570000
*   0 - 1  |  2 - 4          |  5             |  6 - 6+COUNT          * 06571000
*   ESDID  |  IDENTIFY DATE  |  COUNT (0-40)  |  IDRDATA              * 06572000
* --  -- --+ --  --  --  -- -+ --  --  --  -- + --  --  --  --  -- ---* 06573000
         SPACE 1                                                        06574000
USERIDR  CLI   #USEROPT,0          "USER"?                              06575000
         BE    NEXTIDR             NO, BRANCH                           06576000
         BAL   R14,GETIDR          GET A NEW IDR RECORD                 06577000
         ST    R1,IDRLINK                                               06578000
         LR    R2,R1               ADDRESS OF NEW RECORD                06579000
         SPACE 2                                                        06580000
         LR    R4,R5                                                    06581000
         SR    R4,R3               MACHINE LENGTH MOVED                 06582000
         CH    R4,=H'5'            CONTINUED USER HEADER?               06583000
         BNL   USER20              NO, BRANCH                           06584000
         MVC   IDRUPREF(*-*),0(R3) <<EXECUTED>>                         06585000
         EX    R4,*-6              MOVE IN DATA                         06586000
         BAL   R6,IDRCONT          GET THE CONTINUED RECORD AND RETURN  06587000
         SPACE 1                                                        06588000
         LA    R14,IDRUPREF+1(R4)  TARGET OF MOVE                       06589000
         LA    R15,5-1(,R3)        LENGTH BYTE ADDRESS-1 IF NOT SPLIT   06590000
         SR    R15,R4              AMOUNT WE ALREADY HAVE               06591000
         SR    R1,R1                                                    06592000
         IC    R1,0(,R15)          LENGTH BYTE                          06593000
         LA    R15,6-2(,R1)        MACHINE LENGTH OF RECORD -1          06594000
         SR    R15,R4              MACHINE LENGTH TO MOVE               06595000
         MVC   0(*-*,R14),0(R3)    <<EXECUTED>>                         06596000
         EX    R15,*-6             MOVE IT INTO THE RECORD              06597000
         B     USER30                                                   06598000
         SPACE 2                                                        06599000
USER20   SR    R15,R15                                                  06600000
         IC    R15,5(,R3)          LENGTH OF USER DATA AREA             06601000
         LA    R15,5(,R15)         MACHINE LENGTH FOR MOVE              06602000
         MVC   IDRUPREF(*-*),0(R3) <<EXECUTED>>                         06603000
         EX    R15,*-6             MOVE IT INTO THE RECORD              06604000
         SPACE 1                                                        06605000
USER30   LA    R4,1(,R15)          ACTUAL RECORD LENGTH                 06606000
         MVI   IDRTYPE,IDRUSER     USER IDR DATA IDENTIFIER             06607000
         MVC   IDRESDID,IDRUPREF   ADD THE CSECT ID                     06608000
         LA    R1,IDRUPREF+2       YYDDD IDR RECORD CREATED             06609000
         LA    R15,IDRDATE                                              06610000
         BAL   R14,CONVDATE        CONVERT TO MMDDYY FORMAT             06611000
         SR    R15,R15                                                  06612000
         IC    R15,IDRUPREF+5      LENGTH OF USER DATA AREA             06613000
         BCTR  R15,0                                                    06614000
         STC   R15,IDRLDATA                                             06615000
         SPACE 2                                                        06616000
USER40   BXLE  R3,R4,USERIDR                                            06617000
         EJECT                                                          06618000
         SR    R3,R5                                                    06619000
         BCTR  R3,0                ACTUAL REMAINING LENGTH              06620000
         LTR   R4,R3               CONTINUED DATA PORTION?              06621000
         BNP   NEXTIDR             NO, BRANCH                           06622000
         BAL   R6,IDRCONT          GET THE CONTINUED RECORD AND RETURN  06623000
         SPACE 1                                                        06624000
         SR    R14,R14                                                  06625000
         IC    R14,IDRLDATA        ORIGINAL LENGTH -1                   06626000
         LA    R14,IDRDATA+1(R14)  END OF DATA                          06627000
         SR    R14,R4              START POSTION FOR MOVE               06628000
         BCTR  R4,0                MACHINE LENGTH FOR MOVE              06629000
         MVC   0(*-*,R14),0(R3)    <<EXECUTED>>                         06630000
         EX    R4,*-6              MOVE IN THE REMAINDER                06631000
         LA    R4,1(,R4)           ACTUAL LENGTH OF LAST PORTION        06632000
         B     USER40                                                   06633000
         SPACE 4                                                        06634000
*  AMASPZAP IDR RECORDS:                                                06635000
* --  -- -+ --  --  -- + --  --  --  --  --  --  --  --  --  --  -- --* 06636000
*  0 - 1  |  2 - 4     |  5 - 12                                      * 06637000
*  ESDID  |  ZAP DATE  |  IDRDATA OR USER IDENTIFICATION              * 06638000
* --  -- -+ --  --  -- + --  --  --  --  --  --  --  --  --  --  -- --* 06639000
         SPACE 1                                                        06640000
ZAPIDR   CLI   #ZAPOPT,X'01'       "ZAP"?                               06641000
         BNE   NEXTIDR             NO, BRANCH                           06642000
         SR    R4,R4                                                    06643000
         NI    0(R3),X'3F'                                              06644000
         IC    R4,0(R3)            GET COUNT OF AMASPZAP ENTRIES        06645000
         LA    R3,1(R3)                                                 06646000
         LA    R4,1(R4)            JUMP COUNT FOR LOOP                  06647000
         B     ZAPIDR1                                                  06648000
         SPACE 2                                                        06649000
ZAPIDR2  BAL   R14,GETIDR                                               06650000
         ST    R1,IDRLINK                                               06651000
         LR    R2,R1                                                    06652000
         MVC   IDRESDID,0(R3)      MOVE ESDID TO IDR RECORD             06653000
         LA    R1,2(R3)            ADDRESS OF DATE OF RECORD            06654000
         LA    R15,IDRDATE                                              06655000
         BAL   R14,CONVDATE        CONVERT TO MMDDYY FORMAT             06656000
         SPACE 1                                                        06657000
         MVC   IDRDATA,5(R3)       MOVE DATA TO IDR RECORD              06658000
         MVI   IDRLDATA,8          SET LENGTH FOR COMPATIBILITY         06659000
         MVI   IDRTYPE,IDRZAP      INDICATE AMASPZAP ENTRY              06660000
         LA    R3,13(R3)           JUMP DATA ADDRESS                    06661000
         SPACE 1                                                        06662000
ZAPIDR1  BCT   R4,ZAPIDR2          IF ANOTHER ENTRY THIS RECORD         06663000
         B     NEXTIDR             READ NEXT IDR RECORD                 06664000
         EJECT                                                          06665000
*  TRANSLATOR IDR RECORDS:                                              06666000
* --  -- + --  -- + --  --  --  -- ---+ --  --  --  --  --  --  -- +--- 06667000
*  0 - 1 |  2 - 3 |  N - N+1          |  0    (0 IS 1 TRANSLATOR)  |    06668000
*  ESDID |  ...   |  X'80'+LAST ESDID |  FLAG (1 IS 2 TRANSLATORS) |    06669000
* --  -- + --  -- + --  --  --  -- ---+ --  --  --  --  --  --  -- +--- 06670000
*                                                                       06671000
*   --  --  -- --+ --  -- ---+ --  --  -- -+ --  --  --  --  --  -- --* 06672000
*    1 - 10      |  11 - 12  |  13 -15     |  16 - 30                 * 06673000
*    TRANSLATOR  |  VVMM     |  TRANS DATE |  OPTIONAL, SAME AS 1-15  * 06674000
*   --  --  -- --+ --  -- ---+ --  --  -- -+ --  --  --  --  --  -- --* 06675000
         SPACE 1                                                        06676000
TRANIDR  CLI   #TRANOPT,X'01'      "TRAN"?                              06677000
         BNE   NEXTIDR             NO, BRANCH                           06678000
         LR    R4,R5                                                    06679000
         SR    R4,R3               MACHINE LENGTH OK?                   06680000
         BM    NEXTIDR             NO, DONE WITH THIS RECORD            06681000
         BAL   R14,GETIDR                                               06682000
         ST    R1,IDRLINK          CHAIN ON A                           06683000
         LR    R2,R1                         NEW IDR RECORD             06684000
         SPACE 1                                                        06685000
         MVI   IDRTYPE,IDRTRAN     TRANSLATOR TYPE RECORD               06686000
         LTR   R4,R4               MACHINE LENGTH OK?                   06687000
         BP    TRAN20              YES, NOT SPLIT                       06688000
         MVC   IDRESDID(1),0(R3)   NO, ONLY ONE ESDID BYTE              06689000
         BAL   R6,IDRCONT          GET THE CONTINUED RECORD AND RETURN  06690000
         SPACE 1                                                        06691000
         MVC   IDRESDID+1(1),0(R3) SECOND BYTE OF ESDID                 06692000
         BCTR  R3,0                BACK UP THE INPUT POINTER BY ONE     06693000
         B     TRAN30                                                   06694000
         SPACE 2                                                        06695000
TRAN20   MVC   IDRESDID(2),0(R3)   ESDID FIELD                          06696000
         SPACE 1                                                        06697000
TRAN30   MVC   IDRUPREF(2),IDRESDID  ORIGINAL ESDID                     06698000
         NI    IDRESDID,FF-X'80'   TURN OFF THE HIGH-ORDER BIT          06699000
         TM    IDRUPREF,X'80'      LAST ESDID?                          06700000
         BO    TRAN50              YES, BRANCH                          06701000
         LA    R4,2                ESDID WIDTH                          06702000
         BXLE  R3,R4,TRANIDR       CONTINUE FOR ALL ESDID'S             06703000
         B     NEXTIDR             GET THE NEXT RECORD                  06704000
         SPACE 1                                                        06705000
TRAN50   LA    R3,2(,R3)                                                06706000
         LR    R4,R5                                                    06707000
         SR    R4,R3               FLAG BYTE INPUT?                     06708000
         BNM   TRAN60              YES, BRANCH                          06709000
         BAL   R6,IDRCONT          GET THE CONTINUED RECORD AND RETURN  06710000
         SPACE 1                                                        06711000
TRAN60   LA    R1,14               ASSUME ONE TRANSLATOR                06712000
         CLI   0(R3),0             CORRECT?                             06713000
         BE    *+8                 YES, BRANCH                          06714000
         LA    R1,29               NO, TWO TRANSLATORS                  06715000
         MVC   IDRTDATA(30),1(R3)  MOVE IN THE MAXIMUM LENGTH           06716000
         STC   R1,IDRLDATA         MACHINE LENGTH                       06717000
         LA    R4,2(,R1)           ACTUAL SEGMENT LENGTH                06718000
TRAN70   BXLE  R3,R4,TRAN80                                             06719000
         EJECT                                                          06720000
         LR    R4,R3                                                    06721000
         SR    R4,R5               BYTES LEFT +1                        06722000
         S     R4,=F'1'            ANY ACTUAL REMAINING BYTES?          06723000
         BNP   TRAN80              NO, BRANCH                           06724000
         BAL   R6,IDRCONT          GET THE CONTINUED RECORD AND RETURN  06725000
         SPACE 1                                                        06726000
         SR    R14,R14                                                  06727000
         IC    R14,IDRLDATA        ORIGINAL LENGTH -1                   06728000
         LA    R14,IDRTDATA+1(R14) END OF DATA                          06729000
         SR    R14,R4              START POSTION FOR MOVE               06730000
         BCTR  R4,0                MACHINE LENGTH FOR MOVE              06731000
         MVC   0(*-*,R14),0(R3)    <<EXECUTED>>                         06732000
         EX    R4,*-6              MOVE IN THE REMAINDER                06733000
         LA    R3,1(R3,R4)         POSITION FOR THE NEXT SEGMENT        06734000
         SPACE 2                                                        06735000
TRAN80   LA    R1,IDRTDATA+12      ADDRESS OF CREATION YYDDD            06736000
         LA    R15,IDRDATE                                              06737000
         BAL   R14,CONVDATE        CONVERT TO MMDDYY FORMAT             06738000
         LA    R1,#IDRPTR          SCAN IDR CHAIN                       06739000
         SPACE 1                                                        06740000
TRAN90   ICM   R1,B'1111',IDRLINK-IDRENTRY(R1)                          06741000
         BZ    TRANIDR                        DONE, BRANCH              06742000
         CLI   IDRTYPE-IDRENTRY(R1),IDRTRAN   TRANSLATOR TYPE?          06743000
         BNE   TRAN90                         NO, BRANCH                06744000
         CLI   IDRDATE-IDRENTRY(R1),0         ANY DATE YET?             06745000
         BNE   TRAN90                         YES, BRANCH               06746000
         MVC   IDRDATE-IDRENTRY(3+6+1+30,R1),IDRDATE                    06747000
         B     TRAN90                                                   06748000
         DROP  R2                                                       06749000
         SPACE 3                                                        06750000
*  LINKAGE EDITOR IDR RECORDS:                                          06751000
* --  --  --  --  -- ---+ --  -- ---+ --  --  --  --  --  --  --  -- -* 06752000
*  0 - 9                |  10 - 11  |  12 - 14                        * 06753000
*  LINKAGE EDITOR NAME  |  VVMM     |  LINKAGE EDIT DATE              * 06754000
* --  --  --  --  -- ---+ --  -- ---+ --  --  --  --  --  --  --  -- -* 06755000
         SPACE 1                                                        06756000
LKEDIDR  OI    FLAGSCC,FIDR                                             06757000
         LA    R1,12(R3)           ADDRESS OF DATE                      06758000
         LA    R15,LKEDDATE                                             06759000
         BAL   R14,CONVDATE        CONVERT TO MMDDYY FORMAT             06760000
         MVC   LKEDNAME(10),0(R3)  LINKAGE EDITOR NAME                  06761000
         MVC   LKEDVVMM(2),10(R3)  VV.MM IN HEX                         06762000
         SPACE 2                                                        06763000
NEXTIDR  LA    R6,IDRNORML         NOT A CONTINUED RECORD               06764000
         SPACE 1                                                        06765000
IDRCONT  B     IDREXCP             CONTINUED RECORD                     06766000
         EJECT                                                          06767000
LASTIDR  MVC   RLDCOUNT(1),3(R15)    SAVE THE FIRST RLD/CONTROL AMOUNT  06768000
         OC    #ZAPLEN(3),#ZAPLEN    ANY IDR FILTERING?                 06769000
         BZ    LASTIDRZ              NO, BRANCH                         06770000
         SPACE 2                                                        06771000
         USING IDRENTRY,R3                                              06772000
         SR    R4,R4                                                    06773000
         LA    R3,#IDRPTR            SCAN IDR CHAIN                     06774000
IDRFIL10 LR    R2,R3                 PREVIOUS ENTRY                     06775000
         ICM   R3,B'0111',IDRLINK+1  CURRENT ENTRY?                     06776000
         BZ    LASTIDRZ              NO, BRANCH                         06777000
         ICM   R4,B'0111',IDRLINK+1  NEXT ENTRY                         06778000
         SPACE 2                                                        06779000
         SR    R15,R15               COMPARE STRING LENGTH              06780000
         CLI   IDRTYPE,IDRTRAN       IDR TYPE:                          06781000
         BH    IDRFIL40                USER, BRANCH                     06782000
         BL    IDRFIL30                ZAP, BRANCH                      06783000
         LA    R1,#TRANTXT             TRANSLATOR                       06784000
         SPACE 1                                                        06785000
         ICM   R15,B'0001',#TRANLEN  ANY TRANSLATOR FILTERING?          06786000
         BZ    IDRFIL10              NO, BRANCH                         06787000
         CLI   IDRLDATA,15           ONE TRANSLATOR ONLY?               06788000
         BL    IDRFIL60              YES, BRANCH                        06789000
         BCTR  R15,0                 COMPARE MACHINE LENGTH             06790000
         CLC   IDRTDATA+15(*-*),#TRANTXT  <<EXECUTED>>                  06791000
         EX    R15,*-6                    THIS PL/S TRANSLATOR?         06792000
         BE    IDRFIL10                   YES, BRANCH                   06793000
         IC    R15,#TRANLEN          COMPARE STRING LENGTH (AGAIN)      06794000
         B     IDRFIL60              CHECK THE FIRST TRANSLATOR TOO     06795000
         SPACE 2                                                        06796000
IDRFIL30 IC    R15,#ZAPLEN           ZAP IDR RECORD                     06797000
         LA    R1,#ZAPTXT                                               06798000
         B     IDRFIL60                                                 06799000
         SPACE 2                                                        06800000
IDRFIL40 IC    R15,#USERLEN          USER IDR RECORD                    06801000
         LA    R1,#USERTXT                                              06802000
         SPACE 2                                                        06803000
IDRFIL60 S     R15,=F'1'             VALID MACHINE LENGTH?              06804000
         BM    IDRFIL10              NO, BRANCH                         06805000
         SPACE 1                                                        06806000
         CLC   IDRDATA(*-*),0(R1)    <<EXECUTED>>                       06807000
         EX    R15,*-6               PARTIAL NAME MATCH?                06808000
         BE    IDRFIL10              YES, BRANCH                        06809000
         SPACE 1                                                        06810000
         LR    R3,R2                 NO, UNCHAIN THE                    06811000
         ST    R4,IDRLINK                           CURRENT ENTRY       06812000
         B     IDRFIL10                                                 06813000
         EJECT                                                          06814000
LASTIDRZ LA    R3,#IDRPTR          PERFORM AN IDR RECORD SORT           06815000
         SPACE 2                                                        06816000
SORTIDR  ICM   R3,B'1111',IDRLINK                                       06817000
         BZ    SORTIDRZ                                                 06818000
         LR    R1,R3                                                    06819000
         SPACE 1                                                        06820000
SORTIDR2 ICM   R1,B'1111',IDRLINK-IDRENTRY(R1)    GET THE NEXT ENTRY    06821000
         BZ    SORTIDR                                                  06822000
         SPACE 1                                                        06823000
         ICM   R0,B'1110',IDRDATE   ==> SORT BY DATE (DESCENDING ORDER) 06824000
         CLM   R0,B'0010',IDRDATE-IDRENTRY+2(R1)  THIRD BYTE:THIRD BYTE 06825000
         BH    SORTIDR2                           HIGH - NO SWITCH      06826000
         BL    SORTIDR3                           LOW  - NO SWITCH      06827000
         CLM   R0,B'1000',IDRDATE-IDRENTRY+0(R1)  FIRST BYTE:FIRST BYTE 06828000
         BH    SORTIDR2                           HIGH - NO SWITCH      06829000
         BL    SORTIDR3                           LOW  - NO SWITCH      06830000
         CLM   R0,B'0100',IDRDATE-IDRENTRY+1(R1)  SECONDBYTE:SECONDBYTE 06831000
         BNL   SORTIDR2                           HIGH/EQUAL - BRANCH   06832000
         SPACE 1                                                        06833000
SORTIDR3 XC    IDRSTART(LENIDR1),IDRSTART-IDRENTRY(R1)                  06834000
         XC    IDRSTART-IDRENTRY(LENIDR1,R1),IDRSTART                   06835000
         XC    IDRSTART(LENIDR1),IDRSTART-IDRENTRY(R1)                  06836000
         B     SORTIDR2                                                 06837000
         SPACE 1                                                        06838000
SORTIDRZ LM    R14,R12,ESDIDRSV    RESTORE REGISTERS                    06839000
         TM    FLAGSCC,FIDR        ANY IDR RECORDS?                     06840000
         BZR   R14                 NO, RETURN AT +0                     06841000
         B     4(,R14)             YES, RETURN AT +4                    06842000
         DROP  R3                                                       06843000
         SPACE 2                                                        06844000
GETIDR   CLC   ##SUBCOM(8),$ATT      ATTRIB SUBCOMMAND?                 06845000
         BE    NEXTIDR               YES, IGNORE THE RECORD             06846000
         MVI   SUBPOOLT,21                                              06847000
         LA    R0,LENIDR                                                06848000
         ICM   R0,B'1000',SUBPOOLT   SUBPOOL 21                         06849000
         GETMAIN R,LV=(0)                                               06850000
         XC    0(LENIDR,R1),0(R1)                                       06851000
         OI    FLAGSCC,FIDR          IDR DATA EXISTS                    06852000
         BR    R14                                                      06853000
         TITLE 'P D S  --  PDS IF                        1/15/85'       06854000
*********************************************************************** 06855000
***      IF SUBCOMMAND         ADDED BY BRUCE LELAND -- JAN., 1983  *** 06856000
*********************************************************************** 06857000
*                                                                       06858000
         SPACE 1                                                        06859000
IF       CSECT                                                          06860000
         USING *,R8                                                     06861000
         OC    #ACTIONT(8),#ACTIONT   ANY THEN OR ELSE?                 06862000
         BNZ   *+10                   YES, BRANCH                       06863000
         MVC   #ACTIONT(4),THENTBL+4  DEFAULT THEN ACTION IS ATTRIB     06864000
         SPACE 1                                                        06865000
         TM    #OPTOPT,X'80'        PARSE INVOKED?                      06866000
         BNO   IF996                NO, DONE                            06867000
         CLC   #ATTRLO(3),DIRTTR    IN TTR LOWER BOUND?                 06868000
         BH    IF997                NO, DO ANY ELSE                     06869000
         CLC   #ATTRHI(3),DIRTTR    IN TTR UPPER BOUND?                 06870000
         BL    IF997                NO, DO ANY ELSE                     06871000
         SPACE 1                                                        06872000
         TM    FLAGSCC,RECFMU       A LOAD LIBRARY?                     06873000
         BO    IF006                YES, BRANCH                         06874000
         LA    R1,L701              ASSUME LINKEDIT ATTRIBUTES          06875000
         TM    #OPTOPT,X'01'        CORRECT?                            06876000
         BO    MSGNEWXX             YES, ERROR                          06877000
         B     IF016                                                    06878000
         SPACE 2                                                        06879000
IF006    MVC   MODESAVE(1),DIRATTR3 RMODE/AMODE BYTE                    06880000
         TM    DIRATTR2,DIRAOSLE    VS LINKAGE EDITOR?                  06881000
         BO    *+8                  YES, BRANCH                         06882000
         MVI   MODESAVE,0           NO, NO MVS/XA BITS                  06883000
         SR    R15,R15                                                  06884000
         IC    R15,MODESAVE                                             06885000
         SRA   R15,2                AMODE FOR ALIAS                     06886000
         TM    DIRFLAG,X'80'        ALIAS?                              06887000
         BNO   *+8                  NO, BRANCH                          06888000
         STC   R15,MODESAVE         YES, USE ALIAS AMODE BITS           06889000
         NI    MODESAVE,DIRAM64+DIRAM31 TURN OFF OTHER BITS        @D02
         SPACE 3                                                        06891000
IF016    CLI   #RMODE,X'01'         ANY RMODE SELECTION?                06892000
         BL    IF036                NO, BRANCH                          06893000
         MVC   DOUBLE(1),DIRATTR3   RMODE/AMODE BYTE                    06894000
         NI    DOUBLE,DIRRMANY      TURN OFF OTHER BITS                 06895000
         TM    DIRATTR2,DIRAOSLE    VS LINKAGE EDITOR?                  06896000
         BO    *+8                  YES, BRANCH                         06897000
         MVI   DOUBLE,0             NO, NO MVS/XA BITS                  06898000
         SR    R15,R15                                                  06899000
         IC    R15,#RMODE                                               06900000
         SLA   R15,2                #RMODE*4                            06901000
         B     *(R15)               CHECK FOR:                          06902000
         B     IF020                  RMODE=24                          06903000
         B     IF030                  RMODE=ANY                         06904000
         B     IF030                  NO RMODE=24                       06905000
         B     IF020                  NO RMODE=ANY                      06906000
IF020    CLI   DOUBLE,0             RMODE=24?                           06907000
         BNE   IF997                NO, DO ANY ELSE                     06908000
         B     IF036                YES, BRANCH                         06909000
IF030    CLI   DOUBLE,0             RMODE=24?                           06910000
         BE    IF997                YES, DO ANY ELSE                    06911000
         SPACE 3                                                        06912000
IF036    CLI   #AMODE,X'01'         ANY AMODE SELECTION?                06913000
         BL    IF102                NO, BRANCH                          06914000
         SR    R15,R15                                                  06915000
         IC    R15,#AMODE                                               06916000
         SLA   R15,2                #AMODE*4                            06917000
         B     *(R15)               CHECK FOR:                          06918000
         B     IF040                  AMODE=24                          06919000
         B     IF050                  AMODE=31                          06920000
         B     IF060                  AMODE=ANY                         06921000
         B     IF070                  NO AMODE=24                       06922000
         B     IF080                  NO AMODE=31                       06923000
         B     IF090                  NO AMODE=ANY                      06924000
IF040    CLI   MODESAVE,DIRAM24     AMODE=24?                           06925000
         BH    IF997                NO, DO ANY ELSE                     06926000
         B     IF102                YES, BRANCH                         06927000
IF050    CLI   MODESAVE,DIRAM31     AMODE=31?                           06928000
         BNE   IF997                NO, DO ANY ELSE                     06929000
         B     IF102                YES, BRANCH                         06930000
IF055    CLI   MODESAVE,DIRAM64     AMODE=64?                      @D02
         BNE   IF997                NO, DO ANY ELSE                @D02
         B     IF102                YES, BRANCH                    @D02
IF060    CLI   MODESAVE,DIRAM64+DIRAM31  AMODE=ANY?                @D02
         BNE   IF997                     NO, DO ANY ELSE                06932000
         B     IF102                     YES, BRANCH                    06933000
IF070    CLI   MODESAVE,DIRAM24     AMODE=24?                           06934000
         BNH   IF997                YES, DO ANY ELSE                    06935000
         B     IF102                NO, BRANCH                          06936000
IF080    CLI   MODESAVE,DIRAM31     AMODE=31?                           06937000
         BE    IF997                YES, DO ANY ELSE                    06938000
         B     IF102                NO, BRANCH                          06939000
IF085    CLI   MODESAVE,DIRAM64     AMODE=64?                      @D02
         BE    IF997                YES, DO ANY ELSE               @D02
         B     IF102                NO, BRANCH                     @D02
IF090    CLI   MODESAVE,DIRAM64+DIRAM31  AMODE=ANY?                @D02
         BE    IF997                     YES, DO ANY ELSE               06941000
         SPACE 3                                                        06942000
IF102    CLI   #ALIAOPT,X'01'       "ALIAS" OR "NOALIAS"?               06943000
         BL    IF106                NEITHER, BRANCH                     06944000
         BH    IF104                "NOALIAS", BRANCH                   06945000
         TM    DIRFLAG,X'80'        "ALIAS" -- CORRECT?                 06946000
         BO    IF106                YES, BRANCH                         06947000
         B     IF997                NO, DO ANY ELSE                     06948000
IF104    TM    DIRFLAG,X'80'        ALIAS?                              06949000
         BO    IF997                YES, DO ANY ELSE                    06950000
         SPACE 3                                                        06951000
IF106    CLI   #VSLKED,X'01'        "VSLKED" OR "NOVSLKED"?             06952000
         BL    IF110                NEITHER, BRANCH                     06953000
         BH    IF108                "NOVSLKED", BRANCH                  06954000
         TM    DIRATTR2,DIRAOSLE    "VSLKED" -- CORRECT?                06955000
         BO    IF110                YES, BRANCH                         06956000
         B     IF997                NO, DO ANY ELSE                     06957000
IF108    TM    DIRATTR2,DIRAOSLE    VSLKED?                             06958000
         BO    IF997                YES, DO ANY ELSE                    06959000
         SPACE 3                                                        06960000
IF110    CLI   #AUTHOPT,X'01'       "AUTH" OR "NOAUTH"?                 06961000
         BL    IF113                NEITHER, BRANCH                     06962000
         LA    R2,ZERO              ASSUME NOT AUTHORIZED               06963000
         TM    DIRATTR2,DIRAOSLE+DIRAPFLG  APF INFORMATION AVAILABLE?   06964000
         BNO   IF111                       NO, NOT AUTHORIZED           06965000
         LA    R2,DIRAPF            BASIC APF DATA START                06966000
         TM    DIRATTR,ATTRSCTR     SCATTER LOADED?                     06967000
         BNO   *+8                  NO, BRANCH                          06968000
         LA    R2,8(,R2)            YES, EIGHT MORE BYTES               06969000
         TM    DIRFLAG,X'80'        ALIAS?                              06970000
         BO    *+12                 YES, BRANCH                         06971000
         CLI   8(R2),0              CONVERTED ALIAS ENTRY?              06972000
         BE    *+8                  NO, BRANCH                          06973000
         LA    R2,11(,R2)           ADD ALIAS LENGTH                    06974000
         TM    DIRATTR2,DIR2SSI     SSI INFORMATION?                    06975000
         BNO   IF111                NO, BRANCH                          06976000
         LA    R2,5(,R2)            YES, FOUR MORE BYTES                06977000
         N     R2,=F'-2'                                ROUNDED         06978000
IF111    CLI   #AUTHOPT,X'01'       "AUTH" OR "NOAUTH"                  06979000
         BH    IF112                "NOAUTH", BRANCH                    06980000
         CLI   0(R2),X'01'          CORRECT APF LENGTH?                 06981000
         BNE   IF997                NO, CANNOT BE AUTHORIZED            06982000
         CLI   1(R2),0              "AUTH" -- CORRECT?                  06983000
         BH    IF113                YES, BRANCH                         06984000
         B     IF997                NO, DO ANY ELSE                     06985000
IF112    CLI   0(R2),X'01'          CORRECT APF LENGTH?                 06986000
         BNE   IF113                NO, CANNOT BE AUTHORIZED            06987000
         CLI   1(R2),0              AUTHORIZED?                         06988000
         BH    IF997                YES, DO ANY ELSE                    06989000
         SPACE 3                                                        06990000
IF113    CLI   #APFERR,X'01'        "APFERR" OR "NOAPFERR"?             06991000
         BL    IF116                NEITHER, BRANCH                     06992000
         LA    R2,=X'01010101'      ASSUME NO APF ERROR                 06993000
         TM    DIRATTR2,DIRAOSLE+DIRAPFLG  APF INFORMATION AVAILABLE?   06994000
         BNO   IF114                       NO, NO APF ERROR             06995000
         LA    R2,DIRAPF            BASIC APF DATA START                06996000
         TM    DIRATTR,ATTRSCTR     SCATTER LOADED?                     06997000
         BNO   *+8                  NO, BRANCH                          06998000
         LA    R2,8(,R2)            YES, EIGHT MORE BYTES               06999000
         TM    DIRFLAG,X'80'        ALIAS?                              07000000
         BO    *+12                 YES, BRANCH                         07001000
         CLI   8(R2),0              CONVERTED ALIAS ENTRY?              07002000
         BE    *+8                  NO, BRANCH                          07003000
         LA    R2,11(,R2)           ADD ALIAS LENGTH                    07004000
         TM    DIRATTR2,DIR2SSI     SSI INFORMATION?                    07005000
         BNO   IF114                NO, BRANCH                          07006000
         LA    R2,5(,R2)            YES, FOUR MORE BYTES                07007000
         N     R2,=F'-2'                                ROUNDED         07008000
IF114    CLI   #APFERR,X'01'        "APFERR" OR "NOAPFERR"              07009000
         BH    IF115                "NOAPFERR", BRANCH                  07010000
         CLI   0(R2),X'01'          CORRECT APF LENGTH?                 07011000
         BE    IF997                YES, DO ANY ELSE                    07012000
         B     IF116                NO, BRANCH                          07013000
IF115    CLI   0(R2),X'01'          CORRECT APF LENGTH?                 07014000
         BNE   IF997                NO, DO ANY ELSE                     07015000
         SPACE 3                                                        07016000
IF116    CLI   #PAGEOPT,X'01'       "PAGE" OR "NOPAGE"?                 07017000
         BL    IF120                NEITHER, BRANCH                     07018000
         BH    IF118                "NOPAGE", BRANCH                    07019000
         TM    DIRATTR2,DIR2PAGA    "PAGE" -- CORRECT?                  07020000
         BO    IF120                YES, BRANCH                         07021000
         B     IF997                NO, DO ANY ELSE                     07022000
IF118    TM    DIRATTR2,DIR2PAGA    PAGE?                               07023000
         BO    IF997                YES, DO ANY ELSE                    07024000
         SPACE 3                                                        07025000
IF120    CLI   #SSIOPT,X'01'        "SSI" OR "NOSSI"?                   07026000
         BL    IF130                NEITHER, BRANCH                     07027000
         TM    FLAGSCC,RECFMU       RECFM=U?                            07028000
         BO    IF122                YES, BRANCH                         07029000
         LA    R2,ZERO              ASSUME NO SSI                       07030000
         TM    DIRFLAG,X'0F'        SPF STATISTICS?                     07031000
         BO    IF124                YES, NO SSI INFORMATION             07032000
         LA    R2,DIRUSER           POINT TO SSI INFORMATION            07033000
         B     IF124                CHECK FOR ANY SSI                   07034000
IF122    LA    R2,DIRAPF            BASIC APF DATA START                07035000
         TM    DIRATTR,ATTRSCTR     SCATTER LOADED?                     07036000
         BNO   *+8                  NO, BRANCH                          07037000
         LA    R2,8(,R2)            YES, EIGHT MORE BYTES               07038000
         TM    DIRFLAG,X'80'        ALIAS?                              07039000
         BO    *+12                 YES, BRANCH                         07040000
         CLI   8(R2),0              CONVERTED ALIAS ENTRY?              07041000
         BE    *+8                  NO, BRANCH                          07042000
         LA    R2,11(,R2)           ADD ALIAS LENGTH                    07043000
         TM    DIRATTR2,DIRAOSLE    VS LINKAGE EDITOR?                  07044000
         BNO   IF124                NO, BRANCH                          07045000
         TM    DIRATTR2,DIR2SSI     SSI INFORMATION?                    07046000
         BNO   IF128                NO, BRANCH                          07047000
IF124    LA    R2,1(,R2)            ROUND TO START                      07048000
         N     R2,=F'-2'                          OF NEXT HALFWORD      07049000
         CLC   ZERO,0(R2)           ZERO?                               07050000
         BE    IF128                YES, NO SSI                         07051000
         CLC   =F'-1',0(R2)         ALL ONES?                           07052000
         BE    IF128                YES, NO SSI                         07053000
IF126    CLI   #SSIOPT,X'01'        SEARCH FOR "SSI"?                   07054000
         BNE   IF997                NO, BRANCH                          07055000
         OC    #SSITEXT(4),#SSITEXT ANY SSI SEARCH?                     07056000
         BZ    IF130                NO, BRANCH                          07057000
         CLC   0(4,R2),#SSITEXT     THIS SSI?                           07058000
         BE    IF130                YES, BRANCH                         07059000
         B     IF997                NO, DO ANY ELSE                     07060000
IF128    CLI   #SSIOPT,X'01'        SEARCH FOR "SSI"?                   07061000
         BE    IF997                YES, DO ANY ELSE                    07062000
         SPACE 3                                                        07063000
IF130    TM    FLAGSCC,RECFMU       RECFM=U?                            07064000
         BNO   IF140                NO, BRANCH                          07065000
         SR    R1,R1                                                    07066000
         ICM   R1,B'0001',#ATTRYES  ANY YES+0 ATTRIBUTES?               07067000
         BZ    IF132                NO, BRANCH                          07068000
         TM    DIRATTR,*-*          <<EXECUTED>>                        07069000
         EX    R1,*-4               ALL ATTRIBUTES MATCH?               07070000
         BNO   IF997                NO, DO ANY ELSE                     07071000
         SPACE 1                                                        07072000
IF132    ICM   R1,B'0001',#ATTRYES+1 ANY YES+1 ATTRIBUTES?              07073000
         BZ    IF134                NO, BRANCH                          07074000
         TM    DIRATTR+1,*-*        <<EXECUTED>>                        07075000
         EX    R1,*-4               ALL ATTRIBUTES MATCH?               07076000
         BNO   IF997                NO, DO ANY ELSE                     07077000
         SPACE 1                                                        07078000
IF134    ICM   R1,B'0001',#ATTRNO   NO+0 ATTRIBUTES                     07079000
         TM    DIRATTR,*-*          <<EXECUTED>>                        07080000
         EX    R1,*-4               ANY ATTRIBUTES MATCH?               07081000
         BNZ   IF997                YES, DO ANY ELSE                    07082000
         SPACE 1                                                        07083000
         ICM   R1,B'0001',#ATTRNO+1 NO+1 ATTRIBUTES                     07084000
         TM    DIRATTR+1,*-*        <<EXECUTED>>                        07085000
         EX    R1,*-4               ANY ATTRIBUTES MATCH?               07086000
         BNZ   IF997                YES, DO ANY ELSE                    07087000
         SPACE 3                                                        07088000
IF140    CLI   #USERIDO,X'01'       USERID, NOUSERID OR NOTUSERID?      07089000
         BL    IF144                NO, BRANCH                          07090000
         LA    R1,L702              ASSUME DATA SET IS A LOAD MODULE    07091000
         TM    FLAGSCC,RECFMU       CORRECT?                            07092000
         BO    MSGNEWXX             YES, ERROR                          07093000
         TM    DIRFLAG,X'0F'        SPF STATISTICS?                     07094000
         BNO   IF143                NO, BRANCH                          07095000
         CLI   #USERIDO,X'02'       "NOUSERID" DESIRED?                 07096000
         BE    IF997                YES, DO ANY ELSE                    07097000
         SR    R1,R1                                                    07098000
         ICM   R1,B'0001',#USERIDL  ANY USERID FILTERING?               07099000
         BP    IF141                YES, BRANCH                         07100000
         CLI   #USERIDO,X'01'       "USERID" DESIRED?                   07101000
         BE    IF144                YES, BRANCH                         07102000
         B     IF997                NO, DO ANY ELSE                     07103000
         SPACE 1                                                        07104000
IF141    BCTR  R1,0                 MACHINE LENGTH                      07105000
         CLI   #USERIDO,X'01'       "USERID" DESIRED?                   07106000
         BNE   IF142                NO, BRANCH                          07107000
         EX    R1,IF142             PARTIAL USERID MATCH?               07108000
         BNE   IF997                NO, DO ANY ELSE                     07109000
         B     IF144                YES, BRANCH                         07110000
         SPACE 1                                                        07111000
IF142    CLC   #USERTXT(*-*),DIRSPFID <<EXECUTED>>                      07112000
         EX    R1,*-6               PARTIAL USERID MATCH?               07113000
         BE    IF997                YES, DO ANY ELSE                    07114000
         B     IF144                NO, BRANCH                          07115000
         SPACE 1                                                        07116000
IF143    CLI   #USERIDO,X'01'       "USERID" DESIRED?                   07117000
         BE    IF997                YES, DO ANY ELSE                    07118000
         SPACE 3                                                        07119000
IF144    TM    #OPTOPT,X'02'        NEED ANY MAP OR HISTORY DATA?       07120000
         BNO   IF156                NO, BRANCH                          07121000
         MVI   RLDCOUNT,X'FF'       ASSUME NO RLD/CONTROL DATA FOUND    07122000
         SPACE 1                                                        07123000
         L     R15,=A(READESD)                                          07124000
         BALR  R14,R15              ANY ESD DATA?                       07125000
         NOP   0                    NO, IGNORE                          07126000
         SPACE 1                                                        07127000
         ICM   R2,B'1110',#ZAPOPT       SAVE ZAP/USER/TRAN              07128000
         MVC   #ZAPOPT(3),=X'01010101'  CHECK ZAP/USER/TRAN             07129000
         MVC   LKEDDATE+2,X'FF'         NO LINKAGE-EDIT DATE FOUND      07130000
         L     R15,=A(READIDR)                                          07131000
         BALR  R14,R15              ANY IDR DATA?                       07132000
         B     IF145                NO, BRANCH                          07133000
         SPACE 2                                                        07134000
         MVI   #LKEDOPT,0           ASSUME LINKAGE-EDITOR FOUND         07135000
         SR    R1,R1                                                    07136000
         ICM   R1,B'0001',#LKEDLEN  ANY LKED NAME CHECK?                07137000
         BZ    IF145                NO, BRANCH                          07138000
         BCTR  R1,0                 MACHINE COMPARE LENGTH              07139000
         CLC   LKEDNAME(*-*),#LKEDTXT  <<EXECUTED>>                     07140000
         EX    R1,*-6               THIS PARTIAL LKED NAME?             07141000
         BE    IF145                YES, BRANCH                         07142000
         MVI   #LKEDOPT,1           NO, LINKAGE-EDITOR NOT FOUND        07143000
         SPACE 1                                                        07144000
IF145    OC    #IFCREIF(6),#IFCREIF        ANY CREATION DATE RANGE?     07145000
         BZ    IF146                       NO, CONTINUE                 07146000
         ICM   R1,B'0100',LKEDDATE+2       YY OF MMDDYY                 07147000
         ICM   R1,B'0011',LKEDDATE         MMDD OF MMDDYY               07148000
         CLM   R1,B'0111',#IFCREIF         DATA VALUE < FIRST YYMMDD?   07149000
         BL    IF997                       YES, DO ANY ELSE             07150000
         CLM   R1,B'0111',#IFCREIF+3       DATA VALUE > SECOND YYMMDD?  07151000
         BH    IF997                       YES, DO ANY ELSE             07152000
         SPACE 2                                                        07153000
IF146    STCM  R2,B'1110',#ZAPOPT   RESTORE ZAP/USER/TRAN               07154000
         USING ESDENTRY,R2                                              07155000
         LA    R2,#ESDPTR           SCAN ESD CHAIN                      07156000
         SPACE 1                                                        07157000
IF148    ICM   R2,B'1111',ESDLINK   ANY MORE ESD ENTRIES?               07158000
         BZ    IF154                NO, BRANCH                          07159000
         CLI   ESDTYPE,CODESD       CSECT ESD ENTRY?                    07160000
         BNE   IF148                NO, BRANCH                          07161000
         SPACE 1                                                        07162000
         USING IDRENTRY,R3                                              07163000
         LA    R3,#IDRPTR           SCAN IDR CHAIN                      07164000
         SPACE 1                                                        07165000
IF150    ICM   R3,B'1111',IDRLINK   ANY MORE IDR ENTRIES?               07166000
         BZ    IF148                NO, BRANCH                          07167000
         CLC   ESDID,IDRESDID       THIS CSECT IDENTIFIER?              07168000
         BNE   IF150                NO, BRANCH                          07169000
         SPACE 1                                                        07170000
         MVI   #MODOPT,0            YES, MODULE FOUND                   07171000
         CLI   IDRTYPE,IDRTRAN      ZAP RECORD?                         07172000
         BNL   IF152                NO, BRANCH                          07173000
         MVI   #ZAPOPT,0            YES, ZAP RECORDS MATCH              07174000
         OC    #IFMODIF(6),#IFMODIF       ANY MODIFICATION CHECK?       07175000
         BE    IF152                      NO, BRANCH                    07176000
         ICM   R1,B'0100',IDRDATE+2       YY OF MMDDYY                  07177000
         ICM   R1,B'0011',IDRDATE         MMDD OF MMDDYY                07178000
         CLM   R1,B'0111',#IFMODIF        DATA VALUE < FIRST YYMMDD?    07179000
         BL    IF152                      YES, NO MATCH                 07180000
         CLM   R1,B'0111',#IFMODIF+3      DATA VALUE > SECOND YYMMDD?   07181000
         BH    IF152                      YES, NO MATCH                 07182000
         XC    #IFMODIF(6),#IFMODIF       A MODIFICATION RECORD MATCHES 07183000
         SPACE 1                                                        07184000
IF152    CLI   IDRTYPE,IDRTRAN      IDR RECORD TYPE:                    07185000
         BNH   *+8                                                      07186000
         MVI   #USEROPT,0              **USER                           07187000
         BNE   *+8                                                      07188000
         MVI   #TRANOPT,0              **TRANSLATOR                     07189000
         B     IF150                                                    07190000
         DROP  R2,R3                                                    07191000
IF154    OC    #IFMODIF(6),#IFMODIF ANY CHANGES MATCH?                  07192000
         BNZ   IF997                NO, DO ANY ELSE CONDITIONS          07193000
         SPACE 1                                                        07194000
IF156    OC    #ZAPOPT(5),#ZAPOPT   ZAP/USER/TRAN/LKED/MODULE FOUND?    07195000
         BNZ   IF997                NO, DO ANY ELSE                     07196000
         SPACE 3                                                        07197000
         TM    DIRATTR2,DIRAOSLE    OS/VS LINKAGE EDITOR?               07198000
         BO    *+10                 YES, BRANCH                         07199000
         MVC   RLDCOUNT(1),DIRATTR4 NO, WANT MATCHING RLD/CONTROL       07200000
         CLI   #RLDERR,X'01'        "RLDERR" OR "NORLDERR"              07201000
         BL    IF160                NEITHER, BRANCH                     07202000
         BH    IF158                "NORLDERR", BRANCH                  07203000
         CLC   DIRATTR4(1),RLDCOUNT "RLDERR" -- CORRECT?                07204000
         BNE   IF160                YES, BRANCH                         07205000
         B     IF997                NO, DO ANY ELSE                     07206000
IF158    CLC   DIRATTR4(1),RLDCOUNT "NORLDERR" -- CORRECT?              07207000
         BNE   IF997                YES, DO ANY ELSE                    07208000
         SPACE 3                                                        07209000
IF160    NI    #IFABOVE,FF-X'01'    ASSUME SIZE IS NOT AVAILABLE        07210000
         TM    #IFABOVE,X'80'       ANY ABOVE CODED?                    07211000
         BO    IF164                YES, BRANCH                         07212000
         TM    #IFBELOW,X'80'       ANY BELOW CODED?                    07213000
         BZ    IF170                NO, BRANCH                          07214000
         SPACE 1                                                        07215000
IF164    SR    R1,R1                                                    07216000
         ICM   R1,B'0111',DIRSTORE  MODULE SIZE                         07217000
         TM    FLAGSCC,RECFMU       RECFM=U?                            07218000
         BO    IF168                YES, BRANCH                         07219000
         TM    DIRFLAG,X'0F'        SPF STATISTICS PRESENT?             07220000
         BNO   IF180                NO, BRANCH                          07221000
         OC    DIRSPFZ(3),DIRSPFZ   RESERVED AND 00 OF 00YYDDDF ZEROS?  07222000
         BNZ   IF180                NO, BRANCH                          07223000
         CLI   DIRSPFCD,0           00 OF OTHER 00YYDDDF ZERO?          07224000
         BNZ   IF180                NO, BRANCH                          07225000
         LH    R1,DIRSPFSI                                              07226000
         SPACE 1                                                        07227000
IF168    OI    #IFABOVE,X'01'       SIZE IS AVAILABLE                   07228000
         ST    R1,#IFLEN            LENGTH OF THE MEMBER                07229000
         SPACE 1                                                        07230000
IF170    TM    #OPTOPT,X'04'        NEED TO READ THE MEMBER?            07231000
         BNO   IF300                NO, BRANCH                          07232000
         SPACE 1                                                        07233000
IF180    SR    R6,R6                COUNT OF INPUT LOGICAL RECORDS      07234000
         CLC   DIRTTR(3),DS1LSTAR   BEYOND END OF DATA MARKER?          07235000
         BNL   IF242                YES, DONE                           07236000
         OI    ##ADRPA#,$Q          QUIET MODE READ IS REQUIRED         07237000
         MVC   STARTTR(3),DIRTTR    FIRST DISK ADDRESS TO READ          07238000
         SPACE 3                                                        07239000
IF204    L     R15,=A(EXCP)                                             07240000
         BALR  R14,R15                                                  07241000
         B     *+4(R15)             PROCESS RETURN CODE                 07242000
         B     IF208                  00 - SUCCESSFUL READ              07243000
         B     IF240                  04 - END OF MEMBER                07244000
         B     IF240                  08 - END OF DATA SET              07245000
         B     IF242                  12 - I/O ERROR                    07246000
         SPACE 2                                                        07247000
IF208    LR    R3,R0                BUFFER START                        07248000
         L     R5,LS                BLOCK LENGTH                        07249000
         CH    R5,BLKSI             BLKSIZE VALID?                      07250000
         BNH   IF220                YES, BRANCH                         07251000
         OI    #OPTOPT,X'20'        NO, INDICATE A BLOCKSIZE ERROR      07252000
         SPACE 1                                                        07253000
IF220    TM    FLAGSCC,RECFMF       FIXED FORMAT?                       07254000
         BNO   IF222                NO, BRANCH                          07255000
         LH    R14,LRECL            CURRENT LRECL                       07256000
         LR    R0,R5                BLOCK LENGTH                        07257000
         SRDA  R0,32                                                    07258000
         DR    R0,R14               BLKSIZE/LRECL                       07259000
         LTR   R0,R0                ANY REMAINDER?                      07260000
         BZ    IF222                YES, BRANCH                         07261000
         OI    #OPTOPT,X'10'        NOTE: LRECL ERROR (BLKSIZE/LRECL)   07262000
         SPACE 1                                                        07263000
IF222    LR    R1,R5                                                    07264000
         AR    R5,R3                END OF BUFFER                       07265000
         BCTR  R5,0                 END OF BUFFER -1                    07266000
         TM    FLAGSCC,RECFMF       RECFM=F?                            07267000
         LH    R4,LRECL                                                 07268000
         BO    IF228                YES, BRANCH                         07269000
         TM    FLAGSCC,RECFMU       RECFM=U?                            07270000
         LR    R4,R1                                                    07271000
         BO    IF228                YES, BRANCH                         07272000
         TM    FLAGSCC,RECFMV       RECFM=V?                            07273000
         BNO   IF228                NO, ASSUME RECFM=U                  07274000
         AH    R3,=H'4'             SKIP BLOCK LENGTH WORD              07275000
         B     IF226                                                    07276000
         SPACE 3                                                        07277000
IF224    BXLE  R3,R4,IF226          GET THE NEXT LOGICAL RECORD         07278000
         B     IF204                END OF BLOCK, BRANCH                07279000
         SPACE 2                                                        07280000
IF226    TM    FLAGSCC,RECFMV       RECFM=V?                            07281000
         BNO   IF228                NO, BRANCH                          07282000
         SR    R4,R4                                                    07283000
         ICM   R4,B'0011',0(R3)     RECORD LENGTH +4                    07284000
         LR    R14,R4               RECORD LENGTH +4                    07285000
         AH    R3,=H'4'             SKIP RECORD LENGTH WORD             07286000
         SH    R4,=H'4'             RECORD LENGTH VALID?                07287000
         BNM   IF228                YES, BRANCH                         07288000
         SR    R4,R4                NO, USE LENGTH 0                    07289000
         OI    #OPTOPT,X'10'        NOTE: LRECL ERROR (SHORT RECORD)    07290000
         B     IF224                SKIP THE RECORD                     07291000
         SPACE 2                                                        07292000
IF228    LA    R6,1(,R6)            ANOTHER OUTPUT RECORD               07293000
         CH    R14,LRECL            VALID LRECL VALUE?                  07294000
         BNH   IF224                YES, BRANCH                         07295000
         OI    #OPTOPT,X'10'        NOTE: LRECL ERROR (LONG RECORD)     07296000
         B     IF224                                                    07297000
         SPACE 2                                                        07298000
IF240    TM    DIRFLAG,DIR2TTR+DIR1TTR    ANY USER TTR?                 07299000
         BZ    IF244                      NO, BRANCH                    07300000
         STM   R14,R12,12(R13)            CONVERT CCHHR TO TTR          07301000
         LA    R2,CURMBB                  CCHHR TO CONVERT              07302000
         L     R1,INDCB+(DCBDEBAD-IHADCB) DEB ADDRESS                   07303000
         L     R15,ADDRRLTV               ADDRESS OF CCHHR->TTR CONVERT 07304000
         LR    R3,R13                     ADDRESS OF SAVE AREA          07305000
         BALR  R14,R15                    CALL CONVERT ROUTINE          07306000
         LR    R13,R3                     RESTORE SAVE AREA ADDRESS     07307000
         ST    R0,12+4+4(R13)             RESULT TTR RETURNED IN R0     07308000
         LM    R14,R12,12(R13)            RESTORE REGISTERS             07309000
         CLM   R0,B'1110',DIRSTART        TTR ACTUALLY INPUT?           07310000
         BNH   IF242                      NO, I/O ERROR                 07311000
         TM    DIRFLAG,DIR2TTR            A SECOND TTR TOO?             07312000
         BZ    IF244                      NO, BRANCH                    07313000
         CLM   R0,B'1110',DIRNOTE         TTR ACTUALLY INPUT?           07314000
         BH    IF244                      YES, BRANCH                   07315000
         SPACE 1                                                        07316000
IF242    OI    #OPTOPT,X'40'        PERMANENT I/O ERROR                 07317000
         SPACE 2                                                        07318000
IF244    LTR   R6,R6                ANY RECORDS?                        07319000
         BNZ   IF246                YES, BRANCH                         07320000
         OI    #OPTOPT,X'08'        NO, MARK AS NULL                    07321000
         SPACE 3                                                        07322000
IF246    NI    ##ADRPA#,FF-$Q       END OF QUIET MODE READ              07323000
         CLI   #IOERROR,X'01'       "IOERROR" OR "NOIOERROR"?           07324000
         BL    IF260                NEITHER, BRANCH                     07325000
         BH    IF248                "NOIOERROR", BRANCH                 07326000
         TM    #OPTOPT,X'40'        "IOERROR" -- CORRECT?               07327000
         BO    IF260                YES, BRANCH                         07328000
         B     IF997                NO, DO ANY ELSE                     07329000
IF248    TM    #OPTOPT,X'40'        IOERROR?                            07330000
         BO    IF997                YES, DO ANY ELSE                    07331000
         SPACE 3                                                        07332000
IF260    CLI   #BLOCKER,X'01'       "BLOCKERR" OR "NOBLOCKERR"?         07333000
         BL    IF266                NEITHER, BRANCH                     07334000
         BH    IF262                "NOBLOCKERR", BRANCH                07335000
         TM    #OPTOPT,X'20'        "BLOCKERR" -- CORRECT?              07336000
         BO    IF266                YES, BRANCH                         07337000
         B     IF997                NO, DO ANY ELSE                     07338000
IF262    TM    #OPTOPT,X'20'        BLOCKERR?                           07339000
         BO    IF997                YES, DO ANY ELSE                    07340000
         SPACE 3                                                        07341000
IF266    CLI   #LRECLER,X'01'       "LRECLERR" OR "NOLRECLERR"?         07342000
         BL    IF280                NEITHER, BRANCH                     07343000
         BH    IF268                "NOLRECLERR", BRANCH                07344000
         TM    #OPTOPT,X'10'        "LRECLERR" -- CORRECT?              07345000
         BO    IF280                YES, BRANCH                         07346000
         B     IF997                NO, DO ANY ELSE                     07347000
IF268    TM    #OPTOPT,X'10'        LRECLERR?                           07348000
         BO    IF997                YES, DO ANY ELSE                    07349000
         SPACE 3                                                        07350000
IF280    CLI   #NULL,X'01'          "NULL" OR "NONULL"?                 07351000
         BL    IF300                NEITHER, BRANCH                     07352000
         BH    IF282                "NONULL", BRANCH                    07353000
         TM    #OPTOPT,X'08'        "NULL" -- CORRECT?                  07354000
         BO    IF300                YES, BRANCH                         07355000
         B     IF997                NO, DO ANY ELSE                     07356000
IF282    TM    #OPTOPT,X'08'        NULL?                               07357000
         BO    IF997                YES, DO ANY ELSE                    07358000
         SPACE 3                                                        07359000
IF300    TM    #IFABOVE,X'01'         SIZE AVAILABLE?                   07360000
         BNO   *+8                    NO, BRANCH                        07361000
         L     R6,#IFLEN              YES, USE THAT LENGTH              07362000
         SPACE 1                                                        07363000
         TM    #IFABOVE,X'80'         ABOVE CHECK?                      07364000
         BNO   IF320                  NO, BRANCH                        07365000
         CLM   R6,B'0111',#IFABOVE+1  ABOVE THE MINIMUM VALUE?          07366000
         BNH   IF997                  NO, DO ANY ELSE                   07367000
         SPACE 1                                                        07368000
IF320    TM    #IFBELOW,X'80'         BELOW CHECK?                      07369000
         BNO   IF360                  NO, BRANCH                        07370000
         CLM   R6,B'0111',#IFBELOW+1  BELOW THE MAXIMUM VALUE?          07371000
         BNL   IF997                  NO, DO ANY ELSE                   07372000
         SPACE 3                                                        07373000
IF360    CLI   #NAMEERR,X'01'       "NAMEERR" OR "NONAMEERR"?           07374000
         BL    IF390                NO, BRANCH                          07375000
         SPACE 1                                                        07376000
         SR    R3,R3                RESULT REGISTER                     07377000
         LA    R1,7                                                     07378000
         LA    R14,DOUBLE+8                                             07379000
         MVC   DOUBLE(8),DIRNAME                                        07380000
         SPACE 1                                                        07381000
IF382    BCTR  R14,0               SCAN                                 07382000
         CLI   0(R14),X'40'            BACKWARDS                        07383000
         BNE   *+8                              FOR FIRST               07384000
         BCT   R1,IF382                                  NON-BLANK      07385000
         SPACE 1                                                        07386000
         CLI   DIRNAME,C'0'        NUMERIC FIRST CHARACTER?             07387000
         BL    *+8                 NO, BRANCH                           07388000
         LA    R3,1                YES, NON-STANDARD NAME               07389000
         SPACE 1                                                        07390000
         TRT   DOUBLE(*-*),TRTMEM  <<EXECUTED>>                         07391000
         EX    R1,*-6              STANDARD MEMBER NAME?                07392000
         BZ    *+8                 YES, BRANCH                          07393000
         LA    R3,1                NO, NON-STANDARD NAME                07394000
         SPACE 1                                                        07395000
         CLI   #NAMEERR,X'01'       "NAMEERR" OR "NONAMEERR"?           07396000
         BL    IF390                NEITHER, BRANCH                     07397000
         BH    IF384                "NONAMEERR", BRANCH                 07398000
         LTR   R3,R3                "NAMEERR" -- CORRECT?               07399000
         BP    IF390                YES, BRANCH                         07400000
         B     IF997                NO, DO ANY ELSE                     07401000
IF384    LTR   R3,R3                NAMEERR?                            07402000
         BP    IF997                YES, DO ANY ELSE                    07403000
         SPACE 3                                                        07404000
* CHECK EACH MODULE FOR LINKAGE EDIT ATTRIBUTE CONFLICTS IF REQUIRED    07405000
IF390    CLI   #LKEDERR,X'01'              CONFLICT CHECK REQUESTED?    07406000
         BL    IF400                       NO, BRANCH                   07407000
         SPACE 1                                                        07408000
         TM    DIRATTR,ATTRRENT            REENTRANT?                   07409000
         BNO   IF392                       NO, BRANCH                   07410000
         TM    DIRATTR,ATTRREUS            REUSABLE?                    07411000
         BNO   IF399                       NO, CONFLICT FOUND           07412000
         SPACE 1                                                        07413000
IF392    TM    DIRATTR+1,ATTRSYMS+ATTRNE   TEST AND NOT EDIT            07414000
         BO    IF399                       YES, CONFLICT FOUND          07415000
         SPACE 1                                                        07416000
         TM    DIRATTR,ATTRREUS+ATTRSCTR   REUSABLE AND SCATTER         07417000
         BO    IF399                       YES, CONFLICT FOUND          07418000
         SPACE 1                                                        07419000
         TM    DIRATTR,ATTROVLY            OVERLAY ATTRIBUTE?           07420000
         BNO   IF394                       NO, BRANCH                   07421000
         TM    DIRATTR,ATTRRENT++ATTRREUS+ATTRSCTR  RENT/REUS/SCTR?     07422000
         BNZ   IF399                                YES, CONFLICT       07423000
         TM    DIRATTR+1,ATTRREFR          REFRESHABLE?                 07424000
         BO    IF399                       YES, CONFLICT FOUND          07425000
         TM    DIRATTR2,DIRAOSLE           MVS LINKAGE-EDITOR?          07426000
         BNO   IF394                       NO, BRANCH                   07427000
         TM    DIRATTR3,DIRRMANY           RMODE ANY?                   07428000
         BO    IF399                       YES, CONFLICT FOUND          07429000
         TM    MODESAVE,DIRAM31            AMODE 24?                    07430000
         BNZ   IF399                       NO, CONFLICT FOUND           07431000
         SPACE 1                                                        07432000
IF394    TM    DIRATTR2,DIRAOSLE           MVS LINKAGE-EDITOR?          07433000
         BNO   IF397                       NO, BRANCH                   07434000
         TM    DIRATTR3,DIRRMANY           RMODE ANY?                   07435000
         BNO   IF397                       NO, BRANCH                   07436000
         TM    MODESAVE,DIRAM64+DIRAM31    AMODE ANY?              @D02
         BO    IF399                       YES, CONFLICT FOUND     @D02
         TM    MODESAVE,DIRAM31            AMODE 31?               @D02
         BNO   IF399                       NO, CONFLICT FOUND      @D02
         TM    MODESAVE,DIRAM64            AMODE 64?               @D02
         BNO   IF399                       NO, CONFLICT FOUND      @D02
         SPACE 1                                                        07441000
IF397    CLI   #LKEDERR,1                  CONFLICT DESIRED?            07442000
         BE    IF997                       YES, DO ANY ELSE             07443000
         B     IF400                       NO, NONE FOUND               07444000
         SPACE 1                                                        07445000
IF399    CLI   #LKEDERR,1                  CONFLICT DESIRED?            07446000
         BNE   IF997                       NO, DO ANY ELSE              07447000
         SPACE 3                                                        07448000
* LOAD EACH MODULE IF REQUIRED                                          07449000
IF400    CLI   #LOADERR,X'01'      LOAD CHECK REQUESTED?                07450000
         BL    IF420               NO, BRANCH                           07451000
         SPACE 1                                                        07452000
         OI    ##ADRPA#,$Q         QUIET MODE LOAD IS REQUIRED          07453000
         L     R2,RECOVER          PREVIOUS RECOVERY ADDRESS            07454000
         LA    R1,IF402            RESUME ADDRESS                       07455000
         ST    R1,RECOVER          IN-LINE RECOVERY                     07456000
         STM   R2,R8,MSGTEXT2      SAVE REGISTERS                       07457000
         MVI   RECOVER,C'L'        LOAD RECOVERY FLAG                   07458000
         LOAD   EPLOC=DIRNAME,DCB=INDCB                                 07459000
         DELETE EPLOC=DIRNAME                                           07460000
         ST    R2,RECOVER          RESET RECOVERY ADDRESS               07461000
         MVI   RECOVER,0           LOAD WORKED                          07462000
         B     IF404                                                    07463000
         SPACE 1                                                        07464000
IF402    LM    R2,R8,MSGTEXT2      SAVE REGISTERS                       07465000
         ST    R2,RECOVER          RESTORE RECOVERY ADDRESS             07466000
         MVI   RECOVER,1           LOAD DID NOT WORK                    07467000
         SPACE 1                                                        07468000
IF404    NI    ##ADRPA#,FF-$Q       END OF QUIET MODE LOAD              07469000
         CLI   #LOADERR,X'01'       "LOADERR" OR "NOLOADERR"?           07470000
         BL    IF420                NEITHER, BRANCH                     07471000
         BH    IF406                "NOLOADERR", BRANCH                 07472000
         CLI   RECOVER,1            "LOADERR" -- CORRECT?               07473000
         BE    IF420                YES, BRANCH                         07474000
         B     IF997                NO, DO ANY ELSE                     07475000
IF406    CLI   RECOVER,1            LOAD ERROR?                         07476000
         BE    IF997                YES, DO ANY ELSE                    07477000
         SPACE 3                                                        07478000
* CHECK IF THIS MEMBER IS IN USE BY AN SPF EDIT SESSION                 07479000
IF420    CLI   #SPFEDIT,X'01'      INUSE CHECK REQUESTED?               07480000
         BL    IF440               NO, BRANCH                           07481000
         SPACE 1                                                        07482000
         OI    ##ADRPA#,$Q         QUIET MODE SPF USE CHECK             07483000
         SR    R3,R3               ASSUME NOT IN USE                    07484000
         MVC   DSNMEMQ(8),MEMNAME  MEMBER NAME TO CHECK                 07485000
         BAL   R2,ENQMTEST         MEMBER IN USE?                       07486000
         LA    R3,1                YES, MARK AS SUCH                    07487000
         NI    ##ADRPA#,FF-$Q      END OF QUIET MODE                    07488000
         SPACE 1                                                        07489000
         CLI   #SPFEDIT,X'01'       "SPFEDIT" OR "NOSPFEDIT"?           07490000
         BL    IF440                NEITHER, BRANCH                     07491000
         BH    IF422                "NOSPFEDIT", BRANCH                 07492000
         LTR   R3,R3                "SPFEDIT" -- CORRECT?               07493000
         BP    IF440                YES, BRANCH                         07494000
         B     IF997                NO, DO ANY ELSE                     07495000
IF422    LTR   R3,R3                SPFEDIT?                            07496000
         BP    IF997                YES, DO ANY ELSE                    07497000
         SPACE 3                                                        07498000
IF440    CLI   #AALIAS,X'01'        APPARENT ALIAS MEMBER CHECK?        07499000
         BL    IF460                NO, BRANCH                          07500000
         SR    R3,R3                ASSUME NOT AN APPARENT ALIAS        07501000
         TM    DIRFLAG,X'80'        MEMBER AN ALIAS?                    07502000
         BO    IF444                YES, CANNOT BE AN APPARENT ALIAS    07503000
         MVI   STARTTR+2,X'01'      TTR=000001 (START OF DIRECTORY)     07504000
         SPACE 1                                                        07505000
IF442    BAL   R14,READDIR          GET NEXT DIRECTORY MEMBER           07506000
         B     IF444                LAST MEMBER PROCESSED               07507000
         SPACE 1                                                        07508000
         TM    MEMFLAG,X'80'        IS THIS AN ALIAS?                   07509000
         BO    IF442                YES, IGNORE                         07510000
         CLC   DIRTTR,MEMTTR        TTR MATCH?                          07511000
         BNE   IF442                NO, BRANCH                          07512000
         CLC   DIRNAME,MEMNAME      SAME MEMBER?                        07513000
         BE    IF442                YES, BRANCH                         07514000
         LA    R3,1                 AN APPARENT ALIAS MEMBER            07515000
         SPACE 1                                                        07516000
IF444    CLI   #AALIAS,X'01'        "APPARENTALIAS" OR "NOAPPAREN.."?   07517000
         BL    IF460                NEITHER, BRANCH                     07518000
         BH    IF446                "NOAPPARENTALIAS", BRANCH           07519000
         LTR   R3,R3                "APPARENTALIAS" -- CORRECT?         07520000
         BP    IF460                YES, BRANCH                         07521000
         B     IF997                NO, DO ANY ELSE                     07522000
IF446    LTR   R3,R3                APPARENT ALIAS?                     07523000
         BP    IF997                YES, DO ANY ELSE                    07524000
         SPACE 3                                                        07525000
IF460    CLI   #ORPHAN,X'01'        ORPHAN MEMBER CHECK?                07526000
         BL    IF470                NO, BRANCH                          07527000
         TM    DIRFLAG,X'80'        MEMBER AN ALIAS?                    07528000
         BNO   IF463                NO, CANNOT BE AN ORPHAN             07529000
         MVI   STARTTR+2,X'01'      TTR=000001 (START OF DIRECTORY)     07530000
         LA    R3,1                 ASSUME IT IS AN ORPHAN              07531000
         SPACE 1                                                        07532000
IF462    BAL   R14,READDIR          GET NEXT DIRECTORY MEMBER           07533000
         B     IF464                LAST MEMBER PROCESSED               07534000
         SPACE 1                                                        07535000
         TM    MEMFLAG,X'80'        IS THIS AN ALIAS?                   07536000
         BO    IF462                YES, IGNORE                         07537000
         CLC   DIRTTR,MEMTTR        TTR MATCH?                          07538000
         BNE   IF462                NO, BRANCH                          07539000
IF463    SR    R3,R3                NOT AN ORPHAN                       07540000
         SPACE 1                                                        07541000
IF464    CLI   #ORPHAN,X'01'        "ORPHAN" OR "NOORPHAN"?             07542000
         BL    IF470                NEITHER, BRANCH                     07543000
         BH    IF466                "NOORPHAN", BRANCH                  07544000
         LTR   R3,R3                "ORPHAN" -- CORRECT?                07545000
         BP    IF470                YES, BRANCH                         07546000
         B     IF997                NO, DO ANY ELSE                     07547000
IF466    LTR   R3,R3                ORPHAN?                             07548000
         BP    IF997                YES, DO ANY ELSE                    07549000
         SPACE 3                                                        07550000
IF470    CLI   #RLD0,X'01'          "RLDZERO" OR "NORLDZERO"            07551000
         BL    IF476                NEITHER, BRANCH                     07552000
         BH    IF472                "NORLDZERO", BRANCH                 07553000
         CLI   DIRATTR4,0           "RLDZERO" -- CORRECT?               07554000
         BE    IF476                YES, BRANCH                         07555000
         B     IF997                NO, DO ANY ELSE                     07556000
IF472    CLI   DIRATTR4,0           "NORLDZERO" -- CORRECT?             07557000
         BE    IF997                YES, DO ANY ELSE                    07558000
         SPACE 1                                                        07559000
IF476    TM    FLAGSCC,RECFMU            LOAD MODULE?                   07560000
         BO    IF490                     YES, BRANCH                    07561000
         CLI   #IFCREIF+2,0              ANY CREATION DATE?             07562000
         BE    IF480                     NO, CHECK FOR MODIFICATION     07563000
         TM    DIRFLAG,X'0F'             SPF STATISTICS?                07564000
         BNO   IF997                     NO, DO ANY ELSE                07565000
         CLC   #IFCREIF(3),DIRSPFCR+1    HIGHER THAN DIRECTORY?         07566000
         BH    IF997                     YES, DO ANY ELSE               07567000
         CLC   #IFCREIF+3(3),DIRSPFCR+1  LOWER THAN DIRECTORY?          07568000
         BL    IF997                     YES, DO ANY ELSE               07569000
         SPACE 1                                                        07570000
IF480    CLI   #IFMODIF+2,0              ANY MODIFICATION DATE?         07571000
         BE    IF490                     NO, CONTINUE                   07572000
         TM    DIRFLAG,X'0F'             SPF STATISTICS?                07573000
         BNO   IF997                     NO, DO ANY ELSE                07574000
         CLC   #IFMODIF(3),DIRSPFCD+1    HIGHER THAN DIRECTORY?         07575000
         BH    IF997                     YES, DO ANY ELSE               07576000
         CLC   #IFMODIF+3(3),DIRSPFCD+1  LOWER THAN DIRECTORY?          07577000
         BL    IF997                     YES, DO ANY ELSE               07578000
         SPACE 3                                                        07579000
IF490    DS    0H                                                       07580000
         SPACE 1                                                        07581000
IF996    MVC   FINDMEMQ+25(4),=C'THEN'                                  07582000
         L     R2,#ACTIONT          THEN ACTION                         07583000
         B     IF998                                                    07584000
         SPACE 1                                                        07585000
IF997    MVC   FINDMEMQ+25(4),=C'ELSE'                                  07586000
         L     R2,#ACTIONE          ELSE ACTION                         07587000
         SPACE 1                                                        07588000
IF998    LTR   R2,R2                ANY ASSOCIATED ACTION?              07589000
         BNP   NEWCMD               NO, BRANCH                          07590000
         TM    ##ADRPA#-##SUBCOM(R2),$D  DEFAULT MESSAGE SUBCOMMAND?    07591000
         BNZ   IF999                     NO, BRANCH                     07592000
         SPACE 1                                                        07593000
         MESSAGE MSGBLANK                                               07594000
         TM    FLAGSAA,FINDMSG      ANY HEADER MESSAGE?                 07595000
         BNO   IF999                NO, BRANCH                          07596000
         XI    FLAGSAA,FINDMSG      NO MORE MESSAGE                     07597000
         MVC   FINDMEMQ+30(8),0(R2) SUBCOMMAND NAME                     07598000
         MESSAGE FINDMEMQ           OUTPUT THE HEADER MESSAGE           07599000
         SPACE 1                                                        07600000
IF999    MVC   ##ANSWER(LISUBS),ISUBS INITIALIZE THE PDL SAVE AREA      07601000
         MVC   ##SUBCOM(PTW),0(R2)    CHANGE THE SUBCOMMAND             07602000
         B     CALLCMDZ               CALL THE SECONDARY SUBCOMMAND     07603000
         TITLE 'P D S  --  PDS LIST, DIRENTRY, FIND            1/15/85' 07604000
*********************************************************************** 07605000
***      LIST SUBCOMMAND    MODIFIED BY BRUCE LELAND -- JUNE, 1982  *** 07606000
***                                                                 *** 07607000
***      DIRENTRY SUBCOMMAND   ADDED BY BRUCE LELAND -- JUNE, 1982  *** 07608000
***                                                                 *** 07609000
***      FIND SUBCOMMAND    MODIFIED BY BRUCE LELAND -- JUNE, 1982  *** 07610000
*********************************************************************** 07611000
*                                                                       07612000
LIST     CSECT                                                          07613000
         USING *,R8                                                     07614000
         MVC   ##HELOFF(4),=C'LIST'                                     07615000
         B     LIST010                                                  07616000
*                                                                       07617000
         SPACE 1                                                        07618000
DIRENTRY L     R8,$LIS+8           BASE REGISTER FOR LIST               07619000
         LA    R1,L530             ASSUME A NON-PARTITIONED DATA SET    07620000
         TM    DSORG,DS1DSGPO      CORRECT?                             07621000
         BZ    MSGNEW              YES, ERROR                           07622000
         SPACE 1                                                        07623000
         MVC   ##HELOFF(4),=C'DIRE'                                     07624000
         IC    R1,DIRFLAG                                               07625000
         N     R1,=XL4'0000001F'   NUMBER OF HALFWORDS                  07626000
         LA    R5,12(R1,R1)        LENGTH IN BYTES                      07627000
         LA    R6,DIRNAME          START OF DIRECTORY ENTRY             07628000
         LA    R4,16               DUMP FORMAT, WIDTH=16                07629000
         MVI   MTHIGHL+4,2                                              07630000
         MVC   MSGTEXT1(3),L143$2  DIRECTORY DUMP HEADER                07631000
         MVC   INSERT#1(8),DIRNAME                                      07632000
         CVD   R5,DOUBLE                                                07633000
         MVC   INSERT#2-2(4),=X'40202120'                               07634000
         ED    INSERT#2-2(4),DOUBLE+6                                   07635000
         AR    R5,R6                                                    07636000
         BCTR  R5,0                                                     07637000
         LA    R3,LIST610          PROCESSING ROUTINE                   07638000
         BR    R3                                                       07639000
         SPACE 2                                                        07640000
*                                                                       07641000
FIND     L     R8,$LIS+8           BASE REGISTER FOR LIST               07642000
         CLI   FINDLTH+1,0         STRING EVER CODED?                   07643000
         LA    R1,L770                                                  07644000
         BZ    MSGNEWXX            NO, TERMINATE THIS GROUP             07645000
         MVC   ##HELOFF(4),=C'FIND'                                     07646000
         XC    WORKTBL,WORKTBL     RESET THE TRT TABLE                  07647000
         SR    R15,R15                                                  07648000
         IC    R15,FINDSTR         FIRST CHARACTER OF NEW STRING        07649000
         LA    R1,WORKTBL(R15)     ADDRESS OF NEW TRT BYTE              07650000
         MVI   0(R1),X'77'         SET TRT BYTE TO NON-ZERO             07651000
         SPACE 2                                                        07652000
LIST010  MVC   FLAGSDD(1),HFLAGSDD INITIALIZE FLAGSDD                   07653000
         OC    #MAXIN,#MAXIN       ANY INPUT DESIRED?                   07654000
         BZ    LIST910             NO, BRANCH                           07655000
         SPACE 2                                                        07656000
         TM    DSORG,DS1DSGPO        DSORG=PO?                          07657000
         BNO   LIST090               NO, BRANCH                         07658000
         TM    FLAGSCC,RECFMU        LOAD MODULE?                       07659000
         BNO   LIST090               NO, BRANCH                         07660000
         TM    FLAGSDD,LBLOCK+LDUMP+BLOCK+DUMP  ANY LOAD FORMAT?        07661000
         BM    LIST020                          YES, BRANCH             07662000
         MVI   FLAGSDD,LDUMP                    NO, USE LDUMP           07663000
LIST020  TM    FLAGSDD,LBLOCK+LDUMP  LBLOCK OR LDUMP FORMAT?            07664000
         BZ    LIST090               NO, BRANCH                         07665000
         SPACE 1                                                        07666000
         LA    R2,#ESDPTR          START OF ESD LIST                    07667000
         L     R15,=A(READESD)     ESD SYMBOL ROUTINE                   07668000
         BALR  R14,R15             ANY SYMBOLS?                         07669000
         B     *+8                 NO, "NO EXTERNAL SYMBOLS"            07670000
         B     LIST030             YES, BRANCH                          07671000
         SPACE 2                                                        07672000
         MVC   INSERT#1(8),DIRNAME MEMBER NAME IN ERROR                 07673000
         TSMSG L704$1              OUTPUT AN ERROR MESSAGE              07674000
         B     LIST090             CONTINUE, BUT NO CSECT IDENTIFIERS   07675000
         SPACE 2                                                        07676000
         USING ESDENTRY,R2                                              07677000
*  LOOPS TO SET MAXIMUM LENGTH FIELDS FOR LABEL REFERENCE ENTRIES       07678000
*  AND TO ASSOCIATE ENTRY RECORDS WITH THE APPROPRIATE CSECT NAMES      07679000
LIST030  OI    #LISTFLG,X'01'      CSECT OPERATION FLAG                 07680000
         ICM   R2,B'1111',ESDLINK  ANY MORE ENTRIES?                    07681000
         BZ    LIST060             NO, BRANCH                           07682000
         MVI   ESDSEG#,0           CLEAR THE SEGMENT NUMBER             07683000
         CLI   ESDTYPE,CODESD      CSECT ENTRY?                         07684000
         BNE   LIST030             NO, BRANCH                           07685000
         LR    R1,R2                                                    07686000
         SPACE 1                                                        07687000
LIST040  ICM   R1,B'1111',ESDLINK-ESDENTRY(R1)                          07688000
         BZ    LIST060                                                  07689000
         CLI   ESDTYPE-ESDENTRY(R1),CODELR  ASSOCIATED EXTERNAL LABEL?  07690000
         BNE   LIST030                      NO, BRANCH                  07691000
         MVI   ESDSEG#-ESDENTRY(R1),0       CLEAR THE SEGMENT NUMBER    07692000
         ST    R2,ESDCSECT-ESDENTRY(R1)     SAVE POINTER TO NAME        07693000
         SR    R14,R14                                                  07694000
         LH    R0,ESDID                     RELATIVE ESDID OF CSECT     07695000
         STH   R0,ESDID-ESDENTRY(R1)        SAVE FOR ENTRY              07696000
         L     R0,ESDADDR-1                 BASE START ADDRESS          07697000
         ST    R0,ESDMAIN-ESDENTRY(R1)      SAVE MAIN OFFSET            07698000
         A     R0,ESDLEN-1                  BASE MAXIMUM REFERENCE      07699000
         ICM   R14,B'0111',ESDADDR-ESDENTRY(R1)                         07700000
         SR    R0,R14                                                   07701000
         ST    R0,ESDLEN-ESDENTRY-1(R1)     MAXIMUM SYMBOL LENGTH       07702000
         B     LIST040                                                  07703000
         SPACE 2                                                        07704000
*  LOOP TO FILTER THE SYMBOL NAMES                                      07705000
LIST060  LA    R2,#ESDPTR          START OF ESD LIST                    07706000
         SR    R3,R3                                                    07707000
         ICM   R3,B'0001',#MODLEN  ANY FILTERING?                       07708000
         BZ    LIST090             NO, BRANCH                           07709000
         BCTR  R3,0                MACHINE LENGTH                       07710000
         SPACE 1                                                        07711000
LIST070  LR    R1,R2                                                    07712000
         ICM   R2,B'1111',ESDLINK  END OF LIST?                         07713000
         BZ    LIST090             YES, BRANCH                          07714000
         CLC   ESDNAME(*-*),#MODTXT  <<EXECUTED>>                       07715000
         EX    R3,*-6              MATCH THE PARTIAL NAME?              07716000
         BE    LIST070             YES, BRANCH                          07717000
         MVC   ESDLINK-ESDENTRY(4,R1),ESDLINK                           07718000
         LR    R2,R1                    DROP THIS SYMBOL                07719000
         B     LIST070                                                  07720000
         SPACE 1                                                        07721000
LIST090  MVC   STARTTR(3),DIRTTR   FIRST TTR                            07722000
         SPACE 2                                                        07723000
LIST100  L     R15,=A(EXCP)                                             07724000
         BALR  R14,R15                                                  07725000
         B     *+4(R15)                 PROCESS RETURN CODE             07726000
         B     LIST120                    00 - GOOD READ                07727000
         B     LIST110                    04 - END OF MEMBER            07728000
         B     LIST900                    08 - END OF DATA SET          07729000
         B     LIST910                    12 - I/O ERROR                07730000
         SPACE 1                                                        07731000
LIST110  TM    DSORG,DS1DSGIS           ISAM DATA SET?                  07732000
         BNO   LIST900                  NO, BRANCH                      07733000
         TSMSG L005                     YES, OUTPUT A MESSAGE           07734000
         B     LIST100                  CONTINUE                        07735000
         SPACE 1                                                        07736000
LIST120  NI    #LISTFLG,FF-X'20'        TURN OFF THE CSECT DATA FLAG    07737000
         L     R5,LS                    CURRENT LENGTH                  07738000
         LR    R6,R0                    START OF BUFFER                 07739000
         LR    R1,R5                    SAVE BLOCKSIZE FOR LATER        07740000
         LM    R14,R15,#LISTN0          SAVE IF NOT PHYSICAL BLOCKS     07741000
         L     R0,#LISTN0               PREVIOUS MEMBER DISPLACEMENT    07742000
         ST    R0,#LISTN1               UPDATE MEMBER DISPLACEMENT      07743000
         AR    R0,R5                    ADD CURRENT LENGTH FOR NEXT     07744000
         ST    R0,#LISTN0               UPDATE FOR NEXT ENTRY           07745000
         TM    FLAGSDD,BLOCK            BLOCK OUTPUT DESIRED?           07746000
         BO    LIST400                  YES, BRANCH                     07747000
         TM    FLAGSDD,DUMP             DUMP OUTPUT DESIRED?            07748000
         BO    LIST420                  YES, BRANCH                     07749000
         STM   R14,R15,#LISTN0          NOT PHYSICAL BLOCKS             07750000
         AR    R5,R6                    ADDRESS OF END OF BUFFER        07751000
         BCTR  R5,0                     END OF BUFFER ADDRESS           07752000
         LA    R3,LIST200               ASSUME FIXED OR UNDEFINED       07753000
         TM    FLAGSCC,RECFMF           RECFM=F?                        07754000
         LH    R4,LRECL                 GET RECORD LENGTH               07755000
         BOR   R3                       YES, BRANCH                     07756000
         SPACE 1                                                        07757000
         TM    FLAGSCC,RECFMU           RECFM=U?                        07758000
         LR    R4,R1                    BLOCK LENGTH                    07759000
         BOR   R3                       YES, BRANCH                     07760000
         TM    FLAGSCC,RECFMV           RECFM=V?                        07761000
         BNOR  R3                       NO, PROCESS LIKE RECFM=U        07762000
         SPACE 1                        SET END OF BUFFER ADDRESS       07763000
         AH    R6,=H'4'                 RECFM=V; START OF LRECL'S       07764000
         LA    R3,LIST150               VARIABLE LEN RECORD PROCESSOR   07765000
         SPACE 2                                                        07766000
LIST150  SR    R4,R4                                                    07767000
         ICM   R4,B'0011',0(R6)         RECORD LENGTH +4                07768000
         AH    R6,=H'4'                 SKIP OVER HEADER                07769000
         SH    R4,=H'4'                 SUBTRACT HEADER LENGTH          07770000
         BP    LIST200                  BRANCH IF RECORD EXISTS         07771000
         SR    R4,R4                    NO, RESET LENGTH TO ZERO        07772000
         SPACE 1                                                        07773000
LIST160  LR    R0,R4                    PREVIOUS RECORD LENGTH          07774000
         A     R0,#LISTN1               OFFSET IN CURRENT RECORD        07775000
         ST    R0,#LISTN1               UPDATE                          07776000
         BXLE  R6,R4,0(R3)              SKIP TO NEXT RECORD             07777000
         L     R2,=A(DIR000)            DIRENTRY ELEMENT LIST      @D04
         CLI   ##HELOFF,C'D'            DIRENTRY SUBCOMMAND?            07778000
**       BE    NEWCMD                   YES, BRANCH                @D04 07779000
         BER   R2                       YES, BRANCH                @D04
         TM    FLAGSDD,LBLOCK+LDUMP     LBLOCK OR LDUMP?                07780000
         BZ    LIST100                  NO, GET A NEW BLOCK             07781000
         LM    R3,R6,#LFSAVE4           RESTORE R3-R6                   07782000
         BXLE  R6,R4,0(R3)              SKIP TO NEXT RECORD             07783000
         B     LIST100                  REAL END OF BLOCK               07784000
         SPACE 3                                                        07785000
LIST200  L     R0,#LISTN0               PREVIOUS MEMBER DISPLACEMENT    07786000
         ST    R0,#LISTN1               UPDATE MEMBER DISPLACEMENT      07787000
         AR    R0,R4                    ADD CURRENT LENGTH FOR NEXT     07788000
         ST    R0,#LISTN0               UPDATE FOR NEXT ENTRY           07789000
         L     R0,#BLKCNT                                               07790000
         A     R0,=F'1'                                                 07791000
         ST    R0,#BLKCNT                                               07792000
         STM   R3,R6,#LFSAVE4             SAVE FOR LBLOCK/LDUMP         07793000
         L     R0,#SKIPREC                                              07794000
         S     R0,=F'1'                   SKIP THIS RECORD?             07795000
         ST    R0,#SKIPREC                                              07796000
         BNM   LIST160                    YES, BRANCH                   07797000
         L     R0,#MAXIN                                                07798000
         S     R0,=F'1'                   SUFFICIENT INPUT RECORDS?     07799000
         ST    R0,#MAXIN                                                07800000
         BM    LIST910                    YES, BRANCH                   07801000
LIST210  LR    R1,R4                      LENGTH OF DATA AREA           07802000
         TM    FLAGSDD,LBLOCK             LBLOCK?                       07803000
         BO    LIST400                    YES, BRANCH                   07804000
         TM    FLAGSDD,LDUMP              LDUMP?                        07805000
         BO    LIST420                    YES, BRANCH                   07806000
         LA    R0,8                       WIDTH OF LINE NUMBER FIELD    07807000
         LR    R15,R6                     MOVE START POSITION           07808000
         LR    R14,R15                    LINE NUMBER FOR RECFM=V OR U  07809000
         A     R15,#SKIPCOL               ADJUST START FOR START COLUMN 07810000
         S     R1,#SKIPCOL                ADJUST LEN FOR START COLUMN   07811000
         TM    FLAGSDD,NONUM+DONONUM      NONUM FORMAT?                 07812000
         BNZ   LIST330                    YES, BRANCH                   07813000
         AR    R15,R0                     ADJUST START FOR RECFM=V OR U 07814000
         SR    R1,R0                      ADJUST LENGTH, RECFM=V U OR F 07815000
         TM    FLAGSCC,RECFMF             RECFM=F?                      07816000
         BNO   LIST230                    NO, BRANCH                    07817000
         SR    R15,R0                     CORRECT DATA START POINTER    07818000
         LA    R14,0(R4,R6)               END OF LINE                   07819000
         SR    R14,R0                     START OF LINE NUMBER          07820000
LIST230  TM    FLAGSDD,SNUM               SNUM FORMAT?                  07821000
         BO    LIST330                    YES, BRANCH                   07822000
         MVC   MSGLINE+4(8),0(R14)        NUM FORMAT -- GET LINE NUMBER 07823000
         NC    MSGLINE+4(8),=C'00000000'  DROP NUMERIC PART             07824000
         CLC   MSGLINE+4(8),=C'00000000'  ZONE DIGITS FOR ALL BYTES?    07825000
         BE    LIST240                    YES, BRANCH                   07826000
         OI    FLAGSDD,DONONUM            CONTINUE WITH NONUM FORMAT    07827000
         B     LIST210                                                  07828000
         SPACE 1                                                        07829000
LIST240  MVC   MSGLINE+4(6),0(R14)        SPF LINE NUMBER FIELD         07830000
         TM    DIRFLAG,X'0F'              SPF ATTRIBUTES STORED?        07831000
         BO    LIST320                    YES, BRANCH                   07832000
         LA    R0,5                       MAXIMUM OF 5 DIGITS TO BLANK  07833000
         LA    R2,MSGLINE+3               START OF FIELD TO BLANK       07834000
         MVC   MSGLINE+4(6),2(R14)        LINE NUMBER FIELD             07835000
LIST310  LA    R2,1(,R2)                                                07836000
         CLI   0(R2),C'0'                 BLANK LEADING ZEROES IN THE   07837000
         BNE   LIST320                       LINE NUMBER FIELD          07838000
         MVI   0(R2),X'40'                                              07839000
         BCT   R0,LIST310                 DO UP TO 5 DIGITS             07840000
LIST320  LA    R0,249                     MAXIMUM ALLOWED DATA LENGTH   07841000
         MVI   MSGLINE+10,X'40'           BLANK AFTER LINE NUMBER       07842000
         LA    R14,MSGLINE+11             WHERE TO MOVE DATA            07843000
         B     LIST340                                                  07844000
         SPACE 2                                                        07845000
LIST330  LA    R0,256                   MAXIMUM LRECL TO DISPLAY        07846000
         LA    R14,MSGLINE+4            WHERE TO MOVE OUTPUT DATA       07847000
         SPACE 1                                                        07848000
LIST340  CR    R1,R0                    LENGTH>MAXIMUM ALLOWED?         07849000
         BL    *+6                      NO, BRANCH                      07850000
         LR    R1,R0                    YES, USE MAXIMUM                07851000
         S     R1,=F'1'                 MACHINE LENGTH VALID?           07852000
         BM    LIST360                  NO, BRANCH                      07853000
         MVC   0(*-*,R14),0(R15)        <<EXECUTED>>                    07854000
         EX    R1,*-6                   MOVE DATA INTO LINE             07855000
         SPACE 1                                                        07856000
LIST360  LR    R2,R1                    MACHINE LENGTH                  07857000
         LA    R1,MSGLINE+4             START OF DATA                   07858000
         CR    R14,R1                   NUM MODE?                       07859000
         BE    *+8                      NO, BRANCH                      07860000
         AH    R2,=H'7'                 YES, ACCOUNT FOR LINE NO, BLANK 07861000
         A     R2,=F'1'                 ACTUAL DATA LENGTH              07862000
         C     R2,#MAXLEN               LENGTH>#MAXLEN?                 07863000
         BL    *+8                      NO, BRANCH                      07864000
         L     R2,#MAXLEN               YES, USE #MAXLEN INSTEAD        07865000
         S     R2,=F'1'                 MACHINE LENGTH VALID?           07866000
         BM    LIST160                  LENGTH=0, BRANCH                07867000
         LA    R0,5(,R2)                ACTUAL LINE LENGTH + HALFWORDS  07868000
         SLL   R0,16                                                    07869000
         ST    R0,MSGLINE               CREATE OUTPUT LINE HEADER       07870000
         CLI   ##HELOFF,C'F'            FIND OPERATION?                 07871000
         BNE   LIST730                  NO, LIST -- BRANCH              07872000
         SPACE 1                                                        07873000
         LA    R14,1(R1,R2)             END OF DATA                     07874000
         LH    R15,FINDLTH              STRING LENGTH                   07875000
         BCTR  R15,0                    MACHINE LENGTH                  07876000
LIST370  EX    R2,LIST380               FIRST CHARACTER FOUND?          07877000
         BZ    LIST160                  NO, NOT IN STRING, QUIT         07878000
         LR    R2,R14                                                   07879000
         SR    R2,R1                    MACHINE LENGTH LEFT             07880000
         CR    R15,R2                   POSSIBLY IN STRING?             07881000
         BNL   LIST160                  NO, QUIT                        07882000
         EX    R15,LIST390              ENTIRE STRING FOUND?            07883000
         BE    LIST730                  YES, OUTPUT THE LINE            07884000
         LA    R1,1(,R1)                NO, TRY NEXT CHARACTER          07885000
         LR    R2,R14                                                   07886000
         SR    R2,R1                    MACHINE LENGTH LEFT NEGATIVE?   07887000
         BM    LIST160                  YES, NOT IN STRING, QUIT        07888000
         B     LIST370                  CONTINUE SEARCHING              07889000
         SPACE 2                                                        07890000
LIST380  TRT   0(*-*,R1),WORKTBL        <<EXECUTED>> -- FIRST BYTE      07891000
LIST390  CLC   0(*-*,R1),FINDSTR        <<EXECUTED>> -- COMPLETE STRING 07892000
         SPACE 3                                                        07893000
LIST400  LA    R4,64                    BLOCK FORMAT, WIDTH=64          07894000
         LA    R3,LIST600               PROCESSING ROUTINE              07895000
         B     LIST430                  FORMAT HEADER                   07896000
         SPACE 1                                                        07897000
LIST420  LA    R4,16                    DUMP FORMAT, WIDTH=16           07898000
         LA    R3,LIST610               PROCESSING ROUTINE              07899000
         SPACE 1                                                        07900000
LIST430  L     R0,#SKIPCOL              CHARACTERS TO SKIP              07901000
         ST    R0,#LISTN2               UPDATE BLOCK OFFSET             07902000
         A     R0,#LISTN1               CURRENT DATA                    07903000
         ST    R0,#LISTN1                           DISPLACEMENT        07904000
         MVI   MTHIGHL,5                                                07905000
         MVI   MTHIGHL+4,L'MSGDUMP-1                                    07906000
         MVC   MSGTEXT1(3),L140$2                                       07907000
         MVC   INSERT#1(5),=C'BLOCK'                                    07908000
         MVC   INSERT#2-1(40),MSGDUMP   HEADER FOR BLOCK OR DUMP        07909000
         NI    FLAGSDD,FF-OVERLAP       TURN OFF THE OVERLAP INDICATOR  07910000
         LR    R5,R1                    DATA LENGTH                     07911000
         C     R5,#MAXLEN               RESTRICT DATA LENGTH?           07912000
         BL    *+8                      NO, BRANCH                      07913000
         L     R5,#MAXLEN               YES, USE MAX LENGTH             07914000
         AR    R5,R6                    COMPUTE NEW END-OF-BLOCK        07915000
         BCTR  R5,0                     COMPUTE NEW END-OF-BLOCK -1     07916000
         A     R6,#SKIPCOL              ADJUST FOR START COLUMN         07917000
         TM    FLAGSDD,LBLOCK+LDUMP     LBLOCK OR LDUMP?                07918000
         BM    LIST450                  YES, BRANCH                     07919000
         L     R0,#BLKCNT                                               07920000
         A     R0,=F'1'                                                 07921000
         ST    R0,#BLKCNT                                               07922000
         CVD   R0,DOUBLE                                                07923000
         ED    INSERT#2-1(10),DOUBLE+4                                  07924000
         L     R0,#SKIPREC                                              07925000
         S     R0,=F'1'                 SKIP THIS RECORD?               07926000
         ST    R0,#SKIPREC                                              07927000
         BNM   LIST100                  YES, BRANCH                     07928000
         L     R0,#MAXIN                                                07929000
         S     R0,=F'1'                 SUFFICIENT INPUT RECORDS?       07930000
         ST    R0,#MAXIN                                                07931000
         BM    LIST910                  YES, BRANCH                     07932000
         CVD   R1,DOUBLE                  RECORD LENGTH                 07933000
         ED    INSERT#2+MSGDUMPL-MSGDUMP-1(7),DOUBLE+5                  07934000
         STM   R14,R12,12(R13)            CONVERT CCHHR TO TTR          07935000
         LA    R2,CURMBB                  CCHHR TO CONVERT              07936000
         L     R1,INDCB+(DCBDEBAD-IHADCB) DEB ADDRESS                   07937000
         L     R15,ADDRRLTV               ADDRESS OF CCHHR->TTR CONVERT 07938000
         LR    R3,R13                     ADDRESS OF SAVE AREA          07939000
         BALR  R14,R15                    CALL CONVERT ROUTINE          07940000
         LR    R13,R3                     RESTORE SAVE AREA ADDRESS     07941000
         ST    R0,12+4+4(R13)             RESULT TTR RETURNED IN R0     07942000
         LM    R14,R12,12(R13)            RESTORE REGISTERS             07943000
         ST    R0,DOUBLE                SAVE RESULTING TTR              07944000
         UNPK  INSERT#2+MSGDUMPT-MSGDUMP-1(7),DOUBLE(4)                 07945000
         TR    INSERT#2+MSGDUMPT-MSGDUMP-1(6),TRTABLE                   07946000
         MVI   INSERT#2+MSGDUMPT-MSGDUMP+6-1,X'40'                      07947000
         TM    FLAGSDD,DUMP                                             07948000
         BNOR  R3                                                       07949000
         MVC   INSERT#1(5),=C'DUMP '                                    07950000
         BR    R3                                                       07951000
         SPACE 2                                                        07952000
LIST450  TM    #LISTFLG,X'01'           CSECT FORMATTING?               07953000
         BNOR  R3                       NO, BRANCH                      07954000
         OI    #LISTFLG,X'08'           NEED A HEADER CHANGE            07955000
         ST    R4,#LISTWD               WIDTH OF EACH LINE              07956000
         L     R6,EXCPBUFF              BUFFER START                    07957000
         L     R5,LS                    BUFFER LENGTH                   07958000
         AR    R5,R6                    END OF BUFFER                   07959000
         BCTR  R5,0                     END OF BUFFER -1                07960000
         TM    #LISTFLG,X'40'           ANY CSECT ADDRESS YET?          07961000
         BO    LIST460                  YES, BRANCH                     07962000
         TM    0(R6),X'F0'              TEST, SCATTER, CESD OR IDR?     07963000
         BM    LIST100                  YES, BRANCH                     07964000
LIST460  TM    #LISTFLG,X'C0'           ANY CURRENT ESD RECORD?         07965000
         BO    LIST470                  YES, THIS IS A DATA RECORD      07966000
         CLI   8(R6),X'06'              AN ESD RECORD?                  07967000
         BNE   LIST100                  NO, BRANCH                      07968000
         OI    #LISTFLG,X'C0'           FLAGS FOR ESD RECORD INPUT      07969000
         MVC   #LISTVIR+1(3),9(R6)      SAVE THE OFFSET ADDRESS         07970000
         LH    R15,6(R6)                OFFSET TO ESDID                 07971000
         LA    R5,16(R15,R6)            FIRST ESDID FOR THIS BLOCK      07972000
         LH    R6,4(R6)                 ESDID ENTRIES *4                07973000
         SRL   R6,2                     ESDID ENTRIES                   07974000
         LA    R2,#ESDPTR               START OF ESD ADDRESSES          07975000
         SPACE 2                                                        07976000
*  LOOP TO MARK ENTRIES FOR THE NEXT PHYSICAL BLOCK                     07977000
LIST464  ICM   R2,B'1111',ESDLINK       NEXT ENTRY?                     07978000
         BZ    LIST100                  NO, DONE                        07979000
         MVI   ESDIDIN,0                TURN OFF FIRST                  07980000
         LR    R14,R5                   START OF ESDID LIST             07981000
         LR    R15,R6                   NUMBER OF ESDID ENTRIES         07982000
         SPACE 1                                                        07983000
LIST468  CLC   0(2,R14),ESDID           THIS ENTRY?                     07984000
         BNE   *+8                      NO, BRANCH                      07985000
         MVI   ESDIDIN,1                YES, MARK IT                    07986000
         LA    R14,4(,R14)              NEXT ESDID ENTRY                07987000
         BCT   R15,LIST468              MARK ALL ENTRIES THAT MATCH     07988000
         B     LIST464                  CHECK ALL ESD ENTRIES           07989000
         SPACE 3                                                        07990000
LIST470  XI    #LISTFLG,X'A0'           OFF CURRENT ESD; ON CSECT DATA  07991000
         L     R0,#LISTVIR              BLOCK OFFSET                    07992000
         L     R14,#LISTOFF             OFFSET                          07993000
         ST    R14,#LISTN2              BLOCK OFFSET                    07994000
         A     R14,#LISTN1              DATA                            07995000
         ST    R14,#LISTN1                  DISPLACEMENT                07996000
         ICM   R14,B'1111',#LISTOFF     ANY OFFSET?                     07997000
         BP    *+6                      YES, BRANCH                     07998000
         LR    R14,R0                   NO, USE THE BLOCK OFFSET        07999000
         SR    R6,R0                                                    08000000
         ST    R6,#LISTVIR              VIRTUAL BUFFER START ADDRESS    08001000
         LA    R2,#ESDPTR               START OF ESD ADDRESSES          08002000
         AR    R6,R14                   OFFSET --> ACTUAL ADDRESS       08003000
         SPACE 2                                                        08004000
*  LOOP TO FIND A START ENTRY                                           08005000
LIST480  ICM   R2,B'1111',ESDLINK       NEXT ENTRY?                     08006000
         BZ    LIST100                  NO, DONE                        08007000
         SR    R14,R14                                                  08008000
         ICM   R14,B'0111',ESDADDR      START ADDRESS OF SYMBOL         08009000
         LR    R15,R14                  CSECT START OFFSET              08010000
         A     R14,#LISTVIR             OFFSET --> ADDR OF CSECT START  08011000
         A     R15,ESDLEN-1             CSECT END OFFSET                08012000
         A     R15,#LISTVIR             OFFSET --> ADDRESS OF CSECT END 08013000
         CR    R6,R15                   CURRENT:CSECT END               08014000
         BNL   LIST480                    HIGH OR EQUAL, LOOP FOR NEXT  08015000
         CR    R5,R14                   END:CSECT START                 08016000
         BL    LIST480                    LOW, LOOP FOR NEXT            08017000
         CLI   ESDIDIN,1                THIS CSECT ACTIVE?              08018000
         BNE   LIST480                  NO, LOOP FOR NEXT               08019000
         MVC   #LISTID(2),ESDID         YES, MARK THE CURRENT ESDID     08020000
         ST    R2,#LISTENT              SAVE THIS ENTRY START           08021000
         LR    R1,R2                                                    08022000
         SPACE 1                                                        08023000
LIST490  ICM   R1,B'1111',ESDLINK-ESDENTRY(R1)  NEXT ENTRY?             08024000
         BZR   R3                               NO, DONE                08025000
         CLC   #LISTID(2),ESDID-ESDENTRY(R1)    SAME ESDID ON NEXT ONE? 08026000
         BNER  R3                               NO, DONE                08027000
         ICM   R15,B'0111',ESDADDR-ESDENTRY(R1) NEXT ENTRY START        08028000
         A     R15,#LISTVIR                     OFFSET --> NEXT START   08029000
         CR    R14,R15                          CSECT START:NEXT ENTRY  08030000
         BE    LIST490                            SAME, IGNORE ENTRY    08031000
         CR    R15,R6                           NEXT START:CURRENT      08032000
         BNH   LIST480                            NOT ABOVE, USE NEXT   08033000
         BR    R3                                                       08034000
         SPACE 3                                                        08035000
LIST600  BAL   R14,LIST800              PERFORM ANY CSECT POSITIONING   08036000
         LR    R2,R4                    DATA LENGTH                     08037000
         LR    R14,R5                                                   08038000
         SR    R14,R6                   MACHINE LENGTH VALID?           08039000
         BM    LIST160                  NO, BRANCH                      08040000
         CR    R2,R14                                                   08041000
         BNH   *+8                                                      08042000
         LA    R2,1(,R14)               DATA LENGTH FOR THIS SEGMENT    08043000
         BCTR  R2,0                     MACHINE LENGTH FOR THE SEGMENT  08044000
         MVI   MSGLINE+17,C'*'          BEGINNING *                     08045000
         MVC   MSGLINE+18(*-*),0(R6)    <<EXECUTED>>                    08046000
         EX    R2,*-6                   MOVE IN TEXT                    08047000
         LA    R1,MSGLINE+18+1(R2)      POSITION OF FINAL ASTERISK      08048000
         MVI   0(R1),C'*'               FINAL *                         08049000
         UNPK  MSGLINE+4(7),#LISTN1+1(4)    UNPACK ADDRESS              08050000
         TR    MSGLINE+4(6),TRTABLE         CONVERT TO HEXADECIMAL      08051000
         MVI   MSGLINE+10,X'40'             BLANK THE FOLLOWING BYTE    08052000
         UNPK  DOUBLE(7),#LISTN2+1(4)       UNPACK ADDRESS              08053000
         TR    DOUBLE(7),TRTABLE            CONVERT TO HEXADECIMAL      08054000
         MVC   MSGLINE+11(4),DOUBLE+2       MOVE IN ADDRESS             08055000
         MVI   MSGLINE+15,X'40'             BLANK THE FOLLOWING BYTE    08056000
         CLI   DOUBLE+1,C'0'                LESS THAN 64K?              08057000
         BE    *+10                         YES, BRANCH                 08058000
         MVC   MSGLINE+11(5),DOUBLE+1       MOVE IN ADDRESS             08059000
         MVI   MSGLINE+16,X'40'             BLANK ANOTHER BYTE          08060000
         L     R1,#LISTN2                   CSECT                       08061000
         LA    R1,1(R1,R2)                       BYTE                   08062000
         ST    R1,#LISTN2                            DISPLACEMENT       08063000
         LA    R1,20(,R2)               OUTPUT LENGTH                   08064000
         B     LIST640                  FINISH FIND PROCESSING          08065000
         SPACE 2                                                        08066000
LIST610  BAL   R14,LIST800              PERFORM ANY CSECT POSITIONING   08067000
         MVC   MSGLINE(136),MSGBL132    CLEAR THE DATA LINE             08068000
         LR    R2,R4                    DATA LENGTH                     08069000
         LR    R14,R5                                                   08070000
         SR    R14,R6                   MACHINE LENGTH VALID?           08071000
         BM    LIST160                  NO, BRANCH                      08072000
         CR    R2,R14                                                   08073000
         BNH   *+8                                                      08074000
         LA    R2,1(,R14)               DATA LENGTH FOR THIS RECORD     08075000
         BCTR  R2,0                     MACHINE LENGTH FOR THE RECORD   08076000
         LA    R15,MSGLINE+11           PRINT AREA ADDR                 08077000
         MVI   46(R15),C'*'             BEGINNING *                     08078000
         MVC   47(*-*,R15),0(R6)        <<EXECUTED>>                    08079000
         EX    R2,*-6                   MOVE IN TEXT                    08080000
         LA    R1,47+1(R15,R2)                                          08081000
         MVI   0(R1),C'*'               FINAL *                         08082000
         UNPK  MSGLINE+06(7),#LISTN1+1(4)   UNPACK ADDRESS              08083000
         TR    MSGLINE+06(6),TRTABLE        CONVERT TO HEXADECIMAL      08084000
         MVI   MSGLINE+12,X'40'             BLANK THE FOLLOWING BYTE    08085000
         CLI   ##HELOFF,C'D'                DIRENTRY SUBCOMMAND?        08086000
         BNE   *+10                         NO, BRANCH                  08087000
         MVC   MSGLINE+06(6),BLANKS         BLANK THE COUNT FIELD       08088000
         UNPK  DOUBLE(7),#LISTN2+1(4)       UNPACK ADDRESS              08089000
         TR    DOUBLE(7),TRTABLE            CONVERT TO HEXADECIMAL      08090000
         MVC   MSGLINE+13(4),DOUBLE+2       MOVE IN ADDRESS             08091000
         CLI   DOUBLE+1,C'0'                LESS THAN 64K?              08092000
         BE    *+10                         YES, BRANCH                 08093000
         MVC   MSGLINE+13(5),DOUBLE+1       MOVE IN ADDRESS             08094000
         L     R1,#LISTN2                   CSECT                       08095000
         LA    R1,1(R1,R2)                       BYTE                   08096000
         ST    R1,#LISTN2                            DISPLACEMENT       08097000
         LR    R1,R6                    CURRENT DATA POINTER            08098000
         LA    R14,1(,R2)               NUMBER OF BYTES TO FORMAT       08099000
         SR    R0,R0                    CURRENT FORMATTED CHARACTER     08100000
         SPACE 2                                                        08101000
LIST620  MVC   DOUBLE(1),0(R1)          AVOID 0C5 FOR LAST BUFFER BYTE  08102000
         UNPK  8(3,R15),DOUBLE(2)       UNPACK DATA                     08103000
         TR    8(2,R15),TRTABLE         CONVERT TO HEXADECIMAL          08104000
         MVI   10(R15),X'40'            CLEAR FOLLOWING BYTE            08105000
         LA    R15,2(,R15)              INCR INTO PRINT AREA            08106000
         A     R1,=F'1'                 INCREMENT INTO DATA             08107000
         A     R0,=F'1'                 NEXT FORMATTED CHARACTER        08108000
         ST    R0,DOUBLE                                                08109000
         TM    DOUBLE+3,X'03'           4, 8, 12, 16, ...?              08110000
         BNZ   LIST630                  NO, BRANCH                      08111000
         LA    R15,1(,R15)              YES, INCREMENT ONE              08112000
         TM    DOUBLE+3,X'07'           8, 16, 24, 32, ...?             08113000
         BNZ   LIST630                  NO, BRANCH                      08114000
         LA    R15,1(,R15)              YES, INCREMENT ONE              08115000
LIST630  BCT   R14,LIST620              GO FORMAT                       08116000
         LA    R1,62(,R2)               OUTPUT LENGTH                   08117000
         SPACE 1                                                        08118000
LIST640  SLL   R1,16                    CREATE OUTPUT LINE HEADER       08119000
         ST    R1,MSGLINE                                               08120000
         MVC   DOUBLE,DOUBLE                                            08121000
         CLI   ##HELOFF,C'F'            FIND OPERATION?                 08122000
         BNE   LIST700                  NO, LIST -- BRANCH              08123000
         XC    DOUBLE,DOUBLE                                            08124000
         LR    R1,R6                    START OF DATA                   08125000
         LA    R14,0(R6,R2)             END OF DATA -1                  08126000
         LH    R15,FINDLTH              STRING LENGTH                   08127000
         ST    R14,DOUBLE               END OF DISPLAYED PART           08128000
         AR    R14,R15                  MAXIMUM ACCESS                  08129000
         BCTR  R15,0                    MACHINE LENGTH OF STRING        08130000
         CR    R14,R5                   BEYOND RECORD END?              08131000
         BL    LIST660                  NO, BRANCH                      08132000
         LR    R14,R5                   YES, USE END OF RECORD -1       08133000
         SPACE 1                                                        08134000
LIST660  EX    R2,LIST380               FIRST CHARACTER FOUND?          08135000
         BZ    LIST670                  NO, NOT IN STRING               08136000
         LR    R2,R14                                                   08137000
         SR    R2,R1                    MACHINE LENGTH LEFT             08138000
         CR    R15,R2                   POSSIBLY IN STRING?             08139000
         BH    LIST670                  NOT IN STRING                   08140000
         EX    R15,LIST390              ENTIRE STRING FOUND?            08141000
         BNE   *+8                      NO, BRANCH                      08142000
         ST    R1,DOUBLE+4              YES, SAVE THE LAST ADDRESS      08143000
         LA    R1,1(,R1)                NO, TRY NEXT CHARACTER          08144000
         L     R2,DOUBLE                LAST ACCESS BYTE                08145000
         SR    R2,R1                    MACHINE LENGTH LEFT NEGATIVE?   08146000
         BNM   LIST660                  NO, CONTINUE SEARCHING          08147000
         SPACE 2                                                        08148000
LIST670  ICM   R1,B'1111',DOUBLE+4      ANY STRING FOUND?               08149000
         BZ    LIST680                  NO, BRANCH                      08150000
         NI    FLAGSDD,FF-OVERLAP       CLEAR THE OVERLAP FLAG          08151000
         SR    R1,R6                    DISPLACEMENT INTO DISPLAY       08152000
         AH    R1,FINDLTH               LENGTH AT END OF COMPARE        08153000
         CR    R1,R4                    BEYOND DISPLAYED LENGTH?        08154000
         BNH   LIST700                  NO, BRANCH                      08155000
         OI    FLAGSDD,OVERLAP          YES, MARK AS AN OVERLAP         08156000
         B     LIST700                                                  08157000
LIST680  TM    FLAGSDD,OVERLAP          NO STRING FOUND -- OVERLAP SET? 08158000
         BNO   LIST160                  NO, BRANCH                      08159000
         XI    FLAGSDD,OVERLAP          YES, TURN OF THE OVERLAP FLAG   08160000
         SPACE 3                                                        08161000
LIST700  CLI   INSERT#1,X'FF'           ANY HEADER?                     08162000
         BE    LIST760                  NO, BRANCH                      08163000
         CLI   ##HELOFF,C'D'            DIRENTRY SUBCOMMAND?            08164000
         BE    LIST720                  YES, BRANCH                     08165000
         ICM   R0,B'1111',#MAXOUT       ANY MORE OUTPUT?                08166000
         BNP   LIST910                  NO, ALL DONE                    08167000
         CLI   ##HELOFF+3,C'Y'          ANY OUTPUT YET?                 08168000
         BNE   LIST710                  NO, BRANCH                      08169000
         LA    R15,MSGBLANK                                             08170000
         BAL   R14,LIST770              OUTPUT A BLANK LINE             08171000
LIST710  TM    #LISTFLG,X'01'           CSECT OUTPUT?                   08172000
         BO    LIST720                  YES, BRANCH                     08173000
         TM    FLAGSDD,LBLOCK+LDUMP     LBLOCK OR LDUMP?                08174000
         BM    LIST730                  YES, BRANCH                     08175000
LIST720  LA    R15,MSGTEXT1             OUTPUT THE HEADER LINE          08176000
         BAL   R14,LIST770                                              08177000
LIST730  MVI   INSERT#1,X'FF'           TURN OFF THE HEADER             08178000
         L     R0,#MAXOUT               DECREMENT                       08179000
         S     R0,=F'1'                          THE #MAXOUT            08180000
         ST    R0,#MAXOUT                                   COUNTER     08181000
         BM    LIST910                  NEGATIVE, ALL DONE              08182000
LIST760  TR    MSGLINE+4(256),TRLINE    UNPRINTABLES --> PERIODS        08183000
         LA    R15,MSGLINE              OUTPUT THE NEXT LINE            08184000
         BAL   R14,LIST770              OUTPUT THE NEXT LINE            08185000
         TM    ##ADRPA#,$F              FINDLIST MODIFICATION?          08186000
         BNO   *+8                      NO, BRANCH                      08187000
         MVI   ##HELOFF,C'1'            YES, NOW LIST THE REST          08188000
         B     LIST160                  YES, CONTINUE                   08189000
         SPACE 1                                                        08190000
LIST770  STM   R14,R15,#LFSAVE2         SAVE REGISTERS 14 AND 15        08191000
         CLI   ##HELOFF+3,C'D'          FIND AND NO OUTPUT YET?         08192000
         BNE   LIST780                  NO, BRANCH                      08193000
         SPACE 1                                                        08194000
         LA    R1,=C'THEN'                                              08195000
         ICM   R2,B'1111',#ACTIONT      ANY THEN ACTION?                08196000
         BP    LIST980                  YES, BRANCH                     08197000
         SPACE 1                                                        08198000
         ICM   R0,B'1111',#ACTIONE      ANY ELSE ACTION?                08199000
         BP    NEWCMD                   YES, IGNORE THIS MEMBER         08200000
         SPACE 1                                                        08201000
         TM    FLAGSAA,FINDMSG          ANY HEADER MESSAGE?             08202000
         BNO   LIST780                  NO, BRANCH                      08203000
         MESSAGE MSGBLANK               OUTPUT A BLANK LINE             08204000
         MESSAGE FINDMEMQ               OUTPUT THE HEADER LINE          08205000
         NI    FLAGSAA,FF-FINDMSG       TURN OFF THE HEADER LINE        08206000
         SPACE 1                                                        08207000
LIST780  L     R1,#LFSAVE2+4            POINT TO MESSAGE                08208000
         MVI   ##HELOFF+3,C'Y'          OUTPUT WAS GENERATED            08209000
         TSMSG (R1)                     OUTPUT THE MESSAGE              08210000
         L     R14,#LFSAVE2             RESTORE REGISTER 14             08211000
         BR    R14                                                      08212000
         SPACE 3                                                        08213000
LIST800  TM    #LISTFLG,X'60'           CSECT DATA?                     08214000
         BNOR  R14                      NO, RETURN                      08215000
         TM    #LISTFLG,X'08'           NEED ADJUSTMENT?                08216000
         BNO   LIST830                  NO, BRANCH                      08217000
         XI    #LISTFLG,X'08'           RESET THE ADJUSTMENT FLAG       08218000
LIST804  L     R4,#LISTWD               DISPLAY CHARACTER WIDTH         08219000
         ICM   R2,B'1111',#LISTENT      END OF CSECT ENTRIES?           08220000
         BZ    LIST100                  YES, BRANCH                     08221000
         CLI   ESDIDIN,1                THIS CSECT ACTIVE?              08222000
         BNE   LIST100                  NO, GET THE NEXT INPUT BLOCK    08223000
         SPACE 1                                                        08224000
*  ADJUST TO BEGINNING BOUNDARY                                         08225000
         SR    R0,R0                                                    08226000
         ICM   R0,B'0111',ESDADDR       CURRENT OFFSET                  08227000
         A     R0,#LISTVIR              OFFSET --> ACTUAL ADDRESS       08228000
         CR    R0,R6                    VALID ADJUSTMENT?               08229000
         BNH   *+6                      NO, BRANCH                      08230000
         LR    R6,R0                    YES, POSITION TO SYMBOL START   08231000
         LR    R1,R6                                                    08232000
         BCTR  R1,0                                                     08233000
         CR    R1,R5                    IN THIS DATA RECORD?            08234000
         BNL   LIST100                  NO, IGNORE THIS RECORD          08235000
         XC    #LISTOFF(4),#LISTOFF     MODULE OFFSET WAS HONORED       08236000
         MVC   #LISTID(2),ESDID         SAVE THE CURRENT ESD ID         08237000
         MVI   MTHIGHL,38                                               08238000
         MVC   MSGTEXT1(3),L141$1                                       08239000
         MVC   INSERT#1(38),MSGLDUMP    "AT 123456  CSECT 12345678 .."  08240000
         UNPK  INSERT#1(7),ESDADDR(4)                                   08241000
         TR    INSERT#1(6),TRTABLE      OFFSET OF CSECT OR ENTRY        08242000
         MVI   INSERT#1+6,X'40'                                         08243000
         MVC   INSERT#1+14(8),ESDNAME   PRIVATE, COMMON OR CSECT NAME   08244000
         UNPK  INSERT#1+31(7),ESDLEN(4)                                 08245000
         TR    INSERT#1+31(6),TRTABLE   LENGTH OF CSECT                 08246000
         MVI   INSERT#1+31+6,X'40'                                      08247000
         LR    R0,R6                                                    08248000
         S     R0,#LISTVIR              ACTUAL ADDRESS --> OFFSET       08249000
         ST    R0,#LISTN1               OFFSET IN LOAD MODULE           08250000
         SR    R1,R1                                                    08251000
         ICM   R1,B'0111',ESDADDR       ENTRY ADDRESS                   08252000
         SR    R0,R1                                                    08253000
         ST    R0,#LISTN2               OFFSET IN CSECT                 08254000
         CLI   ESDTYPE,CODESD           CSECT ENTRY?                    08255000
         BE    LIST810                  YES, BRANCH                     08256000
         TM    ESDTYPE,CODEPC           PRIVATE CODE OR OVERLAY?        08257000
         BO    LIST810                  YES, BRANCH                     08258000
         L     R15,ESDCSECT             ADDRESS OF MAIN ENTRY           08259000
         MVC   INSERT#1+14(8),4(R15)    CSECT NAME                      08260000
         MVC   INSERT#1+24(6),=C' ENTRY' ENTRY WITHIN A CSECT           08261000
         MVC   INSERT#1+31(8),ESDNAME                                   08262000
         AR    R0,R1                                                    08263000
         ICM   R1,B'0111',ESDMAIN+1     CSECT START ADDRESS             08264000
         SR    R0,R1                                                    08265000
         ST    R0,#LISTN2               OFFSET IN CSECT                 08266000
         SPACE 2                                                        08267000
LIST810  ICM   R0,B'0111',ESDADDR       ENTRY ADDRESS                   08268000
         LR    R15,R0                   SAVE THE ENTRY ADDRESS          08269000
         A     R0,ESDLEN-1              LAST ADDRESS TO BE ACCESSED     08270000
LIST814  LTR   R2,R2                    AT END OF LIST?                 08271000
         BZ    LIST820                  YES, BRANCH                     08272000
         ICM   R2,B'1111',ESDLINK       ANOTHER ESD ENTRY?              08273000
         ST    R2,#LISTENT                                              08274000
         BZ    LIST820                  NO, BRANCH                      08275000
         CLC   #LISTID(2),ESDID         ENTRY FOR THIS CSECT?           08276000
         BNE   LIST820                  NO, USE THE CURRENT ENTRY       08277000
         CLM   R15,B'0111',ESDADDR      START:NEXT START                08278000
         BNL   LIST814                    HIGH OR EQUAL, DISCARD IT     08279000
         CLM   R0,B'0111',ESDADDR       END:NEXT START                  08280000
         BNH   LIST820                    LOW OR EQUAL, USE THIS LIMIT  08281000
         ICM   R0,B'0111',ESDADDR         HIGH, USE THE LOWER LIMIT     08282000
         SPACE 1                                                        08283000
LIST820  LR    R1,R0                    CSECT OR ENTRY END              08284000
         SR    R1,R15                   CSECT OR ENTRY LENGTH           08285000
         C     R1,#MAXLEN               ABOVE MAXIMUM CSECT LENGTH?     08286000
         BL    *+8                      NO, BRANCH                      08287000
         L     R1,#MAXLEN               YES, USE THE REQUESTED MAXIMUM  08288000
         AR    R1,R15                   END OF CSECT OR ENTRY           08289000
         A     R1,#LISTVIR              OFFSET --> ACTUAL ADDRESS       08290000
         ST    R1,#LISTE1               SAVE END ADDRESS                08291000
         SPACE 2                                                        08292000
*  CHECK FOR END OF CSECT OR EXTERNAL LABEL                             08293000
LIST830  LR    R1,R4                    DATA LENGTH                     08294000
         LR    R15,R5                                                   08295000
         SR    R15,R6                   MACHINE LENGTH VALID?           08296000
         BM    LIST100                  NO, IGNORE THIS RECORD          08297000
         CR    R1,R15                                                   08298000
         BNH   *+8                                                      08299000
         LA    R1,1(,R15)               R1=MIN(16 OR 64,LENGTH LEFT)    08300000
         AR    R1,R6                    END OF THIS LINE                08301000
         C     R1,#LISTE1               END ON THIS LINE?               08302000
         BLR   R14                      NO, RETURN                      08303000
         OI    #LISTFLG,X'08'           NEW HEADER IS NEEDED            08304000
         L     R4,#LISTE1               MAXIMUM ADDRESS OF CSECT        08305000
         SR    R4,R6                    DISPLAY LENGTH VALID?           08306000
         BPR   R14                      YES, BRANCH                     08307000
         LTR   R2,R2                    AT END OF LIST?                 08308000
         BZ    LIST100                  YES, IGNORE THIS MEMBER         08309000
         B     LIST804                  NO, TRY THE NEXT CSECT          08310000
         SPACE 3                                                        08311000
LIST900  MVI   ##HELOFF+2,X'FF'         END OF FILE ENCOUNTERED         08312000
LIST910  CLI   ##HELOFF+3,C'D'          FIND AND NO OUTPUT?             08313000
         BNE   LIST920                  NO, BRANCH                      08314000
         LA    R1,=C'ELSE'                                              08315000
         ICM   R2,B'1111',#ACTIONE      ANY ELSE ACTION?                08316000
         BP    LIST980                  YES, BRANCH                     08317000
         TM    FLAGSAA,FMEM#MEM         MEMBER GROUP IN PROGRESS?       08318000
         BO    NEWCMD                   YES, DONE                       08319000
         B     LIST940                  NO, BRANCH                      08320000
         SPACE 1                                                        08321000
LIST920  TM    FLAGSDD,LBLOCK+LDUMP+BLOCK+DUMP SEGMENT FORMAT?          08322000
         BZ    LIST940                         NO, BRANCH               08323000
         MESSAGE MSGBLANK               OUTPUT A BLANK LINE             08324000
         SPACE 1                                                        08325000
LIST940  CLI   ##HELOFF+2,X'FF'         END OF FILE ENCOUNTERED?        08326000
         BNE   NEWCMD                   NO, DONE                        08327000
         MVI   MTHIGHL,L'MSGBLK-1                                       08328000
         LA    R1,L142$1                                                08329000
         MVC   INSERT#1-1(34),MSGBLK                                    08330000
         L     R0,#BLKCNT                                               08331000
         CVD   R0,DOUBLE                                                08332000
         ED    INSERT#1-1(10),DOUBLE+4                                  08333000
         TM    #LISTFLG,X'01'           CSECT FORMATTING?               08334000
         BO    LIST960                  YES, BRANCH                     08335000
         TM    FLAGSDD,DUMP+BLOCK                                       08336000
         BNZ   LIST960                                                  08337000
         MVC   INSERT#1+MSGBLKL-MSGBLK-1(6),=C' LINES'                  08338000
LIST960  TM    DSORG,DS1DSGPO                                           08339000
         BO    MSGNEW                                                   08340000
         MVC   INSERT#1+MSGBLKS-MSGBLK-1(8),=C'DATA SET'                08341000
         B     MSGNEW                                                   08342000
         SPACE 2                                                        08343000
LIST980  MVC   FINDMEMQ+25(4),0(R1)     ADD "THEN" OR "ELSE"            08344000
         TM    ##ADRPA#-##SUBCOM(R2),$D DEFAULT MESSAGE SUBCOMMAND?     08345000
         BNZ   LIST990                  NO, BRANCH                      08346000
         SPACE 1                                                        08347000
         MESSAGE MSGBLANK               OUTPUT A BLANK LINE             08348000
         TM    FLAGSAA,FINDMSG          ANY MESSAGE TO OUTPUT?          08349000
         BNO   LIST990                  NO, BRANCH                      08350000
         XI    FLAGSAA,FINDMSG          NO MORE MESSAGE                 08351000
         MVC   FINDMEMQ+30(8),0(R2)     SUBCOMMAND TO EXECUTE           08352000
         MESSAGE FINDMEMQ               IDENTIFICATION LINE             08353000
         SPACE 1                                                        08354000
LIST990  MVC   ##ANSWER(LISUBS),ISUBS   INITIALIZE THE PDL SAVE AREA    08355000
         MVC   ##SUBCOM(PTW),0(R2)      CHANGE THE SUBCOMMAND           08356000
         MVI   MTHIGHL,8                                                08357000
         MVI   MTHIGHL+4,8                                              08358000
         B     CALLCMDZ                 CALL THE SECONDARY SUBCOMMAND   08359000
         SPACE 3                                                        08360000
MSGDUMP  DC    C' 1,234,567   LENGTH 12,345   TTR 123456 '              08361000
         ORG   MSGDUMP                                                  08362000
         DC    X'40206B2020206B202120'   EDIT PATTERN                   08363000
         ORG   MSGDUMP+19                                               08364000
MSGDUMPL DC    X'4020206B202120'         EDIT PATTERN                   08365000
MSGDUMPT EQU   MSGDUMP+33,6              TTR OUTPUT                     08366000
         ORG   ,                                                        08367000
MSGLDUMP DC    C'123456  CSECT 12345678  LENGTH 123456  '               08368000
*                C'1234567890123456789012345678901234567890             08369000
MSGBLK   DC    C' 1,234,567 BLOCKS IN THIS MEMBER  '                    08370000
         ORG   MSGBLK                                                   08371000
         DC    X'40206B2020206B202120'   EDIT PATTERN                   08372000
MSGBLKL  EQU   MSGBLK+11,6               " LINES"                       08373000
MSGBLKS  EQU   MSGBLK+26,7               "DATA SET"                     08374000
         ORG   ,                                                        08375000
         DROP  R2                                                  @D04
         SPACE 2                                                   @D04
*   Build and write additional information for DIRENTRY            @D04
DIR000   BALR  R8,0                     OUTPUT ADDITIONAL DIR DATA @D04
         USING *,R8                                                @D04
         MESSAGE MSGBLANK               OUTPUT ADDITIONAL DIR DATA @D04
         CLC   ##SUBCOM+#LSUB(8),$DIR   IF OR THEN FORM?           @D04
         BNE   NEWCMD                   YES, NO ADDITIONAL OUTPUT  @D04
         CLI   #DIRSHOR,1               SHORT FORM?                @D04
         BE    NEWCMD                   YES, BRANCH                @D04
         MVI   MTLEN,70                 LENGTH OF MESSAGE INSERT   @D04
         MVC   INSERT#1(100),BLANK128   CLEAR THE HEADER LINE      @D04
         MVC   INSERT#1(40),MSG262H     HEADER INFORMATION         @D04
         TSMSG L262$1                                              @D04
         MVC   INSERT#1(40),MSG262U     UNDERLINE INFORMATION      @D04
         SPACE 2                                                   @D04
         SR    R2,R2                    OFFSET IN THE DIRECTORY    @D04
         LA    R3,DIRHDR                START OF HEADER NAMES      @D04
         BAL   R4,DIRFMT10              OUTPUT FIRST MESSAGE       @D04
         SPACE 1                                                   @D04
         MVC   INSERT#1+13(8),DIRNAME   ADD THE MEMBER NAME        @D04
         BAL   R4,DIRFMT                (00)                       @D04
         LA    R2,8(,R2)                POSITION PAST MEMBER NAME  @D04
         SPACE 1                                                   @D04
         LA    R0,3                     3 INPUT BYTES              @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (08)                       @D04
         LA    R2,3(,R2)                POSITION PAST TTR          @D04
         SPACE 1                                                   @D04
         LA    R0,1                     1 INPUT BYTE               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         IC    R14,DIRFLAG                                         @D04
         SLL   R14,25                   DROP ALIAS BIT             @D04
         SRDL  R14,30                   SAVE HALFWORD COUNT        @D04
         LA    R14,X'F0'(,R14)          CONVERT TO DISPLAY         @D04
         STC   R14,INSERT#1+30          SAVE TTR COUNT IN MESSAGE  @D04
         SPACE 1                                                   @D04
         SRL   R15,32-5                 HALFWORD COUNT             @D04
         CVD   R15,DOUBLE                                          @D04
         MVC   FULLWORD(4),DIR4020      EDIT PATTERN               @D04
         ED    FULLWORD(4),DOUBLE+6                                @D04
         MVC   INSERT#1+45(2),FULLWORD+2  ADD COUNT                @D04
         SPACE 1                                                   @D04
         TM    DIRFLAG,X'80'            ALIAS?                     @D04
         BO    DIR040                   YES, BRANCH                @D04
         MVC   INSERT#1+23+44(12),BLANK128                         @D04
         MVC   INSERT#1+23(44),INSERT#1+30  DROP "ALIAS;"          @D04
         SPACE 1                                                   @D04
DIR040   BAL   R4,DIRFMT                (0B)                       @D04
         LA    R2,1(,R2)                POSITION PAST INDC         @D04
         SPACE 2                                                   @D04
         TM    FLAGSCC,RECFMU           RECFM=U?                   @D04
         BNO   DIR800                   YES, BRANCH                @D04
         LA    R0,4                     TTR +1 BYTE                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         MVC   INSERT#1+21(1),INSERT#1+20                          @D04
         MVC   INSERT#1+20(1),INSERT#1+19                          @D04
         MVI   INSERT#1+19,C','                                    @D04
         BAL   R4,DIRFMT                (0C)                       @D04
         LA    R2,4(,R2)                POSITION PAST TTRT         @D04
         SPACE 1                                                   @D04
         TM    DIRATTR,X'24'            OVERLAY OR SCATTER?        @D04
         BZ    *+8                      NO, BRANCH                 @D04
         BAL   R4,DIRFMT20              YES, GET NEXT DOC.         @D04
         TM    DIRATTR,X'20'            OVERLAY?                   @D04
         BO    DIR110                   YES, BRANCH                @D04
         LA    R0,4                     TTR +1 BYTE                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         MVC   INSERT#1+21(1),INSERT#1+20                          @D04
         MVC   INSERT#1+20(1),INSERT#1+19                          @D04
         MVI   INSERT#1+19,C','                                    @D04
         BAL   R4,DIRFMT                (10)                       @D04
         LA    R2,4(,R2)                POSITION PAST TTRN         @D04
         B     DIR120                                              @D04
         SPACE 1                                                   @D04
DIR110   BAL   R4,DIRFMT20              GET NEXT DOC.              @D04
         LA    R0,3                     TTR                        @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (10)                       @D04
         LA    R2,3(,R2)                POSITION PAST TTRN         @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         IC    R0,DIRNOTE#              NUMBER OF NOTELIST ELEMENTS@D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (13)                       @D04
         LA    R2,1(,R2)                POSITION PAST NL           @D04
         SPACE 1                                                   @D04
DIR120   LA    R3,DIRHDR14              REPOSITION THE HEADER INFO @D04
         BAL   R4,DIRFMT20                                         @D04
         LA    R0,1                     1 INPUT BYTE               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         LA    R14,X'80'*2              TEST MASK                  @D04
         LA    R5,DIRBITP1-2            TEXT OFFSETS               @D04
         BAL   R4,DIRBITS                                          @D04
         BAL   R4,DIRFMT                (14)                       @D04
         SPACE 1                                                   @D04
         LA    R14,X'08'*2              TEST MASK                  @D04
         LA    R5,DIRBITP2-2            TEXT OFFSETS               @D04
         BAL   R4,DIRBITS                                          @D04
         BAL   R4,DIRFMT10              (14)                       @D04
         LA    R2,1(,R2)                SKIP ATR1                  @D04
         SPACE 1                                                   @D04
         LA    R0,1                     1 INPUT BYTE               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         LA    R14,X'80'*2              TEST MASK                  @D04
         LA    R5,DIRBITP3-2            TEXT OFFSETS               @D04
         BAL   R4,DIRBITS                                          @D04
         BAL   R4,DIRFMT                (15)                       @D04
         SPACE 1                                                   @D04
         LA    R14,X'08'*2              TEST MASK                  @D04
         LA    R5,DIRBITP4-2            TEXT OFFSETS               @D04
         BAL   R4,DIRBITS                                          @D04
         BAL   R4,DIRFMT10              (15)                       @D04
         LA    R2,1(,R2)                SKIP ATR2                  @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         ICM   R0,B'0111',DIRSTORE      3 INPUT BYTES              @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (16)                       @D04
         LA    R2,3(,R2)                SKIP STOR                  @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         ICM   R0,B'0011',DIRTEXTL      2 INPUT BYTES              @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (19)                       @D04
         LA    R2,2(,R2)                SKIP FTBL                  @D04
         SPACE 1                                                   @D04
         LA    R0,3                     3 INPUT BYTES              @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (1B)                       @D04
         LA    R2,3(,R2)                SKIP EPA                   @D04
         SPACE 1                                                   @D04
         TM    DIRATTR2,X'80'           VS LINKAGE EDITOR?         @D04
         BO    DIR210                   YES, BRANCH                @D04
         MVC   INSERT#1+04(08),DIRHDROS NEW OPERAND NAME           @D04
         MVC   INSERT#1+23(44),DIRHDROS+8  NEW DESCRIPTION         @D04
         LA    R0,3                     3 INPUT BYTES              @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (1E)                       @D04
         LA    R2,3(,R2)                SKIP FTB0, FTB1, FTB2      @D04
         B     DIR300                                              @D04
         SPACE 1                                                   @D04
DIR210   LA    R0,1                     1 INPUT BYTE               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (1E)                       @D04
         LA    R2,1(,R2)                SKIP FTB0                  @D04
         SPACE 1                                                   @D04
         LA    R4,DIR220                NEXT RETURN POINT          @D04
         TM    DIRATTR2,X'20'           PAGE ALIGNED?              @D04
         BO    DIRFMT10                 YES, BRANCH                @D04
         BAL   R4,DIRFMT20              NO, GET NEXT DOC.          @D04
         SPACE 1                                                   @D04
DIR220   LA    R4,DIR230                NEXT RETURN POINT          @D04
         TM    DIRATTR2,X'10'           SSI PRESENT?               @D04
         BO    DIRFMT10                 YES, BRANCH                @D04
         BAL   R4,DIRFMT20              NO, GET NEXT DOC.          @D04
         SPACE 1                                                   @D04
DIR230   LA    R4,DIR230A               NEXT RETURN POINT          @D04
         TM    DIRATTR2,X'08'           APF INFORMATION VALID?     @D04
         BO    DIRFMT10                 YES, BRANCH                @D04
         BAL   R4,DIRFMT20              NO, GET NEXT DOC.          @D04
         SPACE 1                                                   @D04
DIR230A  LA    R4,DIR230B               NEXT RETURN POINT          @D04
         TM    DIRATTR2,DIR2LFMT        PROGRAM OBJECT FORMAT?     @D04
         BO    DIRFMT10                 YES, BRANCH                @D04
         BAL   R4,DIRFMT20              NO, GET NEXT DOC.          @D04
         SPACE 1                                                   @D04
DIR230B  LA    R4,DIR240                NEXT RETURN POINT          @D04
         TM    DIRATTR2,DIR2BIG         16M OR MORE?               @D04
         BO    DIRFMT10                 YES, BRANCH                @D04
         BAL   R4,DIRFMT20              NO, GET NEXT DOC.          @D04
         SPACE 1                                                   @D04
DIR240   LA    R0,1                     1 INPUT BYTE               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         TM    DIRATTR3,DIRRMANY        RMODE=ANY?                 @D04
         BO    *+10                     YES, BRANCH                @D04
         MVC   INSERT#1+29(4),DIR24     NO, RMODE 24               @D04
         SPACE 1                                                   @D04
         TM    DIRATTR3,DIRAA31+DIRAA64 ALIAS AMODE=ANY?           @D04
         BO    DIR250                   YES, BRANCH                @D04
         MVC   INSERT#1+46(4),=C'  ; '  NO, "  ; "                 @D04
         TM    DIRATTR3,DIRAA31         ALIAS AMODE=31?            @D04
         BNO   *+4+6+4                  NO, BRANCH                 @D04
         MVC   INSERT#1+46(2),DIR31     YES, "31"                  @D04
         B     DIR250                                              @D04
         TM    DIRATTR3,DIRAA64         ALIAS AMODE=64?            @D04
         BNO   *+4+6+4                  NO, BRANCH                 @D04
         MVC   INSERT#1+46(2),DIR64     YES, "64"                  @D04
         B     DIR250                                              @D04
         MVC   INSERT#1+46(2),DIR24     "24"                       @D04
         SPACE 1                                                   @D04
DIR250   TM    DIRATTR3,DIRAM31+DIRAM64 MAIN AMODE=ANY?            @D04
         BO    DIR260                   YES, BRANCH                @D04
         MVC   INSERT#1+62(4),=C'    '  NO, "    "                 @D04
         TM    DIRATTR3,DIRAM31         MAIN AMODE=31?             @D04
         BNO   *+4+6+4                  NO, BRANCH                 @D04
         MVC   INSERT#1+62(2),DIR31     YES, "31"                  @D04
         B     DIR260                                              @D04
         TM    DIRATTR3,DIRAM64         MAIN AMODE=64?             @D04
         BNO   *+4+6+4                  NO, BRANCH                 @D04
         MVC   INSERT#1+62(2),DIR64     YES, "64"                  @D04
         B     DIR260                                              @D04
         MVC   INSERT#1+62(2),DIR24     "24"                       @D04
         SPACE 1                                                   @D04
DIR260   BAL   R4,DIRFMT                (1F)                       @D04
         LA    R2,1(,R2)                SKIP FTB1                  @D04
         SPACE 2                                                   @D04
         LA    R0,1                     1 INPUT BYTE               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (20)                       @D04
         LA    R2,1(,R2)                SKIP FTB2                  @D04
         SPACE 1                                                   @D04
DIR300   LA    R3,DIRHDR21              REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
         TM    DIRATTR,X'04'            SCATTER LOAD?              @D04
         BNO   DIR400                   NO, BRANCH                 @D04
         SR    R0,R0                                               @D04
         ICM   R0,B'0011',DIRSCLL       COUNT                      @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (21)                       @D04
         LA    R2,2(,R2)                SKIP SLSZ                  @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         ICM   R0,B'0011',DIRSCTL       COUNT                      @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (23)                       @D04
         LA    R2,2(,R2)                SKIP TTSZ                  @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         ICM   R0,B'0011',DIRSCET       COUNT                      @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (25)                       @D04
         LA    R2,2(,R2)                SKIP ESDT                  @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         ICM   R0,B'0011',DIRSCEP       COUNT                      @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (27)                       @D04
         LA    R2,2(,R2)                SKIP ESDC                  @D04
         SPACE 1                                                   @D04
DIR400   LA    R3,DIRHDR29              REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
         TM    DIRFLAG,DIRALIAS         ALIAS?                     @D04
         BNO   DIR500                   NO, BRANCH                 @D04
         LA    R0,3                     3 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (29)                       @D04
         LA    R2,3(,R2)                SKIP EPM                   @D04
         SPACE 1                                                   @D04
         LA    R1,DIRNAME(R2)           START OF MAIN MEMBER NAME  @D04
         MVC   INSERT#1+13(8),0(R1)     MOVE INTO MESSAGE AREA     @D04
         BAL   R4,DIRFMT                (2C)                       @D04
         LA    R2,8(,R2)                SKIP MNM                   @D04
         SPACE 1                                                   @D04
DIR500   LA    R3,DIRHDR34              REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
         TM    DIRATTR2,X'80'           VS LINKAGE EDITOR?         @D04
         BO    DIR550                   YES, BRANCH                @D04
         LA    R2,1(,R2)                                           @D04
         N     R2,=F'-2'                ROUND TO HALFWORD BOUNDARY @D04
         CLC   ZERO,0(R2)               ZERO?                      @D04
         BE    DIR990                   YES, NO SSI                @D04
         CLC   =F'-1',0(R2)             FFFFFFFF?                  @D04
         BE    DIR990                   YES, NO SSI                @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (34)                       @D04
         LA    R2,4(,R2)                SKIP SSI                   @D04
         B     DIR990                                              @D04
         SPACE 1                                                   @D04
DIR550   TM    DIRATTR2,DIR2SSI         ANY SSI INFORMATION?       @D04
         BNO   DIR600                   NO, BRANCH                 @D04
         LA    R2,1(,R2)                                           @D04
         N     R2,=F'-2'                ROUND TO HALFWORD BOUNDARY @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (34)                       @D04
         LA    R2,4(,R2)                SKIP SSI                   @D04
         SPACE 1                                                   @D04
DIR600   LA    R3,DIRHDR38              REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
         TM    DIRATTR2,DIRAPFLG        VALID APF INFORMATION?     @D04
         BNO   DIR650                   NO, BRANCH                 @D04
         LA    R0,1                     1 HEX BYTE                 @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (38)                       @D04
         LA    R2,1(,R2)                SKIP APFCT                 @D04
         SPACE 1                                                   @D04
         LA    R0,1                     1 HEX BYTE                 @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (39)                       @D04
         LA    R2,1(,R2)                SKIP APFAC                 @D04
         B     DIR660                                              @D04
         SPACE 1                                                   @D04
DIR650   L     R3,=A(DIRHDRLP)          REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
DIR660   DS    0H                                                  @D04
         SPACE 2                                                   @D04
DIR700   DS    0H                                                  @D04
         L     R3,=A(DIRHDRPM)          REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
         LA    R2,1(,R2)                                           @D04
         N     R2,=F'-2'                ROUND TO HALFWORD          @D04
         LA    R1,DIRNAME(R2)           POINT INTO DIRECTORY       @D04
***PDSMAN CHANGES: DIRENTER FOR LISTING PDSMAN ATTRIBUTES          @D04
         TM    3(R1),X'0F'              PDSMAN DATE? 0CYYDDDF      @D04
         BNO   DIR990                   NO, BRANCH                 @D04
         TM    0(R1),X'FE'              PDSMAN DATE? 0CYYDDDF      @D04
         BNZ   DIR990                   NO, BRANCH                 @D04
         TM    8(R1),X'0F'              PDSMAN DATE?   YYDDDF      @D04
         BNO   DIR990                   NO, BRANCH                 @D04
         TM    21(R1),X'0F'             PDSMAN DATE?   YYDDDF      @D04
         BNO   DIR990                   NO, BRANCH                 @D04
         SPACE 1                                                   @D04
         LA    R0,4                     4 HEX DIGITS               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                                           @D04
         LA    R2,4(,R2)                SKIP MANMODD               @D04
         SPACE 1                                                   @D04
         LA    R0,2                     2 HEX DIGITS               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                                           @D04
         LA    R2,2(,R2)                SKIP MANMODT               @D04
         SPACE 1                                                   @D04
         LA    R0,3                     3 HEX DIGITS               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                                           @D04
         LA    R2,3(,R2)                SKIP MANEXPR               @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         IC    R0,DIRNAME(R2)           LEVEL NUMBER               @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                                           @D04
         LA    R2,1(,R2)                SKIP MANMODN               @D04
         SPACE 1                                                   @D04
         LA    R1,DIRNAME(R2)           POINT TO LAST USER         @D04
         MVC   INSERT#1+13(8),0(R1)     LAST USER                  @D04
         BAL   R4,DIRFMT                                           @D04
         LA    R2,8(,R2)                SKIP MANUSER               @D04
         SPACE 1                                                   @D04
         LA    R0,1                     1 HEX DIGIT                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                                           @D04
         LA    R2,1(,R2)                SKIP MANPROD               @D04
         SPACE 1                                                   @D04
         LA    R0,3                     3 HEX DIGITS               @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                                           @D04
         LA    R2,3(,R2)                SKIP MANREAD               @D04
         B     DIR990                                              @D04
         SPACE 3                                                   @D04
DIR800   TM    DIRFLAG,X'0F'            SPF STATISTICS?            @D04
         BO    DIR900                   YES, BRANCH                @D04
         TM    DIRFLAG,X'14'            SPF STATISTICS EXT?        @D04
         BO    DIR900                   YES, BRANCH                @D04
         MVC   DOUBLE(1),DIRFLAG        COPY THE ATTRIBUTE BYTE    @D04
         NI    DOUBLE,X'FF'-X'80'       RESET THE ALIAS FLAG       @D04
         CLI   DOUBLE,X'02'             SSI INFORMATION?           @D04
         BL    DIR990                   NO, BRANCH                 @D04
         LA    R3,DIRHDR34              REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (34)                       @D04
         LA    R2,4(,R2)                SKIP SSI                   @D04
         B     DIR990                                              @D04
         SPACE 1                                                   @D04
DIR900   L     R3,=A(DIRHDRSP)          REPOSITION HEADER          @D04
         BAL   R4,DIRFMT20                                         @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         IC    R0,DIRNAME(R2)                                      @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (SPF-0C)                   @D04
         LA    R2,1(,R2)                SKIP SPFV                  @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         IC    R0,DIRNAME(R2)                                      @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (SPF-0D)                   @D04
         LA    R2,1(,R2)                SKIP SPFR                  @D04
         SPACE 1                                                   @D04
*        LH    R0,DIRNAME(R2)                                      @D04
*        BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         LA    R0,1                     1 HEX BYTE                 @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-0E)                   @D04
         LA    R2,1(,R2)                SKIP SPFSC                 @D04
         SPACE 1                                                   @D04
         LA    R0,1                     1 HEX BYTE                 @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-0F)                   @D04
         LA    R2,1(,R2)                SKIP SPFCS                 @D04
         SPACE 1                                                   @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-10)                   @D04
         LA    R2,4(,R2)                SKIP SPFCR                 @D04
         SPACE 1                                                   @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-14)                   @D04
         LA    R2,4(,R2)                SKIP SPFCD                 @D04
         SPACE 1                                                   @D04
         LA    R0,2                     2 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-18)                   @D04
         LA    R2,2(,R2)                SKIP SPFCT                 @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         LA    R1,DIRNAME(R2)                                      @D04
         ICM   R0,B'0011',0(R1)                                    @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (SPF-1A)                   @D04
         LA    R2,2(,R2)                SKIP SPFSI                 @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         LA    R1,DIRNAME(R2)                                      @D04
         ICM   R0,B'0011',0(R1)                                    @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (SPF-1C)                   @D04
         LA    R2,2(,R2)                SKIP SPFIN                 @D04
         SPACE 1                                                   @D04
         SR    R0,R0                                               @D04
         LA    R1,DIRNAME(R2)                                      @D04
         ICM   R0,B'0011',0(R1)                                    @D04
         BAL   R4,DIRDEC                CONVERT TO DECIMAL         @D04
         BAL   R4,DIRFMT                (SPF-1E)                   @D04
         LA    R2,2(,R2)                SKIP SPFMD                 @D04
         SPACE 1                                                   @D04
         LA    R1,DIRNAME(R2)           START OF MAIN MEMBER       @D04
         MVC   INSERT#1+13(8),0(R1)     MOVE INTO MESSAGE AREA     @D04
         BAL   R4,DIRFMT                (SPF-20)                   @D04
         LA    R2,8(,R2)                SKIP SPFID                 @D04
         SPACE 1                                                   @D04
         TM    DIRSPFFL,DIRSPFXS        EXTENDED STATS?            @D04
         BNO   DIR990                   NO                         @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-28)                   @D04
         LA    R2,4(,R2)                SKIP SPFSI-X               @D04
         SPACE 1                                                   @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-2C)                   @D04
         LA    R2,4(,R2)                SKIP SPFIN-X               @D04
         SPACE 1                                                   @D04
         LA    R0,4                     4 HEX BYTES                @D04
         BAL   R4,DIRHEX                CONVERT TO HEX             @D04
         BAL   R4,DIRFMT                (SPF-30)                   @D04
         LA    R2,4(,R2)                SKIP SPFMD-X               @D04
         SPACE 1                                                   @D04
DIR990   MESSAGE MSGBLANK                                          @D04
         B     NEWCMD                                              @D04
DIRDEC   C     R0,DIRDEC99                                         @D04
         BH    DIRDEC10                                            @D04
         CVD   R0,DOUBLE                                           @D04
         MVC   INSERT#1+100+8(8),BLANK128                          @D04
         MVC   INSERT#1+100(8),DIR2020                             @D04
         ED    INSERT#1+100(7),DOUBLE+5                            @D04
         LA    R1,INSERT#1+100-1                                   @D04
         LA    R1,1(,R1)                                           @D04
         CLI   0(R1),X'40'                                         @D04
         BE    *-8                                                 @D04
         MVC   INSERT#1+13(8),0(R1)                                @D04
         BR    R4                                                  @D04
DIRDEC10 LR    R1,R0                                               @D04
         LA    R1,1023(,R1)                                        @D04
         SRL   R1,10                    THE NEXT HIGHER K VALUE    @D04
         CVD   R1,DOUBLE                                           @D04
         MVC   INSERT#1+100+8(8),BLANK128                          @D04
         MVC   INSERT#1+100(7),DIR2020                             @D04
         MVI   INSERT#1+100+7,C'K'                                 @D04
         ED    INSERT#1+100(7),DOUBLE+5                            @D04
         LA    R1,INSERT#1+100-1                                   @D04
         LA    R1,1(,R1)                                           @D04
         CLI   0(R1),X'40'                                         @D04
         BE    *-8                                                 @D04
         MVC   INSERT#1+13(8),0(R1)                                @D04
         BR    R4                                                  @D04
DIRDEC99 DC    F'99999'                                            @D04
         SPACE 3                                                   @D04
DIRHEX   LA    R1,DIRNAME(R2)           POINT TO DATA              @D04
         LA    R15,INSERT#1+13          START OF OUTPUT DATA       @D04
         SPACE 1                                                   @D04
DIRHEX10 UNPK  0(3,R15),0(2,R1)         UNPACK TO HEXADECIMAL      @D04
         TR    0(2,R15),TRTABLE         CONVERT TO PRINTABLE       @D04
         MVI   2(R15),X'40'             BLANK GARBAGE BYTE         @D04
         LA    R15,2(,R15)              NEXT OUTPUT DIGIT          @D04
         LA    R1,1(,R1)                NEXT INPUT DIGIT           @D04
         BCT   R0,DIRHEX10              FORMAT ALL INPUT DIGITS    @D04
         BR    R4                                                  @D04
         SPACE 3                                                   @D04
DIRFMT   STC   R2,DOUBLE                SAVE OFFSET IN STORAGE     @D04
         UNPK  INSERT#1(3),DOUBLE(2)    UNPACK TO HEXADECIMAL      @D04
         TR    INSERT#1(2),TRTABLE      CONVERT TO PRINTABLE OFFSET@D04
         MVI   INSERT#1+2,X'40'         CLEAR GARBAGE BYTE         @D04
         SPACE 1                                                   @D04
DIRFMT10 TR    INSERT#1(70),TRLINE      CONVERT TO PRINTABLE       @D04
         TSMSG L262$1                   OUTPUT                     @D04
         SPACE 1                                                   @D04
DIRFMT20 MVC   INSERT#1(100),BLANK128   BLANK THE OUTPUT AREA      @D04
         MVC   INSERT#1+04(08),0(R3)    ADD THE PDS... NAME        @D04
         MVC   INSERT#1+23(44),8(R3)    ADD THE DESCRIPTION        @D04
         LR    R6,R3                    THIS TEXT                  @D04
         LA    R3,52(,R3)               NEXT TEXT                  @D04
         BR    R4                                                  @D04
         SPACE 3                                                   @D04
DIRBITS  ST    R14,DOUBLE+4             SAVE TEST MASK             @D04
         LA    R15,INSERT#1+23          OUTPUT START               @D04
         MVC   0(44,R15),BLANK128                                  @D04
         LA    R0,4                     BITS PER LINE              @D04
         LR    R1,R6                    INPUT TEXT                 @D04
         SPACE 1                                                   @D04
DIRBIT10 LA    R5,2(,R5)                NEXT OFFSET                @D04
         LH    R6,0(,R5)                                           @D04
         LPR   R6,R6                                               @D04
         ST    R6,FULLWORD              OFFSET OF TEXT             @D04
         AR    R6,R1                                               @D04
         ST    R6,DOUBLE                START OF TEXT              @D04
         LH    R6,2(,R5)                                           @D04
         LPR   R6,R6                                               @D04
         S     R6,FULLWORD                                         @D04
         ST    R6,FULLWORD              LENGTH OF TEXT             @D04
         L     R14,DOUBLE+4             SHIFT                      @D04
         SRL   R14,1                         FOR NEXT              @D04
         ST    R14,DOUBLE+4                          BIT TEST      @D04
         LA    R6,DIRNAME(R2)           POINT TO TARGET DATA       @D04
         TM    0(R5),X'80'              NEGATIVE FORM?             @D04
         BO    DIRBIT20                 YES, BRANCH                @D04
         TM    0(R6),*-*                <<EXECUTED>>               @D04
         EX    R14,*-4                  ADD "NOT "?                @D04
         BO    DIRBIT40                 NO, BRANCH                 @D04
         B     DIRBIT30                 YES, BRANCH                @D04
         SPACE 1                                                   @D04
DIRBIT20 TM    0(R6),*-*                <<EXECUTED>>               @D04
         EX    R14,*-4                  ADD "NOT "?                @D04
         BNO   DIRBIT40                 NO, BRANCH                 @D04
         SPACE 1                                                   @D04
DIRBIT30 MVC   0(4,R15),DIRNOT          ADD "NOT "                 @D04
         LA    R15,4(,R15)              UPDATE LENGTH              @D04
         SPACE 1                                                   @D04
DIRBIT40 L     R14,FULLWORD             ACTUAL LENGTH              @D04
         BCTR  R14,0                    MACHINE LENGTH             @D04
         L     R6,DOUBLE                START OF STRING            @D04
         MVC   0(*-*,R15),0(R6)         <<EXECUTED>>               @D04
         EX    R14,*-6                  MOVE IN STRING             @D04
         LA    R15,1(R14,R15)           NEXT OUTPUT LOCATION       @D04
         BCT   R0,DIRBIT10              DO ALL 4 BITS              @D04
         BR    R4                                                  @D04
         SPACE 3                                                   @D04
DIRBITP1 DC    0H'0',AL2(+08,+19,+25,+34,+38)                      @D04
DIRBITP2 DC    0H'0',AL2(+08,+19,+28,+34,+40)                      @D04
DIRBITP3 DC    0H'0',AL2(-08,+12,+24,-30,+38)                      @D04
DIRBITP4 DC    0H'0',AL2(-08,+14,+20,+28,+39)                      @D04
         SPACE 1                                                   @D04
DIRNOT   DC    C'NOT '                                             @D04
DIR24    DC    C'24; '                                             @D04
DIR31    DC    C'31'                                               @D04
DIR64    DC    C'64'                                               @D04
DIR2020  DC    X'4020206B2021204B'      EDIT MASK                  @D04
DIR4020  DC    X'40202120'              EDIT MASK                  @D04
MSG262H  DC    CL40'LOC NAME     VALUE     DESCRIPTION'            @D04
MSG262U  DC    CL40'--- ----     -----     -----------'            @D04
*IRHDR    DC CL52'1234567890123456789012345678901234567890123456789012'
DIRHDR    DC CL52'PDS2NAMEMEMBER NAME                                 '
          DC CL52'PDS2TTRPTTR OF FIRST BLOCK OF DATA                  '
          DC CL52'PDS2INDCALIAS; N TTRS FOLLOW; NN HALFWORDS OF DATA  '
          DC CL52'PDS2TTRTTTR OF FIRST TEXT BLOCK                     '
          DC CL52'PDS2TTRN(NOT USED FOR THIS MEMBER)                  '
          DC CL52'PDS2TTRNTTR OF SCATTER TRANSLATION TABLE            '
          DC CL52'PDS2TTRNTTR OF OVERLAY NOTE LIST                    '
          DC CL52'PDS2NL  NUMBER OF ENTRIES IN NOTE LIST              '
*                           1    1    2    2    3    3    4    4
*                           0    5    0    5    0    5    0    5
DIRHDR14  DC CL52'PDS2ATR1REENTRANT; REUS; OVERLAY; TEST          '
          DC CL52'        ONLY LOAD; SCATTER; EXEC; 1 TEXT            '
          DC CL52'PDS2ATR2DC; TEXT ORG=0; EP=0; HAS RLDS              '
          DC CL52'        EDIT; TEST; LKED F; REFRESHABLE             '
          DC CL52'PDS2STORTOTAL CONTIGUOUS MAIN STORAGE REQUIRED      '
          DC CL52'PDS2FTBLLENGTH OF FIRST BLOCK OF TEXT               '
          DC CL52'PDS2EPA ENTRY POINT ADDRESS                         '
          DC CL52'PDS2FTB1PROCESSED BY OS/VS LINKAGE EDITOR           '
          DC CL52'        PAGE ALIGNMENT REQUIRED                     '
          DC CL52'        SSI INFORMATION IS PRESENT                  '
          DC CL52'        APF INFORMATION IS VALID                    '
          DC CL52'        PROGRAM OBJECT FORMAT                       '
          DC CL52'        REQUIRES 16M OR MORE OF VIRTUAL STORAGE     '
          DC CL52'PDS2FTB2RMODE ANY; ALIAS AMODE ANY; MAIN AMODE ANY  '
          DC CL52'PDS2FTB3RLD/CONTROL RECORDS AFTER FIRST TEXT BLOCK  '
DIRHDROS  DC CL52'PDS2FTB0ORIGIN OF FIRST BLOCK OF TEXT (FOR O.S. USE)'
DIRHDR21  DC CL52'PDS2SLSZNUMBER OF BYTES IN SCATTER LIST             '
          DC CL52'PDS2TTSZNUMBER OF BYTES IN TRANSLATION TABLE        '
          DC CL52'PDS2ESDTESD CSECT IDENTIFIER OF FIRST TEXT BLOCK    '
          DC CL52'PDS2ESDCESD CSECT IDENTIFIER OF ENTRY POINT BLOCK   '
DIRHDR29  DC CL52'PDS2EPM ENTRY POINT OF MAIN MEMBER                  '
          DC CL52'PDS2MNM MEMBER NAME OF MAIN MEMBER                  '
DIRHDR34  DC CL52'PDSSSIWDSSI INFORMATION                             '
DIRHDR38  DC CL52'PDSAPFCTLENGTH OF PROGRAM AUTHORIZATION CODE        '
          DC CL52'PDSAPFACPROGRAM AUTHORIZATION CODE                  '
DIRHDRLP  DC CL52'PDS2LPOLLENGTH OF LARGE PROGRAM OBJECT SECTION      '
          DC CL52'PDS2VSTRVIRTUAL STORAGE REQUIREMENT FOR THIS MODULE '
          DC CL52'PDS2MEPAMAIN ENTRY POINT OFFSET                     '
          DC CL52'PDS2AEPAALIAS ENTRY POINT OFFSET                    '
DIRHDRPM  DC CL52'MANMODD DATE LAST MODIFIED   -- FORMAT: 0CYYDDDF    '
          DC CL52'MANMODT TIME                 -- FORMAT: HHMM        '
          DC CL52'MANEXPIREXPIRATION BASE DATE -- FORMAT: YYDDDF      '
          DC CL52'MANMODN MEMBER MODIFICATION LEVEL                   '
          DC CL52'MANUSER UPDATING JOBNAME OR TSO USER                '
          DC CL52'MANPROD PRODUCTIONS STATUS INDICATOR -- X''80''     '
          DC CL52'MANREAD DATE LAST READ       -- FORMAT: YYDDDF      '
DIRHDRSP  DC CL52'DIRSPFV MEMBER VERSION NUMBER                       '
          DC CL52'DIRSPFR MEMBER REVISION NUMBER                      '
          DC CL52'DIRSPFFLEXTENDED STATS -- X''20''  SCLM -- X''80''  '
          DC CL52'DIRSPFCSLAST CHANGE TIME -- FORMAT: SS              '
          DC CL52'DIRSPFCRCREATION DATE    -- FORMAT: 0CYYDDDF        '
          DC CL52'DIRSPFCDLAST CHANGE DATE -- FORMAT: 0CYYDDDF        '
          DC CL52'DIRSPFCTLAST CHANGE TIME -- FORMAT: HHMM            '
          DC CL52'DIRSPFSINUMBER OF LINES CURRENTLY                   '
          DC CL52'DIRSPFINNUMBER OF LINES INITIALLY                   '
          DC CL52'DIRSPFMDNUMBER OF MODIFIED LINES                    '
          DC CL52'DIRSPFIDUSERID OF LAST PERSON TO UPDATE             '
          DC CL52'DIRSPXSINUMBER OF LINES CURRENTLY - EXTENDED STATS  '
          DC CL52'DIRSPXINNUMBER OF LINES INITIALLY - EXTENDED STATS  '
          DC CL52'DIRSPXMDNUMBER OF MODIFIED LINES  - EXTENDED STATS  '
**** END OF LINES ADDED BY --------------------------------------- @D04
         TITLE 'P D S  --  PDS MAP                             1/15/85' 08376000
*********************************************************************** 08377000
***      MAP SUBCOMMAND                                             *** 08378000
*********************************************************************** 08379000
*                                                                       08380000
         SPACE 1                                                        08381000
MAP      CSECT                                                          08382000
         USING *,R8                                                     08383000
         LA    R1,L530          ASSUME A NON-PARTITIONED DATA SET       08384000
         TM    DSORG,DS1DSGPO   CORRECT?                                08385000
         BZ    MSGNEW           YES, BRANCH                             08386000
         SPACE 1                                                        08387000
         LA    R1,L701          ASSUME NOT A LOAD LIBRARY               08388000
         TM    FLAGSCC,RECFMU   CORRECT?                                08389000
         BZ    MSGNEW           YES, BRANCH                             08390000
         MVI   ENTRYPT,C'?'     NO ENTRY POINT YET                      08391000
         SPACE 1                                                        08392000
         L     R15,=A(READESD)  FORMAT THE ESD DATA                     08393000
         BALR  R14,R15          ANY ESD DATA?                           08394000
         B     *+8              NO, BRANCH                              08395000
         B     MAP04            YES, BRANCH                             08396000
MAPNOESD TM    FLAGSAA,FMEM#MEM+FINDMSG  GROUP HEADER TO BE WRITTEN?    08397000
         BNO   MAP02                     NO, BRANCH                     08398000
         CLI   #MODLEN,0                 ANY FILTERING?                 08399000
         BH    NEWCMD                    NO, BRANCH                     08400000
         MESSAGE MSGBLANK                                               08401000
         MESSAGE FINDMEMQ                                               08402000
         SPACE 1                                                        08403000
MAP02    LA    R1,MSGTEXT1               MESSAGE IDENTIFIER             08404000
         TSMSG (R1)                                                     08405000
         B     MAPNOMSG                                                 08406000
         SPACE 1                                                        08407000
MAP04    LA    R4,#ESDPTR       ESD TABLE CHAIN POINTER                 08408000
         USING ESDENTRY,R4      BASE FOR TABLE                          08409000
         TM    FLAGSAA,FINDMSG  ANY GROUP HEADER?                       08410000
         BNO   MAPESD           NO, BRANCH                              08411000
         MESSAGE MSGBLANK                                               08412000
         MESSAGE FINDMEMQ                                               08413000
         NI    FLAGSAA,FF-FINDMSG                                       08414000
         SPACE 2                                                        08415000
MAPESD   MVC   MSGTEXT1(136),MSGBL132                                   08416000
         ICM   R4,B'1111',ESDLINK    END OF CHAIN?                      08417000
         BZ    MAPLAST               YES, BRANCH                        08418000
         SPACE 1                                                        08419000
         CLI   #MAPOPT,X'04'         RELINK FORMAT?                @D01
         BE    MAP600                YES, BRANCH                   @D01
         CLI   #MAPOPT,X'05'         RELINK FORMAT?                @D01
         BE    MAP600                YES, BRANCH                   @D01
         CLI   ESDTYPE,CODELR        EXTERNAL REFERENCE?                08420000
         BE    MAPLR                 YES                                08421000
         CLI   ESDTYPE,CODEER        $UNRESOLVED EXTERNAL REF?     @D01
         BE    MAPER                 YES, BRANCH                   @D01
         CLI   ESDTYPE,CODEWK        $UNRESOLVED WEAK EXTERN REF?  @D01
         BE    MAPWK                 YES, BRANCH                   @D01
         SPACE 2                                                        08422000
         CLC   ESDADDR(3),DIREPA     ENTRY POINT?                       08423000
         BNE   *+10                  NO, BRANCH                         08424000
         MVC   ENTRYPT,ESDNAME       SAVE THE ENTRY POINT NAME          08425000
         MVC   MSGTEXT1+4(8),ESDNAME                                    08426000
         UNPK  MSGTEXT1+14(7),ESDADDR(4)                                08427000
         TR    MSGTEXT1+14(6),TRTABLE                                   08428000
         MVI   MSGTEXT1+20,X'40'     CLEAR GARBAGE BYTE                 08429000
         UNPK  MSGTEXT1+22(7),ESDLEN(4)                                 08430000
         TR    MSGTEXT1+22(6),TRTABLE                                   08431000
         MVI   MSGTEXT1+28,X'40'     CLEAR GARBAGE BYTE                 08432000
         SPACE 1                                                        08433000
         TM    DIRATTR,ATTROVLY      OVERLAY PROGRAM?                   08434000
         BZ    MAPNOVLY              NO, BRANCH                         08435000
         SR    R0,R0                                                    08436000
         IC    R0,ESDSEG#                                               08437000
         CVD   R0,DOUBLE                                                08438000
         OI    DOUBLE+7,X'0F'                                           08439000
         UNPK  MSGTEXT1+30(2),DOUBLE+6(2)                               08440000
         B     MAPPRINT                                                 08441000
         SPACE 1                                                        08442000
MAPNOVLY CLI   ESDXAFLG,AMODE24          RMODE 24 AND AMODE 24?         08443000
         BNH   MAPPRINT                  NO, BRANCH                     08444000
         MVC   MSGTEXT1+30(5),=C'RMODE'                                 08445000
         MVC   MSGTEXT1+36(3),=C'ANY'                                   08446000
         TM    ESDXAFLG,RMODEANY         RMODE ANY?                     08447000
         BO    *+10                      YES, BRANCH                    08448000
         MVC   MSGTEXT1+36(3),=C'24 '    RMODE 24                       08449000
         MVC   MSGTEXT1+40(5),=C'AMODE'                                 08450000
         MVC   MSGTEXT1+46(3),=C'24 '                                   08451000
         TM    ESDXAFLG,AMODE31          AMODE 31?                      08452000
         BNO   *+10                      NO, BRANCH                     08453000
         MVC   MSGTEXT1+46(3),=C'31 '    AMODE 31                       08454000
         TM    ESDXAFLG,AMODE64          AMODE 64?                 @D02
         BNO   *+10                      NO, BRANCH                @D02
         MVC   MSGTEXT1+46(3),=C'64 '    AMODE 64                  @D02
         TM    ESDXAFLG,AMODE64+AMODE31  AMODE ANY?                @D02
         BNO   *+10                      NO, BRANCH                     08456000
         MVC   MSGTEXT1+46(3),=C'ANY'    AMODE ANY                      08457000
         B     MAPPRINT                                                 08458000
         SPACE 2                                                   @D01
MAPWK    MVC   INSERT#1(8),ESDNAME       Set name as insert        @D01
         TSMSG L441$1                    Say "(WEAK)"              @D01
         B     MAPESD                    Do next external symbol   @D01
         SPACE 2                                                   @D01
MAPER    MVC   INSERT#1(8),ESDNAME       Set name as insert        @D01
         TSMSG L442$1                    Say "(MISSING)"           @D01
         B     MAPESD                    Do next external symbol   @D01
         SPACE 2                                                        08459000
MAPLR    CLC   ESDADDR(3),DIREPA     ENTRY POINT?                       08460000
         BNE   *+10                  NO, BRANCH                         08461000
         MVC   ENTRYPT,ESDNAME       SAVE THE ENTRY POINT NAME          08462000
         MVC   MSGTEXT1+56(8),ESDNAME                                   08463000
         UNPK  MSGTEXT1+66(7),ESDADDR(4)                                08464000
         TR    MSGTEXT1+66(6),TRTABLE                                   08465000
         MVI   MSGTEXT1+66+6,X'40'   CLEAR GARBAGE BYTE                 08466000
         SPACE 1                                                        08467000
MAPPRINT MESSAGE MSGTEXT1                                               08468000
         B     MAPESD                                                   08469000
         SPACE 2                                                        08470000
MAPLAST  MESSAGE MSGBLANK                                               08471000
MAPNOMSG UNPK  INSERT#1(7),DIREPA(4)                                    08472000
         TR    INSERT#1(6),TRTABLE                                      08473000
         MVC   INSERT#1+6(2),BLANKS                                     08474000
         MVC   INSERT#2(8),ENTRYPT NAME OF THE ENTRY POINT              08475000
         TR    INSERT#2(8),TRLINE     MAKE PRINTABLE                    08476000
         LA    R1,L102$1              ASSUME NONE FOUND                 08477000
         CLI   ENTRYPT,C'?'           ANY FOUND?                        08478000
         BE    *+8                    NO, BRANCH                        08479000
         LA    R1,L103$2              YES, SHOW ENTRY SYMBOL            08480000
         TSMSG (R1)                                                     08481000
         SPACE 1                                                        08482000
         UNPK  INSERT#1(7),DIRSTORE(4)                                  08483000
         TR    INSERT#1(6),TRTABLE                                      08484000
         MVC   INSERT#1+6(2),BLANKS                                     08485000
         ICM   R1,B'0111',DIRSTORE    ACTUAL MODULE LENGTH              08486000
         LA    R1,1023(,R1)           NEXT HIGHER                       08487000
         SRL   R1,10                             1K VALUE               08488000
         CVD   R1,DOUBLE                                                08489000
         MVC   INSERT#2(8),=X'402020202120D2404040'                     08490000
         ED    INSERT#2(6),DOUBLE+5                                     08491000
         TSMSG L104$2                                                   08492000
         SPACE 1                                                        08493000
         TM    DIRFLAG,X'80'      IS MODULE AN ALIAS?                   08494000
         BZ    NEWCMD             NO, NO ALIAS INFORMATION              08495000
         CLI   #MAPOPT,X'01'      SHORT OR ENTRY POINT MAP?             08496000
         BH    NEWCMD             YES, DONE                             08497000
         TM    FLAGSGG,FALINCON   NO ALIAS INFORMATION DEFAULT?         08498000
         BO    NEWCMD             YES, DONE                             08499000
         EJECT                                                          08500000
*        FIND THE CORRESPONDING MAIN MODULE                             08501000
         MVI   STARTTR+2,X'01'    TTR=000001 (START OF DIRECTORY)       08502000
         XC    INSERT#1(8),INSERT#1  NO MAIN(S) FOUND                   08503000
         SPACE 1                                                        08504000
MAPAREAL BAL   R14,READDIR        GET NEXT DIRECTORY MEMBER             08505000
         B     MAPNREAL           LAST MEMBER PROCESSED                 08506000
         SPACE 1                                                        08507000
         TM    MEMFLAG,X'80'      THIS MODULE AN ALIAS?                 08508000
         BO    MAPAREAL           YES, IGNORE                           08509000
         CLC   DIRTTR,MEMTTR      TTR MATCH?                            08510000
         BNE   MAPAREAL           NO, BRANCH                            08511000
         SPACE 1                                                        08512000
         MVC   INSERT#1(8),MEMNAME                                      08513000
         TSMSG L066$1                                                   08514000
         B     MAPAREAL                                                 08515000
         SPACE 2                                                        08516000
MAPNREAL OC    INSERT#1(8),INSERT#1  ANY MAIN(S) FOUND?                 08517000
         BNZ   NEWCMD                YES, QUIT                          08518000
         TSMSG L860                                                     08519000
         TM    FLAGSCC,RECFMU     LOAD MODULE?                          08520000
         BNO   NEWCMD             NO, BRANCH                            08521000
         MVC   INSERT#1(8),DIRREAL                                      08522000
         SPACE 1                                                        08523000
         TM    DIRATTR,ATTRSCTR   SCATTER LOADED?                       08524000
         BNO   *+10               NO, BRANCH                            08525000
         MVC   INSERT#1(8),DIRREALS                                     08526000
         LA    R1,L861$1                                                08527000
         B     MSGNEW                                                   08528000
         SPACE 1                                                        08529000
* GENERATE JCL AND CONTROL CARDS TO LINKAGE EDIT A MODULE          @D03
MAP600   TM    DIRFLAG,X'80'                     ALIAS?            @D03
         BNO   MAP604                            NO, BRANCH        @D03
         MVI   STARTTR+2,X'01'                   READ DIRECTORY    @D03
         SPACE 1                                                   @D03
MAP602   BAL   R14,READDIR                       GET NEXT MEMBER   @D03
         B     MAP604                            END OF MEMBERS    @D03
         SPACE 1                                                   @D03
         CLC   DIRTTR(3),MEMTTR                  THIS TTR?         @D03
         BNE   MAP602                            NO, LOOP          @D03
         TM    MEMTTR+3,X'80'                    ALIAS?            @D03
         BO    MAP602                            YES, LOOP         @D03
         L     R14,DIRPTRS                       START OF ENTRY    @D03
         MVC   DIRNAME(DIREND-DIRNAME),0(R14)    REPLACE THE ENTRY @D03
         SPACE 2                                                   @D03
MAP604   MVC   MSGTEXT1+4(L'MAPLLKED),MAPLLKED   //LKED  EXEC PGM= @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 2                                                   @D03
         MVC   MSGTEXT1+4(L'MAPLPARM),MAPLPARM   //      PARM='... @D03
         LA    R1,MSGTEXT1+4+L'MAPLPARM                            @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTRRENT                  REENTRANT?        @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(5,R1),MAPLATTR+00               YES, ADD ,RENT    @D03
         LA    R1,5(,R1)                                           @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTRREUS                  REUSABLE?         @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(5,R1),MAPLATTR+05               YES, ADD ,REUS    @D03
         LA    R1,5(,R1)                                           @D03
         SPACE 1                                                   @D03
         TM    DIRATTR+1,ATTRREFR                REFRESHABLE?      @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(5,R1),MAPLATTR+10               YES, ADD ,REFR    @D03
         LA    R1,5(,R1)                                           @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTROVLY                  OVERLAY?          @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(5,R1),MAPLATTR+15               YES, ADD ,OVLY    @D03
         LA    R1,5(,R1)                                           @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTRTEST                  TEST SYMBOLS?     @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(5,R1),MAPLATTR+20               YES, ADD ,TEST    @D03
         LA    R1,5(,R1)                                           @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTRSCTR                  SCATTER LOADED?   @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(5,R1),MAPLATTR+25               YES, ADD ,SCTR    @D03
         LA    R1,5(,R1)                                           @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTRLOAD                  ONLY LOADABLE?    @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(3,R1),MAPLATTR+30               YES, ADD ,OL      @D03
         LA    R1,3(,R1)                                           @D03
         SPACE 1                                                   @D03
         TM    DIRATTR+1,ATTRNE                  NOT EDITABLE?     @D03
         BNO   *+14                              NO, BRANCH        @D03
         MVC   0(3,R1),MAPLATTR+33               YES, ADD ,NE      @D03
         LA    R1,3(,R1)                                           @D03
         SPACE 1                                                   @D03
         MVI   0(R1),C''''                       ADD FINAL QUOTE   @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+4(L'MAPLSUT1),MAPLSUT1   //SYSUT1          @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+4(L'MAPLSPRT),MAPLSPRT   //SYSPRINT        @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+4(L'MAPLSLIB),MAPLSLIB   //SYSLIB          @D03
         MVC   MSGTEXT1+4+L'MAPLSLIB(44),DSNAME  ADD DSNAME        @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+4(L'MAPLSMOD),MAPLSMOD   //SYSLMOD         @D03
         MVC   MSGTEXT1+4+L'MAPLSMOD(44),DSNAME  ADD DSNAME        @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+4(L'MAPLSLIN),MAPLSLIN   //SYSLIN          @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+4(L'MAPLINCL),MAPLINCL   ADD "INCLUDE SYSL @D03
         MVC   MSGTEXT1+4+L'MAPLINCL(8),DIRNAME  ADD MEMBER NAME   @D03
         LA    R1,MSGTEXT1+4+L'MAPLINCL+8                          @D03
         CLI   0(R1),X'40'                                         @D03
         BNE   *+8                                                 @D03
         BCT   R1,*-8                                              @D03
         MVI   1(R1),C')'                                          @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTROVLY                  OVERLAY MODULE?   @D03
         BO    MAP700                            YES, BRANCH       @D03
         SPACE 3                                                   @D03
         LA    R4,#ESDPTR                                          @D03
         SPACE 1                                                   @D03
MAP610   LA    R1,MSGTEXT1+4+8                   START OF CSECTS   @D03
         LA    R0,MSGTEXT1+4+60                  END OF CSECTS     @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         MVC   MSGTEXT1+4+1(5),MAPLORD           ADD " ORDER"      @D03
         SPACE 1                                                   @D03
MAP620   ICM   R4,B'1111',ESDLINK                NEXT ESD ELEMENT? @D03
         BZ    MAP670                            NO, BRANCH        @D03
         CLI   ESDTYPE,CODESD                    CSECT?            @D03
         BE    MAP630                            YES, BRANCH       @D03
         CLI   ESDTYPE,CODELR                    EXTRN?            @D03
         BE    MAP630                            YES, BRANCH       @D03
         CLC   ESDNAME(8),MAPL$BLK               BLANK COMMON?     @D03
         BE    MAP620                            YES, BRANCH       @D03
         CLI   ESDTYPE,CODECM                    COMMON?           @D03
         BNE   MAP620                            NO, BRANCH        @D03
         B     MAP640                            NO, BRANCH        @D03
         SPACE 1                                                   @D03
MAP630   CLC   ESDADDR(3),DIREPA                 ENTRY POINT?      @D03
         BNE   *+10                              NO, BRANCH        @D03
         MVC   ENTRYPT,ESDNAME                   YES, SAVE THE NAME@D03
         CLI   ESDTYPE,CODELR                    EXTRN?            @D03
         BE    MAP620                            YES, BRANCH       @D03
         SPACE 1                                                   @D03
MAP640   MVC   1(8,R1),ESDNAME                   ADD THE ESDNAME   @D03
         LA    R14,8(,R1)                                          @D03
         SPACE 1                                                   @D03
         CLI   0(R14),X'40'                      BLANK?            @D03
         BNE   *+8                               NO, BRANCH        @D03
         BCT   R14,*-8                                             @D03
         SPACE 1                                                   @D03
         TM    DIRATTR2,DIR2PAGA                 PAGE ALIGN?       @D03
         BNO   MAP660                            NO, BRANCH        @D03
         TM    ESDADDR+1,X'0F'                   POSSIBLE 4K MULT? @D03
         BNZ   MAP660                            NO, BRANCH        @D03
         TM    ESDADDR+2,X'FF'                   4K MULTIPLE?      @D03
         BNZ   MAP660                            NO, BRANCH        @D03
         MVC   1(3,R14),MAPLPAG                  YES, ADD "(P)"    @D03
         LA    R14,3(,R14)                                         @D03
         SPACE 1                                                   @D03
MAP660   MVI   1(R14),C','                       ADD A COMMA       @D03
         LA    R1,1(,R14)                                          @D03
         CR    R1,R0                             END OF CARD?      @D03
         BNH   MAP620                            NO, BRANCH        @D03
         SPACE 2                                                   @D03
         MVI   0(R1),X'40'                       CLEAR LAST COMMA  @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         B     MAP610                                              @D03
         SPACE 2                                                   @D03
MAP670   CLI   MSGTEXT1+4+9,X'40'                ANY TEXT?         @D03
         BE    MAP800                            NO, BRANCH        @D03
         MVI   0(R1),X'40'                       CLEAR LAST COMMA  @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         B     MAP800                                              @D03
         SPACE 2                                                   @D03
MAP700   MVC   STARTTR(3),DIRSTART               ADDRESS OF NOTELI @D03
         L     R15,=A(EXCP)                                        @D03
         BALR  R14,R15                                             @D03
         LA    R1,L751                           NOTELIST NOT FOUND@D03
         LTR   R15,R15                           ANY ERROR?        @D03
         BP    MSGNEW                            YES, BRANCH       @D03
         SPACE 1                                                   @D03
         LR    R2,R0                             START OF RECORD   @D03
         LR    R5,R0                             START OF RECORD   @D03
         LA    R14,24(,R2)                       FIRST SEGMENT     @D03
         LA    R0,4                              INCREMENT         @D03
         LR    R1,R2                                               @D03
         A     R1,LS                             LAST SEGMENT      @D03
         SR    R1,R0                             FOR BXLE          @D03
         SR    R15,R15                                             @D03
         SPACE 1                                                   @D03
MAP710   LA    R15,1(,R15)                       NEXT SEGMENT #    @D03
         STC   R15,3(,R14)                       STORE IN SEGTAB   @D03
         BXLE  R14,R0,MAP710                     DO ALL ENTRIES    @D03
         SPACE 2                                                   @D03
         MVI   0(R14),X'FF'                      MARK END OF TABLE @D03
         MVC   FULLWORD,=F'1'                    REGION = 1        @D03
         LA    R2,24(,R5)                        BEGIN SEGMENT 1   @D03
         LA    R6,8(,R5)                         BEGIN REGION 1    @D03
         SPACE 1                                                   @D03
MAP720   SR    R1,R1                                               @D03
         IC    R1,0(,R6)                         # OF LAST SEGMENT @D03
         LTR   R1,R1                             END OF STRUCTURE? @D03
         BZ    MAP800                            YES, BRANCH       @D03
         SLL   R1,2                              SEGMENT * 4       @D03
         LA    R3,20(R1,R5)                      LAST SEGMENT      @D03
         SPACE 2                                                   @D03
MAP724   LA    R4,#ESDPTR                        START OF ESD      @D03
         SPACE 1                                                   @D03
MAP730   LA    R1,MSGTEXT1+4+8                   START OF CSECTS   @D03
         LA    R0,MSGTEXT1+4+62                  END OF CSECTS     @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         MVC   MSGTEXT1+4+1(6),MAPLINS           ADD " INSERT"     @D03
         SPACE 1                                                   @D03
MAP732   ICM   R4,B'1111',ESDLINK                NEXT ESD ELEMENT? @D03
         BZ    MAP742                            NO, BRANCH        @D03
         CLC   ESDSEG#(1),3(R2)                  THIS SEGMENT?     @D03
         BNE   MAP732                            NO, BRANCH        @D03
         CLI   ESDTYPE,CODESD                    CSECT?            @D03
         BE    MAP734                            YES, BRANCH       @D03
         CLI   ESDTYPE,CODELR                    EXTRN?            @D03
         BE    MAP734                            YES, BRANCH       @D03
         CLC   ESDNAME(8),MAPL$BLK               BLANK COMMON?     @D03
         BE    MAP732                            YES, BRANCH       @D03
         CLI   ESDTYPE,CODECM                    COMMON?           @D03
         BNE   MAP732                            NO, BRANCH        @D03
         B     MAP740                                              @D03
         SPACE 1                                                   @D03
MAP734   CLC   ESDADDR(3),DIREPA                 ENTRY POINT?      @D03
         BNE   *+10                              NO, BRANCH        @D03
         MVC   ENTRYPT,ESDNAME                   YES, SAVE NAME    @D03
         CLI   ESDTYPE,CODELR                    EXTRN?            @D03
         BE    MAP732                            YES, BRANCH       @D03
         SPACE 1                                                   @D03
MAP740   MVC   1(8,R1),ESDNAME                   ADD THE ESDNAME   @D03
         LA    R14,8(,R1)                                          @D03
         SPACE 1                                                   @D03
         CLI   0(R14),X'40'                      BLANK?            @D03
         BNE   *+8                               NO, BRANCH        @D03
         BCT   R14,*-8                                             @D03
         SPACE 1                                                   @D03
         MVI   1(R14),C','                       ADD A COMMA       @D03
         LA    R1,1(,R14)                                          @D03
         CR    R1,R0                             END OF CARD?      @D03
         BNH   MAP732                            NO, BRANCH        @D03
         SPACE 2                                                   @D03
         MVI   0(R1),X'40'                       CLEAR LAST COMMA  @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         B     MAP730                                              @D03
         SPACE 1                                                   @D03
MAP742   CLI   MSGTEXT1+4+9,X'40'                ANY TEXT?         @D03
         BE    MAP750                            NO, BRANCH        @D03
         MVI   0(R1),X'40'                       CLEAR LAST COMMA  @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 2                                                   @D03
MAP750   CLI   4(R2),X'FF'                       END OF SEGTAB?    @D03
         BE    MAP800                            YES, BRANCH       @D03
         CR    R2,R3                             END OF REGION?    @D03
         BE    MAP764                            YES, BRANCH       @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+4+1(7),MAPLOVER          ADD " OVERLAY"    @D03
         MVC   MSGTEXT1+4+1+7+1(6),MAPLREG+1     ADD " REGION"     @D03
         MVC   MSGTEXT1+4+1+7+1+6(1),FULLWORD+3  ADD REGION NUMBER @D03
         OI    MSGTEXT1+4+1+7+1+6,X'F0'          MAKE PRINTABLE    @D03
         SPACE 1                                                   @D03
         SR    R1,R1                                               @D03
         ICM   R1,B'0001',4(R2)                  PREVIOUS SEGMENT? @D03
         BZ    MAP760                            NO, BRANCH        @D03
         MVC   MSGTEXT1+4+1+7+1(6),MAPLOVLY      ADD " OVLY"       @D03
         CVD   R1,DOUBLE                                           @D03
         OI    DOUBLE+7,X'0F'                                      @D03
         UNPK  MSGTEXT1+4+1+7+1+4(3),DOUBLE+6(2) ADD SEGMENT NUM   @D03
MAP760   TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 1                                                   @D03
MAP764   LA    R0,4                                                @D03
         LR    R1,R3                                               @D03
         BXLE  R2,R0,MAP724                      DO EACH SEGMENT   @D03
         SPACE 2                                                   @D03
         LA    R6,2(,R6)                                           @D03
         CLI   0(R6),X'00'                       ANY SEGMENTS?     @D03
         BE    MAP800                            NO, BRANCH        @D03
         L     R1,FULLWORD                                         @D03
         LA    R0,4                                                @D03
         CR    R1,R0                             4TH REGION DONE?  @D03
         BNL   MAP800                            YES, BRANCH       @D03
         LA    R1,1(,R1)                         NEXT REGION       @D03
         ST    R1,FULLWORD                                         @D03
         MVC   MSGTEXT1+4+1(7),MAPLOVER          ADD " OVERLAY"    @D03
         MVC   MSGTEXT1+4+1+7+1(6),MAPLREG+1     ADD "REGION"      @D03
         STC   R1,MSGTEXT1+4+1+7+1+6             ADD REGION NUMBER @D03
         OI    MSGTEXT1+4+1+7+1+6,X'F0'          MAKE PRINTABLE    @D03
         MVC   MSGTEXT1+4+1+7+1+6+1(8),MAPLREG   ADD "(REGION)"    @D03
         MVC   MSGTEXT1+4+1+7+1(6),MAPLREG+1     ADD "REGION"      @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         B     MAP720                                              @D03
         SPACE 2                                                   @D03
MAP800   LA    R2,DIRAPF               POINT TO APF INFORMATION    @D03
         SPACE 1                                                   @D03
         TM    DIRATTR,ATTRSCTR        SCATTER FORMAT?             @D03
         BNO   *+8                     NO, BRANCH                  @D03
         LA    R2,8(,R2)               YES, ADD SCATTER SIZE       @D03
         SPACE 1                                                   @D03
         TM    DIRFLAG,X'80'           ALIAS?                      @D03
         BO    MAP802                  YES, BRANCH                 @D03
         CLI   8(R2),0                 CONVERTED ALIAS ENTRY?      @D03
*        BE    *+8                     NO, BRANCH                  @D03
         B     *+8                     BRANCH                      @D03
MAP802   LA    R2,11(,R2)              ADD ALIAS LENGTH            @D03
MAP803   DS    0H                                                  @D03
         SPACE 1                                                   @D03
         TM    DIRATTR2,DIRAOSLE       VS LINKAGE EDITOR?          @D03
         BNO   MAP804                  NO, BRANCH                  @D03
         SPACE 1                                                   @D03
         TM    DIRATTR2,DIR2SSI        SSI PRESENT?                @D03
         BNO   MAP820                  NO, SKIP SSI PROCESSING     @D03
         SPACE 1                                                   @D03
MAP804   LA    R2,1(,R2)               ROUND UP TO HALFWORD        @D03
         N     R2,=F'-2'                                           @D03
         SPACE 1                                                   @D03
         CLC   ZERO,0(R2)              ZERO?                       @D03
         BE    MAP820                  YES, NO SSI                 @D03
         CLC   =F'-1',0(R2)            FFFFFFFF?                   @D03
         BE    MAP820                  YES, NO SSI                 @D03
         SPACE 1                                                   @D03
         MVC   MSGTEXT1+5(6),MAPLSET   ADD " SETSSI"               @D03
         UNPK  MSGTEXT1+5+6+2(9),0(5,R2)                           @D03
         TR    MSGTEXT1+5+6+2(8),TRTABLE                           @D03
         MVI   MSGTEXT1+5+6+2+8,X'40'                              @D03
         LA    R2,4(,R2)               ADD SSI SIZE                @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 2                                                   @D03
MAP820   TM    DIRATTR2,DIRAOSLE           VS LINKAGE EDITOR?      @D03
         BZ    MAP860                      NO, CAN'T BE AUTHORIZED @D03
         SR    R1,R1                                               @D03
         IC    R1,DIRATTR3                 AMODE BITS              @D03
         TM    DIRFLAG,X'80'               ALIAS?                  @D03
         BNO   *+8                         NO, BRANCH              @D03
         SRL   R1,2                        YES, SHIFT AMODE BITS   @D03
         STC   R1,MODESAVE                 SAVE CURRENT AMODE      @D03
         TM    DIRATTR3,DIRRMANY           RMODE ANY?              @D03
         BNO   *+8                         NO, BRANCH              @D03
         OI    MODESAVE,DIRRMANY           YES, SET RMODE AGAIN    @D03
         SPACE 1                                                   @D03
         TM    MODESAVE,DIRRMANY+DIRAM31+DIRAM64                   @D03
*                                          UNUSUAL RMODE/AMODE?    @D03
         BZ    MAP840                      NO, BRANCH              @D03
         MVC   DOUBLE(8),BLANKS            RMODE/AMODE FILLER      @D03
         MVC   DOUBLE(3),=C'24 '           MOVE IN THE RMODE TEXT  @D03
         TM    MODESAVE,DIRRMANY           RMODE ANY?              @D03
         BZ    *+10                        NO, BRANCH              @D03
         MVC   DOUBLE(3),=C'ANY'           MOVE IN THE RMODE TEXT  @D03
         MVC   DOUBLE+4(3),=C'24 '         MOVE IN THE AMODE TEXT  @D03
         TM    MODESAVE,DIRAM31            AMODE 31?               @D03
         BZ    *+10                        NO, BRANCH              @D03
         MVC   DOUBLE+4(3),=C'31 '         MOVE IN THE AMODE TEXT  @D03
         TM    MODESAVE,DIRAM64            AMODE 64?               @D03
         BNO   *+10                        NO, BRANCH              @D03
         MVC   DOUBLE+4(3),=C'64 '         MOVE IN THE AMODE TEXT  @D03
         TM    MODESAVE,DIRAM64+DIRAM31    AMODE ANY?              @D03
         BNO   *+10                        NO, BRANCH              @D03
         MVC   DOUBLE+4(3),=C'ANY'         MOVE IN THE AMODE TEXT  @D03
         MVC   MSGTEXT1+4(L'MAPLMODE),MAPLMODE                     @D03
         LA    R1,MSGTEXT1+4+L'MAPLMODE                            @D03
         MVC   0(3,R1),DOUBLE              ADD 24/ANY              @D03
         CLI   2(R1),X'40'                 ANY DATA?               @D03
         BE    *+8                         NO, BRANCH              @D03
         LA    R1,1(,R1)                   YES, ADD 1              @D03
         MVC   2(L'MAPLAMO,R1),MAPLAMO     ADD "),AMODE("          @D03
         LA    R1,2+L'MAPLAMO(,R1)                                 @D03
         MVC   0(3,R1),DOUBLE+4            ADD 24/31/64 OR ANY     @D03
         CLI   2(R1),X'40'                 ANY DATA?               @D03
         BE    *+8                         NO, BRANCH              @D03
         LA    R1,1(,R1)                   YES, ADD 1              @D03
         MVI   2(R1),C')'                  ADD FINAL PARENTHESIS   @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 2                                                   @D03
MAP840   TM    DIRATTR2,DIRAPFLG       APF DATA PRESENT AND VALID? @D03
         BNO   MAP860                  NO, BRANCH                  @D03
         SPACE 1                                                   @D03
         LA    R1,L721                 ASSUME APF LENGTH INCORRECT @D03
         CLI   0(R2),1                 APF DATA LENGTH OK?         @D03
         BNE   MAP860                  NO, BRANCH                  @D03
         SPACE 3                                                   @D03
         LA    R1,L021                 ASSUME AUTHORIZED           @D03
         CLI   1(R2),1                 AUTHORIZED?                 @D03
         BL    MAP860                  NO, BRANCH                  @D03
         MVC   MSGTEXT1+4(L'MAPLAUTH),MAPLAUTH                     @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 2                                                   @D03
MAP860   MVC   MSGTEXT1+4(L'MAPLENTR),MAPLENTR                     @D03
         CLI   ENTRYPT,C'?'           ANY ENTRY POINT?             @D03
         BE    *+10                   NO, BRANCH                   @D03
         MVC   MSGTEXT1+4+L'MAPLENTR-8(8),ENTRYPT                  @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         SPACE 2                                                   @D03
         MVC   ENTRYPT(8),DIRNAME      DEFAULT MODULE NAME         @D03
         MVI   STARTTR+2,X'01'         TTR=000001 DIRECTORY START  @D03
         SPACE 2                                                   @D03
MAP880   LA    R2,MSGTEXT1+4+8                   START OF CSECTS   @D03
         LA    R3,MSGTEXT1+4+62                  END OF CSECTS     @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         MVC   MSGTEXT1+4+1(5),MAPLALIA          ADD " ALIAS"      @D03
         SPACE 1                                                   @D03
MAP890   BAL   R14,READDIR        GET NEXT DIRECTORY MEMBER        @D03
         B     MAP910             LAST MEMBER PROCESSED            @D03
         SPACE 1                                                   @D03
         CLC   DIRTTR,MEMTTR      TTR MATCH?                       @D03
         BNE   MAP890             NO, BRANCH                       @D03
         TM    MEMFLAG,X'80'      ALIAS ENTRY FOUND?               @D03
         BO    MAP900             YES, BRANCH                      @D03
         TM    DIRFLAG,X'80'      ALIAS ORIGINALLY?                @D03
         BNO   MAP890             NO, BRANCH                       @D03
         MVC   ENTRYPT(8),MEMNAME SAVE REAL MEMBER NAME            @D03
         B     MAP890                                              @D03
         SPACE 1                                                   @D03
MAP900   MVC   1(8,R2),MEMNAME                   ADD ALIAS NAME    @D03
         LA    R14,8(,R2)                                          @D03
         SPACE 1                                                   @D03
         CLI   0(R14),X'40'                      BLANK?            @D03
         BNE   *+8                               NO, BRANCH        @D03
         BCT   R14,*-8                                             @D03
         SPACE 1                                                   @D03
         MVI   1(R14),C','                       ADD A COMMA       @D03
         LA    R2,1(,R14)                                          @D03
         CR    R2,R3                             END OF CARD?      @D03
         BNH   MAP890                            NO, BRANCH        @D03
         SPACE 2                                                   @D03
         MVI   0(R2),X'40'                       CLEAR LAST COMMA  @D03
         TSMSG MSGTEXT1                                            @D03
         MVC   MSGTEXT1(136),MSGBL132                              @D03
         B     MAP880                                              @D03
         SPACE 2                                                   @D03
MAP910   CLI   MSGTEXT1+4+9,X'40'                ANY TEXT?         @D03
         BE    MAP920                            NO, BRANCH        @D03
         MVI   0(R2),X'40'                       CLEAR LAST COMMA  @D03
         TSMSG MSGTEXT1                                            @D03
         SPACE 1                                                   @D03
MAP920   MVC   MSGTEXT1(136),MSGBL132                              @D03
         MVC   MSGTEXT1+5(L'MAPLNAME),MAPLNAME                     @D03
         MVC   MSGTEXT1+5+8(8),ENTRYPT                             @D03
         LA    R1,MSGTEXT1+5+8+8                                   @D03
         SPACE 1                                                   @D03
         CLI   0(R1),X'40'                       BLANK?            @D03
         BNE   *+8                               NO, BRANCH        @D03
         BCT   R1,*-8                                              @D03
         SPACE 1                                                   @D03
         MVC   1(3,R1),MAPLREP                                     @D03
         SPACE 1                                                   @D03
         TSMSG MSGTEXT1                                            @D03
         B     NEWCMD                                              @D03
MAPLLKED DC    C'//LKED   EXEC  PGM=IEWL,'                         @D03
MAPLPARM DC    C'//       PARM=''NCAL,MAP,LIST,LET'                @D03
MAPLATTR DC    C',RENT,REUS,REFR,OVLY,TEST,SCTR,OL,NE'             @D03
*MAPLSUT1 DC    C'//SYSUT1   DD  UNIT=SYSDA,SPACE=(1024,(200,20))' @D03
MAPLSUT1 DC    C'//SYSUT1   DD  UNIT=&TUNIT,SPACE=(1024,(200,20))' @D03
MAPLSPRT DC    C'//SYSPRINT DD  SYSOUT=A'                          @D03
MAPLSLIB DC    C'//SYSLIB   DD  DISP=SHR,DSN='                     @D03
MAPLSMOD DC    C'//SYSLMOD  DD  DISP=SHR,DSN='                     @D03
MAPLSLIN DC    C'//SYSLIN   DD  *'                                 @D03
MAPLINCL DC    C' INCLUDE SYSLIB('                                 @D03
MAPLAUTH DC    C' SETCODE AC(1)'                                   @D03
MAPLENTR DC    C' ENTRY   ????????'                                @D03
MAPLMODE DC    C' MODE    RMODE('                                  @D03
MAPLAMO  DC    C'),AMODE('                                         @D03
MAPLNAME DC    C'NAME'                                             @D03
MAPLSET  DC    C'SETSSI'                                           @D03
MAPLALIA DC    C'ALIAS'                                            @D03
MAPLORD  DC    C'ORDER'                                            @D03
MAPLPAG  DC    C'(P)'                                              @D03
MAPLREP  DC    C'(R)'                                              @D03
MAPLREG  DC    C'(REGION)'                                         @D03
MAPLOVER DC    C'OVERLAY'                                          @D03
MAPLOVLY DC    C'OVLY'                                             @D03
MAPLINS  DC    C'INSERT'                                           @D03
         DROP  R4                                                  @D03
         SPACE 3                                                   @D03
         TITLE 'P D S  --  PDS MAP ESD SCAN SUBROUTINE         1/15/85' 08531000
*                                                                       08532000
*        ESD SCAN SUBROUTINE                                            08533000
*                                                                       08534000
         SPACE 2                                                        08535000
READESD  STM   R14,R12,ESDIDRSV   SAVE REGISTERS FOR RETURN             08536000
         LR    R8,R15             ENTRY POINT ADDRESS                   08537000
         USING READESD,R8         SUBROUTINE BASE REGISTER              08538000
         LA    R2,#ESDPTR         ROOT OF ESD CHAIN                     08539000
         MVC   STARTTR(3),DIRTTR  FIRST TTR                             08540000
         SPACE 1                                                        08541000
ESDEXCP  L     R15,=A(EXCP)                                             08542000
         BALR  R14,R15                                                  08543000
         B     *+4(R15)           PROCESS RETURN CODE                   08544000
         B     ESDEXCP1             00 - GOOD READ                      08545000
         B     ESDLAST              04 - END OF MEMBER                  08546000
         B     ESDLAST              08 - END OF DATA SET                08547000
         B     NEWCMD               12 - I/O ERROR                      08548000
         SPACE 1                                                        08549000
ESDEXCP1 LR    R3,R0              START OF RECORD                       08550000
         CLI   0(R3),X'40'        TEST SYM RECORD?                      08551000
         BE    ESDEXCP            YES, SKIP RECORD                      08552000
         CLI   0(R3),X'20'        CESD RECORD?                          08553000
         BNE   ESDLAST            NO, BRANCH                            08554000
         SPACE 1                                                        08555000
         LH    R6,4(,R3)          RELATIVE # OF 1ST ESD ID              08556000
         LH    R5,6(,R3)          LENGTH OF DATA IN BUFFER              08557000
         LA    R3,8(,R3)          START OF ESD DATA                     08558000
         AR    R5,R3                                                    08559000
         LA    R4,16              LENGTH OF ONE ENTRY                   08560000
         SR    R5,R4                                                    08561000
         SPACE 2                                                        08562000
         USING ESDNAME,R3                                               08563000
ESDSCAN  IC    R0,ESDTYPE                                               08564000
         LA    R1,CODESEG         CHECK FOR SEGTAB/ENTAB                08565000
         TM    DIRATTR,ATTROVLY   OVERLAY MODULE?                       08566000
         BO    *+8                YES, BRANCH                           08567000
         NI    ESDXAFLG,RMODEANY+AMODE24+AMODE31                        08568000
         NI    ESDTYPE,X'0F'                                            08569000
         NR    R0,R1                                                    08570000
         CLI   #MAPOPT,X'03'      ENTRY POINT ONLY?                     08571000
         BE    ESDSCAN2           YES, BRANCH                           08572000
         CLC   ##SUBCOM(8),$ALI   ALIAS SEARCH REQUEST?                 08573000
         BNE   ESDMAP             NO, BRANCH                            08574000
ESDSCAN2 CLI   ESDTYPE,CODESD     VALID EXTERNAL SYMBOL?                08575000
         BE    ESDCHK             YES, BRANCH                           08576000
         CLI   ESDTYPE,CODELR     ANOTHER VALID ENTRY                   08577000
         BNE   NEXTESD            NO, GET THE NEXT ESD                  08578000
         SPACE 1                                                        08579000
ESDCHK   TM    DIRATTR,ATTROVLY   OVERLAY ATTRIBUTE?                    08580000
         BNO   ESDCHK1            NO, BRANCH                            08581000
         CLI   ESDSEG#,1          SYMBOL IN ROOT SEGMENT?               08582000
         BNE   NEXTESD            NO, IGNORE                            08583000
ESDCHK1  CLC   ESDADDR(3),DIREPA  THIS ENTRY POINT ADDRESS?             08584000
         BNE   ESDCHK2            NO, BRANCH                            08585000
         MVC   ENTRYPT,ESDNAME    YES, ENTRY POINT NAME IF NO ESD MATCH 08586000
         CLI   #MAPOPT,X'03'      ENTRY POINT MAP ONLY?                 08587000
         BE    ESDUSE3            YES, BRANCH                           08588000
ESDCHK2  CLC   ESDNAME,DIRNAME    THIS NAME?                            08589000
         BNE   NEXTESD            NO, BRANCH                            08590000
         IC    R0,ESDXAFLG        GET MVS/XA ESD FLAGS                  08591000
         SR    R1,R1                                                    08592000
         ICM   R1,B'0111',ESDADDR GET SYMBOL OFFSET                     08593000
         ST    R6,ESDIDRSV+4      RETURN ESDID IN REG 15                08594000
         STM   R0,R1,ESDIDRSV+4+4 RETURN ESD FLAGS, OFFSET IN REGS 0,1  08595000
         MVC   ENTRYPT,ESDNAME    USE THIS ESDNAME FOR THE ENTRY POINT  08596000
         B     ESDOUT             FOUND THE SYMBOL                      08597000
         SPACE 1                                                        08598000
ESDMAP   CR    R0,R1              THIS SEGTAB/ENTAB ENTRY?              08599000
         BE    ESDUSE1            YES, BRANCH                           08600000
         CLI   ESDTYPE,CODESD     SD ENTRY?                             08601000
         BE    ESDUSE2            YES, BRANCH                           08602000
         CLI   ESDTYPE,CODECM     COMMON BLOCK CODE?                    08603000
         BE    ESDUSE2            YES, BRANCH                           08604000
         CLC   ##SUBCOM(8),$MAP   MAP SUBCOMMAND?                  @D01
         BNE   ESDMAP4            NO, BRANCH                       @D01
         CLI   ESDTYPE,CODEER     $UNRESOLVED EXTERNAL REFERENCE?  @D01
         BE    ESDUSE2            YES, BRANCH                      @D01
         CLI   #MAPOPT,X'02'      SHORT MAP?                       @D01
         BE    ESDMAP4            YES, BRANCH                      @D01
         CLI   ESDTYPE,CODEWK     $UNRESOLVED WEAK EXTRN?          @D01
         BE    ESDUSE2            YES, BRANCH                      @D01
ESDMAP4  CLI   ESDTYPE,CODELR     LR ENTRY?                        @D01 08605000
         BNE   ESDMAPPC           NO, BRANCH                            08606000
         CLI   #MAPOPT,X'02'      SHORT MAP?                            08607000
         BL    ESDUSE2            NO, BRANCH                            08608000
         CLC   ESDADDR(3),DIREPA  THIS ENTRY POINT?                     08609000
         BE    ESDUSE2            NO, BRANCH                            08610000
ESDMAPPC CLI   ESDTYPE,CODEPC     PC ENTRY?                             08611000
         BNE   NEXTESD            NO, BRANCH                            08612000
         MVC   ESDNAME,=CL8'$PRIVATE'  PRIVATE CODE                     08613000
         B     ESDUSE2                                                  08614000
         SPACE 1                                                        08615000
ESDUSE1  STC   R0,ESDTYPE                          RESTORE OVERLAY TYPE 08616000
         MVC   ESDNAME(8),=CL8'$SEGTAB'            ASSUME SEGMENT TABLE 08617000
         OC    ESDADDR(3),ESDADDR                  CORRECT?             08618000
         BZ    ESDUSE2                             YES, BRANCH          08619000
         MVC   ESDNAME(8),=CL8'$ENTAB'             NO, ENTRY TABLE      08620000
ESDUSE2  SR    R1,R1                                                    08621000
         CLC   ##SUBCOM(8),$LIS                    LIST SUBCOMMAND?     08622000
         BE    ESDUSE3                             YES, BRANCH          08623000
         ICM   R1,B'0001',#MODLEN                  ANY MODULE FILTER?   08624000
         BZ    ESDUSE3                             NO, BRANCH           08625000
         BCTR  R1,0                                MACHINE LENGTH       08626000
         CLC   ESDNAME(*-*),#MODTXT                <<EXECUTED>>         08627000
         EX    R1,*-6                              THIS PARTIAL NAME?   08628000
         BNE   NEXTESD                             NO, BRANCH           08629000
ESDUSE3  BAL   R14,GETESD                                               08630000
         ST    R1,ESDLINK-ESDENTRY(R2)             SAVE LINK POINTER    08631000
         STH   R6,ESDID-ESDENTRY(R1)               SAVE ESD ID          08632000
         MVC   ESDNAME-ESDENTRY(LENESD1,R1),0(R3)  SAVE ESD ENTRY       08633000
         LR    R2,R1                               CHAIN TO NEXT ONE    08634000
NEXTESD  LA    R6,1(R6)                                                 08635000
         BXLE  R3,R4,ESDSCAN                                            08636000
         B     ESDEXCP            GET NEXT ESD RECORD                   08637000
         DROP  R3                                                       08638000
         EJECT                                                          08639000
         USING ESDENTRY,R2                                              08640000
ESDLAST  MVC   MSGTEXT1(3),L740                                         08641000
         L     R14,ESDIDRSV                                             08642000
         LA    R2,#ESDPTR                                               08643000
         OC    #ESDPTR,#ESDPTR    ANY ESD DATA AVAILABLE?               08644000
         BNZ   ESDSORT            YES, BRANCH                           08645000
         CLI   #MODLEN,0          ANY ESD FILTERING?                    08646000
         BH    ESDEXIT            YES, BRANCH                           08647000
         MVC   MSGTEXT1(3),L703                                         08648000
         B     ESDEXIT                                                  08649000
         SPACE 1                                                        08650000
ESDSORT  L     R2,ESDLINK                                               08651000
         ICM   R1,B'1111',ESDLINK END OF ESD ENTRIES?                   08652000
         BZ    ESDOUT             YES, BRANCH                           08653000
         SPACE 1                                                        08654000
ESDSORT2 TM    DIRATTR,ATTROVLY             OVERLAY ATTRIBUTE?          08655000
         BNO   ESDNOSEG                                                 08656000
         CLC   ESDSEG#,ESDSEG#-ESDENTRY(R1) CHECK ENTRY SEGMENT         08657000
         BL    ESDSORT3                                                 08658000
         BH    ESDSWAP                                                  08659000
         SPACE 1                                                        08660000
ESDNOSEG CLC   ESDADDR,ESDADDR-ESDENTRY(R1)                             08661000
         BL    ESDSORT3                                                 08662000
         BH    ESDSWAP                                                  08663000
         CLC   ESDTYPE,ESDTYPE-ESDENTRY(R1)                             08664000
         BL    ESDSORT3                                                 08665000
         BH    ESDSWAP                                                  08666000
         CLC   ESDNAME,ESDNAME-ESDENTRY(R1)                             08667000
         BNH   ESDSORT3                                                 08668000
         SPACE 1                                                        08669000
ESDSWAP  XC    ESDNAME(LENESD2),ESDNAME-ESDENTRY(R1)                    08670000
         XC    ESDNAME-ESDENTRY(LENESD2,R1),ESDNAME                     08671000
         XC    ESDNAME(LENESD2),ESDNAME-ESDENTRY(R1)                    08672000
         SPACE 1                                                        08673000
ESDSORT3 ICM   R1,B'1111',ESDLINK-ESDENTRY(R1)                          08674000
         BNZ   ESDSORT2                                                 08675000
         B     ESDSORT                                                  08676000
         DROP  R2                                                       08677000
         SPACE 2                                                        08678000
GETESD   MVI   SUBPOOLT,21                                              08679000
         LA    R0,LENESD                                                08680000
         ICM   R0,B'1000',SUBPOOLT   SUBPOOL 21                         08681000
         GETMAIN R,LV=(0)                                               08682000
         XC    0(LENESD,R1),0(R1)                                       08683000
         BR    R14                                                      08684000
         SPACE 1                                                        08685000
ESDOUT   L     R14,ESDIDRSV                                             08686000
         LA    R14,4(,R14)         ADJUST EXIT ADDRESS                  08687000
ESDEXIT  LM    R15,R12,ESDIDRSV+4                                       08688000
         BR    R14                 EXIT                                 08689000
MAPL$BLK DC    CL8'$BLKCOM'                                        @D01
         TITLE 'P D S  --  PDS OPTIONS                         1/15/85' 08690000
*********************************************************************** 08691000
***      OPTIONS SUBCOMMAND                                         *** 08692000
*********************************************************************** 08693000
*                                                                       08694000
         SPACE 2                                                        08695000
OPTIONS  CSECT                                                          08696000
         USING *,R8                                                     08697000
ONIX     LTR   R2,R2                  RETURN=0?                         08698000
         BZ    OPT200                 YES, BRANCH                       08699000
         TSMSG L071                                                     08700000
         SPACE 1                                                        08701000
         LA    R3,$TBL-PTW            POINT TO FIRST TABLE ENTRY -WIDTH 08702000
         LA    R4,ONIX                START OF THIS CSECT               08703000
         SPACE 1                                                        08704000
OPT120   LA    R3,PTW(,R3)            NEXT TABLE ENTRY                  08705000
         CLI   0(R3),X'FF'            END OF TABLE?                     08706000
         BE    OPT300                 YES, EXIT                         08707000
         CLI   0(R3),X'40'            DISABLED ENTRY?                   08708000
         BE    OPT120                 YES, BRANCH                       08709000
         SR    R1,R1                                                    08710000
         ICM   R1,B'0011',28(R3)      ANY OPTION ENTRY?                 08711000
         BZ    OPT120                 NO, BRANCH                        08712000
         TM    12(R3),@S              DEFINED FOR SEQUENTIAL DATA SET?  08713000
         BO    OPT140                 YES, BRANCH                       08714000
         TM    DSORG,DS1DSGPO         DSORG=PO?                         08715000
         BNO   OPT120                 NO, BRANCH                        08716000
         SPACE 1                                                        08717000
OPT140   AR    R1,R4                  ADDRESS OF OPTION DATA            08718000
         MVC   MSGTEXT1(80),0(R1)     OPTION LINE                       08719000
         MVC   MSGTEXT1+4(8),0(R3)    CHANGE TO SUBCOMMAND NAME USED    08720000
         MESSAGE MSGTEXT1             OUTPUT THIS MESSAGE               08721000
         B     OPT120                                                   08722000
         SPACE 3                                                        08723000
OPT200   L     R2,0(,R15)             START OF SUBCOMMAND               08724000
         MVC   INSERT#1(8),0(R2)      NO, BRANCH                        08725000
         LA    R3,1(,R3)              ACTUAL LENGTH OF SUBCOMMAND       08726000
         STC   R3,MTHIGHL             SAVE LENGTH                       08727000
         TSMSG L771$1                 INVALID COMMAND                   08728000
         TM    FLAGSEE,FBKGRND        BACKGROUND EXECUTION?             08729000
         BO    *+8                    YES, BRANCH                       08730000
         NI    FLAGSBB,FF-FONESHOT    NO, ERROR -- DO NOT TERMINATE     08731000
         LA    R1,80                  ASSUME AN ACTIVE MODE             08732000
         AIF ('&CISP' EQ 'NO SPF').MA00620                         @D01
         TM    SPFLAG0,SPFDON         ISPMODE ACTIVE?                   08733000
         BO    OPT202                 YES, BRANCH                       08734000
.MA00620 ANOP  ,                                                   @D01
         TM    CONTOPTN,1             ANY LOG RECORDING?                08735000
         BO    OPT202                 YES, BRANCH                       08736000
         GTSIZE
         CH    R1,=H'120'             120 OR LESS BYTES?                08738000
         BL    *+8                    YES, BRANCH                       08739000
         LH    R1,=H'120'             NO, USE 120 BYTES                 08740000
OPT202   MVC   MSGTEXT1(136),MSGBL132                                   08741000
         MVC   MSGTEXT1+4(12),=C'SUBCOMMANDS:'                          08742000
         LA    R3,$TBL-PTW            POINT TO FIRST TABLE ENTRY -WIDTH 08743000
         LA    R4,MSGTEXT1+4(R1)      END OF LINE ADDRESS               08744000
         LA    R5,MSGTEXT1+4+13       START OF LINE                     08745000
         SPACE 1                                                        08746000
OPT220   LA    R3,PTW(,R3)            NEXT TABLE ENTRY                  08747000
         CLI   0(R3),X'FF'            END OF TABLE?                     08748000
         BE    OPT280                 YES, EXIT                         08749000
         CLI   0(R3),X'40'            DISABLED ENTRY?                   08750000
         BE    OPT220                 YES, BRANCH                       08751000
         CLC   28(2,R3),ZERO          ANY OPTION ENTRY?                 08752000
         BZ    OPT220                 NO, BRANCH                        08753000
         TM    12(R3),@S              DEFINED FOR SEQUENTIAL DATA SET?  08754000
         BO    OPT240                 YES, BRANCH                       08755000
         TM    DSORG,DS1DSGPO         DSORG=PO?                         08756000
         BNO   OPT220                 NO, BRANCH                        08757000
         SPACE 1                                                        08758000
OPT240   LA    R1,9(,R5)              POTENTIAL ENTRY POSITION          08759000
         CR    R1,R4                  LINE FULL?                        08760000
         BL    OPT260                 NO, CONTINUE                      08761000
         MESSAGE MSGTEXT1             OUTPUT THIS PART OF THE MESSAGE   08762000
         LA    R5,MSGTEXT1+4+13       START OF LINE                     08763000
         MVC   MSGTEXT1(136),MSGBL132                                   08764000
         SPACE 1                                                        08765000
OPT260   MVC   0(8,R5),0(R3)          ADD THE SUBCOMMAND NAME           08766000
         LA    R5,9(,R5)              POSITION FOR NEXT ENTRY           08767000
         B     OPT220                                                   08768000
         SPACE 1                                                        08769000
OPT280   MESSAGE MSGTEXT1                                               08770000
         SPACE 2                                                        08771000
OPT300   MESSAGE MSGBLANK                                               08772000
         B     NEWCMD                                                   08773000
         TITLE 'P D S  --  PDS OPTIONS OUTPUT MESSAGES         1/15/85' 08774000
         PRINT NOGEN                                                    08775000
OATT     MSG   'ATTRIB   - LIST ATTRIBUTES OF A MEMBER'                 08776000
OALI     MSG   'ALIAS    - ASSIGN AN ALIAS TO A MEMBER'                 08777000
OBRO     MSG   'BROWSE   - BROWSE USING SPF'                            08778000
OCHA     MSG   'CHANGE   - SELECT A NEW DATA SET'                       08779000
OCAR     MSG   'COMPARE  - COMPARE TWO MEMBERS FROM THE DATA SET'       08780000
OCMX     MSG   'COMPRESS - COMPRESS IN PLACE OF THE DATA SET'           08781000
OCON     MSG   'CONTROL  - SET PROGRAM CONTROLS'                        08782000
ODIS     MSG   'DISPLAY  - DISPLAY DIRECTORY MEMBER NAMES'              08783000
ODIR     MSG   'DIRENTRY - DUMP A DIRECTORY ENTRY'                      08784000
ODEL     MSG   'DELETE   - DELETE A MEMBER'                             08785000
ODSN     MSG   'DSNAME   - DISPLAY THE CURRENT ALLOCATION'              08786000
ODSP     MSG   'DSPRINT  - PRINT A HARDCOPY WITH DSPRINT'               08787000
OEDI     MSG   'EDIT     - EDIT USING SPF'                              08788000
OEND     MSG   'END      - STOP THE PROGRAM'                            08789000
OEXE     MSG   'EXEC     - EXECUTE PDS SUBCOMMANDS FROM A CLIST'        08790000
OFIN     MSG   'FIND     - LIST LINES CONTAINING A STRING'              08791000
OFIX     MSG   'FIXPDS   - MODIFY DATA SET ATTRIBUTES'                  08792000
OFSE     MSG   'FSE      - EDIT USING FSE'                              08793000
OHEL     MSG   'HELP     - DISPLAY PDS SUBCOMMAND HELP'                 08794000
OHIS     MSG   'HISTORY  - LIST HISTORY OF A LOAD MODULE'               08795000
OIFX     MSG   'IF       - CONDITIONALLY EXECUTE A PDS SUBCOMMAND'      08796000
OISP     MSG   'ISPF     - INVOKE ISPF PRIMARY PANEL'                   08797000
OISM     MSG   'ISPMODE  - SET ISPF DIALOG DISPLAY MODE'       SS JUL84 08798000
OLIS     MSG   'LIST     - DISPLAY A MEMBER'                            08799000
OMAP     MSG   'MAP      - MAP A LOAD MODULE'                           08800000
OMEM     MSG   'MEMBERS  - DISPLAY A MEMBER GROUP'                      08801000
OMML     MSG   'MEMLIST  - DISPLAY A MEMBER GROUP IN ISP TABLE'         08802000
OOPT     MSG   'OPTIONS  - DISPLAY THIS LIST OF SUBCOMMANDS'            08803000
OOUT     MSG   'OUTCOPY  - OUTPUT IEBCOPY MEMBER SELECT STATEMENTS'     08804000
OPAT     MSG   'PATTERN  - DISPLAY DIRECTORY NAMES MATCHING A PATTERN'  08805000
OPRI     MSG   'PRINTOFF - PRINT A HARDCOPY'                            08806000
OREC     MSG   'RECALL   - DISPLAY THE PREVIOUS SUBCOMMAND'             08807000
OREN     MSG   'RENAME   - RENAME A MEMBER'                             08808000
ORES     MSG   'RESTORE  - RESURRECT A PREVIOUSLY DELETED MEMBER'       08809000
OREV     MSG   'REVIEW   - BROWSE DATA'                                 08810000
OSUB     MSG   'SUBMIT   - SUBMIT JCL'                                  08811000
OTSO     MSG   'TSO      - INVOKE A TSO COMMAND'                        08812000
OTSE     MSG   'TSOEDIT  - EDIT USING TSO EDIT'                         08813000
OTSL     MSG   'TSOLIST  - LIST DATA WITH TSO LIST'                     08814000
OUSA     MSG   'USAGE    - LIST DATA SET STATISTICS'                    08815000
*OUT1    MSG   'UT1      - UTILITY PANEL #1 (NON-MEMBER)'      SS NOV84 08816000
*OUT2    MSG   'UT2      - UTILITY PANEL #2 (WITH MEMBERS)'    SS NOV84 08817000
OVER     MSG   'VERIFY   - VALIDITY CHECK THE DATA SET'                 08818000
         DC    X'FF'                                                    08819000
         PRINT GEN                                                      08820000
         TITLE 'P D S  --  PDS OUTCOPY                         1/15/85' 08821000
*********************************************************************** 08822000
***      OUT SUBCOMMAND        ADDED BY BRUCE LELAND -- JULY, 1983  *** 08823000
*********************************************************************** 08824000
*                                                                       08825000
         SPACE 1                                                        08826000
OUTCOPY  CSECT                                                          08827000
         USING *,R8                                                     08828000
         LA    R1,L530                       ASSUME NON-PARTITIONED     08829000
         TM    DSORG,DS1DSGPO                CORRECT?                   08830000
         BZ    MSGNEW                        YES, BRANCH                08831000
         TM    #OUT,1                        CLOSE FORCED?              08832000
         BO    OUT84                         YES, BRANCH                08833000
         TM    DCBOFLGS-IHADCB+QAMDCB,X'10'  OUTPUT ALREADY OPEN?       08834000
         BO    OUT10                         YES, BRANCH                08835000
         AIF ('&CISP' EQ 'NO SPF').NSPF250                              08836000
         TM    FLAGSEE,FBKGRND               BACKGROUND MODE?           08837000
         BO    OUT04                         YES, BRANCH                08838000
         TM    FLAGSFF,FSPFOPT6+FSPFERR+FSPFCALL+FSPFDIAL  CHANGE SPF?  08839000
         BNZ   OUT04                                       NO, BRANCH   08840000
         BAL   R2,SPFRECUR                   INVOKE PDS AS A DIALOG     08841000
         SPACE 1                                                        08842000
.NSPF250 ANOP                                                           08843000
OUT04    MVC   QAMDCB(LQSAMDCB),QSAMDCB      CONSTRUCT A DCB            08844000
         MVI   OPENLIST,X'80'                END OF LIST                08845000
         OPEN  (QAMDCB,(OUTPUT)),MF=(E,OPENLIST)                        08846000
         MVC   INSERT#1(8),OTEXTOUT          OUTCOPY                    08847000
         LA    R1,L780$1                     ASSUME OPEN ERROR          08848000
         TM    DCBOFLGS-IHADCB+QAMDCB,X'10'  OUTPUT OPEN?               08849000
         BNO   MSGNEWXX                      NO, ERROR                  08850000
         CLI   #OUT,1                        CORRECT DCB ATTRIBUTES?    08851000
         BNE   OUT84                         NO, BRANCH                 08852000
         SPACE 2                                                        08853000
OUT10    MVI   #OUT,X'40'                                               08854000
***TEST  TM    FLAGSGG,FSAVEOP               SAVE TEXT?                 08855000
***TEST  BNZ   OUT12                         NO, BRANCH                 08856000
         LA    R15,FIRST4K                                              08857000
         LA    R15,SAVEOUT-FIRST4K(,R15)     SAVE TEXT AREA             08858000
         CLI   #OUTOPTN,1                    ANY TEXT?                  08859000
         BNE   *+10                          NO, BRANCH                 08860000
         MVC   0(40,R15),MSGLINE             YES, SAVE THE DEFAULT TEXT 08861000
         CLI   #OUTOPTN,2                    NOTEXT?                    08862000
         BNE   *+8                           NO, BRANCH                 08863000
         MVI   0(R15),0                      YES, RESET DEFAULT TEXT    08864000
         MVC   MSGLINE(40),0(R15)            SET THE TEXT OPERAND       08865000
         B     OUT14                                                    08866000
         SPACE 1                                                        08867000
OUT12    CLI   #OUTOPTN,1                    ANY TEXT?                  08868000
         BE    OUT14                         YES, BRANCH                08869000
         MVI   MSGLINE,0                     NO, RESET THE TEXT         08870000
         SPACE 1                                                        08871000
OUT14    TM    FLAGSEE,FOUTASS               ALIASES ALSO DESIRED?      08872000
         BNO   *+8                           NO, BRANCH                 08873000
         MVI   STARTTR+2,X'01'               YES, SET THE START TTR     08874000
         L     R2,RECOVER                    PREVIOUS RECOVERY ADDRESS  08875000
         LA    R1,OUT80                      RESUME ADDRESS             08876000
         ST    R1,RECOVER                    IN-LINE RECOVERY           08877000
         STM   R2,R8,#OUTREGS                SAVE REGISTERS             08878000
         TM    FLAGSFF,FCHANGE               CHANGED DATA SET?          08879000
         BNZ   OUT50                         NO, BRANCH                 08880000
         OI    FLAGSFF,FCHANGE               YES, GOT A COPY STATEMENT  08881000
         MVC   #OUT,OUTCOPYS                 " COPY OUTPUT=OUTDD,IN..." 08882000
         SR    R1,R1                         MACHINE LENGTH             08883000
         LA    R3,DSNAME-2                                              08884000
         AH    R3,DSNLEN                                                08885000
         LA    R0,8                          MAX LOOPS +1               08886000
         CH    R0,DSNLEN                     MIN (8, NAME LENGTH)       08887000
         BH    *+8                                                      08888000
         LH    R0,DSNLEN                                                08889000
OUT30    S     R0,=F'1'                      ONE CHARACTER?             08890000
         BZ    OUT40                         YES, BRANCH                08891000
         CLI   0(R3),C'.'                    PERIOD?                    08892000
         BE    OUT40                         YES, BRANCH                08893000
         LA    R1,1(,R1)                     MACHINE LENGTH             08894000
         BCT   R3,OUT30                      BACK UP ONE BYTE           08895000
         SPACE 1                                                        08896000
OUT40    MVC   #OUT+33(*-*),1(R3)            <<EXECUTED>>               08897000
         EX    R1,*-6                        MOVE LOW-LEVEL QUALIFIER   08898000
         PUT   QAMDCB,#OUT                   OUTPUT THIS LINE           08899000
         LA    R3,OUTMEMBS                   START OF DUPLICATE LIST    08900000
         TM    FLAGSFF,FNOECHO               OUTPUT TO THE TERMINAL?    08901000
         BNZ   OUT42                         NO, BRANCH                 08902000
         MVC   MSGTEXT1+4(80),#OUT           OUTPUT LINE                08903000
         LA    R0,84                                                    08904000
         SLL   R0,16                                                    08905000
         ST    R0,MSGTEXT1                                              08906000
         MESSAGE MSGTEXT1                                               08907000
         SPACE 1                                                        08908000
OUT42    ICM   R3,B'0111',1(R3)              NEXT DUPLICATE STRUCTURE   08909000
         BZ    OUT50                         END, BRANCH                08910000
         MVI   6(R3),0                       CLEAR THE                  08911000
         MVI   7(R3),1                                CURRENT COUNT     08912000
         B     OUT42                         LOOP FOR ALL STRUCTURES    08913000
         SPACE 1                                                        08914000
OUT50    LA    R4,OUTMEMBS                   ROOT OF DUP STRUCTURES     08915000
OUT54    LR    R3,R4                                                    08916000
         ICM   R4,B'0111',1(R4)              NEXT LIST ENTRY?           08917000
         BNZ   OUT60                         YES, BRANCH                08918000
         LA    R5,256                        256 -1 MEMBERS             08919000
         LR    R0,R5                                                    08920000
         SLL   R0,3                          ELEMENT WIDTH IS 8         08921000
         MVI   OUTMEMBS,22                   SUBPOOL IS 22              08922000
         ICM   R0,B'1000',OUTMEMBS           GET THE SUBPOOL            08923000
         GETMAIN R,LV=(0)                                               08924000
         LR    R4,R1                                                    08925000
         STCM  R4,B'0111',1(R3)              CHAIN TO LAST STUCTURE     08926000
         XC    0(8,R4),0(R4)                 NULL LINK POINTERS         08927000
         STH   R5,4(,R4)                     MAXIMUM ELEMENTS/STRUCTURE 08928000
         MVI   7(R4),1                       ONE ITEM CURRENTLY         08929000
         B     OUT70                                                    08930000
         SPACE 2                                                        08931000
OUT60    LH    R5,6(R4)                      NUMBER OF ELEMENTS         08932000
         LR    R1,R4                                                    08933000
OUT64    S     R5,=F'1'                      ANY MORE ITEMS?            08934000
         BZ    OUT70                         NO, BRANCH                 08935000
         LA    R1,8(,R1)                     NEXT ELEMENT               08936000
         CLC   0(8,R1),DIRNAME               THIS ELEMENT?              08937000
         BNE   OUT64                         NO, BRANCH                 08938000
         B     OUT74                         YES, IGNORE DUPLICATE      08939000
         SPACE 1                                                        08940000
OUT70    CLC   6(2,R4),4(R4)                 CURRENT:MAXIMUM            08941000
         BE    OUT54                         EQUAL - GET NEXT STRUCTURE 08942000
         MVC   8(8,R1),DIRNAME               ADD THIS ITEM              08943000
         LH    R5,6(R4)                      ADD                        08944000
         LA    R5,1(,R5)                        1 TO                    08945000
         STH   R5,6(R4)                             NUMBER OF ELEMENTS  08946000
         MVC   #OUT,OUTSEL                   "          S M=12345678  " 08947000
         MVC   #OUT+14(8),DIRNAME            MEMBER NAME                08948000
         LA    R1,#OUT+14                    POINT TO EQUALS            08949000
         SPACE 1                                                        08950000
         LA    R1,1(,R1)                     FIND                       08951000
         CLI   0(R1),X'40'                       NEXT                   08952000
         BNE   *-8                                   BLANK              08953000
         SPACE 1                                                        08954000
         CLI   MSGLINE,0                     ANY TEXT?                  08955000
         BE    OUT72                         NO, BRANCH                 08956000
         MVC   #OUT+24(40),MSGLINE           YES, ADD THE TEXT          08957000
         B     OUT73                                                    08958000
         SPACE 1                                                        08959000
OUT72    MVI   1(R1),C','                    ADD BLANK AND COMMA        08960000
         MVC   2(8,R1),DIRNAME               MEMBER NAME AGAIN          08961000
         SPACE 1                                                        08962000
         LA    R1,1(,R1)                     FIND                       08963000
         CLI   0(R1),X'40'                       NEXT                   08964000
         BNE   *-8                                   BLANK              08965000
         SPACE 1                                                        08966000
         MVI   0(R1),C')'                    ADD ONE PARENTHESIS        08967000
         MVI   1(R1),C')'                    ADD SECOND PARENTHESIS     08968000
OUT73    PUT   QAMDCB,#OUT                   OUTPUT THIS LINE           08969000
         TM    FLAGSFF,FNOECHO               OUTPUT TO THE TERMINAL?    08970000
         BNZ   OUT74                         NO, BRANCH                 08971000
         MVC   MSGTEXT1+4(80),#OUT           OUTPUT LINE                08972000
         LA    R0,84                                                    08973000
         SLL   R0,16                                                    08974000
         ST    R0,MSGTEXT1                                              08975000
         MESSAGE MSGTEXT1                                               08976000
         SPACE 1                                                        08977000
OUT74    TM    FLAGSEE,FOUTASS               ASSOCIATE MEMBERS DESIRED? 08978000
         BNO   OUT76                         NO, BRANCH                 08979000
         BAL   R14,READDIR                   GET NEXT DIRECTORY MEMBER  08980000
         B     OUT76                         LAST MEMBER PROCESSED      08981000
         SPACE 1                                                        08982000
         CLC   DIRTTR,MEMTTR                 TTR MATCH?                 08983000
         BNE   OUT74                         NO, BRANCH                 08984000
         MVC   DIRNAME(8),MEMNAME            SUBSTITUTE THE MEMBER NAME 08985000
         B     OUT50                         ADD ALIAS TO THE OUTPUT    08986000
         SPACE 2                                                        08987000
OUT76    ST    R2,RECOVER                    RESET THE RECOVERY ADDRESS 08988000
         B     NEWCMD                        TERMINATE                  08989000
         SPACE 3                                                        08990000
OUT80    LM    R2,R8,#OUTREGS                RESET REGISTERS            08991000
         ST    R2,RECOVER                    RESTORE RECOVERY ADDRESS   08992000
         SPACE 1                                                        08993000
OUT84    MVI   OPENLIST,X'80'                END OF LIST                08994000
         CLOSE (QAMDCB),MF=(E,OPENLIST)      CLOSE OUT DATA SET         08995000
         NI    FLAGSFF,FF-FCHANGE            NEED A COPY STATEMENT      08996000
         LA    R1,L781$1                     OUT DCB IS NOT FB, 80      08997000
         MVC   INSERT#1(8),OTEXTOUT          OUTCOPY                    08998000
         CLI   #OUT,0                        ERROR CLOSE?               08999000
         BE    MSGNEWXX                      YES, OUTPUT A MESSAGE      09000000
         LA    R1,L080                       DATA SET IS NOW CLOSED     09001000
         B     MSGNEWXX                      NOW CLOSED                 09002000
         SPACE 4                                                        09003000
         USING IHADCB,R1                                                09004000
OUT90    CLC   DCBDSORG(2),ZERO              ANY DSORG?                 09005000
         BNE   *+8                           YES, BRANCH                09006000
         OI    DCBDSORG,DS1DSGPS             NO, USE DSORG=PS           09007000
         TM    DCBDSORG,DS1DSGPS             DSORG=PS?                  09008000
         BNOR  R14                           NO, ERROR                  09009000
         CLI   DCBRECFM,0                    ANY RECFM?                 09010000
         BNE   *+8                           YES, BRANCH                09011000
         MVI   DCBRECFM,DCBRECF+DCBRECBR     NO, USE RECFM=FB           09012000
         TM    DCBRECFM,DCBRECF              RECFM=F.?                  09013000
         BNOR  R14                           NO, ERROR                  09014000
         LA    R0,80                         DEFAULT LRECL              09015000
         CLC   DCBLRECL(2),ZERO              ANY LRECL?                 09016000
         BNE   *+8                           YES, BRANCH                09017000
         STH   R0,DCBLRECL                   NO, USE LRECL=80           09018000
         CH    R0,DCBLRECL                   LRECL=80?                  09019000
         BNER  R14                           NO, ERROR                  09020000
         LA    R0,3120                       DEFAULT BLKSIZE            09021000
         CLC   DCBBLKSI(2),ZERO              ANY BLKSIZE?               09022000
         BNE   *+8                           YES, BRANCH                09023000
         STH   R0,DCBBLKSI                   NO, USE BLKSIZE=3120       09024000
         MVI   #OUT,1                        ALL ATTRIBUTES ARE CORRECT 09025000
         BR    R14                                                      09026000
         DROP  R1                                                       09027000
         SPACE 2                                                        09028000
         PRINT NOGEN                                                    09029000
QSAMDCB  DCB   DSORG=PS,DDNAME=PDSOUT,MACRF=(PM),EXLST=OUT99            09030000
LQSAMDCB EQU   *-QSAMDCB                                                09031000
         PRINT GEN                                                      09032000
         SPACE 2                                                        09033000
OUT99    DC    0F'0',X'85',AL3(OUT90)        OPEN EXIT ONLY             09034000
OUTCOPYS DC    CL80'          COPY OUTDD=OUTPUT,INDD=1'                 09035000
OUTSEL   DC    CL80'          S M=12345678            '                 09036000
OTEXTOUT DC    CL8'OUTCOPY'                                             09037000
         TITLE 'P D S  --  PDS PRINTOFF AND ITS ALIASES        1/15/85' 09038000
*********************************************************************** 09039000
***    PRINTOFF SUBCOMMAND (AND ITS ALIASES)                        *** 09040000
*********************************************************************** 09041000
*                                                                       09042000
         SPACE 1                                                        09043000
PRINTOFF CSECT                                                          09044000
         USING *,R8                                                     09045000
         MVC   MSGTEXT1+4(8),##SUBCAL   PROCESSOR TO ATTACH             09046000
         MVI   MSGTEXT1+12,X'40'        ADD A BLANK                     09047000
         MVI   MSGTEXT1+13,C''''        ADD A QUOTE                     09048000
         MVC   MSGTEXT1+14(44),DSNAME   ADD THE DATA SET NAME           09049000
         LH    R15,DSNLEN               DSNAME ACTUAL LENGTH            09050000
         LA    R4,14(,R15)              LENGTH OF "PRINTOFF'"           09051000
         LA    R3,MSGTEXT1+13(R15)      POINT TO CURRENT BYTE -1        09052000
         TM    DSORG,DS1DSGPO           NON-PARTITIONED DATA SET?       09053000
         BZ    PRINT6                   YES, BRANCH                     09054000
         SPACE 1                                                        09055000
         MVI   1(R3),C'('               MEMBER NAME PARENTHESIS         09056000
         MVC   2(8,R3),DIRNAME          MEMBER NAME                     09057000
         LA    R3,2+8(,R3)              END OF MEMBER +1                09058000
         LA    R4,2+8(,R4)              LENGTH OF MEMBER +1             09059000
         LA    R2,8                     MAXIMUM MACHINE LENGTH+1        09060000
PRINT3   BCTR  R3,0                     SCAN                            09061000
         BCTR  R4,0                         BACKWARDS                   09062000
         CLI   0(R3),X'40'                           FOR                09063000
         BNE   *+8                                       FIRST          09064000
         BCT   R2,PRINT3                                      NON-BLANK 09065000
         SPACE 1                                                        09066000
         BCTR  R2,0                     MACHINE LENGTH                  09067000
         TRT   DIRNAME(*-*),TRTMEM      <<EXECUTED>>                    09068000
         EX    R2,*-6                   VALID MEMBER NAME?              09069000
         BNZ   BADMEMB                  NO, ERROR                       09070000
         CLI   DIRNAME,C'0'             VALID FIRST CHARACTER?          09071000
         BNL   BADMEMB                  NO, BRANCH                      09072000
         LA    R3,1(,R3)                POINT TO TERMINATOR             09073000
         MVI   0(R3),C')'               ADD A CLOSING PARENTHESIS       09074000
         SPACE 1                                                        09075000
PRINT6   MVI   1(R3),C''''              ADD A QUOTE                     09076000
         MVI   2(R3),X'40'              ADD A BLANK                     09077000
         LA    R4,3(,R4)                ACCOUNT FOR ")' "               09078000
         LA    R2,MSGLINE               START OF ANY ADDED TEXT         09079000
         SR    R2,R4                    WHERE TO START MESSAGE          09080000
         LR    R14,R4                   CURRENT MESSAGE LENGTH          09081000
         BCTR  R14,0                    MESSAGE MACHINE LENGTH          09082000
         MVC   0(*-*,R2),MSGTEXT1       <<EXECUTED>>                    09083000
         EX    R14,*-6                  MOVE IN MESSAGE TEXT            09084000
         SPACE 1                                                        09085000
         TM    FLAGSGG,FSAVEOP         SAVE TEXT MODE?                  09086000
         BNZ   PRINT9                  NO, BRANCH                       09087000
         IC    R1,##ADRCM#             INDEX TO SAVE TEXT               09088000
         N     R1,=F'15'               MASK OFF HIGH BITS               09089000
         MH    R1,=H'40'               OFFSET OF SAVE TEXT              09090000
         LA    R15,FIRST4K                                              09091000
         LA    R15,SAVETEXT-FIRST4K(R1,R15)  SAVE TEXT AREA             09092000
         CLI   #COMMDSZ+1,0            ANY OPERAND?                     09093000
         BE    PRINT8                  NO, BRANCH                       09094000
         MVC   0(40,R15),MSGLINE       YES, SAVE NEW DEFAULT TEXT       09095000
         B     PRINT9                                                   09096000
PRINT8   MVC   MSGLINE(40),0(R15)      USE THE DEFAULT OPERAND          09097000
         CLI   0(R15),0                ANY DEFAULT?                     09098000
         BE    PRINT9                  NO, BRANCH                       09099000
         MVI   #COMMDSZ+1,40           YES, USE A 40 CHARACTER LENGTH   09100000
         SPACE 1                                                        09101000
PRINT9   AH    R4,#COMMDSZ              ADD REMAINING LENGTH            09102000
         SLL   R4,16                    CLEAR BOTTOM TWO BYTES          09103000
         STCM  R4,B'1111',0(R2)         SAVE STRING TOTAL LENGTH        09104000
         SPACE 1                                                        09105000
         LA    R3,##SUBCAL              PROCESSOR TO ATTACH             09106000
*        MESSAGE (R2)                   DELETE * TO OUTPUT COMMAND      09107000
         ST    R2,ADDRTEXT              COMMAND ADDRESS                 09108000
         ST    R2,ADDRCBUF              COMMAND ADDRESS                 09109000
         CLI   ##SUBCAL,C'%'            IMPLIED CLIST?                  09110000
         BE    EXEC                     YES, BRANCH                     09111000
         MVI   3(R2),9                  POINT TO OPERAND OFFSET         09112000
         L     R14,ADDRECT                                              09113000
         MVC   ECTPCMD-ECT(8,R14),##SUBCAL  PROCESSOR COMMAND NAME      09114000
         LA    R1,ADDRTEXT              ADDRESS OF THE CPPL             09115000
         LA    R3,##SUBCAL              PROCESSOR TO ATTACH             09116000
         BAL   R2,ATTACH                CLEAR THE ATTENTION ECB         09117000
         B     NEWSTAX                  DO THE NEXT COMMAND             09118000
         TITLE 'P D S  --  PDS RENAME                          1/15/85' 09119000
*********************************************************************** 09120000
***      RENAME SUBCOMMAND                                          *** 09121000
*********************************************************************** 09122000
*                                                                       09123000
         SPACE 1                                                        09124000
RENAME   CSECT                                                          09125000
         USING *,R8                                                     09126000
         CLI   #RENRANG,1              RENAME GROUP?                    09127000
         BE    RENAME30                YES, BRANCH                      09128000
         AIF ('&CISP' EQ 'NO SPF').MA00640                         @D01
         SPACE 1                                                        09129000
         TM    SPFLAG2,SPFPOST            LINE COMMAND?                 09130000
         BNO   RENAME3                    NO, BRANCH                    09131000
         LA    R1,FIRST4K                 GET ADDRESSABILITY            09132000
         MVC   MEMLNMSV-FIRST4K(8,R1),MEMBER2                           09133000
         B     RENAME6                    NO, BRANCH                    09134000
.MA00640 ANOP  ,                                                   @D01
         SPACE 1                                                        09135000
RENAME3  MVC   MEMBERD+1(2),LMEMBER2   CHANGE DEFAULT MEMBER LENGTH     09136000
         MVC   MEMBERD+1+2(8),MEMBER2  CHANGE DEFAULT MEMBER NAME       09137000
         MVI   MEMBERD,FMEMBER1        ONLY ONE MEMBER NAME NOW         09138000
         NI    FLAGSEE,FF-FMEMLIST     NO MEMBER LIST                   09139000
         BAL   R14,DEFGROUP                    ADD DEFAULT GROUP        09140000
         SPACE 1                                                        09141000
RENAME6  MVC   DSNMEMQ(8),MEMBER1      MEMBER NAME TO TEST              09142000
         BAL   R2,ENQMTEST             MEMBER IN USE?                   09143000
         B     NEWCMD                  YES, ERROR                       09144000
         SPACE 1                                                        09145000
         BAL   R2,OPENSTOW             OPEN STOW DCB; ENQUEUES          09146000
         B     NEWCMD                  COULD NOT OPEN -- ERROR          09147000
         LA    R6,NEWCMD               ASSUME NOT A SWAP REQUEST        09148000
         SPACE 1                                                        09149000
         CLC   MEMBER1(8),MEMBER2      UPDATE ALIASES ONLY?             09150000
         BE    RENAME90                YES, BRANCH                      09151000
         SPACE 2                                                        09152000
         TM    #RENSWAP,X'01'          SWAP MEMBER NAMES?               09153000
         BNO   RENAME20                NO, BRANCH                       09154000
         SPACE 1                                                        09155000
*** RENAME WITH SWAP OPERAND *** *** *** *** *** *** *** *** *** *** ** 09156000
         MVC   MSGTEXT1(DIREND-DIRNAME),DIRNAME  SAVE THE FIRST MEMBER  09157000
         XC    DIRUSER,DIRUSER         CLEAR THE USER FIELDS            09158000
         MVC   DIRNAME,MEMBER2         SECOND MEMBER NAME               09159000
         SPACE 2                                                        09160000
         BLDL  INDCB,BLDLLIST          LOCATE DIRECTORY ENTRY           09161000
         B     *+4(R15)                PROCESS RETURN CODE              09162000
         B     RENAME10                  00 - SUCCESSFUL                09163000
         B     NOMEMBER                  04 - MEMBER NOT FOUND          09164000
         B     IOERROR                   08 - I/O ERROR                 09165000
         SPACE 2                                                        09166000
RENAME10 MVC   DIRFLAG(DIREND-DIRFLAG),DIRFLAG+2 BLDL ADDS THINGS       09167000
         MVC   DIRNAME,MEMBER1         FIRST MEMBER NAME                09168000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   09169000
         STOW  STOWDCB,DIRNAME,R       REPLACE THIS MEMBER ENTRY        09170000
         SPACE 1                                                        09171000
         LTR   R15,R15                 SUCCESSFUL?                      09172000
         BNZ   IOERROR                 NO, I/O ERROR                    09173000
         MVC   MSGTEXT2(DIREND-DIRNAME),DIRNAME  SAVE THE SECOND MEMBER 09174000
         SPACE 2                                                        09175000
         MVC   DIRNAME(DIREND-DIRNAME),MSGTEXT1  FIRST MEMBER           09176000
         MVC   DIRNAME,MEMBER2         SECOND MEMBER NAME               09177000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   09178000
         STOW  STOWDCB,DIRNAME,R       REPLACE THIS MEMBER ENTRY        09179000
         SPACE 1                                                        09180000
         LTR   R15,R15                 SUCCESSFUL?                      09181000
         BNZ   IOERROR                 NO, I/O ERROR                    09182000
         BAL   R6,RENAME90             UPDATE ANY ALIAS MEMBERS         09183000
         MVC   DIRNAME(DIREND-DIRNAME),MSGTEXT2  SECOND MEMBER          09184000
         MVC   MEMBER1(8),MEMBER2      SWAP THE                         09185000
         MVC   MEMBER2(8),DIRNAME              MEMBER NAMES             09186000
         BAL   R6,RENAME90             UPDATE ANY ALIAS MEMBERS         09187000
         B     NEWCMD                                                   09188000
         SPACE 3                                                        09189000
*** RENAME WITH NO OPERANDS  *** *** *** *** *** *** *** *** *** *** ** 09190000
RENAME20 MVC   DIRNAME(8),MEMBER2      MEMBER NAME FOR AN ERROR MESSAGE 09191000
         STOW  STOWDCB,MEMBER1,C       ISSUE STOW WITH CHANGE OPTION    09192000
         SPACE 1                                                        09193000
         B     *+4(R15)                PROCESS RETURN CODE              09194000
         B     RENAME90                  00 - SUCCESSFUL                09195000
         B     MEMEXIST                  04 - THIS NAME ALREADY EXISTS  09196000
         B     NOMEMBER                  08 - MEMBER NAME NOT FOUND     09197000
         EX    0,*                       12 - INVALID RETURN CODE       09198000
         B     IOERROR                   16 - DIRECTORY I/O ERROR       09199000
         SPACE 3                                                        09200000
*** RENAME WITH GROUP OPERAND ** *** *** *** *** *** *** *** *** *** ** 09201000
RENAME30 NI    FLAGSBB,FF-FLINESET     NO OUTPUT IN PROGRESS YET        09202000
         MVI   SUBPOOLT,21             TEMPORARY STORAGE IN USE         09203000
         MVI   STARTTR+2,X'01'         READ THE DIRECTORY               09204000
         LA    R5,256/2                256 MEMBERS INITIALLY            09205000
         SPACE 1                                                        09206000
RENAME40 SLL   R5,1                    MEMBERS*2 FOR EACH LOOP          09207000
         SR    R2,R2                                                    09208000
         LR    R3,R5                                                    09209000
         LR    R0,R5                                                    09210000
         SLL   R0,4                    MEMBERS*16 IS TABLE SIZE         09211000
         ICM   R0,B'1000',SUBPOOLT                                      09212000
         GETMAIN R,LV=(0)              ALLOCATE A NEW MEMBER TABLE      09213000
         LR    R4,R1                   NEW TABLE ADDRESS                09214000
         ICM   R0,B'1111',#MEMPTR      ANY PREVIOUS MEMBERS?            09215000
         BZ    RENAME42                NO, BRANCH                       09216000
         SRL   R3,1                    YES, USE SECOND HALF OF TABLE    09217000
         LR    R14,R4                  NEW TABLE START ADDRESS          09218000
         LR    R15,R5                                                   09219000
         SLL   R15,3                   MEMBERS*8 IS OLD TABLE SIZE      09220000
         LR    R2,R15                  DISPLACEMENT TO NEW PART         09221000
         LR    R1,R15                                                   09222000
         MVCL  R14,R0                  PRESERVE THE PREVIOUS TABLE      09223000
         L     R1,#MEMPTR                                               09224000
         LR    R0,R2                   LENGTH TO FREE                   09225000
         ICM   R0,B'1000',SUBPOOLT     SUBPOOL TO FREE                  09226000
         FREEMAIN R,LV=(0),A=(1)                                        09227000
         SPACE 1                                                        09228000
RENAME42 ST    R4,#MEMPTR              MEMBER TABLE BASE                09229000
         AR    R4,R2                   WHERE TO ADD MEMBERS             09230000
         SPACE 3                                                        09231000
RENAME44 BAL   R14,READDIR             GET THE NEXT MEMBER              09232000
         B     RENAME52                END OF MEMBERS, BRANCH           09233000
         SPACE 1                                                        09234000
         LH    R1,LMEMBER1             MEMBER NAME LENGTH               09235000
         CLC   MEMNAME(*-*),MEMBER1    <<EXECUTED>>                     09236000
         EX    R1,*-6                  MEMBER:GROUP                     09237000
         BL    RENAME44                  LOW, LOOP                      09238000
         BH    RENAME52                  HIGH, DONE WITH FIRST PHASE    09239000
         MVC   DSNMEMQ(8),MEMNAME        EQUAL, CHECK FOR ENQUEUED      09240000
         BAL   R2,ENQMTEST                                              09241000
         NOP   0                       OUTPUT AN ERROR MESSAGE ONLY     09242000
         SPACE 2                                                        09243000
         LA    R2,MEMNAME+7                                             09244000
         TM    FLAGSBB,FLINESET        LINE IN PROGRESS?                09245000
         BO    RENAME46                YES, BRANCH                      09246000
         OI    FLAGSBB,FLINESET        LINE NOW IN PROGRESS             09247000
         LA    R1,80                   ASSUME AN ACTIVE MODE            09248000
         AIF ('&CISP' EQ 'NO SPF').MA00660                         @D01
         TM    SPFLAG0,SPFDON          ISPMODE ACTIVE?                  09249000
         BO    RENAME45                YES, BRANCH                      09250000
.MA00660 ANOP  ,                                                   @D01
         TM    CONTOPTN,1              ANY LOG RECORDING?               09251000
         BO    RENAME45                YES, BRANCH                      09252000
         GTSIZE
         CH    R1,=H'120'              120 OR LESS BYTES?               09254000
         BL    *+8                     YES, BRANCH                      09255000
         LH    R1,=H'120'              NO, USE 120 BYTES                09256000
RENAME45 SH    R1,=H'7'                LESS SEVEN FOR PREFIX            09257000
         ST    R1,LINESIZE             CHARACTERS/LINE                  09258000
         MVC   MSGLINE+4(L'MSGRENAM),MSGRENAM                           09259000
         LA    R6,MSGLINE+4+L'MSGRENAM                                  09260000
         MVC   FULLWORD(3),L161$1                                       09261000
         SPACE 1                                                        09262000
RENAME46 CLI   0(R2),X'40'             SCAN FOR                         09263000
         BNE   *+8                             LAST                     09264000
         BCT   R2,RENAME46                         NON-BLANK            09265000
         SPACE 1                                                        09266000
         LA    R0,MEMNAME                                               09267000
         SR    R2,R0                                                    09268000
         BNM   *+6                                                      09269000
         SR    R2,R2                                                    09270000
         LA    R15,2(R6,R2)                                             09271000
         LA    R1,MSGLINE                                               09272000
         SR    R15,R1                                                   09273000
         C     R15,LINESIZE                                             09274000
         BNH   RENAME50                                                 09275000
         LA    R1,MSGLINE+4                                             09276000
         SR    R6,R1                                                    09277000
         STC   R6,MTHIGHL                                               09278000
         MVC   INSERT#1(127),MSGLINE+4                                  09279000
         LA    R1,FULLWORD                                              09280000
         TSMSG (R1)                                                     09281000
         MVI   MTHIGHL,8                                                09282000
         MVI   FULLWORD+2,C'9'                                          09283000
         LA    R6,MSGLINE+3            INDENT FOR BLANKS                09284000
         SPACE 1                                                        09285000
RENAME50 MVI   0(R6),X'40'                                              09286000
         MVC   1(8,R6),MEMNAME                                          09287000
         TR    1(8,R6),TRLINE                                           09288000
         LA    R1,2(R2,R6)                                              09289000
         MVI   0(R1),C','                                               09290000
         LA    R6,3(R2,R6)                                              09291000
         MVC   0(16,R4),MEMNAME        CURRENT MEMBER NAME              09292000
         LA    R4,16(,R4)              NEXT MEMBER NAME                 09293000
         S     R3,=F'1'                ANY HOLD POSITIONS LEFT?         09294000
         BP    RENAME44                YES, BRANCH                      09295000
         B     RENAME40                NO, REALLOCATE                   09296000
         SPACE 2                                                        09297000
RENAME52 LA    R1,L401                 ASSUME NO MEMBERS FOUND          09298000
         TM    FLAGSBB,FLINESET        LINE IN PROGRESS?                09299000
         BZ    MSGNEW                  NO, EXIT                         09300000
         LA    R1,MSGLINE+5                                             09301000
         SR    R6,R1                                                    09302000
         STC   R6,MTHIGHL                                               09303000
         MVC   INSERT#1(127),MSGLINE+4                                  09304000
         LA    R1,FULLWORD                                              09305000
         TSMSG (R1)                                                     09306000
         MVI   MTHIGHL,8                                                09307000
         MESSAGE MSGBLANK                                               09308000
         SPACE 1                                                        09309000
         LA    R1,PDS391A              VERIFY THAT YOU WISH TO RENAME.. 09310000
         BAL   R2,YESNO                PROMPT FOR YES OR NO             09311000
         B     NEWCMD                  NO, BRANCH                       09312000
         SPACE 2                                                        09313000
         BAL   R2,OPENSTOW             OPEN STOW DCB; ENQUEUE           09314000
         B     NEWCMD                  OPEN FAILED -- ERROR             09315000
         SPACE 3                                                        09316000
         L     R3,#MEMPTR              FIRST MEMBER POINTER             09317000
         LA    R6,RENAME60             WHERE TO GO                      09318000
         MVI   #RENDEFT,FMEMBER1+FMEMBER2+FMEMRANG+FMEM#MEM             09319000
         MVC   #RENDEFT+1(2+8+8+2),LMEMBER1  LENGTH1, MEMBER1, M2, L2   09320000
         SPACE 1                                                        09321000
RENAME60 MVC   MEMBERD(1+2+8+8+2),#RENDEFT    FLAG, LEN1, MEM1, M2, L2  09322000
         MVC   MEMBERD+1(2),#RENDEFT+1+2+8+8  REPEAT LEN2 FOR LEN1      09323000
         MVC   MEMBERD+1+2(8),#RENDEFT+1+2+8  REPEAT MEM2 FOR MEM1      09324000
         NI    FLAGSEE,FF-FMEMLIST            NO MEMBER LIST            09325000
         CR    R3,R4                   DONE?                            09326000
         BE    NEWCMD                  YES, BRANCH                      09327000
         MVC   DIRNAME(16),0(R3)       CURRENT MEMBER NAME              09328000
         LA    R3,16(,R3)              NEXT MEMBER NAME                 09329000
         MVC   MEMBER1(8),DIRNAME                                       09330000
         MVC   MEMBER2(8),DIRNAME                                       09331000
         LH    R1,LMEMBER2                                              09332000
         MVC   MEMBER2(*-*),#RENDEFT+1+2+8  <<EXECUTED>>                09333000
         EX    R1,*-6                       MOVE IN FIRST FEW BYTES     09334000
         SPACE 1                                                        09335000
         CLC   MEMBER1(8),MEMBER2      UPDATE ALIASES ONLY?             09336000
         BE    RENAME90                YES, BRANCH                      09337000
         SPACE 2                                                        09338000
         TM    #RENSWAP,X'01'          SWAP MEMBER NAMES?               09339000
         BO    RENAME70                YES, BRANCH                      09340000
         SPACE 1                                                        09341000
         MVC   DIRNAME(8),MEMBER2      MEMBER NAME FOR AN ERROR MESSAGE 09342000
         STOW  STOWDCB,MEMBER1,C       ISSUE STOW WITH CHANGE OPTION    09343000
         SPACE 1                                                        09344000
         B     *+4(R15)                PROCESS RETURN CODE              09345000
         B     RENAME90                  00 - SUCCESSFUL                09346000
         B     MEMEXIST                  04 - THIS NAME ALREADY EXISTS  09347000
         EX    0,*                       08 - MEMBER NAME NOT FOUND     09348000
         EX    0,*                       12 - INVALID RETURN CODE       09349000
         B     IOERROR                   16 - DIRECTORY I/O ERROR       09350000
         SPACE 3                                                        09351000
*** RENAME WITH GROUP AND SWAP OPERAND   *** *** *** *** *** *** *** ** 09352000
RENAME70 XC    DIRUSER,DIRUSER         CLEAR THE USER FIELDS            09353000
         MVC   DIRNAME,MEMBER1         FIRST MEMBER NAME                09354000
         SPACE 1                                                        09355000
         BLDL  INDCB,BLDLLIST          LOCATE DIRECTORY ENTRY           09356000
         LTR   R15,R15                 ANY PROBLEM?                     09357000
         BNZ   IOERROR                 YES, ERROR                       09358000
         SPACE 1                                                        09359000
         MVC   DIRFLAG(DIREND-DIRFLAG),DIRFLAG+2 BLDL ADDS THINGS       09360000
         MVC   MSGTEXT1(DIREND-DIRNAME),DIRNAME  SAVE THE FIRST MEMBER  09361000
         XC    DIRUSER,DIRUSER         CLEAR THE USER FIELDS            09362000
         MVC   DIRNAME,MEMBER2         SECOND MEMBER NAME               09363000
         SPACE 2                                                        09364000
         BLDL  INDCB,BLDLLIST          LOCATE DIRECTORY ENTRY           09365000
         B     *+4(R15)                PROCESS RETURN CODE              09366000
         B     RENAME80                  00 - SUCCESSFUL                09367000
         B     NOMEMBER                  04 - MEMBER NOT FOUND          09368000
         B     IOERROR                   08 - I/O ERROR                 09369000
         SPACE 3                                                        09370000
RENAME80 MVC   DIRFLAG(DIREND-DIRFLAG),DIRFLAG+2 BLDL ADDS THINGS       09371000
         MVC   DIRNAME,MEMBER1         FIRST MEMBER NAME                09372000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   09373000
         STOW  STOWDCB,DIRNAME,R       REPLACE THIS MEMBER ENTRY        09374000
         SPACE 1                                                        09375000
         LTR   R15,R15                 SUCCESSFUL?                      09376000
         BNZ   IOERROR                 NO, I/O ERROR                    09377000
         MVC   MSGTEXT2(DIREND-DIRNAME),DIRNAME  SAVE THE SECOND MEMBER 09378000
         SPACE 2                                                        09379000
         MVC   DIRNAME(DIREND-DIRNAME),MSGTEXT1  FIRST MEMBER           09380000
         MVC   DIRNAME,MEMBER2         SECOND MEMBER NAME               09381000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   09382000
         STOW  STOWDCB,DIRNAME,R       REPLACE THIS MEMBER ENTRY        09383000
         SPACE 1                                                        09384000
         LTR   R15,R15                 SUCCESSFUL?                      09385000
         BNZ   IOERROR                 NO, I/O ERROR                    09386000
         BAL   R6,RENAME90             UPDATE ANY ALIAS MEMBERS         09387000
         MVC   DIRNAME(DIREND-DIRNAME),MSGTEXT2  SECOND MEMBER          09388000
         MVC   MEMBER1(8),MEMBER2      SWAP THE                         09389000
         MVC   MEMBER2(8),DIRNAME              MEMBER NAMES             09390000
         BAL   R6,RENAME90             UPDATE ANY ALIAS MEMBERS         09391000
         B     RENAME60                PROCESS OTHER MEMBERS IN GROUP   09392000
         SPACE 2                                                        09393000
** UPDATE ANY ALIAS ENTRIES FOR LOAD MODULES                            09394000
RENAME90 MVC   INSERT#1(8),MEMBER1                                      09395000
         MVC   INSERT#2(8),MEMBER2        NEW MEMBER NAME          @D01
         TSMSG L090$2                                              @D01 09396000
         SPACE 1                                                        09397000
         TM    FLAGSCC,RECFMU          LOAD MODULE?                     09398000
         BNOR  R6                      NO, BRANCH                       09399000
         TM    DIRFLAG,DIRALIAS        AN ALIAS?                        09400000
         BOR   R6                      YES, BRANCH                      09401000
         SPACE 2                                                        09402000
         MVI   STARTTR+2,X'01'         TTR=000001 (START OF DIRECTORY)  09403000
         SPACE 1                                                        09404000
RENAME95 BAL   R14,READDIR             GET NEXT DIRECTORY MEMBER        09405000
         B     0(R6)                   LAST MEMBER PROCESSED            09406000
         SPACE 1                                                        09407000
         CLC   DIRTTR,MEMTTR           TTR'S MATCH?                     09408000
         BNE   RENAME95                NO, BRANCH                       09409000
         TM    MEMFLAG,X'80'           ALIAS ENTRY?                     09410000
         BNO   RENAME95                NO, CONTINUE SEARCHING           09411000
         SPACE 2                                                        09412000
         L     R14,DIRPTRS             CURRENT DIRECTORY ENTRY          09413000
         MVC   DIRNAME(DIREND-DIRNAME),0(R14)                           09414000
         SPACE 1                                                        09415000
         LA    R14,DIRREAL             CORRESPONDING MAIN ENTRY NAME    09416000
         TM    DIRATTR,ATTRSCTR        SCATTER LOADED?                  09417000
         BNO   *+8                     NO, BRANCH                       09418000
         LA    R14,DIRREALS            YES, USE THIS NAME               09419000
         CLC   0(8,R14),MEMBER2        ALIAS NAME POINTER=MEMBER NAME?  09420000
         BE    RENAME95                YES, BRANCH                      09421000
         SPACE 1                                                        09422000
         MVC   0(8,R14),MEMBER2        CHANGE THE MEMBER POINTER        09423000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   09424000
         STOW  STOWDCB,DIRNAME,R       REPLACE THIS MEMBER ENTRY        09425000
         SPACE 1                                                        09426000
         LR    R5,R15                  SAVE RETURN CODE                 09427000
         MVC   INSERT#1(8),DIRNAME     MEMBER NAME                      09428000
         TSMSG L065$1                                                   09429000
         LTR   R15,R5                  SUCCESSFUL?                      09430000
         BNZ   IOERROR                 NO, I/O ERROR                    09431000
         B     RENAME95                CONTINUE FOR ALL ALIASES         09432000
         TITLE 'P D S  --  PDS RESTORE                         1/15/85' 09433000
*********************************************************************** 09434000
***   RESTORE SUBCOMMAND    MODIFIED BY BRUCE LELAND -- JUNE, 1982  *** 09435000
*********************************************************************** 09436000
*                                                                       09437000
         SPACE 1                                                        09438000
RESTORE  CSECT                                                          09439000
         USING *,R8                                                     09440000
         ICM   R1,B'1111',MEMBER2       TTR TO BE USED                  09441000
         CLI   LMEMBER2+1,1             COMPARE LENGTH:1                09442000
         BH    REST010                    HIGH (DO NOT ADJUST)          09443000
         SRL   R1,8                                                     09444000
         BE    REST010                    EQUAL (ADJUSTED ONE TIME)     09445000
         SRL   R1,8                       LOW (ADJUSTED TWICE)          09446000
         SPACE 1                                                        09447000
REST010  STCM  R1,B'1111',MEMBER2       SAVE THE UPDATED ADDRESS        09448000
         STCM  R1,B'1111',DIRTTR        SAVE THE UPDATED ADDRESS        09449000
         TM    FLAGSCC,RECFMU           LOAD MODULE?                    09450000
         BNO   REST020                  NO, BRANCH                      09451000
         MVI   #RESTDIR,X'20'+12        1 TEXT TTR, 12 HALFWORDS        09452000
         MVI   #RESTDIR+9,ATTREXEC      EXECUTABLE                      09453000
         MVI   #RESTDIR+10,ATTRNODC+ATTRZORG+ATTREP0+ATTRFLEV           09454000
*                                       NOT DC, ZERO ORG, EP=0, F-LEVEL 09455000
         MVI   #RESTDIR+19,DIRAOSLE+DIRAPFLG  VS EDITOR, APF DATA IS OK 09456000
         SPACE 1                                                        09457000
REST020  CLI   #RESTLIK,0               ANY LIKE OPERAND?               09458000
         BE    REST080                  NO, BRANCH                      09459000
         XC    DIRNAME(74),DIRNAME                                      09460000
         MVC   DIRNAME,#RESTLIK         LIKE NAME                       09461000
         BLDL  INDCB,BLDLLIST           GET MEMBER DIRECTORY            09462000
         SPACE 1                                                        09463000
         B     *+4(R15)                 PROCESS RETURN CODE             09464000
         B     REST030                    00 - FOUND                    09465000
         B     NOMEMBER                   04 - NOT FOUND                09466000
         B     IOERROR                    08 - I/O ERROR IN DIRECTORY   09467000
         SPACE 1                                                        09468000
REST030  MVC   DIRFLAG(DIREND-DIRFLAG),DIRFLAG+2  BLDL ADDS THINGS      09469000
         MVC   #RESTDIR,DIRFLAG         SAVE USER DATA                  09470000
         NI    #RESTDIR,FF-X'80'        TURN OFF ANY ALIAS BIT          09471000
         TM    FLAGSCC,RECFMU           LOAD MODULE?                    09472000
         BNO   REST080                  NO, BRANCH                      09473000
         XC    #RESTDIR,#RESTDIR        CLEAR THE USER DATA             09474000
         LA    R2,DIRAPF                POINT TO APF DATA               09475000
         TM    DIRATTR,ATTRSCTR         SCATTER LOAD?                   09476000
         BNO   *+8                      NO, BRANCH                      09477000
         LA    R2,8(,R2)                YES, POSITION OVER FIELDS       09478000
         TM    DIRFLAG,X'80'            ALIAS?                          09479000
         BO    *+12                     YES, BRANCH                     09480000
         CLI   8(R2),0                  CONVERTED ALIAS ENTRY?          09481000
         BE    *+8                      NO, BRANCH                      09482000
         LA    R2,11(,R2)               ADD ALIAS LENGTH                09483000
         TM    DIRATTR2,DIRAOSLE        O/S MVS LINKAGE EDITOR?         09484000
         BNO   REST040                  NO, BRANCH                      09485000
         TM    DIRATTR2,DIR2SSI         ANY SSI FIELD?                  09486000
         BNO   REST050                  NO, BRANCH                      09487000
REST040  LA    R1,1(,R2)                ADD FOR ROUNDING TO HALFWORD    09488000
         N     R1,=F'-2'                ROUND TO HALFWORD               09489000
         CLC   ZERO,0(R1)               ZERO?                           09490000
         BE    REST050                  YES, BRANCH                     09491000
         CLC   =F'-1',0(R1)             HIGH VALUES?                    09492000
         BE    REST050                  YES, BRANCH                     09493000
         MVC   #RESTSSI,0(R1)           SAVE THE SSI VALUE              09494000
         LA    R2,4(,R1)                POSITION AFTER SSI              09495000
         SPACE 1                                                        09496000
REST050  TM    DIRATTR2,DIRAOSLE+DIRAPFLG  VS LKED AND APF DATA GOOD?   09497000
         BO    REST060                     YES, BRANCH                  09498000
         XC    DIRATTR2(3),DIRATTR2        NO, CLEAR NEW FLAGS          09499000
         B     REST070                                                  09500000
         SPACE 1                                                        09501000
REST060  CLI   0(R2),X'01'              VALID APF LENGTH?               09502000
         BNE   REST070                  NO, BRANCH                      09503000
         MVC   #RESTAPF,1(R2)           YES, SAVE APF DATA              09504000
         SPACE 1                                                        09505000
REST070  MVI   #RESTDIR,X'20'+12        1 TEXT TTR, 12 HALFWORDS        09506000
         NI    DIRATTR,X'CA'            RENT, REUS, ONLY LOAD, EXEC.    09507000
         NI    DIRATTR+1,X'09'          NOT EDIT, REFR                  09508000
         MVC   #RESTDIR+9(2),DIRATTR    COPY INTO THE HOLD AREA         09509000
         OI    #RESTDIR+10,ATTRNODC+ATTRZORG+ATTREP0+ATTRFLEV           09510000
*                                       NOT DC, ZERO ORG, EP=0, F-LEVEL 09511000
         NI    DIRATTR2,DIR2PAGA        PAGE BOUNDARY FLAG              09512000
         NI    DIRATTR2+1,X'1F'         RMODE, AMODE FLAGS              09513000
         MVC   #RESTDIR+19(2),DIRATTR2  COPY INTO THE HOLD AREA         09514000
         OI    #RESTDIR+19,DIRAOSLE+DIRAPFLG  VS EDITOR, APF DATA IS OK 09515000
         SPACE 1                                                        09516000
REST080  MVC   DIRNAME,MEMBER1          MEMBER NAME TO BE RESTORED      09517000
         MVC   DIRTTR(3),MEMBER2        TTR OF MEMBER TO BE RESTORED    09518000
         SPACE 1                                                        09519000
         LA    R1,L873                                                  09520000
         CLC   DIRTTR(3),DS1LSTAR       IN DATA SET BOUNDS?             09521000
         BNL   MSGNEW                   NO, ERROR                       09522000
         SPACE 1                                                        09523000
         TM    #RESFLAG,#RESFREP+#RESFDIS  REPEAT, DISPLAY OR PROMPT?   09524000
         BZ    RESTOR03                    NO, BRANCH                   09525000
         SPACE 1                                                        09526000
         OI    FLAGSII,FNOTDOUB         FORCE SINGLE OR MULTIPLE BUFFER 09527000
         ICM   R1,B'1110',DIRTTR        T T R X  ZERO?                  09528000
         BZ    RESTSC08                 YES, BRANCH                     09529000
         SRL   R1,8                     0 T T R                         09530000
         S     R1,=F'1'                 0 T T R - 1 = 0?                09531000
         BZ    RESTSC08                 YES, BRANCH                     09532000
         SLL   R1,8                     T T R 0 (WHERE R IS REDUCED)    09533000
         STCM  R1,B'1110',DIRTTR        T T R                           09534000
         CLI   MEMBER2+2,X'01'          R OF TTR 1 OR LESS?             09535000
         BH    RESTSC08                 YES, BRANCH                     09536000
         SRL   R1,16                    0 0 T T                         09537000
         BCTR  R1,0                     0 0 T T - 1                     09538000
         SLL   R1,16                    T T 0 0 (WHERE TT IS REDUCED)   09539000
         STCM  R1,B'1100',DIRTTR        T T  UPDATED                    09540000
         MVI   DIRTTR+2,X'01'           RESET R TO 1 OF PREVIOUS TRACK  09541000
         SPACE 1                                                        09542000
RESTSC08 TM    #RESFLAG,#RESFREP        REPEAT?                         09543000
         BZ    RESTSC09                 NO, BRANCH                      09544000
         SPACE 2                                                        09545000
         LA    R1,7                     MACHINE LENGTH                  09546000
         LA    R2,DIRNAME+7             LAST CHARACTER                  09547000
         SPACE 1                                                        09548000
         CLI   0(R2),X'40'              BLANK?                          09549000
         BNE   *+10                     NO, BRANCH                      09550000
         BCTR  R2,0                     PREVIOUS CHARACTER              09551000
         BCT   R1,*-10                  TRY ALL BYTES                   09552000
         SPACE 1                                                        09553000
         ST    R1,#RESTLEN                          NAME LENGTH         09554000
         SPACE 3                                                        09555000
RESTSC09 MVI   SUBPOOLT,21              MARK TEMPORARY STORAGE IN USE   09556000
         LA    R5,1024                  1024 MEMBERS INITIALLY          09557000
         SPACE 1                                                        09558000
RESTSC10 LR    R0,R5                                                    09559000
         SLL   R0,2                     MEMBERS*4 FOR TABLE SIZE        09560000
         ICM   R0,B'1000',SUBPOOLT                                      09561000
         GETMAIN R,LV=(0)                                               09562000
         ST    R1,#MEMPTR               START OF TTR LIST               09563000
         LR    R4,R1                                                    09564000
         XC    0(4,R4),0(R4)            DUMMY FIRST ELEMENT             09565000
         LR    R3,R5                    NUMBER OF ELEMENTS              09566000
         MVI   STARTTR+2,X'01'          TTR=000001 (START OF DIRECTORY) 09567000
         SPACE 2                                                        09568000
RESTSC12 BAL   R14,READDIR              GET THE NEXT MEMBER             09569000
         B     RESTSC16                 END OF DIRECTORY, BRANCH        09570000
         SPACE 1                                                        09571000
         CLC   DIRTTR(3),MEMTTR         TTR START<TTR OF THIS MEMBER?   09572000
         BNL   RESTSC12                 NO, IGNORE                      09573000
         S     R3,=F'1'                 WILL THIS FIT?                  09574000
         BNP   RESTSC14                 NO, BRANCH                      09575000
         LA    R4,4(,R4)                NEXT TTR TABLE POSITION         09576000
         MVC   0(3,R4),MEMTTR           SAVE THE MEMBER START TTR       09577000
         MVI   3(R4),0                  CLEAR THE END FLAG              09578000
         B     RESTSC12                 GET THE NEXT ENTRY              09579000
         SPACE 1                                                        09580000
RESTSC14 SR    R0,R0                                                    09581000
         ICM   R0,B'1000',SUBPOOLT      SUBPOOL TO FREE                 09582000
         FREEMAIN R,SP=(0)                                              09583000
         SLL   R5,1                     DOUBLE THE NUMBER OF ENTRIES    09584000
         B     RESTSC10                                                 09585000
         SPACE 2                                                        09586000
RESTSC16 MVI   3(R4),X'FF'              MARK THE END OF THE TTR LIST    09587000
         BAL   R2,CLEAR                 CLEAR THE SCREEN                09588000
RESTSC17 TM    #RESFLAG,#RESFREP        REPEAT RESTORE?                 09589000
         BNO   RESTSC18                 NO, BRANCH                      09590000
         L     R1,#RESTSEQ              THIS MEMBER NUMBER              09591000
         LA    R1,1(,R1)                                                09592000
         ST    R1,#RESTSEQ              NEW MEMBER NUMBER               09593000
         CVD   R1,DOUBLE                                                09594000
         OI    DOUBLE+7,X'0F'           CORRECT SIGN                    09595000
         L     R1,#RESTLEN              MACHINE LENGTH                  09596000
         UNPK  DIRNAME(8),DOUBLE(8)     CONVERT THE SEQUENTIAL NAME     09597000
         MVC   DIRNAME(*-*),MEMBER1     <<EXECUTED>>                    09598000
         EX    R1,*-6                   ADD THE CODED NAME PORTION      09599000
         B     RESTSC20                 SKIP THIS CLEAR                 09600000
         SPACE 1                                                        09601000
RESTSC18 BAL   R2,CLEAR                 CLEAR THE SCREEN                09602000
         SPACE 3                                                        09603000
RESTSC20 MESSAGE MSGBLANK               ONE BLANK LINE                  09604000
         MVC   STARTTR(3),DIRTTR        FIRST DISK ADDRESS TO READ      09605000
         MVI   #RESTERR+1,3             ALLOW 3 PERMANENT ERRORS/MEMBER 09606000
         SPACE 2                                                        09607000
RESTSC22 L     R15,=A(EXCP)                                             09608000
         BALR  R14,R15                                                  09609000
         LA    R1,L006                  ASSUME END OF DATA SET          09610000
         B     *+4(R15)                 PROCESS RETURN CODE             09611000
         B     RESTSC22                   00 - SUCCESSFUL READ          09612000
         B     RESTSC24                   04 - END OF MEMBER            09613000
         B     MSGNEW                     08 - END OF DATA SET          09614000
         B     RESTSC23                   12 - I/O ERROR                09615000
         SPACE 1                                                        09616000
*  PERMANENT I/O ERROR                                                  09617000
*    A.  IF TOO MANY ERRORS FOR THIS MEMBER, TERMINATE                  09618000
*    B.  SIMULATE AN END OF MEMBER CONDITION                            09619000
*    C.  CONTINUE ON THE NEXT TRACK                                     09620000
RESTSC23 LA    R1,L804                  ASSUME TOO MANY ERRORS          09621000
         LH    R0,#RESTERR                                              09622000
         S     R0,=F'1'                 CORRECT?                        09623000
         BM    MSGNEW                   YES, BRANCH                     09624000
         STH   R0,#RESTERR                                              09625000
         TSMSG L801                                                     09626000
         STM   R2,R12,28(R13)                                           09627000
         LA    R2,CURMBB                                                09628000
         L     R1,INDCB+(DCBDEBAD-IHADCB)                               09629000
         L     R15,ADDRRLTV                                             09630000
         LR    R3,R13                                                   09631000
         BALR  R14,R15                                                  09632000
         LR    R13,R3                                                   09633000
         LM    R2,R12,28(R13)                                           09634000
         SRL   R0,16                    TT OF LAST INPUT TTRN           09635000
         A     R0,=F'1'                                                 09636000
         STH   R0,STARTTR               TT OF NEXT TRACK                09637000
         MVI   STARTTR+2,X'01'          R OF TTR                        09638000
         SPACE 2                                                        09639000
*  END OF MEMBER, GET THE NEXT DATA BLOCK                               09640000
RESTSC24 L     R15,=A(EXCP)                                             09641000
         BALR  R14,R15                                                  09642000
         LA    R1,L006                  ASSUME END OF DATA SET          09643000
         B     *+4(R15)                 PROCESS RETURN CODE             09644000
         B     RESTSC26                   00 - SUCCESSFUL READ          09645000
         B     RESTSC24                   04 - END OF MEMBER            09646000
         B     MSGNEW                     08 - END OF DATA SET          09647000
         B     RESTSC23                   12 - I/O ERROR                09648000
         SPACE 1                                                        09649000
RESTSC26 STM   R2,R12,28(R13)           CONVERT MBBCCHHR TO TTR         09650000
         LA    R2,CURMBB                                                09651000
         L     R1,INDCB+(DCBDEBAD-IHADCB)                               09652000
         L     R15,ADDRRLTV                                             09653000
         LR    R3,R13                                                   09654000
         BALR  R14,R15                                                  09655000
         LR    R13,R3                                                   09656000
         LM    R2,R12,28(R13)                                           09657000
         STCM  R0,B'1110',DIRTTR        TTR OF THIS MEMBER              09658000
         CLM   R0,B'1110',MEMBER2       AT OR AFTER THE START POINT?    09659000
         BL    RESTSC22                 NO, BRANCH                      09660000
         SPACE 1                                                        09661000
         L     R4,#MEMPTR               START OF TTR TABLE              09662000
RESTSC28 CLC   DIRTTR(3),0(R4)          IN THE TABLE?                   09663000
         BE    RESTSC22                 YES, IGNORE THIS MEMBER         09664000
         CLI   3(R4),X'FF'              END OF TTR TABLE?               09665000
         LA    R4,4(,R4)                                                09666000
         BNE   RESTSC28                 NO, BRANCH                      09667000
         SPACE 1                                                        09668000
         UNPK  INSERT#1(7),DIRTTR(4)    TTR OF THIS DELETED MEMBER      09669000
         TR    INSERT#1(6),TRTABLE      MAKE PRINTABLE                  09670000
         MVC   INSERT#1+6(2),BLANKS                                     09671000
         TSMSG L101$1                                                   09672000
         TM    #RESFLAG,#RESFDIS        DISPLAY OPTION?                 09673000
         BNO   RESTSC90                 NO, BRANCH                      09674000
         MESSAGE MSGBLANK                                               09675000
         SR    R5,R5                    LINE IN PROGRESS POINTER        09676000
         SR    R6,R6                    OUTPUT COUNTER                  09677000
         TM    FLAGSCC,RECFMU           RECFM=U?                        09678000
         BO    RESTSC36                 YES, BRANCH                     09679000
         B     RESTSC62                 NO, MUST BE V OR F              09680000
         SPACE 3                                                        09681000
*  RECORD FORMAT U (LOAD MODULE)                                        09682000
RESTSC30 L     R15,=A(EXCP)                                             09683000
         BALR  R14,R15                                                  09684000
         B     *+4(R15)                 PROCESS RETURN CODE             09685000
         B     RESTSC36                   00 - SUCCESSFUL READ          09686000
         B     RESTSC32                   04 - END OF MEMBER            09687000
         B     RESTSC32                   08 - END OF DATA SET          09688000
         B     RESTSC23                   12 - I/O ERROR                09689000
         SPACE 1                                                        09690000
RESTSC32 LTR   R5,R5                    LINE IN PROGRESS?               09691000
         BNP   RESTSC34                 NO, BRANCH                      09692000
         LA    R1,MSGLINE+5                                             09693000
         SR    R5,R1                    MESSAGE LENGTH                  09694000
         STC   R5,MTHIGHL                                               09695000
         MVC   INSERT#1(127),MSGLINE+4                                  09696000
         LA    R1,FULLWORD                                              09697000
         TSMSG (R1)                                                     09698000
         MVI   MTHIGHL,8                                                09699000
         B     RESTSC90                                                 09700000
         SPACE 1                                                        09701000
RESTSC34 TSMSG L805                     NO CESD OR LKED IDR RECORDS     09702000
         MVC   STARTTR(3),DIRTTR        RE-READ THE MEMBER              09703000
         B     RESTSC60                 OUTPUT WITH CHARACTER OUTPUT    09704000
         SPACE 2                                                        09705000
RESTSC36 L     R3,EXCPBUFF              BUFFER ADDRESS                  09706000
         CLI   0(R3),X'20'              CESD RECORD?                    09707000
         BNE   RESTSC50                 NO, CHECK FOR LINKAGE-EDIT IDR  09708000
**       CH    R6,=H'5'                 NEED TO BUILD MORE LINES?  @D01 09709000
         C     R6,#RESTNUM              NEED TO BUILD MORE CSECT LINES?
*                                                                  @D01
         BNL   RESTSC30                 NO, BRANCH                      09710000
         LH    R4,6(,R3)                LENGTH OF ESD DATA              09711000
         SRL   R4,4                     LENGTH/16=NUMBER OF ENTRIES     09712000
         LA    R3,8(,R3)                START OF ESD DATA               09713000
         SPACE 1                                                        09714000
         USING ESDNAME,R3                                               09715000
RESTSC38 TM    ESDTYPE,X'0F'            CSECT ENTRY?                    09716000
         BNZ   RESTSC46                 NO, BRANCH                      09717000
         CLI   ESDNAME,X'40'            BLANK CSECT NAME?               09718000
         BE    RESTSC46                 YES, IGNORE                     09719000
         LA    R2,ESDNAME+7                                             09720000
         LTR   R5,R5                    LINE IN PROGRESS?               09721000
         BP    RESTSC40                 YES, BRANCH                     09722000
         LA    R1,80                    ASSUME AN ACTIVE MODE           09723000
         AIF ('&CISP' EQ 'NO SPF').MA00680                         @D01
         TM    SPFLAG0,SPFDON           ISPMODE ACTIVE?                 09724000
         BO    RESTSC39                 YES, BRANCH                     09725000
.MA00680 ANOP  ,                                                   @D01
         TM    CONTOPTN,1               ANY LOG RECORDING?              09726000
         BO    RESTSC39                 YES, BRANCH                     09727000
         GTSIZE
         CH    R1,=H'120'               120 OR LESS BYTES?              09729000
         BL    *+8                      YES, BRANCH                     09730000
         LH    R1,=H'120'               NO, USE 120 BYTES               09731000
RESTSC39 TM    FLAGSCC,RECFMU           LOAD LIBRARY?                   09732000
         BNO   *+8                      NO, BRANCH                      09733000
         SH    R1,=H'7'                 YES, LESS SEVEN FOR PREFIX      09734000
         ST    R1,LINESIZE              CHARACTERS/LINE                 09735000
         MVC   MSGLINE+4(L'MSGRESTO),MSGRESTO                           09736000
         LA    R5,MSGLINE+4+L'MSGRESTO                                  09737000
         MVC   FULLWORD(3),L164$1                                       09738000
         SPACE 2                                                        09739000
RESTSC40 CLI   0(R2),X'40'              SCAN BACKWARDS                  09740000
         BNE   *+8                                   FOR FIRST          09741000
         BCT   R2,RESTSC40                                   NON-BLANK  09742000
         SPACE 1                                                        09743000
         LA    R0,ESDNAME                                               09744000
         SR    R2,R0                    MACHINE LENGTH OF NAME          09745000
         LA    R15,2(R2,R5)             CURRENT + NAME-1 + BLANK + 1    09746000
         LA    R1,MSGLINE                                               09747000
         SR    R15,R1                   DISPLACEMENT INTO THE LINE      09748000
         C     R15,LINESIZE             PAST END OF LINE?               09749000
         BNH   RESTSC44                 NO, BRANCH                      09750000
         SPACE 1                                                        09751000
         LA    R6,1(,R6)                ONE MORE OUTPUT LINE            09752000
**       CH    R6,=H'5'                 ENOUGH LINES?              @D01 09753000
         C     R6,#RESTNUM              ENOUGH LINES?              @D01
         BL    RESTSC42                 NO, BRANCH                      09754000
         MVC   0(4,R5),=C' ...'         INDICATE MORE CSECTS EXIST      09755000
         LA    R5,5(,R5)                INCREMENT TO END +1             09756000
         B     RESTSC30                                                 09757000
         SPACE 2                                                        09758000
RESTSC42 LA    R1,MSGLINE+4                                             09759000
         SR    R5,R1                    MESSAGE LENGTH                  09760000
         STC   R5,MTHIGHL                                               09761000
         MVC   INSERT#1(127),MSGLINE+4                                  09762000
         LA    R1,FULLWORD                                              09763000
         TSMSG (R1)                                                     09764000
         MVI   MTHIGHL,8                                                09765000
         MVI   FULLWORD+2,C'9'                                          09766000
         LA    R5,MSGLINE+3             INCREMENT TO END                09767000
         SPACE 1                                                        09768000
RESTSC44 MVI   0(R5),X'40'              BLANK BEFORE CSECT NAME         09769000
         MVC   1(8,R5),ESDNAME          CSECT NAME                      09770000
         TR    1(8,R5),TRLINE           MAKE PRINTABLE                  09771000
         LA    R5,2(R2,R5)              POSITION TO FOLLOWING COMMA     09772000
         MVI   0(R5),C','               ADD THE COMMA                   09773000
         LA    R5,1(,R5)                POSITION AFTER THE COMMA        09774000
         SPACE 1                                                        09775000
RESTSC46 LA    R3,16(,R3)               NEXT ESD ENTRY                  09776000
         BCT   R4,RESTSC38              LOOP FOR ALL ENTRIES            09777000
         B     RESTSC30                 GET THE NEXT RECORD             09778000
         DROP  R3                                                       09779000
         SPACE 3                                                        09780000
RESTSC50 CLI   0(R3),X'80'              IDR RECORD?                     09781000
         BNE   RESTSC30                 NO, CONTINUE INPUT              09782000
         TM    2(R3),IDRLKED            LINKAGE EDITOR IDR RECORD?      09783000
         BNO   RESTSC30                 NO, CONTINUE INPUT              09784000
         LTR   R5,R5                    LINE IN PROGRESS?               09785000
         BNP   RESTSC52                 NO, BRANCH                      09786000
         LA    R1,MSGLINE+5                                             09787000
         SR    R5,R1                    LENGTH OF MESSAGE SO FAR        09788000
         STC   R5,MTHIGHL                                               09789000
         MVC   INSERT#1(127),MSGLINE+4                                  09790000
         LA    R1,FULLWORD                                              09791000
         TSMSG (R1)                                                     09792000
         MVI   MTHIGHL,8                                                09793000
         SPACE 1                                                        09794000
RESTSC52 MESSAGE MSGBLANK                                               09795000
         LA    R1,12+3(,R3)             ADDRESS OF YYDDD FORMAT DATE    09796000
         LA    R15,LKEDDATE             ADDRESS OF YYMMDD FORMAT OUTPUT 09797000
         BAL   R14,CONVDATE             CONVERT TO MMDDYY FORMAT        09798000
         MVC   INSERT#1-1(9),DATEMASK                                   09799000
         ED    INSERT#1-1(9),LKEDDATE                                   09800000
         MVI   MTLEN+4,18+14                      Insert length    @D01
         MVC   INSERT#2(10),3(R3)                 LKED name        @D01
         MVC   INSERT#2+10(2),=CL2' V'            Constant "V"     @D01
         UNPK  INSERT#2+10+2(3),10+3(2,R3)        Version          @D01
         MVC   INSERT#2+10+2+2(2),=CL2' M'        Constant "M"     @D01
         UNPK  INSERT#2+10+2+2+2(3),10+3+1(2,R3)  Level            @D01
****     TSMSG L106$1                                                   09801000
         TSMSG L064$2                                              @D01
         MVI   MTLEN+4,8                LENGTH OF STANDARD INSERT  @D01
         B     RESTSC90                 PROMPT FOR RESTORE              09802000
         SPACE 2                                                        09803000
*  RECORD FORMAT V, F OR U                                              09804000
RESTSC60 L     R15,=A(EXCP)                                             09805000
         BALR  R14,R15                                                  09806000
         B     *+4(R15)                 PROCESS RETURN CODE             09807000
         B     RESTSC62                   00 - SUCCESSFUL READ          09808000
         B     RESTSC78                   04 - END OF MEMBER            09809000
         B     RESTSC78                   08 - END OF DATA SET          09810000
         B     RESTSC23                   12 - I/O ERROR                09811000
         SPACE 1                                                        09812000
RESTSC62 L     R5,LS                    BLOCK LENGTH                    09813000
         L     R2,EXCPBUFF              BUFFER START                    09814000
         LR    R1,R5                                                    09815000
         AR    R5,R2                    END OF BUFFER                   09816000
         BCTR  R5,0                     END OF BUFFER -1                09817000
         TM    FLAGSCC,RECFMF           RECFM=F?                        09818000
         LH    R4,LRECL                                                 09819000
         BO    RESTSC68                 YES, BRANCH                     09820000
         TM    FLAGSCC,RECFMU           RECFM=U?                        09821000
         LR    R4,R1                                                    09822000
         BO    RESTSC68                 YES, BRANCH                     09823000
         TM    FLAGSCC,RECFMV           RECFM=V?                        09824000
         BNO   RESTSC68                 NO, ASSUME RECFM=U              09825000
         AH    R2,=H'4'                 SKIP BLOCK LENGTH WORD          09826000
         B     RESTSC66                                                 09827000
         SPACE 2                                                        09828000
RESTSC64 BXLE  R2,R4,RESTSC66           GET THE NEXT LOGICAL RECORD     09829000
         B     RESTSC60                 END OF BLOCK, BRANCH            09830000
         SPACE 2                                                        09831000
RESTSC66 TM    FLAGSCC,RECFMV           RECFM=V?                        09832000
         BNO   RESTSC68                 NO, BRANCH                      09833000
         SR    R4,R4                                                    09834000
         ICM   R4,B'0011',0(R2)         RECORD LENGTH +4                09835000
         AH    R2,=H'4'                 SKIP RECORD LENGTH WORD         09836000
         SH    R4,=H'4'                 RECORD LENGTH VALID?            09837000
         BP    RESTSC68                 YES, BRANCH                     09838000
         SR    R4,R4                    NO, USE LENGTH ZERO             09839000
         B     RESTSC64                 IGNORE THE RECORD               09840000
         SPACE 1                                                        09841000
RESTSC68 LA    R6,1(,R6)                ANOTHER OUTPUT RECORD           09842000
**       CH    R6,=H'5'                 ENOUGH OUTPUT?             @D01 09843000
         C     R6,#RESTNUM              ENOUGH OUTPUT?             @D01
         BH    RESTSC78                 YES, BRANCH                     09844000
         MVC   INSERT#1(8),BLANKS       BLANK                           09845000
         LA    R0,240(,R6)              PRINTABLE COUNT CHARACTER       09846000
         STC   R0,INSERT#1                                              09847000
         TSMSG L144$1                                                   09848000
         LR    R1,R4                    CURRENT RECORD LENGTH           09849000
         CH    R1,=H'256'                                               09850000
         BNH   *+8                                                      09851000
         LH    R1,=H'256'               MAXIMUM DISPLAY LENGTH          09852000
         BCTR  R1,0                     MACHINE LENGTH                  09853000
         MVC   MSGTEXT1+4(*-*),0(R2)    <<EXECUTED>>                    09854000
         EX    R1,*-6                   MOVE IN THE DISPLAY TEXT        09855000
         TR    MSGTEXT1+4(256),TRLINE   CONVERT TO PRINTABLES           09856000
         LA    R1,4+1(,R1)              MESSAGE LENGTH                  09857000
         CH    R4,=H'256'               TRUNCATED RECORD MESSAGE?       09858000
         BNH   *+14                     NO, BRANCH                      09859000
         MVC   MSGTEXT1+4+256(4),=C' ...'  INDICATE THAT MORE EXISTS    09860000
         LA    R1,4(,R1)                ADD TO THE MESSAGE LENGTH       09861000
         STH   R1,MSGTEXT1                                              09862000
         MESSAGE MSGTEXT1                                               09863000
         C     R4,LINESIZE              LRECL EXACTLY MATCH LINESIZE?   09864000
         BE    RESTSC64                 YES, A BLANK LINE ALREADY (+1)  09865000
         MESSAGE MSGBLANK                                               09866000
         B     RESTSC64                                                 09867000
         SPACE 1                                                        09868000
RESTSC78 TM    FLAGSCC,RECFMU           RECFM=U?                        09869000
         BO    RESTSC20                 YES, INVALID LOAD MODULE        09870000
RESTSC90 MESSAGE MSGBLANK                                               09871000
         TM    #RESFLAG,#RESFPRO        PROMPT OPTION?                  09872000
         BO    RESTSC94                 YES, BRANCH                     09873000
         TM    #RESFLAG,#RESFPRO*2+#RESFPRO*4  NOPROMPT OR NO.. GLOBAL? 09874000
         BNZ   RESTOR05                        YES, BRANCH              09875000
RESTSC94 TM    FLAGSEE,FBKGRND+FNOTTERM INPUT FROM THE TERMINAL?        09876000
         BNZ   RESTOR05                 NO, RESTORE THIS MEMBER         09877000
         LA    R1,PDS390A               CORRECT MEMBER MESSAGE          09878000
         BAL   R2,YESNO1                RESPONSE "YES" OR "NO"?         09879000
         B     RESTSC18                 NO, CONTINUE SEARCHING          09880000
         BAL   R2,CLEAR                 YES, CLEAR THE SCREEN           09881000
         B     RESTOR05                      NO DIRECTORY CHECK NEEDED  09882000
         SPACE 3                                                        09883000
RESTOR03 MVI   STARTTR+2,X'01'          TTR=000001 (START OF DIRECTORY) 09884000
         SPACE 2                                                        09885000
RESTOR04 BAL   R14,READDIR              GET NEXT DIRECTORY MEMBER       09886000
         B     RESTOR05                 LAST MEMBER PROCESSED           09887000
         SPACE 1                                                        09888000
         CLC   DIRTTR(3),MEMTTR         TTR'S MATCH?                    09889000
         BNE   RESTOR04                 NO, BRANCH                      09890000
         SPACE 1                                                        09891000
         MVC   INSERT#1(8),MEMNAME                                      09892000
         LA    R1,L802$1                MEMBER ALREADY EXISTS AT TTR    09893000
         TM    MEMFLAG,X'80'            AN ALIAS?                       09894000
         BNO   *+8                      NO, BRANCH                      09895000
         LA    R1,L190$1                AN ALIAS ALREADY EXISTS AT TTR  09896000
         TSMSG (R1)                                                     09897000
         SPACE 1                                                        09898000
         TM    MEMFLAG,X'80'            ALIAS ENTRY?                    09899000
         BO    RESTOR04                 YES, CONTINUE SEARCHING         09900000
         SPACE 1                                                        09901000
         CLC   =C'TEMP',DIRNAME         ALLOW IT ANYWAY?                09902000
         BNE   NEWCMD                   NO, BRANCH                      09903000
         SPACE 2                                                        09904000
RESTOR05 TM    FLAGSCC,RECFMU      LOAD LIBRARY?                        09905000
         BNO   RESTOR96            NO, STOW AND QUIT                    09906000
         XC    DIRUSER,DIRUSER     CLEAR THE ADDITIONAL FIELDS          09907000
         MVC   DIRFLAG(33),#RESTDIR  INITIALIZE THE USER AREA           09908000
         SPACE 1                                                        09909000
         MVI   #RESTESD,AMODE24    AMODE 24 IS THE DEFAULT              09910000
         MVI   #RESTMOD,RMODEANY   SET RMODE ANY SUMMARY START          09911000
         XC    #BLKSI(4),#BLKSI    CLEAR THE MAXIMUM MEMBER BLOCKSIZE   09912000
         LA    R2,RESTOR10         WHERE-TO-GO                          09913000
         MVC   STARTTR(3),DIRTTR   START ADDRESS                        09914000
         SPACE 3                                                        09915000
RESTOR06 L     R15,=A(EXCP)                                             09916000
         BALR  R14,R15                                                  09917000
         B     *+4(R15)                 PROCESS RETURN CODE             09918000
         B     RESTOR08                   00 - GOOD READ                09919000
         B     RESTOR90                   04 - END OF MEMBER            09920000
         B     RESTOR90                   08 - END OF DATA SET          09921000
         B     NEWCMD                     12 - I/O ERROR                09922000
         SPACE 2                                                        09923000
RESTOR08 L     R5,LS                    CURRENT LENGTH                  09924000
         LR    R4,R0                    START OF BUFFER                 09925000
         C     R5,#BLKSI                BLKSIZE>MAX?                    09926000
         BNHR  R2                       NO, BRANCH                      09927000
         ST    R5,#BLKSI                YES, SAVE NEW MAXIMUM           09928000
         BR    R2                       DECODE THE RECORD               09929000
         SPACE 3                                                        09930000
RESTOR10 MVI   ENTRYPT,C'?'             NO ENTRY POINT NAME YET         09931000
         CLI   0(R4),X'40'              TEST SYM RECORD?                09932000
         BNE   RESTOR12                 NO, BRANCH                      09933000
         OI    DIRATTR,ATTRTEST         TEST SYM FLAG                   09934000
         OI    DIRATTR+1,ATTRSYMS       SYMBOLS ARE AVAILABLE           09935000
         SPACE 1                                                        09936000
RESTOR12 LA    R2,RESTOR12              WHERE-TO-GO NEXT                09937000
         CLI   0(R4),X'40'              TEST SYM RECORD?                09938000
         BE    RESTOR06                 YES, GET NEXT RECORD            09939000
         SPACE 1                                                        09940000
         CLI   0(R4),X'20'              CESD RECORD?                    09941000
         BNE   RESTOR20                 NO, BRANCH                      09942000
         SPACE 1                                                        09943000
         LH    R6,4(,R4)                CURRENT ESDID                   09944000
         LA    R3,8(,R4)                START OF ESD DATA               09945000
         USING ESDNAME,R3                                               09946000
         LH    R5,6(,R4)                LENGTH OF DATA IN BUFFER        09947000
         AR    R5,R3                    END OF DATA                     09948000
         LA    R4,16                    LENGTH OF ONE ENTRY             09949000
         SR    R5,R4                    END OF DATA -(ONE ENTRY LENGTH) 09950000
         SPACE 3                                                        09951000
RESTOR13 IC    R0,ESDTYPE                                               09952000
         LA    R1,CODESEG          CHECK FOR SEGTAB/ENTAB               09953000
         NI    ESDTYPE,X'0F'                                            09954000
         NR    R0,R1                                                    09955000
         CLI   ESDTYPE,CODESD      VALID EXTERNAL SYMBOL?               09956000
         BE    RESTOR14            YES, BRANCH                          09957000
         CLI   ESDTYPE,CODELR      EXTERNAL REFERENCE?                  09958000
         BNE   RESTOR17            NO, BRANCH                           09959000
         SPACE 1                                                        09960000
RESTOR14 CLC   ESDNAME,DIRNAME     THIS MEMBER NAME?                    09961000
         BNE   RESTOR15            NO, BRANCH                           09962000
         SR    R14,R14                                                  09963000
         ICM   R14,B'0111',ESDADDR  ENTRY ADDRESS ZERO?                 09964000
         BZ    *+8                  YES, BRANCH                         09965000
         NI    DIRATTR+1,FF-ATTREP0 NO, INSURE ATTR FLAG OFF            09966000
         STCM  R14,B'0111',DIREPA  MOVE ENTRY ADDRESS TO DIRECTORY      09967000
         MVC   ENTRYPT,ESDNAME     SAVE THE NAME FOR LATER              09968000
         STCM  R6,B'0011',DIRSCEP  SAVE THE ESDID OF THE ENTRY POINT    09969000
         MVC   #RESTESD,ESDXAFLG   SAVE THE MVS/XA ESD FLAG ENTRY       09970000
         SPACE 1                                                        09971000
RESTOR15 OC    ESDADDR(3),ESDADDR  ZERO OFFSET?                         09972000
         BNZ   RESTOR17            NO, BRANCH                           09973000
         CLI   ENTRYPT,C'?'        ANY SYMBOL NAME YET?                 09974000
         BNE   RESTOR17            YES, BRANCH                          09975000
         MVC   ENTRYPT,ESDNAME     SAVE THE NAME FOR LATER              09976000
         STCM  R6,B'0011',DIRSCEP  SAVE THE ESDID OF THE ENTRY POINT    09977000
         MVC   #RESTESD,ESDXAFLG   SAVE THE MVS/XA ESD FLAG ENTRY       09978000
RESTOR17 CR    R0,R1               THIS SEGTAB/ENTAB ENTRY?             09979000
         BE    RESTOR18            YES, BRANCH                          09980000
         CLI   ESDTYPE,CODESD      EXTERNAL DEFINITION?                 09981000
         BE    RESTOR18            YES, BRANCH                          09982000
         CLI   ESDTYPE,CODEPC      PRIVATE CODE?                        09983000
         BE    RESTOR18            YES, BRANCH                          09984000
         CLI   ESDTYPE,CODECM      COMMON STORAGE?                      09985000
         BNE   RESTOR19            NO, BRANCH                           09986000
         SPACE 1                                                        09987000
RESTOR18 L     R1,ESDADDR-1        RELATIVE OFFSET                      09988000
         L     R14,ESDLEN-1        LENGTH OF ESD ENTRY                  09989000
         LA    R14,7(R1,R14)       MAXIMUM DISPLACEMENT +7              09990000
         N     R14,=X'FFFFFFF8'    ROUND TO NEXT DOUBLE WORD            09991000
         CLM   R14,B'0111',DIRSTORE SMALLER THAN PREVIOUS HIGH?         09992000
         BL    *+8                 YES, BRANCH                          09993000
         STCM  R14,B'0111',DIRSTORE NO, UPDATE MODULE LENGTH            09994000
         NC    #RESTMOD,ESDXAFLG   SUMMARIZE ALL RMODE ENTRIES          09995000
         OC    ESDADDR,ESDADDR     ORIGIN AT LOCATION ZERO?             09996000
         BNZ   RESTOR19            NO, BRANCH                           09997000
         OC    ESDLEN,ESDLEN       NULL LENGTH BLOCK?                   09998000
         BZ    RESTOR19            YES, BRANCH                          09999000
         STCM  R6,B'0011',DIRSCET  SAVE THE FIRST TEXT ESDID            10000000
         SPACE 1                                                        10001000
RESTOR19 A     R6,=F'1'            NEXT ESDID                           10002000
         BXLE  R3,R4,RESTOR13                                           10003000
         B     RESTOR06            GET NEXT RECORD                      10004000
         SPACE 3                                                        10005000
         DROP  R3                                                       10006000
RESTOR20 LA    R2,RESTOR20         WHERE-TO-GO NEXT                     10007000
         CLI   0(R4),X'80'         IDR RECORD?                          10008000
         BE    RESTOR06            YES, GET NEXT RECORD                 10009000
         SPACE 1                                                        10010000
         LA    R2,RESTOR30         WHERE-TO-GO NEXT                     10011000
         CLI   0(R4),X'0D'         FILLER RECORD?                       10012000
         BNE   RESTOR30            NO, BRANCH                           10013000
         OI    DIRATTR+1,ATTRNRLD  NO RLD ENTRIES                       10014000
         OI    DIRATTR,ATTR1TXT    ASSUME ONLY ONE TEXT RECORD TOO      10015000
         SPACE 1                                                        10016000
RESTOR30 CLI   0(R4),X'0D'         FILLER RECORD?                       10017000
         BE    RESTOR06            YES, IGNORE                          10018000
         CLI   0(R4),X'01'         RLD ENTRY?                           10019000
         BNE   RESTOR31            NO, BRANCH                           10020000
         MVC   DIRATTR4,3(R4)      GET THE NUMBER OF LATER ESD ENTRIES  10021000
         B     RESTOR06                                                 10022000
         SPACE 1                                                        10023000
RESTOR31 TM    DIRATTR+1,ATTRNRLD  NO RLD MARKED?                       10024000
         BNO   RESTOR33            NO, BRANCH                           10025000
         CLM   R5,B'0111',DIRSTORE FIRST TEXT LENGTH=TOTAL LENGTH?      10026000
         BE    RESTOR33            YES, ONLY ONE TEXT BLOCK             10027000
         NI    DIRATTR,FF-ATTR1TXT NO, MULTI-BLOCK TEXT AND NO RLD      10028000
         SPACE 1                                                        10029000
RESTOR33 STM   R14,R12,12(R13)            CONVERT CCHHR TO TTR          10030000
         LA    R2,CURMBB                  CCHHR TO CONVERT              10031000
         L     R1,INDCB+(DCBDEBAD-IHADCB) DEB ADDRESS                   10032000
         L     R15,ADDRRLTV               ADDRESS OF CCHHR->TTR CONVERT 10033000
         LR    R3,R13                     ADDRESS OF SAVE AREA          10034000
         BALR  R14,R15                    CALL CONVERT ROUTINE          10035000
         LR    R13,R3                     RESTORE SAVE AREA ADDRESS     10036000
         ST    R0,12+4+4(R13)             RESULT TTR RETURNED IN R0     10037000
         LM    R14,R12,12(R13)            RESTORE REGISTERS             10038000
         CLI   0(R4),X'10'         SCATTER LOADED?                      10039000
         BE    RESTOR60            YES, BRANCH                          10040000
         STCM  R0,B'1110',DIRSTART RESULT TTR                           10041000
         STCM  R5,B'0011',DIRTEXTL SAVE LENGTH OF FIRST TEXT RECORD     10042000
         LA    R2,RESTOR06         WHERE-TO-GO NEXT TIME                10043000
         CLI   0(R4),X'00'         OVERLAY DEFINITION RECORD?           10044000
         BNER  R2                  NO, LOOP UNTIL END OF MEMBER         10045000
         LA    R2,RESTOR40         WHERE-TO-GO NEXT                     10046000
         OI    DIRATTR,ATTROVLY    OVERLAY MODULE                       10047000
         XI    DIRFLAG,X'40'+X'20' TWO USER TTR'S NOW                   10048000
         LA    R14,7(,R5)                                               10049000
         N     R14,=X'FFFFFFF8'    ROUND TO NEXT DOUBLE WORD            10050000
         OC    DIREPA(3),DIREPA    NON-ZERO ENTRY POINT?                10051000
         BNZ   RESTOR06            YES, BRANCH                          10052000
         STCM  R14,B'0111',DIREPA  MOVE ENTRY ADDRESS TO DIRECTORY      10053000
         NI    DIRATTR+1,FF-ATTREP0  INSURE ATTR FLAG OFF               10054000
         MVI   ENTRYPT,C'?'        ENTRY POINT ADDRESS IS NOT KNOWN     10055000
         MVI   #RESTESD,AMODE24    AMODE 24 AGAIN                       10056000
         MVI   #RESTMOD,0          RMODE 24 FOR SUMMARY                 10057000
         B     RESTOR06                                                 10058000
         SPACE 2                                                        10059000
RESTOR40 SRL   R5,2                LENGTH/4                             10060000
         STC   R5,DIRNOTE#         NUMBER OF ENTRIES                    10061000
         STM   R14,R12,12(R13)            CONVERT CCHHR TO TTR          10062000
         LA    R2,CURMBB                  CCHHR TO CONVERT              10063000
         L     R1,INDCB+(DCBDEBAD-IHADCB) DEB ADDRESS                   10064000
         L     R15,ADDRRLTV               ADDRESS OF CCHHR->TTR CONVERT 10065000
         LR    R3,R13                     ADDRESS OF SAVE AREA          10066000
         BALR  R14,R15                    CALL CONVERT ROUTINE          10067000
         LR    R13,R3                     RESTORE SAVE AREA ADDRESS     10068000
         ST    R0,12+4+4(R13)             RESULT TTR RETURNED IN R0     10069000
         LM    R14,R12,12(R13)            RESTORE REGISTERS             10070000
         STCM  R0,B'1110',DIRNOTE  SAVE OVERLAY TABLE TTR               10071000
         B     RESTOR06            CONTINUE UNTIL END-OF-MEMBER         10072000
         SPACE 1                                                        10073000
RESTOR60 STCM  R0,B'1110',DIRNOTE  START OF SCATTER LIST TABLE          10074000
         LA    R2,RESTOR63         WHERE-TO-GO NEXT                     10075000
         MVI   DIRFLAG,X'40'+16    2 TEXT TTRS, 16 HALFWORDS            10076000
         OI    DIRATTR,ATTRSCTR    SCATTER LOADED MODULE                10077000
         SR    R3,R3               ACCUMULATE LENGTH OF OVERLAY RECORDS 10078000
         SPACE 1                                                        10079000
RESTOR63 CLI   0(R4),X'10'           SCATTER DEFINITION RECORD?         10080000
         BNE   RESTOR65              NO, BRANCH                         10081000
         AR    R3,R5                 ACCUMULATE SCATTER RECORD LENGTH   10082000
         SH    R3,=H'4'              LESS THE HEADER AMOUNT             10083000
         B     RESTOR06              CONTINUE FOR ALL SCATTER RECORDS   10084000
         SPACE 1                                                        10085000
RESTOR65 LA    R2,RESTOR67           WHERE-TO-GO NEXT                   10086000
         CLI   0(R4),X'0D'           FILLER RECORD?                     10087000
         BNE   RESTOR67              NO, BRANCH                         10088000
         OI    DIRATTR+1,ATTRNRLD    NO RLD ENTRIES                     10089000
         OI    DIRATTR,ATTR1TXT      ASSUME ONLY ONE TEXT RECORD TOO    10090000
         SPACE 1                                                        10091000
RESTOR67 CLI   0(R4),X'0D'         FILLER RECORD?                       10092000
         BE    RESTOR06            YES, IGNORE                          10093000
         CLI   0(R4),X'01'         RLD ENTRY?                           10094000
         BNE   RESTOR72            NO, BRANCH                           10095000
         MVC   DIRATTR4,3(R4)      GET THE NUMBER OF LATER ESD ENTRIES  10096000
         B     RESTOR06                                                 10097000
         SPACE 1                                                        10098000
RESTOR72 TM    DIRATTR+1,ATTRNRLD    NO RLD MARKED?                     10099000
         BNO   RESTOR76              NO, BRANCH                         10100000
         CLM   R5,B'0111',DIRSTORE   FIRST TEXT LENGTH=TOTAL LENGTH?    10101000
         BE    RESTOR76              YES, ONLY ONE TEXT BLOCK           10102000
         NI    DIRATTR,FF-ATTR1TXT   NO, MULTI-BLOCK TEXT AND NO RLD    10103000
         SPACE 2                                                        10104000
RESTOR76 STM   R14,R12,12(R13)            CONVERT CCHHR TO TTR          10105000
         LA    R2,CURMBB                  CCHHR TO CONVERT              10106000
         L     R1,INDCB+(DCBDEBAD-IHADCB) DEB ADDRESS                   10107000
         L     R15,ADDRRLTV               ADDRESS OF CCHHR->TTR CONVERT 10108000
         LR    R3,R13                     ADDRESS OF SAVE AREA          10109000
         BALR  R14,R15                    CALL CONVERT ROUTINE          10110000
         LR    R13,R3                     RESTORE SAVE AREA ADDRESS     10111000
         ST    R0,12+4+4(R13)             RESULT TTR RETURNED IN R0     10112000
         LM    R14,R12,12(R13)            RESTORE REGISTERS             10113000
         STCM  R0,B'1110',DIRSTART   START OF TEXT                      10114000
         STCM  R5,B'0011',DIRTEXTL   LENGTH OF FIRST TEXT RECORD        10115000
         LA    R6,2(R6,R6)           (#CSECTS+1)*2+2                    10116000
         SRL   R6,2                  ((#CSECTS+1)*2+2)/4                10117000
         SLL   R6,2                  ROUNDED TO NEXT FULLWORD*2         10118000
         STCM  R6,B'0011',DIRSCTL    SAVE LENGTH OF TRANSLATE TABLE     10119000
         SR    R3,R6                                                    10120000
         STCM  R3,B'0011',DIRSCLL    SAVE LENGTH OF SCATTER LIST        10121000
         LA    R2,RESTOR06           WHERE-TO-GO NEXT TIME              10122000
         BR    R2                    SCAN UNTIL END-OF-MEMBER           10123000
         SPACE 1                                                        10124000
RESTOR90 LA    R1,L800                                                  10125000
         OC    DIRSTART(3),DIRSTART     ANY TEXT TTR?                   10126000
         BZ    RESTOR98                 NO, ERROR                       10127000
         SPACE 1                                                        10128000
         LA    R1,L703                                                  10129000
         OC    DIRSTORE(3),DIRSTORE     STORAGE SIZE AVAILABLE?         10130000
         BZ    RESTOR98                 NO, ERROR                       10131000
         SPACE 1                                                        10132000
         CLC   #BLKSI+2(2),=H'1024'     LARGEST BLOCK=1024?             10133000
         BNE   *+8                      NO, PROBABLY NOT DC             10134000
         NI    DIRATTR+1,FF-ATTRNODC    YES, TURN OFF NO DC             10135000
         SPACE 1                                                        10136000
         LA    R2,DIRAPF                APF FLAG                        10137000
         TM    DIRATTR,ATTRSCTR         SCATTER LOADED?                 10138000
         BNO   *+8                      NO, BRANCH                      10139000
         LA    R2,8(,R2)                YES, SKIP OVER SCATTER DATA     10140000
         OC    #RESTSSI,#RESTSSI        ANY SSI DATA?                   10141000
         BZ    RESTOR93                 NO, BRANCH                      10142000
         LA    R2,1(,R2)                PREPARE FOR HALFWORD ROUNDING   10143000
         N     R2,=F'-2'                ROUND TO HALFWORD               10144000
         OI    DIRATTR2,DIR2SSI         SSI DATA IS PRESENT             10145000
         OI    DIRFLAG,X'02'            ADD TWO MORE HALFWORDS          10146000
         MVC   0(4,R2),#RESTSSI         ADD THE SSI DATA                10147000
         LA    R2,4(,R2)                POSITION OVER SSI DATA          10148000
         SPACE 1                                                        10149000
RESTOR93 MVI   0(R2),X'01'              APF LENGTH IS 1                 10150000
         MVC   1(1,R2),#RESTAPF         ADD APF DATA                    10151000
         CLI   #RESTLIK,0               ANY LIKE MEMBER?                10152000
         BH    RESTOR96                 YES, BRANCH (RMODE, AMODE SET)  10153000
         SPACE 1                                                        10154000
         TM    #RESTMOD,RMODEANY        ALL CSECTS RMODE ANY?           10155000
         BNO   *+8                      NO, BRANCH                      10156000
         OI    DIRATTR3,DIRRMANY        YES, SET RMODE ANY              10157000
         TM    #RESTESD,AMODE24         LOW-ORDER BIT ON?          @D02
         BNO   *+8                      NO, BRANCH                 @D02
         OI    DIRATTR3,DIRAM24         YES, SET AMODE 24 ON       @D02
         TM    #RESTESD,AMODE31         HIGH-ORDER BIT ON?         @D02
         BNO   *+8                      NO, BRANCH                 @D02
         OI    DIRATTR3,DIRAM31         YES, SET AMODE 31 ON       @D02
         TM    #RESTESD,AMODE64         AMODE 64 BIT ON?           @D02
         BNO   *+8                      NO, BRANCH                 @D02
         OI    DIRATTR3,DIRAM64         YES, SET AMODE 64 ON       @D02
         SPACE 1                                                        10164000
RESTOR96 BAL   R2,OPENSTOW         OPEN THE STOW DCB; ENQUEUE           10165000
         B     NEWCMD              COULD NOT OPEN -- ERROR              10166000
         MVC   DCBRELAD-IHADCB+STOWDCB(3),DIRTTR  TTR                   10167000
         STOW  STOWDCB,DIRNAME,A   ADD AT THE GIVEN TTR                 10168000
         LR    R5,R15              SAVE RETURN CODE                     10169000
         BAL   R2,SHUTSTOW         CLOSE STOW, RELEASE ENQUEUES         10170000
         SPACE 1                                                        10171000
         B     *+4(R5)             PROCESS RETURN CODE                  10172000
         B     RESTOR97              00 - ADDED CORRECTLY               10173000
         B     MEMEXIST              04 - NAME ALREADY IN THE DIRECTORY 10174000
         EX    0,*                   08 - SHOULD NOT HAPPEN WITH ADD    10175000
         B     FULLDIR               12 - DIRECTORY IS ALREADY FULL     10176000
         B     IOERROR               16 - I/O ERROR IN THE DIRECTORY    10177000
         SPACE 1                                                        10178000
RESTOR97 MVC   INSERT#1(8),DIRNAME   RESTORED MEMBER                    10179000
         TSMSG L091$1                                                   10180000
         SPACE 1                                                        10181000
         AIF ('&CISP' EQ 'NO SPF').MA00700                         @D01
         TM    SPFLAG2,SPFPOST            LINE COMMAND?                 10182000
         BO    RESTOR9D                   YES, BRANCH                   10183000
.MA00700 ANOP  ,                                                   @D01
         SPACE 1                                                        10184000
         MVC   MEMBERD+1(2+8+8+2),LMEMBER1          DEFAULT MEMBER1     10185000
         MVC   MEMBERD+1+2+8(8),LMEMBER1+2          DEFAULT MEMBER2     10186000
         MVC   MEMBERD+1+2+8+8(2),LMEMBER1          DEFAULT LENGTH      10187000
         MVI   MEMBERD,FMEMBER1                     ASSUME ONE MEMBER   10188000
         NI    FLAGSEE,FF-FMEMLIST                  NO MEMBER LIST      10189000
         TM    #RESFLAG,#RESFREP                    REPEAT?             10190000
         BZ    *+8                                  NO, BRANCH          10191000
         OI    MEMBERD,FMEMBER2+FMEMRANG+FMEM#MEM   MEMBER RANGE        10192000
         BAL   R14,DEFGROUP                    ADD DEFAULT GROUP        10193000
         SPACE 2                                                        10194000
RESTOR9D TM    FLAGSCC,RECFMU         LOAD LIBRARY?                     10195000
         BNO   RESTOR99               NO, DONE WITH THIS MEMBER         10196000
         SPACE 1                                                        10197000
         UNPK  INSERT#1(7),DIREPA(4)                                    10198000
         TR    INSERT#1(6),TRTABLE                                      10199000
         MVC   INSERT#1+6(2),BLANKS                                     10200000
         MVC   INSERT#2(8),ENTRYPT    NAME OF THE ENTRY POINT           10201000
         TR    INSERT#2(8),TRLINE     MAKE PRINTABLE                    10202000
         LA    R1,L102$1              ASSUME NONE FOUND                 10203000
         CLI   ENTRYPT,C'?'           ANY FOUND?                        10204000
         BE    *+8                    NO, BRANCH                        10205000
         LA    R1,L103$2              YES, SHOW ENTRY SYMBOL            10206000
         TSMSG (R1)                                                     10207000
         SPACE 1                                                        10208000
         UNPK  INSERT#1(7),DIRSTORE(4)                                  10209000
         TR    INSERT#1(6),TRTABLE                                      10210000
         MVC   INSERT#1+6(2),BLANKS                                     10211000
         ICM   R1,B'0111',DIRSTORE    ACTUAL MODULE LENGTH              10212000
         LA    R1,1023(,R1)           NEXT HIGHER                       10213000
         SRL   R1,10                             1K VALUE               10214000
         CVD   R1,DOUBLE                                                10215000
         MVC   INSERT#2(8),=X'402020202120D2404040'                     10216000
         ED    INSERT#2(6),DOUBLE+5                                     10217000
         TSMSG L104$2                                                   10218000
         B     RESTOR99                                                 10219000
         SPACE 1                                                        10220000
RESTOR98 TSMSG (R1)                                                     10221000
         SPACE 2                                                        10222000
RESTOR99 TM    #RESFLAG,#RESFREP   REPEAT OPTION?                       10223000
         BNO   NEWCMD              NO, DONE                             10224000
         TM    #RESFLAG,#RESFPRO*2+#RESFPRO*4  NOPROMPT OR NO.. GLOBAL? 10225000
         BZ    RESTSC17                        NO, BRANCH               10226000
         TM    #RESFLAG,#RESFPRO   PROMPT OPTION?                       10227000
         BO    RESTSC17            YES, PROCESS THE NEXT DELETED MEMBER 10228000
         MESSAGE MSGBLANK          ONE BLANK LINE                       10229000
         MESSAGE MSGBLANK          ONE BLANK LINE                       10230000
         B     RESTSC17            PROCESS THE NEXT DELETED MEMBER      10231000
         SPACE 2                                                        10232000
#RESFREP EQU     X'01'            RESTORE: REPEAT                       10233000
#RESFDIS EQU     X'02'            RESTORE: DISPLAY                      10234000
#RESFPRO EQU     X'04'            RESTORE: PROMPT                       10235000
         TITLE 'P D S  --  PDS TIME                            1/15/85' 10236000
*********************************************************************** 10237000
***      TIME  SUBCOMMAND                                           *** 10238000
*********************************************************************** 10239000
*                                                                       10240000
         SPACE 1                                                        10241000
TIME     CSECT                                                          10242000
         USING *,R8                                                     10243000
         MVC   MSGTEXT2(132),MSGBL132    BLANK LINE                     10244000
         MVC   MSGTEXT2+4(14),TIMETBL    EDIT MASK                      10245000
         TIME  DEC                                                      10246000
         CL    R0,=XL4'12000000'         MORNING?                       10247000
         BL    *+12                      YES, BRANCH                    10248000
         MVI   MSGTEXT2+14,C'P'          NO, SET TO PM                  10249000
         SL    R0,=XL4'12000000'         NO, SUBTRACT 12 HOURS          10250000
         ST    R0,TIMEWRKW               ADJUSTED TIME                  10251000
         TM    TIMEWRKW,X'08'            ADJUSTMENT ERROR (20 OR 21)?   10252000
         BZ    *+8                       NO, BRANCH                     10253000
         NI    TIMEWRKW,X'09'            YES, CONVERT TO 8 OR 9 (PM)    10254000
         CLI   TIMEWRKW,X'00'            ZERO HOURS?                    10255000
         BNE   *+8                       NO, BRANCH                     10256000
         MVI   TIMEWRKW,X'12'            YES, CONVERT ZERO TO 12        10257000
         ED    MSGTEXT2+4(9),TIMEWRKW    FINISH TIME PROCESSING         10258000
         MVC   MSGTEXT2+34(25),DATEPC    TIME CONSTANT                  10259000
         ST    R1,TIMEWRKW               SAVE 00YYDDDF DATE WORD        10260000
         UNPK  MSGTEXT2+44(5),TIMEWRKW+1(3) MOVE IN "YY"                10261000
         MVC   MSGTEXT2+51(2),MSGTEXT2+44 (YY.                          10262000
         MVC   MSGTEXT2+54(3),MSGTEXT2+46 DDD)                          10263000
         OI    MSGTEXT2+56,X'F0'         FIX THE ZONE                   10264000
         MVC   MSGTEXT2+46(3),=C'   '    BLANK THE NEXT THREE BYTES     10265000
         LH    R1,TIMEWRKW+2                                            10266000
         SRL   R1,12                     D..  (HUNDREDS)                10267000
         M     R0,=F'10'                                                10268000
         IC    R15,TIMEWRKW+2                                           10269000
         N     R15,=F'15'                                               10270000
         AR    R1,R15                    .D.  (TENS)                    10271000
         M     R0,=F'10'                                                10272000
         IC    R15,TIMEWRKW+3                                           10273000
         SRL   R15,4                                                    10274000
         AR    R1,R15                    ..D  (UNITS)                   10275000
         PACK  TIMEDOUB(8),MSGTEXT2+44(2)                               10276000
         CVB   R15,TIMEDOUB              CONVERT YEAR TO BINARY         10277000
         LR    R0,R15                                                   10278000
         N     R15,=X'FFFFFFFC'          YEAR/4*4  (INTEGER DIVISION)   10279000
         CR    R0,R15                    LEAP YEAR?                     10280000
         BE    NOADJUST                  YES, NO ADJUSTMENT NEEDED      10281000
         CH    R1,CUMDAYS+4              BEFORE FEB 30?                 10282000
         BL    NOADJUST                  YES, NO ADJUSTMENT NEEDED      10283000
         AH    R1,=H'1'                  ADD 1 TO THE JULIAN DATE       10284000
NOADJUST SR    R15,R15                                                  10285000
         AH    R15,=H'2'                                                10286000
         CH    R1,CUMDAYS(R15)                                          10287000
         BH    *-8                                                      10288000
         SH    R1,CUMDAYS-2(R15)                                        10289000
         LR    R14,R15                                                  10290000
         SRL   R15,1                     MONTH IN BINARY                10291000
         LA    R14,0(R14,R15)                                           10292000
         LA    R14,MONTHS-3(R14)                                        10293000
         MVC   MSGTEXT2+34(3),0(R14)     MONTH TEXT                     10294000
         AR    R15,R15                                                  10295000
         LA    R15,CONVTBL(R15)                                         10296000
         MVC   TIMEDOUB+4(2),0(R15)      MOVE IN MONTH                  10297000
         LR    R15,R1                    DAY OF MONTH IN BINARY         10298000
         AR    R15,R15                                                  10299000
         LA    R15,CONVTBL(R15)                                         10300000
         MVC   MSGTEXT2+38(2),0(R15)     MOVE IN DAY OF MONTH           10301000
         MVC   TIMEDOUB(4),MSGTEXT2+42   MOVE IN '19XX'                 10302000
         MVC   TIMEDOUB+6(2),MSGTEXT2+38 MOVE IN DAY OF MONTH           10303000
         BAL   R14,WEEKDAY               FIND THE DAY OF WEEK           10304000
         L     R15,TIMEWRKW                                             10305000
         SLL   R15,4                                                    10306000
         SRL   R15,28                                                   10307000
         MH    R15,=H'10'                                               10308000
         LA    R15,DAY@WEEK(R15)                                        10309000
         MVC   MSGTEXT2+22(10),0(R15)                                   10310000
         MVI   MSGTEXT2+1,79                                            10311000
         MESSAGE MSGTEXT2                                               10312000
         B     NEWCMD                                                   10313000
         SPACE 4                                                        10314000
DAY@WEEK DC    CL10'SUNDAY',CL10'MONDAY',CL10'TUESDAY',CL10'WEDNESDAY'  10315000
         DC    CL10'THURSDAY',CL10'FRIDAY',CL10'SATURDAY'               10316000
         SPACE 2                                                        10317000
CONVTBL  DC    CL32' 0 1 2 3 4 5 6 7 8 9101112131415'                   10318000
         DC    CL32'16171819202122232425262728293031'                   10319000
         SPACE 2                                                        10320000
TIMETBL  DC    XL14'4021204B20204B202040C1D44040'                       10321000
         SPACE 2                                                        10322000
DATEPC   DC    CL26'ABC EF, 19GH    (12.456)'                           10323000
         SPACE 2                                                        10324000
CUMDAYS  DC    H'0,31,60,91,121,152,182,213,244,274,305,335,32000'      10325000
         SPACE 2                                                        10326000
MONTHS   DC    CL36'JANFEBMARAPRMAYJUNJULAUGSEPOCTNOVDEC'               10327000
         EJECT                                                          10328000
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 10329000
*                                                                     * 10330000
*     THIS REENTRANT SUBROUTINE DETERMINES THE DAY OF THE             * 10331000
*   WEEK FOR ANY GREGORIAN DATE FROM OCTOBER 15,1582, THROUGH         * 10332000
*   FEBRUARY 28, 4000.                                                * 10333000
*                                                                     * 10334000
*         NOTE:  DATE IS THE ARGUMENT AND DAY IS THE ANSWER.          * 10335000
*           THEY HAVE THE FOLLOWING FORMATS, RESPECTIVELY -           * 10336000
*                                                                     * 10337000
*TIMEDOUB DS   0ZL8     ARGUMENT                                      * 10338000
*TIMEINYR DS   ZL4      YEAR - ANY VALUE 1582-4000                    * 10339000
*TIMEINMT DS   ZL2      MONTH - ANY VALUE 01-12                       * 10340000
*TIMEINDY DS   ZL2      DAY OF MONTH - ANY VALUE 01-31                * 10341000
*TIMEWRKW DS   ZL1      DAY OF WEEK -  0 (SUNDAY) - 6 (SATURDAY)      * 10342000
*                                                                     * 10343000
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 10344000
         SPACE 1                                                        10345000
WEEKDAY  ST    R14,R14SAVE                                              10346000
         XC    TIMEDDAT(8),TIMEDDAT                                     10347000
         PACK  TIMEDECC,TIMEINDY                                        10348000
         CVB   R1,TIMEDDAT                                              10349000
         PACK  TIMEDECM,TIMEINMT                                        10350000
         CVB   R15,TIMEDDAT                                             10351000
         IC    R15,FFTBL-1(R15)      FIND FUDGE FACTOR                  10352000
         AR    R1,R15                   AND APPLY IT TO CORRECTION      10353000
         PACK  TIMEDECC,TIMEINYR                                        10354000
         SP    TIMEDECC,=P'3'        ADJUST YEAR IF JANUARY OR FEBRUARY 10355000
         OI    TIMEYRSG,15           LEGITIMIZE SIGN FOR ZAP            10356000
         ZAP   TIMEDECC,TIMEDECY                                        10357000
         CVB   R15,TIMEDDAT                                             10358000
         SR    R14,R14                                                  10359000
         LA    R0,3                  USED TO FIND CENTURY MOD 4         10360000
         D     R14,=F'100'           FIND CENTURY                       10361000
         NR    R15,R0                CENTURIES MOD 4                    10362000
         NR    R0,R14                THIS MANY COMMON YEARS             10363000
         SRA   R14,2                   AND                              10364000
         AR    R15,R14                   THIS MANY LEAP YEARS           10365000
         MH    R15,=H'5'                                                10366000
         AR    R1,R15                                                   10367000
         AR    R1,R0                                                    10368000
         SR    R1-1,R1-1             PREPARE TO DIVIDE                  10369000
         D     R1-1,=F'7'                                               10370000
         STC   R1-1,TIMEWRKW                                            10371000
         OI    TIMEWRKW,X'F0'        ADD A ZONE FIELD                   10372000
         L     R14,R14SAVE                                              10373000
         BR    R14                   AND RETURN                         10374000
         SPACE 1                                                        10375000
FFTBL    DC    FL1'0,3,2,5,0,3,5,1,4,6,2,4'  FUDGE FACTORS              10376000
         TITLE 'P D S  --  PDS TSO                             1/15/85' 10377000
*********************************************************************** 10378000
***      TSO   SUBCOMMAND      ADDED BY BRUCE LELAND -- AUG., 1982  *** 10379000
*********************************************************************** 10380000
*                                                                       10381000
         SPACE 1                                                        10382000
TSO      CSECT                                                          10383000
         USING *,R8                                                     10384000
         XC    MSGTEXT2(32),MSGTEXT2                                    10385000
TSO000   L     R1,ADDRCBUF                 POINT TO THE COMMAND BUFFER  10386000
         ST    R1,ADDRTEXT                                              10387000
         MVC   MSGTEXT2(4),0(R1)           COMMAND BUFFER LENGTHS       10388000
         LA    R1,PARMLIST                 USE THE SAME PARAMETER LIST  10389000
         L     R15,ADDRSCAN                SCAN START ADDRESS           10390000
         BALR  R14,R15                     INVOKE COMMAND SCAN          10391000
         SPACE 1                                                        10392000
         LA    R5,SCANANSR                       ADDR OF ANSWER AREA    10393000
         TM    CSOAFLG-CSOA(R5),CSOANOC          EMPTY BUFFER?          10394000
         BO    TSO090                            YES, NO TSO COMMAND    10395000
         TM    CSOAFLG-CSOA(R5),CSOAVWP+CSOAVNP  VALID COMMAND?         10396000
         LA    R1,L874                           ASSUME NOT             10397000
         BZ    MSGNEW                            NO, BRANCH             10398000
         L     R2,CSOACNM-CSOA(,R5)              ADDR OF COMMAND NAME   10399000
         LH    R3,CSOALNM-CSOA(,R5)              LENGTH OF NAME         10400000
         BCTR  R3,0                              MACHINE LENGTH         10401000
         SPACE 1                                                        10402000
         MVC   DIRNAME,BLANKS              INITIALIZE WITH BLANKS       10403000
         MVC   DIRNAME(*-*),0(R2)          <<EXECUTED>>                 10404000
         EX    R3,*-6                      MOVE IN THE COMMAND NAME     10405000
         SPACE 1                                                        10406000
         L     R1,ADDRCBUF                 COMMAND BUFFER ADDRESS       10407000
         ST    R1,ADDRTEXT                 COMMAND ADDRESS              10408000
         SPACE 1                                                        10409000
TSO005   CLC   DIRNAME(5),=C'TIME '        TIME REQUEST?                10410000
         BNE   *+10                        NO, BRANCH                   10411000
         MVC   DIRNAME(8),=C'IKJEFT25'     YES, USE IKJEFT25 INSTEAD    10412000
         SPACE 1                                                        10413000
         CLC   DIRNAME(2),=C'H '           HELP REQUEST?                10414000
         BE    TSO010                      YES, BRANCH                  10415000
         CLC   DIRNAME(5),=C'HELP '        HELP REQUEST?                10416000
         BNE   TSO020                      NO, BRANCH                   10417000
TSO010   MVC   DDNAMEH,DDNAME              SAVE ACTUAL DDNAME           10418000
         MVC   DDNAME,SYSHELP              DDNAME TO FREE               10419000
         BAL   R2,DEALLOCZ                 FORCE A FREE OF SYSHELP      10420000
         MVC   DDNAME,DDNAMEH              RESTORE ACTUAL DDNAME        10421000
         SPACE 1                                                        10422000
TSO020   ICM   R15,B'1111',=V(VTSOCMD)     VERIFY THE TSO COMMAND?      10423000
         BZ    TSO024                      NO, BRANCH                   10424000
         OI    FLAGSJJ,FTSOCMD             YES, SET A ESTAE FLAG        10425000
         MVC   MSGTEXT1(16),ADDRTEXT       MOVE ARGUMENT LIST           10426000
         LA    R2,DIRNAME                  COMMAND NAME                 10427000
         ST    R2,MSGTEXT1+16              FOR VERIFICATION ROUTINE     10428000
         OI    MSGTEXT1+16,X'80'           MARK END OF LIST             10429000
         LA    R1,MSGTEXT1                 START OF ARGUMENT LIST       10430000
         BALR  R14,R15                     CALL VERIFICATION ROUTINE    10431000
         NI    FLAGSJJ,FF-FTSOCMD          RESET THE ESTAE FLAG         10432000
         LTR   R15,R15                     AUTHORIZED?                  10433000
         BZ    TSO024                      YES, BRANCH                  10434000
         MVC   INSERT#1(8),DIRNAME         COMMAND NAME                 10435000
         TSMSG L910$1                      NOT AUTHORIZED               10436000
         B     TSO090                      BYPASS THIS COMMAND          10437000
         SPACE 1                                                        10438000
TSO024   L     R4,ADDRECT                  ECT ADDRESS                  10439000
         OI    ECTSWS-ECT(R4),ECTNOPD      ASSUME NO OPERAND            10440000
         TM    CSOAFLG-CSOA(R5),CSOAVWP    ANY OPERAND?                 10441000
         BNO   *+8                         NO, BRANCH                   10442000
         NI    ECTSWS-ECT(R4),FF-ECTNOPD   YES, ZAP THE NO OPERAND FLAG 10443000
         AIF   (&MVT).MA00720                                      @D01
         TM    CSOAFLG-CSOA(R5),CSOAEXEC   IMPLIED CLIST?               10444000
         BO    TSO030                      YES, BRANCH                  10445000
         SPACE 2                                                        10446000
*** MODULE NOT AN IMPLIED CLIST, TRY FOR A LINKLIST LIBRARY             10447000
         BLDL  0,BLDLLIST                  CHECK FOR A LOAD MODULE      10448000
         LTR   R15,R15                     IN THE LINKLIST?             10449000
         BZ    TSO040                      YES, ATTACH IT               10450000
         L     R15,CVTPTR                  NEED TO ALSO CHECK LPALIB    10451000
         L     R15,CVTLPDIA-CVTMAP(R15)    POINT TO LINK PACK DIRECTORY 10452000
         SPACE 2                                                        10453000
*** MODULE NOT IN LINKLIST, TRY THE LPALIB DIRECTORY (IN STORAGE)       10454000
TSO026   CLC   8(8,R15),DIRNAME            THIS MODULE NAME?            10455000
         BE    TSO040                      YES, FOUND                   10456000
         CLI   8(R15),X'FF'                END OF DIRECTORY?            10457000
         LA    R15,40(,R15)                                             10458000
         BNE   TSO026                      NO, BRANCH                   10459000
         SPACE 2                                                        10460000
*** MODULE NOT FOUND ANYWHERE, TRY IT AS AN IMPLIED CLIST               10461000
TSO030   MVC   DIRNAME(8),$EXE+20          INVOKE CLIST PROCESSOR       10462000
         L     R15,ADDRCBUF                COMMAND LINE                 10463000
         MVC   0(4,R15),MSGTEXT2           RESET THE OPERAND OFFSET     10464000
*        NI    ECTSWS-ECT(R4),FF-ECTNOPD   ZAP THE NO OPERAND FLAG      10465000
         SR    R1,R1                                                    10466000
         ICM   R1,B'0011',2(R15)           OFFSET TO OPERAND            10467000
         BZ    TSO040                      NULL RETURN                  10468000
         STCM  R1,B'1100',2(R15)           CLEAR THE OFFSET             10469000
TSO034   LA    R15,1(,R15)                 NEXT BYTE                    10470000
         MVI   3(R15),X'40'                CLEAR THE BYTE               10471000
         BCT   R1,TSO034                   REPEAT FOR ALL CHARACTERS    10472000
         SPACE 1                                                        10473000
         AGO   .NA00720
.MA00720 ANOP  ,                                                   @D01
         SPACE 1                                                   @D01
*        Test if module is in time-sharing LPA                     @D01
         L     R15,CVTPTR          Get CVT address                 @D01
         USING CVT,R15             Addressability for CVT          @D01
         L     R1,CVTTSCVT         Point to TSCVT                  @D01
         USING TSCVT,R1            Addressability for TSCVT        @D01
         L     R1,TSCVTLPA         Point to TSO LPAQ               @D01
         LA    R1,0(,R1)           Clear high order byte           @D01
         DROP  R1                  End TSCVT addressability        @D01
TSO036   DS    0H                  Search TSO LPAQ                 @D01
         LTR   R1,R1               End of TSO LPAQ?                @D01
         BZ    TSO037              Yes, go search system LPAQ      @D01
         CLC   DIRNAME,6(R1)       Is this CDE for our module?     @D01
         BE    TSO040              Yes, found                      @D01
         L     R1,0(,R1)           Else point to next CDE          @D01
         LA    R1,0(,R1)           Clear high order byte           @D01
         B     TSO036              Back to look at next CDE        @D01
*        Test if module is in LPA                                  @D01
         SPACE 1                                                   @D01
         L     R1,CVTQLPAQ         Get address of LPAQ base        @D01
         DROP  R15                 End CVT addressability          @D01
         L     R1,0(,R1)           Point to first CDE              @D01
         LA    R1,0(,R1)           Clear high order byte           @D01
TSO037   DS    0H                  Search LPAQ                     @D01
         LTR   R1,R1               End of LPAQ?                    @D01
         BZ    TSO038              Yes, go search link list        @D01
         CLC   DIRNAME,6(R1)       Is this CDE for our module?     @D01
         BE    TSO040              Yes, found                      @D01
         L     R1,0(,R1)           Else point to next CDE          @D01
         LA    R1,0(,R1)           Clear high order byte           @D01
         B     TSO037              Back to look at it              @D01
         SPACE 1                                                   @D01
*        Not in LPA, search link list                              @D01
         SPACE 1                                                   @D01
TSO038   DS    0H                  Search link list                @D01
         BLDL  0,BLDLLIST          Test if found in link list      @D01
         LTR   R15,R15             Was module found                @D01
         BZ    TSO040              Yes, go attach it               @D01
         SPACE 1                                                   @D01
*        Not found, error                                          @D01
         LH    R15,CSOALNM-CSOA(,R5)                               @D01
*                                  Get command name length         @D01
         STC   R15,MTLEN           Set length for insert           @D01
         MVC   INSERT#1(8),DIRNAME Set command name as insert      @D01
         TSMSG L911$1              Say "command not found"         @D01
         MVI   MTLEN,8             Restore standard insert length  @D01
         B     NEWSTAX             Continue                        @D01
.NA00720 ANOP  ,                                                   @D01
*** MODULE WAS FOUND, WE CAN ATTACH IT DIRECTLY                         10474000
TSO040   MVC   ECTPCMD-ECT(8,R4),DIRNAME   COMMAND NAME                 10475000
         MVC   ECTSCMD-ECT(8,R4),BLANKS    NO SUBCOMMAND                10476000
         SPACE 1                                                        10477000
         CLI   ##SUBCAL,X'40'              TSOEXEC-TYPE PROCESSOR?      10478000
         BE    TSO050                      NO, BRANCH                   10479000
         CLC   ECTPCMD-ECT(8,R4),$EXE+20   CLIST PROCESSOR?             10480000
         BE    TSO050                      YES, BRANCH                  10481000
         LA    R3,##SUBCAL                 PDS EXTERNAL SUBCOMMAND      10482000
         NI    ECTSWS-ECT(R4),FF-ECTNOPD   ZAP THE NO OPERAND FLAG      10483000
         MVC   ECTPCMD-ECT(8,R4),##SUBCAL  COMMAND NAME IS TSOEXEC      10484000
         L     R15,ADDRCBUF                COMMAND BUFFER ADDRESS       10485000
         MVC   0(4,R15),MSGTEXT2           RESTORE THE COMMAND OFFSETS  10486000
         MVC   DIRNAME(8),##SUBCAL         INVOKE TSOEXEC AXC           10486010
         SPACE 1                                                        10487000
TSO050   L     R1,ADDRTEXT                 CPPL START                   10488000
*        MESSAGE (R1)                      DELETE * FOR OUTPUT          10489000
         LA    R1,ADDRTEXT                 CPPL START                   10490000
         MVI   ATTNECB,0                   CLEAR ATTENTION ECB          10491000
         LA    R3,DIRNAME                  PDS EXTERNAL SUBCOMMAND      10492000
         BAL   R2,ATTACH                   GO ATTACH IT                 10493000
         SPACE 1                                                        10494000
TSO090   ICM   R1,B'1111',MSGTEXT2+4+4     ANY GETLINE BUFFER?          10495000
         BZ    TSO092                      NO, BRANCH                   10496000
         LH    R0,0(,R1)                   LENGTH                       10497000
         ICM   R0,B'1000',=X'01'           SUBPOOL 1                    10498000
         FREEMAIN R,LV=(0),A=(1)                                        10499000
         SPACE 1                                                        10500000
TSO092   L     R4,ADDRECT                                               10501000
         L     R1,ECTIOWA-ECT(R4)          --> I/O WORK AREA            10502000
         L     R1,0(,R1)                   --> ELEMENT ON STACK         10503000
         TM    0(R1),X'40'                 FROM CLIST?                  10504000
         BZ    NEWSTAX                     NO, BRANCH                   10505000
         CLM   R1,B'0111',PARMSTAK+1       SAME AS ORIGINAL STACK? @D01
         BE    NEWSTAX                     YES, EXIT               @D01
         SPACE 1                                                        10506000
         LA    R1,MSGTEXT2+12              I/O PARM LIST OFR GETLINE    10507000
         L     R2,ADDRUPT                  UPT FOR GETLINE              10508000
         L     R3,ADDRECT                  ECT FOR GETLINE              10509000
         L     R4,MSGTEXT2+12+16           ECB FOR GETLINE              10510000
         L     R15,ADDRGETL                ADDRESS OF GETLINE           10511000
         MVC   MSGTEXT2+4(TSO099),TSO098   INITIALIZE GETLINE PARMS     10512000
         GETLINE PARM=MSGTEXT2+4,UPT=(R2),ECT=(R3),ECB=(R4),          XX10513000
               ENTRY=(15),MF=(E,(1))                                    10514000
         CH    R15,=H'16'                  END OF INPUT?                10515000
         BE    NEWSTAX                     YES, BRANCH                  10516000
         L     R1,MSGTEXT2+4+4             NEXT COMMAND                 10517000
         ST    R1,ADDRCBUF                                              10518000
         SPACE 2                                                        10519000
         LA    R15,PARMLIST                                             10520000
         USING CSPL,R15                                                 10521000
         SPACE 1                                                        10522000
         L     R1,ADDRUPT              ADDRESS OF THE UPT               10523000
         L     R2,ADDRECT              ADDRESS OF THE ECT               10524000
         LA    R3,ATTNECB              ADDRESS OF THE ATTENTION ECB     10525000
         LA    R4,ZERO                 ADDRESS OF A ZERO FLAG AREA      10526000
         LA    R5,SCANANSR             ADDRESS OF THE RESULT AREA       10527000
         L     R6,ADDRCBUF             ADDRESS OF THE SUBCOMMAND        10528000
         STM   R1,R6,CSPLUPT           SETUP CSPLUPT, CSPLECT, CSPLECB, 10529000
         DROP  R15                           CSPLFLG, CSPLOA & CSPLCBUF 10530000
         B     TSO000                                                   10531000
         SPACE 1                                                        10532000
         AGO   .MA00740                                            @D01
TSO096   LOAD  EPLOC=$TSO,SF=L                                          10533000
TSO097   EQU   *-TSO096                                                 10534000
.MA00740 ANOP  ,                                                   @D01
TSO098   GETLINE MF=L                                                   10535000
TSO099   EQU   *-TSO098                                                 10536000
* MSGTEXT2+00,4   COMMAND BUFFER START HALFWORDS                        10537000
* MSGTEXT2+04,8   GETLINE I/O AREA                                      10538000
* MSGTEXT2+12,16  GETLINE I/O PARM LIST                                 10539000
* MSGTEXT2+28,4   GETLINE ECB                                           10540000
         TITLE 'P D S  --  PDS TSOEDIT AND FSE                 1/15/85' 10541000
*********************************************************************** 10542000
***      TSOEDIT AND FSE SUBCOMMANDS                                *** 10543000
*********************************************************************** 10544000
*                                                                       10545000
         SPACE 1                                                        10546000
TSOEDIT  CSECT                                                          10547000
         USING *,R8                                                     10548000
         MVC   DSNMEMQ(8),DIRNAME       MEMBER NAME TO CHECK            10549000
         BAL   R2,ENQMTEST              MEMBER IN USE?                  10550000
         NOP   0                        IF YES, OUTPUT A WARNING ONLY   10551000
         CLI   #EDITOLD,X'01'           "NEW" SPECIFIED?                10552000
         BNE   TSOED5                   NO, BRANCH                      10553000
         TM    DSORG,DS1DSGPO           NON-PARTITIONED DATA SET?       10554000
         BZ    TSOED5                   YES, BRANCH                     10555000
         BLDL  INDCB,BLDLLIST           INSURE IT DOES NOT EXIST        10556000
         SPACE 1                                                        10557000
         B     *+4(R15)                 PROCESS RETURN CODE             10558000
         B     MEMEXIST                   00 - MEMBER IS NOT NEW        10559000
         B     TSOED5                     04 - MEMBER DOES NOT EXIST    10560000
         B     IOERROR                    08 - I/O ERROR IN DIRECTORY   10561000
         SPACE 1                                                        10562000
TSOED5   MVC   MSGTEXT2+4(8),##SUBCOM   MOVE IN "EDIT" OR "FSE"         10563000
         MVI   MSGTEXT2+12,C''''        ADD A QUOTE                     10564000
         MVC   MSGTEXT2+13(44),DSNAME   ADD THE DATA SET NAME           10565000
         LH    R15,DSNLEN               DSNAME ACTUAL LENGTH            10566000
         LA    R3,MSGTEXT2+12(R15)      POINTER TO CURRENT BYTE         10567000
         MVI   1(R3),C'('               MEMBER NAME PAREN               10568000
         SR    R5,R5                    LENGTH OF LAST QUALIFIER        10569000
         LR    R14,R3                   BACKWARD SCAN POINTER           10570000
         SPACE 1                                                        10571000
TSOED6   BCTR  R14,0                    SCAN                            10572000
         LA    R5,1(,R5)                    TO                          10573000
         CLI   0(R14),C'.'                    PREVIOUS                  10574000
         BNE   TSOED6                                 PERIOD            10575000
         MVC   MSGTEXT1+4(9),1(R14)                                     10576000
         TM    DSORG,DS1DSGPO           NON-PARTITIONED DATA SET?       10577000
         BZ    TSOED8                   YES, BRANCH                     10578000
         MVC   2(8,R3),DIRNAME          MEMBER NAME                     10579000
         LA    R3,2+8(,R3)              END OF MEMBER +1                10580000
         LA    R1,8                     MAXIMUM MACHINE LENGTH+1        10581000
         SPACE 1                                                        10582000
TSOED7   BCTR  R3,0                     SCAN                            10583000
         CLI   0(R3),X'40'                  BACKWARDS                   10584000
         BNE   *+8                                   FOR FIRST          10585000
         BCT   R1,TSOED7                                      NON-BLANK 10586000
         SPACE 1                                                        10587000
         BCTR  R1,0                     MACHINE LENGTH                  10588000
         TRT   DIRNAME(*-*),TRTMEM      <<EXECUTED>>                    10589000
         EX    R1,*-6                   VALID MEMBER NAME?              10590000
         BNZ   BADMEMB                  NO, ERROR                       10591000
         CLI   DIRNAME,C'0'             VALID FIRST CHARACTER?          10592000
         BNL   BADMEMB                  NO, BRANCH                      10593000
         LA    R3,1(,R3)                POINT TO TERMINATOR             10594000
         MVI   0(R3),C')'               ADD A CLOSING PARENTHESIS       10595000
         SPACE 1                                                        10596000
TSOED8   MVI   1(R3),C''''              ADD A QUOTE                     10597000
         MVI   2(R3),X'40'              ADD A BLANK                     10598000
         LA    R3,3(,R3)                                                10599000
         CLI   #EDITNON,1               NONUM CODED?                    10600000
         BNE   TSOED9                   NO, BRANCH                      10601000
         SPACE 2                                                        10602000
         MVC   0(6,R3),=C'NONUM '       YES                             10603000
         LA    R3,6(,R3)                                                10604000
TSOED9   CLI   #EDITOLD,1               "NEW" SPECIFIED?                10605000
         BNE   TSOED10                  NO, BRANCH                      10606000
         MVC   0(4,R3),=C'NEW '         YES                             10607000
         LA    R3,4(,R3)                                                10608000
TSOED10  CLI   #EDITASI,1               ASIS CODED?                     10609000
         BNE   TSOED11                  NO, BRANCH                      10610000
         MVC   0(5,R3),=C'ASIS '        YES                             10611000
         LA    R3,5(,R3)                                                10612000
TSOED11  ICM   R15,B'1111',#EDITTYP     ANY DATA TYPE CODED?            10613000
         BZ    TSOED13                  NO, BRANCH                      10614000
         MH    R15,=H'7'                INDEX  =  OPTIONUM * 7          10615000
         LA    R15,EDITTYPE-7(R15)      POINT TO THE PROPER OPTION      10616000
         B     TSOED20                  DONE WITH FORMATTING            10617000
         SPACE 1                                                        10618000
TSOED13  BCTR  R5,0                     MACHINE QUALIFIER LENGTH        10619000
         LA    R15,EDITTYPE-7                                           10620000
TSOED15  LA    R15,7(,R15)              TABLE WIDTH IS 7                10621000
         CLC   PLIF,0(R15)              END OF DESCRIPTIVE QUALIFIERS?  10622000
         BE    TSOED17                  YES, USE "DATA" OR "GOFORT"     10623000
         CLC   0(*-*,R15),MSGTEXT1+4    <<EXECUTED>>                    10624000
         EX    R5,*-6                   THIS QUALIFIER?                 10625000
         BNE   TSOED15                  NO, TRY THE NEXT ONE            10626000
         B     TSOED20                  YES, USE THIS QUALIFIER         10627000
         SPACE 1                                                        10628000
TSOED17  LA    R15,EDITTYPE             NOT FOUND, ASSUME "DATA"        10629000
         CLC   =C'FORT(',MSGTEXT1+4     FORT QUALIFIER?                 10630000
         BNE   TSOED20                                                  10631000
         LA    R15,GOFORT               YES, USE "GOFORT" (EDIT RULES)  10632000
         SPACE 1                                                        10633000
TSOED20  MVC   0(7,R3),0(R15)           MOVE IN DATA TYPE               10634000
         LA    R1,MSGTEXT2                                              10635000
         ST    R1,ADDRTEXT              COMMAND ADDRESS                 10636000
         LA    R3,7(,R3)                                                10637000
         SR    R3,R1                    COMMAND LENGTH                  10638000
         SLL   R3,16                                                    10639000
         ST    R3,MSGTEXT2              SAVE LENGTH OF STRING           10640000
*        MESSAGE MSGTEXT2               DELETE * TO OUTPUT THE COMMAND  10641000
         MVI   MSGTEXT2+3,8             OPERAND OFFSET                  10642000
         BAL   R2,CLOSEIT               NEED TO CLOSE BEFORE THE EDIT   10643000
         MVI   VOLALLOC,X'40'           READ THE DSCB AGAIN             10644000
         LA    R0,RESTART4              ABEND RECOVERY ADDRESS          10645000
         ST    R0,RECOVER                                               10646000
         SPACE 1                                                        10647000
         L     R4,ADDRECT                                               10648000
         MVC   ECTPCMD-ECT(8,R4),##SUBCAL      COMMAND IS EDIT OR FSE   10649000
         NI    ECTSWS-ECT(R4),FF-ECTNOPD       WE ALWAYS HAVE OPERANDS  10650000
         LA    R1,ADDRTEXT                     THE CPPL FOR EDIT/FSE    10651000
         LA    R3,##SUBCAL                     TSO EDIT/FSE COMMAND     10652000
         BAL   R2,ATTACH2                      GO ATTACH IT             10653000
         MVI   VOLALLOC,X'40'           READ THE DSCB AGAIN             10654000
         SPACE 1                                                        10655000
         MVI   ##ADRCM#,EDITOR          NO REPEATED WARNING MESSAGE     10656000
**       L     R1,X'21C'                --> CURRENT TCB            @D01 10657000
         L     R1,16               Get address of CVT              @D01
         L     R1,0(,R1)           Point to TCB words              @D01
         L     R1,4(,R1)           Point to our TCB                @D01
         L     R1,X'00C'(,R1)           --> TIOT                        10658000
         LA    R1,24(,R1)               TIOENTRY                        10659000
TSOED97  CLI   0(R1),0                  END OF TIOT?                    10660000
         BE    RESTART0                 YES, REALLOCATE AND OPEN AGAIN  10661000
         CLC   4(8,R1),DDNAME           THIS DDNAME?                    10662000
         BE    RESTART4                 YES, JUST OPEN AGAIN            10663000
         SR    R15,R15                                                  10664000
         IC    R15,0(,R1)                                               10665000
         LA    R1,0(R15,R1)                                             10666000
         B     TSOED97                                                  10667000
         TITLE 'P D S  --  PDS USAGE                           1/15/85' 10668000
*********************************************************************** 10669000
***      USAGE SUBCOMMAND                                           *** 10670000
*********************************************************************** 10671000
*                                                                       10672000
         SPACE 1                                                        10673000
USAGE    CSECT                                                          10674000
         USING *,R8                                                     10675000
         L     R15,$DSN+8                                               10676000
         BALR  R2,R15                   FORMAT THE ALLOCATION STATUS    10677000
         SPACE 1                                                        10678000
         MVC   INSERT#1(66),MSG180H                                     10679000
         MVI   MTHIGHL,56                                               10680000
         CLI   DS1SYSCD+8,X'FF'        ASM2 IDENTIFIER?                 10681000
         BNE   *+8                     NO, BRANCH                       10682000
         MVI   MTHIGHL,66              YES, USE 66 CHARACTERS           10683000
         TSMSG L180$1                                                   10684000
         MVC   INSERT#1(66),MSGBL132+4                                  10685000
         SR    R15,R15                                                  10686000
         MVC   INSERT#1+10(7),=C'0/00/00'                               10687000
         ICM   R15,B'0111',DS1CREDT    DATA SET CREATION DATE NULL?     10688000
         BZ    US070                   YES, BRANCH                      10689000
         ST    R15,MSGTEXT1            SAVE FOR LATER                   10690000
         SRL   R15,16                  YEAR ONLY                        10691000
         MH    R15,=H'1000'            SHIFT FOR THE ADDITION           10692000
         AH    R15,MSGTEXT1+2          RESET DAYS                       10693000
         CVD   R15,MSGTEXT1            STORE AS 00000000 00YYDDDF       10694000
         LA    R1,MSGTEXT1+5           POINT TO YYDDDF                  10695000
         LA    R15,MSGTEXT1            WHERE RESULT GOES                10696000
         BAL   R14,CONVDATE            CONVERT TO MM/DD/YY              10697000
         MVC   INSERT#1+08(9),=X'402021612020612020'                    10698000
         ED    INSERT#1+08(9),MSGTEXT1                                  10699000
         SPACE 1                                                        10700000
US070    SR    R15,R15                                                  10701000
         MVC   INSERT#1+19(7),=C'0/00/00'                               10702000
         ICM   R15,B'0111',DS1EXPDT    DATA SET EXPIRATION DATE NULL?   10703000
         BZ    US080                   YES, BRANCH                      10704000
         ST    R15,MSGTEXT1            SAVE FOR LATER                   10705000
         SRL   R15,16                  YEAR ONLY                        10706000
         MH    R15,=H'1000'            SHIFT FOR THE ADDITION           10707000
         AH    R15,MSGTEXT1+2          RESET DAYS                       10708000
         CVD   R15,MSGTEXT1            STORE AS 00000000 00YYDDDF       10709000
         LA    R1,MSGTEXT1+5           POINT TO YYDDDF                  10710000
         LA    R15,MSGTEXT1            WHERE RESULT GOES                10711000
         BAL   R14,CONVDATE            CONVERT TO MM/DD/YY              10712000
         MVC   INSERT#1+17(9),=X'402021612020612020'                    10713000
         ED    INSERT#1+17(9),MSGTEXT1                                  10714000
         SPACE 1                                                        10715000
US080    SR    R15,R15                                                  10716000
         MVC   INSERT#1+29(7),=C'0/00/00'                               10717000
         ICM   R15,B'0111',DS1REFD     LAST OPEN DATE NULL?             10718000
         BZ    US090                   YES, BRANCH                      10719000
         ST    R15,MSGTEXT1            SAVE FOR LATER                   10720000
         SRL   R15,16                  YEAR ONLY                        10721000
         MH    R15,=H'1000'            SHIFT FOR THE ADDITION           10722000
         AH    R15,MSGTEXT1+2          RESET DAYS                       10723000
         CVD   R15,MSGTEXT1            STORE AS 00000000 00YYDDDF       10724000
         LA    R1,MSGTEXT1+5           POINT TO YYDDDF                  10725000
         LA    R15,MSGTEXT1            WHERE RESULT GOES                10726000
         BAL   R14,CONVDATE            CONVERT TO MM/DD/YY              10727000
         MVC   INSERT#1+27(9),=X'402021612020612020'                    10728000
         ED    INSERT#1+27(9),MSGTEXT1                                  10729000
         SPACE 1                                                        10730000
US090    MVC   INSERT#1+38(3),=C'YES'  ASSUME UPDATED                   10731000
         TM    DS1DSIND,DS1DSCHA       CORRECT?                         10732000
         BO    *+10                    YES, BRANCH                      10733000
         MVC   INSERT#1+38(3),=C'NO '  NO, RESET THE DATA               10734000
         SPACE 1                                                        10735000
         MVC   INSERT#1+47(4),=C'NONE' ASSUME NO SECURITY               10736000
         TM    DS1DSIND,X'40'+X'10'+X'04'  CORRECT?                     10737000
         BZ    US100                   YES, BRANCH                      10738000
         MVC   INSERT#1+47(4),=C'RACF' ASSUME RACF DEFINED              10739000
         TM    DS1DSIND,X'40'          CORRECT?                         10740000
         BO    US100                   YES, BRANCH                      10741000
         MVC   INSERT#1+47(4),=C'READ' ASSUME READ PROTECTED            10742000
         TM    DS1DSIND,X'10'+X'04'    CORRECT?                         10743000
         BM    US100                   YES, BRANCH                      10744000
         MVC   INSERT#1+47(5),=C'WRITE'  MUST BE WRITE PROTECTED        10745000
         SPACE 1                                                        10746000
US100    MVC   INSERT#1+57(8),DS1SYSCD USERID IF ANY                    10747000
         SPACE 1                                                        10748000
         TSMSG L180$1                                                   10749000
         MESSAGE MSGBLANK                                               10750000
         SPACE 2                                                        10751000
         L     R1,DCBDEBAD-IHADCB+INDCB GET DEB ADDRESS                 10752000
         LH    R14,NUMEXT               NUMBER OF EXTENTS               10753000
         SR    R0,R0                                                    10754000
         SPACE 1                                                        10755000
USEXTNT  AH    R0,32+14(,R1)            ADD NUMBER OF TRACKS IN EXTENT  10756000
         LA    R1,16(,R1)               NEXT EXTENT                     10757000
         BCT   R14,USEXTNT              IF MORE EXTENTS                 10758000
         STH   R0,DSNTOTAL              SAVE TOTAL D.S. SIZE IN TRACKS  10759000
         LH    R1,DS1LSTAR              GET TT OF LAST TRACK            10760000
         CLC   DS1LSTAR(3),ZERO         ANY ALLOCATION?                 10761000
         BE    *+8                      NO, BRANCH                      10762000
         LA    R1,1(,R1)                JUMP FOR COMPUTATION            10763000
         SR    R0,R1                                                    10764000
         STH   R0,DSNEMPTY              TOTAL FREE SPACE                10765000
         SPACE 2                                                        10766000
         MVC   INSERT#1(120),MSGBL132+4                                 10767000
         MVI   MTHIGHL,120                                              10768000
         L     R4,DCBDEBAD-IHADCB+INDCB GET DEB ADDRESS                 10769000
         LH    R3,NUMEXT               NUMBER OF EXTENTS                10770000
         LA    R2,INSERT#1-2           POSITION FOR FIRST DATA          10771000
         SPACE 1                                                        10772000
US120    LH    R1,32+14(,R4)           TRACKS IN THIS EXTENT            10773000
         CVD   R1,DOUBLE                                                10774000
         MVC   MSGTEXT1(6),=X'402020202120'                             10775000
         ED    MSGTEXT1(6),DOUBLE+5                                     10776000
         LA    R1,MSGTEXT1-1                                            10777000
         LA    R5,6                                                     10778000
         SPACE 1                                                        10779000
US130    LA    R1,1(,R1)               SCAN                             10780000
         BCTR  R5,0                        FOR                          10781000
         CLI   0(R1),X'40'                    FIRST                     10782000
         BE    US130                               NON-BLANK            10783000
         SPACE 1                                                        10784000
         MVI   0(R2),C','                                               10785000
         MVC   2(*-*,R2),0(R1)        <<EXECUTED>>                      10786000
         EX    R5,*-6                 MOVE IN THE LENGTH TEXT           10787000
         LA    R2,2+1(R2,R5)          POSITION FOR NEXT COMMA           10788000
         LA    R4,16(,R4)             NEXT EXTENT START                 10789000
         BCT   R3,US120               DO ALL EXTENTS                    10790000
         SPACE 1                                                        10791000
         TSMSG L181$1                                                   10792000
         MESSAGE MSGBLANK                                               10793000
         SPACE 2                                                        10794000
US200    MVI   MTHIGHL,38                                               10795000
         MVC   INSERT#1(38),MSG182H                                     10796000
         TSMSG L182$1                                                   10797000
         MVC   INSERT#1(38),MSG182E                                     10798000
         SPACE 2                                                        10799000
         LH    R1,DSNTOTAL            TOTAL DATA SET TRACKS             10800000
         CVD   R1,DOUBLE                                                10801000
         ED    INSERT#1+11(6),DOUBLE+5                                  10802000
         SPACE 1                                                        10803000
         LH    R1,DSNTOTAL            TOTAL DATA SET TRACKS             10804000
         SH    R1,DSNEMPTY            TOTAL DATA SET USED TRACKS        10805000
         CVD   R1,DOUBLE                                                10806000
         ED    INSERT#1+17(6),DOUBLE+5                                  10807000
         SPACE 1                                                        10808000
         LH    R1,DSNEMPTY            TOTAL DATA SET FREE TRACKS        10809000
         CVD   R1,DOUBLE                                                10810000
         ED    INSERT#1+23(6),DOUBLE+5                                  10811000
         SPACE 1                                                        10812000
         LH    R1,NUMEXT              TOTAL DATA SET EXTENTS            10813000
         CVD   R1,DOUBLE                                                10814000
         ED    INSERT#1+34(4),DOUBLE+6                                  10815000
         SPACE 1                                                        10816000
         TSMSG L182$1                                                   10817000
         MESSAGE MSGBLANK                                               10818000
         SPACE 2                                                        10819000
         TM    DSORG,DS1DSGPO         DSORG=PO?                         10820000
         BNO   US300                  NO, BRANCH                        10821000
         MVI   STARTTR+2,X'01'        TTR=000001 (START OF DIRECTORY)   10822000
         SPACE 1                                                        10823000
         BAL   R14,READDIR            SCAN THROUGH THE DIRECTORY        10824000
         SPACE 1                                                        10825000
         MVI   MTHIGHL,60                                               10826000
         MVC   INSERT#1(60),MSG183H                                     10827000
         TSMSG L183$1                                                   10828000
         MVC   INSERT#1(60),MSG183E                                     10829000
         SPACE 1                                                        10830000
         LH    R1,TOTBLOCK            TOTAL DIRECTORY BLOCKS            10831000
         CVD   R1,DOUBLE                                                10832000
         ED    INSERT#1+11(6),DOUBLE+5                                  10833000
         SPACE 1                                                        10834000
         LH    R1,TOTUSED             TOTAL USED DIRECTORY BLOCKS       10835000
         CVD   R1,DOUBLE                                                10836000
         ED    INSERT#1+17(6),DOUBLE+5                                  10837000
         SPACE 1                                                        10838000
         LH    R1,TOTBLOCK            TOTAL DIRECTORY BLOCKS            10839000
         SH    R1,TOTUSED             TOTAL FREE DIRECTORY BLOCKS       10840000
         CVD   R1,DOUBLE                                                10841000
         ED    INSERT#1+23(6),DOUBLE+5                                  10842000
         SPACE 1                                                        10843000
         LH    R1,TOTTRKS             TOTAL TRACKS FOR DIRECTORY BLOCKS 10844000
         CVD   R1,DOUBLE                                                10845000
         ED    INSERT#1+31(6),DOUBLE+5                                  10846000
         SPACE 1                                                        10847000
         LH    R1,TOTMEMR             TOTAL REAL ENTRIES                10848000
         AH    R1,TOTMEMA             TOTAL ALIAS ENTRIES               10849000
         CVD   R1,DOUBLE                                                10850000
         ED    INSERT#1+40(6),DOUBLE+5                                  10851000
         SPACE 1                                                        10852000
         LH    R1,TOTMEMA             TOTAL ALIAS ENTRIES               10853000
         CVD   R1,DOUBLE                                                10854000
         ED    INSERT#1+49(6),DOUBLE+5                                  10855000
         SPACE 1                                                        10856000
         TSMSG L183$1                                                   10857000
         MESSAGE MSGBLANK                                               10858000
         SPACE 2                                                        10859000
US300    TM    FLAGSAA,FOPTIONS       ANY OPTION?                       10860000
         BNO   NEWCMD                 NO, BRANCH                        10861000
         MVI   MTHIGHL,70                                               10862000
         MVC   INSERT#1(70),MSG184H                                     10863000
         TSMSG L184$1                                                   10864000
         MVC   INSERT#1(70),MSG184U                                     10865000
         TSMSG L184$1                                                   10866000
         MVC   INSERT#1(70),MSGBL132+4                                  10867000
         L     R2,DCBDEBAD-IHADCB+INDCB GET DEB ADDRESS                 10868000
         LH    R3,NUMEXT                                                10869000
         SR    R4,R4                  EXTENT NUMBER                     10870000
         SR    R5,R5                  BEGINNING TT OF TTR               10871000
         SPACE 1                                                        10872000
US310    CVD   R4,DOUBLE              EXTENT                            10873000
         A     R4,=F'1'                                                 10874000
         MVC   INSERT#1+2(4),=X'40202120'                               10875000
         ED    INSERT#1+2(4),DOUBLE+6                                   10876000
         L     R1,32(,R2)             UCB ADDRESS                       10877000
         MVC   INSERT#1+8(3),13(R1)                                     10878000
         LH    R6,32+14(,R2)          TRACKS IN THIS EXTENT             10879000
         LR    R0,R5                                                    10880000
         AR    R5,R6                  START OF NEXT EXTENT              10881000
         LA    R15,2                  LOOPS                             10882000
         LA    R14,INSERT#1+16                                          10883000
         SPACE 1                                                        10884000
US320    SRDL  R0,4                   TT OF TTR                         10885000
         SRL   R1,28                  LOW REGISTER POSITION             10886000
         MVI   2(R14),C'.'                                              10887000
         IC    R1,HEXTBL(R1)                                            10888000
         STC   R1,1(,R14)                                               10889000
         SRDL  R0,4                                                     10890000
         SRL   R1,28                                                    10891000
         IC    R1,HEXTBL(R1)                                            10892000
         STC   R1,0(,R14)                                               10893000
         SH    R14,=H'3'                                                10894000
         BCT   R15,US320                                                10895000
         SPACE 1                                                        10896000
         CLI   INSERT#1+24,C'.'       SECOND TTR VALUE?                 10897000
         BE    US330                  YES, BRANCH                       10898000
         LA    R14,INSERT#1+22                                          10899000
         LA    R15,2                                                    10900000
         LTR   R0,R5                  ANY DATA?                         10901000
         BZ    US320                  NO, BRANCH                        10902000
         BCTR  R0,0                   YES, REDUCE BY ONE                10903000
         B     US320                                                    10904000
         SPACE 1                                                        10905000
US330    MVI   INSERT#1+18,X'40'      CLEAR FIRST EXTRA PERIOD          10906000
         MVI   INSERT#1+24,X'40'      CLEAR SECOND EXTRA PERIOD         10907000
         CVD   R6,DOUBLE              TRACKS                            10908000
         MVC   INSERT#1+26(6),=X'402020202120'                          10909000
         ED    INSERT#1+26(6),DOUBLE+5                                  10910000
         SPACE 2                                                        10911000
         ICM   R0,B'1111',38(R2)      FIRST DEVICE CC.CC.HH.HH          10912000
         LA    R15,4                  LOOPS                             10913000
         LA    R14,INSERT#1+43                                          10914000
         SPACE 1                                                        10915000
US420    SRDL  R0,4                   TT OF TTR                         10916000
         SRL   R1,28                  LOW REGISTER POSITION             10917000
         MVI   2(R14),C'.'                                              10918000
         IC    R1,HEXTBL(R1)                                            10919000
         STC   R1,1(,R14)                                               10920000
         SRDL  R0,4                                                     10921000
         SRL   R1,28                                                    10922000
         IC    R1,HEXTBL(R1)                                            10923000
         STC   R1,0(,R14)                                               10924000
         SH    R14,=H'3'                                                10925000
         BCT   R15,US420                                                10926000
         SPACE 1                                                        10927000
         CLI   INSERT#1+57,C'.'       SECOND TTR VALUE?                 10928000
         BE    US430                  YES, BRANCH                       10929000
         LA    R14,INSERT#1+55                                          10930000
         ICM   R0,B'1111',42(R2)      SECOND CC.CC.HH.HH FIGURE         10931000
         LA    R15,4                                                    10932000
         B     US420                                                    10933000
         SPACE 1                                                        10934000
US430    MVI   INSERT#1+45,X'40'                                        10935000
         MVI   INSERT#1+57,X'40'                                        10936000
         MVC   INSERT#1+59(3),=C'CYL' ASSUME CYLINDER BOUNDARY          10937000
         CLC   40(2,R2),ZERO          FIRST HH.HH=0?                    10938000
         BE    *+10                   YES, BRANCH                       10939000
         MVC   INSERT#1+59(3),=C'TRK' NO, TRACK BOUNDARY                10940000
         LH    R1,44(,R2)                                               10941000
         LA    R1,1(,R1)                                                10942000
         CH    R1,DEVTTRKS            END HH.HH=MAX/DEVICE              10943000
         BE    *+10                   YES, BRANCH                       10944000
         MVC   INSERT#1+59(3),=C'TRK' NO, TRACK BOUNDARY                10945000
         SPACE 1                                                        10946000
         TSMSG L184$1                                                   10947000
         LA    R2,16(,R2)             NEXT EXTENT                       10948000
         BCT   R3,US310               DO ALL EXTENTS                    10949000
         SPACE 2                                                        10950000
         MESSAGE MSGBLANK                                               10951000
         B     NEWCMD                                                   10952000
         SPACE 3                                                        10953000
MSG180H  DC    CL66'DATA SET: CREATED  EXPIRES  LAST USE  UPDATED  SECUX10954000
               RITY  ASM2ID'                                            10955000
MSG182H  DC    CL38'TRACKS: ALLOCATED  USED  FREE  EXTENTS'             10956000
MSG182E  DC    CL38'                                      '             10957000
         ORG   MSG182E+11                                               10958000
         DC    X'402020202120'                                          10959000
         ORG   MSG182E+17                                               10960000
         DC    X'402020202120'                                          10961000
         ORG   MSG182E+23                                               10962000
         DC    X'402020202120'                                          10963000
         ORG   MSG182E+34                                               10964000
         DC    X'40202120'                                              10965000
         ORG   ,                                                        10966000
MSG183H  DC    CL60'DIRECTORY: BLOCKS  USED  FREE  TRACKS  MEMBERS  ALIX10967000
               ASES'                                                    10968000
MSG183E  DC    CL60'                                            '       10969000
         ORG   MSG183E+11                                               10970000
         DC    X'402020202120'                                          10971000
         ORG   MSG183E+17                                               10972000
         DC    X'402020202120'                                          10973000
         ORG   MSG183E+23                                               10974000
         DC    X'402020202120'                                          10975000
         ORG   MSG183E+31                                               10976000
         DC    X'402020202120'                                          10977000
         ORG   MSG183E+40                                               10978000
         DC    X'402020202120'                                          10979000
         ORG   MSG183E+49                                               10980000
         DC    X'402020202120'                                          10981000
         ORG   ,                                                        10982000
MSG184H  DC    CL70'EXTENT  UCB  LO TT-HI TT  TRACKS     LOW CCHH-HIGH X10983000
               CCHH    BOUNDARY '                                       10984000
MSG184U  DC    CL70'------  ---  ----- -----  ------  ----------- -----X10985000
               ------  -------- '                                       10986000
         PRINT GEN                                                      10987000
         TITLE 'P D S  --  PDS VERIFY                    1/15/85'       10988000
*********************************************************************** 10989000
***      VERIFY SUBCOMMAND     ADDED BY BRUCE LELAND --  MAY, 1983  *** 10990000
*********************************************************************** 10991000
*                                                                       10992000
         SPACE 1                                                        10993000
VERIFY   CSECT                                                          10994000
         USING *,R8                                                     10995000
         TM    FLAGSCC,RECFMF      FIXED FORMAT RECORDS?                10996000
         BNO   VERP00              NO, BRANCH                           10997000
         LH    R15,BLKSI           BLKSIZE                              10998000
         SR    R14,R14                                                  10999000
         LH    R1,LRECL            LRECL                                11000000
         LTR   R1,R1               ANY LRECL?                           11001000
         BZ    VERP00              NO, AVOID DIVIDE ERROR               11002000
         DR    R14,R1              BLKSIZE/LRECL                        11003000
         LTR   R14,R14             INTEGRAL NUMBER OF LRECL RECORDS?    11004000
         BZ    VERP00              YES, BRANCH                          11005000
         TSMSG L482                NO, ERROR                            11006000
         SPACE 2                                                        11007000
VERP00   TM    DSORG,DS1DSGPO      PARTITIONED DATA SET?                11008000
         BNO   VERS00              NO, PERFORM OTHER GROUP OF CHECKS    11009000
         SPACE 1                                                        11010000
         TM    FLAGSAA,FMEMBER1+FMEMBER2  ALL MEMBERS?                  11011000
         BNZ   VERP02                     NO, BRANCH                    11012000
         TM    FLAGSAA,FMEM#MEM           MEMBER GROUP?                 11013000
         BNO   VERP03                     NO, BRANCH                    11014000
         SPACE 2                                                        11015000
* SINGLE MEMBER CHECK IS DESIRED                                        11016000
VERP02   OI    #VERUPDT,4+2               SET FLAG FOR LATER            11017000
         SR    R1,R1                      NO MESSAGE YET                11018000
         BAL   R2,VERMBR                  OUTPUT MEMBER IDENTIFIER      11019000
         LA    R4,#VERR4                  POINT TO A WORK AREA          11020000
         ST    R4,#MEMPTR                 ADD AT END OF THE TABLE       11021000
         SR    R3,R3                      NO TABLE ENTRIES              11022000
         B     VERP18                     SKIP INITIALIZATION           11023000
         SPACE 2                                                        11024000
VERP03   LA    R1,L875             ASSUME NO DIRECTORY BLOCKS           11025000
         CLC   DS1LSTAR(3),ZERO    CORRECT?                             11026000
         BE    MSGNEW              YES, BRANCH                          11027000
         TM    #VERUPDT,2          NOUPDATE SPECIFIED?                  11028000
         BO    VERP09              YES, DO NOT OPEN STOW                11029000
         BAL   R2,OPENSTOW         OPEN THE STOW DCB; ENQUEUE           11030000
         B     VERP08              COULD NOT OPEN -- ERROR              11031000
         SPACE 1                                                        11032000
         MVI   MSGTEXT2,X'F9'          HIGH IN COLLATING SEQUENCE       11033000
         MVC   #DIRFIX+1(7),=C'FIXPDS' TEMPORARY STOW AND DELETE NAME   11034000
         MVI   MSGTEXT2+11,B'1001111'  ALIAS/MAX LENGTH ENTRY           11035000
         STOW  STOWDCB,MSGTEXT2,A      ADD THIS MEMBER                  11036000
         SPACE 1                                                        11037000
         B     *+4(R15)                PROCESS RETURN CODE              11038000
         B     VERP06                    00 - SUCCESSFUL                11039000
         B     VERP06                    04 - MEMBER ALREADY EXISTS     11040000
         EX    0,*                       08 - SHOULD NOT OCCUR          11041000
         B     VERP04                    12 - FULL DIRECTORY            11042000
         TSMSG L836                      16 - I/O ERROR IN DIRECTORY    11043000
         B     VERP08                                                   11044000
         SPACE 1                                                        11045000
VERP04   TSMSG L855                    DIRECTORY IS FULL                11046000
         B     VERP08                    12 - FULL DIRECTORY            11047000
         SPACE 2                                                        11048000
VERP06   STOW  STOWDCB,MSGTEXT2,D      DELETE THIS MEMBER               11049000
         SPACE 1                                                        11050000
         LTR   R15,R15                 ANY ERROR?                       11051000
         BNP   VERP08                  NO, BRANCH                       11052000
         TSMSG L836                    YES, I/O ERROR IN DIRECTORY      11053000
VERP08   BAL   R2,SHUTSTOW         CLOSE THE STOW DCB; DEQUEUE          11054000
         SPACE 2                                                        11055000
VERP09   MVI   SUBPOOLT,21         TEMPORARY STORAGE IN USE             11056000
         MVI   STARTTR+2,X'01'     READ THE DIRECTORY                   11057000
         LA    R5,1024/2           1024 MEMBERS INITIALLY               11058000
         SPACE 1                                                        11059000
VERP10   SLL   R5,1                MEMBERS*2 FOR EACH LOOP              11060000
         SR    R6,R6                                                    11061000
         LR    R3,R5                                                    11062000
         LR    R0,R5                                                    11063000
         SLL   R0,4                MEMBERS*16 IS TABLE SIZE             11064000
         ICM   R0,B'1000',SUBPOOLT                                      11065000
         GETMAIN R,LV=(0)          ALLOCATE A NEW MEMBER TABLE          11066000
         LR    R4,R1               NEW TABLE ADDRESS                    11067000
         ICM   R0,B'1111',#MEMPTR  ANY PREVIOUS MEMBERS?                11068000
         BZ    VERP12              NO, BRANCH                           11069000
         SRL   R3,1                YES, USE SECOND HALF OF TABLE        11070000
         LR    R14,R4              NEW TABLE START ADDRESS              11071000
         LR    R15,R5                                                   11072000
         SLL   R15,3               MEMBERS*8 IS OLD TABLE SIZE          11073000
         LR    R6,R15              DISPLACEMENT TO NEW PART             11074000
         LR    R1,R15                                                   11075000
         MVCL  R14,R0              PRESERVE THE PREVIOUS TABLE          11076000
         L     R1,#MEMPTR                                               11077000
         LR    R0,R6               LENGTH TO FREE                       11078000
         ICM   R0,B'1000',SUBPOOLT SUBPOOL TO FREE                      11079000
         FREEMAIN R,LV=(0),A=(1)                                        11080000
         SPACE 1                                                        11081000
VERP12   ST    R4,#MEMPTR          MEMBER TABLE BASE                    11082000
         AR    R4,R6               WHERE TO ADD MEMBERS                 11083000
         SPACE 2                                                        11084000
VERP14   BAL   R14,READDIR         GET THE NEXT MEMBER                  11085000
         B     VERP50              END OF MEMBERS, BRANCH               11086000
         MVI   #MEMPTR,0           CLEAR THE MEMBER FLAG                11087000
         SPACE 3                                                        11088000
* CHECK FOR STANDARD MEMBER NAMES IF REQUIRED                           11089000
         TM    #VERSTND,X'02'      STANDARD NAME CHECK?                 11090000
         BNZ   VERP18              NO, BRANCH                           11091000
         SPACE 1                                                        11092000
         LA    R1,7                                                     11093000
         LA    R14,DOUBLE+8                                             11094000
         MVC   DOUBLE(8),MEMNAME                                        11095000
         SPACE 1                                                        11096000
VERP16   BCTR  R14,0               SCAN                                 11097000
         CLI   0(R14),X'40'            BACKWARDS                        11098000
         BNE   *+8                              FOR FIRST               11099000
         BCT   R1,VERP16                                 NON-BLANK      11100000
         SPACE 1                                                        11101000
         SR    R1,R1               NO MESSAGE YET                       11102000
         LA    R2,VERP18           EXIT ADDRESS                         11103000
         CLI   MEMNAME,C'0'        NUMERIC FIRST CHARACTER?             11104000
         BNL   VERMBR              YES, NON-STANDARD                    11105000
         SPACE 1                                                        11106000
         TRT   DOUBLE(*-*),TRTMEM  <<EXECUTED>>                         11107000
         EX    R1,*-6              STANDARD MEMBER NAME?                11108000
         LA    R1,0                                                     11109000
         LA    R2,VERP18                                                11110000
         BNZ   VERMBR              NO, BRANCH                           11111000
         SPACE 3                                                        11112000
* CHECK FOR CONFLICTING LOAD MODULE ATTRIBUTES                          11113000
VERP18   L     R14,DIRPTRS                 CURRENT MEMBER               11114000
         MVC   DIRNAME(12),0(R14)          MOVE IN NAME, FIRST TTR      11115000
         TM    FLAGSCC,RECFMU              LOAD LIBRARY?                11116000
         BZ    VERP28                      NO, BRANCH                   11117000
         MVC   DIRNAME(40),0(R14)          MOVE IN NAME, LKED FLAGS     11118000
         TM    DIRATTR2,DIRAOSLE           VS LINKAGE EDITOR?           11119000
         BNO   VERP20                      NO, BRANCH                   11120000
         TM    DIRATTR3,DIRRMANY           RMODE ANY?                   11121000
         BZ    VERP20                      NO, BRANCH                   11122000
         SR    R1,R1                                                    11123000
         IC    R1,DIRATTR3                 AMODE BITS                   11124000
         TM    DIRFLAG,X'80'               ALIAS?                       11125000
         BNO   *+8                         NO, BRANCH                   11126000
         SRL   R1,2                        YES, SHIFT AMODE BITS        11127000
         STC   R1,MODESAVE                 SAVE CURRENT AMODE           11128000
         LA    R1,=C'ANY'                  ASSUME AMODE IS ANY     @D02
         MVI   MTHIGHL,3                   Set insert length       @D02
         TM    MODESAVE,DIRAM64+DIRAM31    CORRECT?                @D02
         BO    VERP19                      YES, INVALID            @D02
         TM    MODESAVE,DIRAM31            AMODE 31?               @D02
         BO    VERP20                      YES, BRANCH             @D02
         TM    MODESAVE,DIRAM64            AMODE 64?               @D02
         BO    VERP20                      YES, BRANCH             @D02
         LA    R1,=C'24 '                  AMODE MUST BE 24        @D02
         MVI   MTHIGHL,2                   Set insert length       @D02
VERP19   DS    0H                                                  @D01
**       MVI   MTHIGHL,3                   MESSAGE LENGTH               11135000
         MVC   INSERT#1(3),0(R1)           MOVE IN THE AMODE TEXT       11136000
         LA    R1,L880$1                   RMODE ANY/AMODE CONFLICT     11137000
         BAL   R2,VERMBR                   OUTPUT AN ERROR MESSAGE      11138000
         MVI   MTHIGHL,8                   Restore standard length @D01
         SPACE 3                                                        11139000
VERP20   TM    DIRATTR,ATTRRENT                REENTRANT?               11140000
         BNO   VERP22                          NO, BRANCH               11141000
         TM    DIRATTR,ATTRREUS                REUSABLE?                11142000
         BO    VERP22                          YES, BRANCH              11143000
         LA    R1,L881                         RENT AND NOT REUS        11144000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11145000
VERP22   LA    R1,L882                         TEST AND NOT EDIT        11146000
         TM    DIRATTR+1,ATTRSYMS+ATTRNE       TEST AND NOT EDIT?       11147000
         BNO   *+8                             NO, BRANCH               11148000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11149000
         LA    R1,L883                         REUSABLE AND SCATTER     11150000
         TM    DIRATTR,ATTRREUS+ATTRSCTR       REUSABLE AND SCATTER?    11151000
         BNO   *+8                             NO, BRANCH               11152000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11153000
         TM    DIRATTR,ATTROVLY                OVERLAY DEFINED?         11154000
         BNO   VERP24                          NO, BRANCH               11155000
         MVC   INSERT#1(8),BLANKS              BLANKS                   11156000
         MVC   INSERT#1(4),RENTTXT+3           OVERLAY AND REENTRANT    11157000
         LA    R1,L884$1                       OVERLAY CONFLICT MESSAGE 11158000
         TM    DIRATTR,ATTRRENT                CORRECT?                 11159000
         BNO   *+8                             NO, BRANCH               11160000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11161000
         MVC   INSERT#1(4),REUSTXT+3           OVERLAY AND REUSABLE     11162000
         LA    R1,L884$1                       OVERLAY CONFLICT MESSAGE 11163000
         TM    DIRATTR,ATTRREUS                CORRECT?                 11164000
         BNO   *+8                             NO, BRANCH               11165000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11166000
         MVC   INSERT#1(4),REFRTXT+3           OVERLAY AND REFRESHABLE  11167000
         LA    R1,L884$1                       OVERLAY CONFLICT MESSAGE 11168000
         TM    DIRATTR+1,ATTRREFR              CORRECT?                 11169000
         BNO   *+8                             NO, BRANCH               11170000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11171000
         MVC   INSERT#1(4),SCTRTXT+3           OVERLAY AND SCATTER      11172000
         LA    R1,L884$1                       OVERLAY CONFLICT MESSAGE 11173000
         TM    DIRATTR,ATTRSCTR                CORRECT?                 11174000
         BNO   *+8                             NO, BRANCH               11175000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11176000
         TM    DIRATTR2,DIRAOSLE               MVS LINKAGE-EDITOR?      11177000
         BNO   VERP24                          NO, BRANCH               11178000
         MVC   INSERT#1(5),=C'RMODE'                                    11179000
         MVC   INSERT#1+6(3),=C'ANY'           RMODE ANY                11180000
         LA    R1,L884$1                       OVERLAY CONFLICT MESSAGE 11181000
         TM    DIRATTR3,DIRRMANY               RMODE ANY?               11182000
         BNO   *+8                             NO, BRANCH               11183000
         BAL   R2,VERMBR                       YES, ERROR MESSAGE       11184000
         MVI   INSERT#1,C'A'                   AMODE ANY                11185000
         SR    R1,R1                                                    11186000
         IC    R1,DIRATTR3                     AMODE BITS               11187000
         TM    DIRFLAG,X'80'                   ALIAS?                   11188000
         BNO   *+8                             NO, BRANCH               11189000
         SRL   R1,2                            YES, SHIFT AMODE BITS    11190000
         STC   R1,MODESAVE                     SAVE CURRENT AMODE       11191000
         LA    R1,L884$1                       OVERLAY CONFLICT MESSAGE 11192000
         SPACE 1                                                   @D02
         TM    MODESAVE,DIRAM31+DIRAM64        AMODE ANY?          @D02
         BO    VERP23                          YES, ERROR          @D02
         MVC   INSERT#1+6(3),=C'31 '           AMODE 31            @D02
         TM    MODESAVE,DIRAM31                AMODE 31?           @D02
         BO    VERP23                          YES, ERROR          @D02
         MVC   INSERT#1+6(3),=C'64 '           AMODE 64            @D02
         TM    MODESAVE,DIRAM64                AMODE 64?           @D02
         BO    VERP23                          YES, ERROR          @D02
         B     VERP24                          NO, BRANCH          @D02
VERP23   DS    0H                                                  @D02
         BAL   R2,VERMBR                       ERROR MESSAGE            11198000
         SPACE 3                                                        11199000
* LOAD EACH MEMBER IF REQUIRED AND THIS IS A LOAD LIBRARY               11200000
VERP24   TM    #VERLOAD,X'02'      LOAD CHECK REQUESTED?                11201000
         BNZ   VERP28              NO, BRANCH                           11202000
         SPACE 1                                                        11203000
         TM    FLAGSCC,RECFMU      LOAD LIBRARY?                        11204000
         BZ    VERP28              NO, BRANCH                           11205000
         SPACE 1                                                        11206000
         OI    ##ADRPA#,$Q         ENTER QUIET MODE PROCESSING          11207000
         L     R2,RECOVER          PREVIOUS RECOVERY ADDRESS            11208000
         LA    R1,VERP26           RESUME ADDRESS                       11209000
         ST    R1,RECOVER          IN-LINE RECOVERY                     11210000
         STM   R2,R8,#SAVEREG      SAVE REGISTERS                       11211000
         LOAD   EPLOC=DIRNAME,DCB=INDCB                                 11212000
         DELETE EPLOC=DIRNAME                                           11213000
         ST    R2,RECOVER          RESET RECOVERY ADDRESS               11214000
         B     VERP28                                                   11215000
         SPACE 1                                                        11216000
VERP26   LM    R2,R8,#SAVEREG      SAVE REGISTERS                       11217000
         ST    R2,RECOVER          RESTORE RECOVERY ADDRESS             11218000
         MVI   MTHIGHL,4           FOUR CHARACTERS FROM ABEND MESSAGE   11219000
*        MVC   INSERT#1(4),INSERT#1                                     11220000
         LA    R1,L998$1           "ABEND SNNN LOADING THIS MODULE"     11221000
         BAL   R2,VERMBR           OUTPUT AN ABENDED MESSAGE            11222000
         SPACE 3                                                        11223000
* CHECK IF THIS MEMBER IS IN USE BY AN SPF EDIT SESSION                 11224000
VERP28   OI    ##ADRPA#,$Q         ENTER QUIET MODE PROCESSING          11225000
         SPACE 1                                                        11226000
         MVC   DSNMEMQ(8),DIRNAME  MEMBER NAME TO CHECK                 11227000
         BAL   R2,ENQMTEST         MEMBER IN USE?                       11228000
         BAL   R2,VERMBR           YES, OUTPUT AN IN-USE MESSAGE        11229000
         SPACE 3                                                        11230000
* CHECK THAT THE PDS DIRECTORY MEMBERS ARE IN CORRECT COLLATING ORDER   11231000
VERP30   NI    ##ADRPA#,FF-$Q      LEAVE QUIET MODE PROCESSING          11232000
         CLC   #VERMBR(8),DIRNAME  PREVIOUS:CURRENT                     11233000
         BH    VERP32                HIGH  -- ERROR, OUT OF ORDER       11234000
         MVC   #VERMBR(8),DIRNAME                                       11235000
         BL    VERP34                LOW   -- VALID                     11236000
         LA    R1,L824               EQUAL -- ERROR, DUPLICATE          11237000
         BAL   R2,VERMBR                                                11238000
         B     VERP14              IGNORE THIS MEMBER                   11239000
         SPACE 1                                                        11240000
VERP32   LA    R1,L825             MEMBER OUT OF SEQUENCE               11241000
         BAL   R2,VERMBR                                                11242000
         B     VERP14              IGNORE THIS MEMBER                   11243000
         SPACE 3                                                        11244000
* SELECT THE HIGHEST TTR POINTERS FOR THIS MEMBER                       11245000
VERP34   MVC   0(8+4,R4),DIRNAME   MOVE IN THE NAME, FIRST TTR          11246000
         XC    12(4,R4),12(R4)     CLEAR THE SECOND TTR ADDRESS         11247000
         TM    MEMTTR+3,DIR1TTR+DIR2TTR  ANY OTHER TTR'S?               11248000
         BZ    VERP35                    NO, BRANCH                     11249000
         SPACE 1                                                        11250000
         MVC   12(3,R4),DIRNAME+12 ADD FIRST USER TTR                   11251000
         TM    MEMTTR+3,DIR2TTR    SECOND TTR?                          11252000
         BZ    VERP35              NO, BRANCH                           11253000
         SPACE 1                                                        11254000
         CLC   12(3,R4),DIRNAME+16 FIRST TTR > SECOND TTR?              11255000
         BH    *+10                YES, BRANCH                          11256000
         MVC   12(3,R4),DIRNAME+16 NO, USE SECOND TTR                   11257000
         SPACE 1                                                        11258000
VERP35   NI    11(R4),X'80'        SAVE ONLY THE ALIAS BIT              11259000
         CLC   8(3,R4),DS1LSTAR    IN DATA SET BOUNDS?                  11260000
         BNH   VERP36              YES, BRANCH                          11261000
         LA    R1,L872                                                  11262000
         BAL   R2,VERMBR           NO, OUTPUT AN ERROR MESSAGE          11263000
         B     VERP38                                                   11264000
         SPACE 1                                                        11265000
VERP36   CLC   12(3,R4),DS1LSTAR   IN DATA SET BOUNDS?                  11266000
         BNH   VERP37              YES, BRANCH                          11267000
         LA    R1,L873                                                  11268000
         BAL   R2,VERMBR           NO, OUTPUT AN ERROR MESSAGE          11269000
         SPACE 1                                                        11270000
VERP37   MVI   15(R4),X'FF'        ASSUME NOT AN OS/VS LINKAGE-EDITOR   11271000
         TM    FLAGSCC,RECFMU      RECFM=U?                             11272000
         BNO   VERP38              NO, BRANCH                           11273000
         TM    DIRATTR2,DIRAOSLE   OS/VS LINKAGE-EDITOR?                11274000
         BNO   VERP38              NO, BRANCH                           11275000
         NI    DIRATTR3,DIRRMANY+DIRAM31+DIRAM64                   @D02
         OC    11(1,R4),DIRATTR3   SAVE THE RMODE/AMODE CHARACTER       11277000
         MVC   15(1,R4),DIRATTR4   SAVE THE RLD/CONTROL COUNT           11278000
         SPACE 3                                                        11279000
* PERFORM AN INSERTION SORT OF THIS ENTRY                               11280000
VERP38   MVC   DIRNAME(16),0(R4)   SAVE ENTRY FOR INSERTION SORT        11281000
         LR    R14,R4              LAST SORT POSITION                   11282000
         L     R1,#MEMPTR          FIRST SORT POSTION                   11283000
         SH    R1,=H'16'           ADJUST FOR NEXT LA                   11284000
         SPACE 1                                                        11285000
VERP40   LA    R1,16(,R1)          NEXT TABLE ENTRY                     11286000
         CLC   8(4,R1),DIRTTR      TABLE TTR:NEW TTR                    11287000
         BL    VERP40                LOW   --  ITERATE                  11288000
         BH    VERP41                HIGH  --  INSERT                   11289000
         CLC   0(8,R1),DIRNAME       EQUAL --  TABLE NAME:NEW NAME      11290000
         BL    VERP40                            LOW   -- ITERATE       11291000
         BE    VERP42                            EQUAL -- IN PLACE      11292000
         SPACE 1                                                        11293000
VERP41   SH    R14,=H'16'          PREVIOUS TABLE ENTRY                 11294000
         MVC   16(16,R14),0(R14)   SLIDE DOWN TO MAKE ROOM              11295000
         CR    R14,R1              DONE WITH SHIFTING?                  11296000
         BH    VERP41              NO, BRANCH                           11297000
         MVC   0(16,R1),DIRNAME    INSERT NEW ENTRY TO ITS POSITION     11298000
         SPACE 2                                                        11299000
VERP42   LA    R4,16(,R4)          NEXT TABLE ENTRY                     11300000
         S     R3,=F'1'            ANY MORE ENTRIES FIT?                11301000
         BP    VERP14              YES, BRANCH                          11302000
         BZ    VERP10              NO, REALLOCATE THE MEMBER TABLE      11303000
         SPACE 3                                                        11304000
* SINGLE MEMBER -- CHECK DIRECTORY ATTRIBUTES                           11305000
         ST    R4,#MEMLAST         UPDATE LAST MEMBER POINTER           11306000
         MVI   STARTTR+2,X'01'     TTR=00001 (START OF DIRECTORY)       11307000
         XC    INSERT#1(8),INSERT#1                                     11308000
         SPACE 1                                                        11309000
VERP44   BAL   R14,READDIR         GET NEXT MEMBER                      11310000
         B     VERP48              LAST MEMBER, BRANCH                  11311000
         SPACE 1                                                        11312000
         CLC   DIRTTR,MEMTTR       TTR MATCH?                           11313000
         BNE   VERP44              NO, BRANCH                           11314000
         TM    DIRFLAG,X'80'       FIRST THE MAIN ENTRY?                11315000
         BZ    VERP45              YES, BRANCH                          11316000
         TM    MEMFLAG,X'80'       SECOND AN ALIAS?                     11317000
         BO    VERP44              YES, IGNORE                          11318000
         SPACE 1                                                        11319000
* FOUND A REAL CORRESPONDING ENTRY                                      11320000
         MVC   INSERT#1(8),MEMNAME REAL ENTRY FOR THE ALIAS             11321000
         TSMSG L066$1                                                   11322000
         TM    FLAGSCC,RECFMU      LOAD MODULE?                         11323000
         BNO   VERP44              NO, DONE                             11324000
         LA    R14,DIRREAL                                              11325000
         TM    DIRATTR,ATTRSCTR    SCATTER LOADED?                      11326000
         BNO   *+8                 NO, BRANCH                           11327000
         LA    R14,DIRREALS                                             11328000
         MVC   INSERT#2(8),0(R14)                                       11329000
         TR    INSERT#2(8),TRLINE                                       11330000
         LA    R1,L820$2                                                11331000
         CLC   0(8,R14),MEMNAME    CORRECT MEMBER NAME?                 11332000
         BE    *+8                 YES, BRANCH                          11333000
         BAL   R2,VERMBR           NO, MESSAGE                          11334000
         B     VERP47                                                   11335000
         SPACE 3                                                        11336000
* FOUND AN ALIAS CORRESPONDING ENTRY                                    11337000
VERP45   MVC   INSERT#1(8),MEMNAME                                      11338000
         TM    MEMFLAG,X'80'       AN ALIAS?                            11339000
         BO    VERP46              YES, BRANCH                          11340000
         CLC   DIRNAME(8),MEMNAME  FIND MYSELF?                         11341000
         BE    VERP44              YES, BRANCH                          11342000
         TSMSG L864$1              FOUND AN APPARENT ALIAS              11343000
         B     VERP73                                                   11344000
         SPACE 1                                                        11345000
VERP46   TM    FLAGSCC,RECFMU      LOAD MODULE?                         11346000
         BNO   VERP44              NO, BRANCH                           11347000
         L     R3,DIRPTRS                                               11348000
         LA    R14,DIRREAL-DIRNAME(R3)                                  11349000
         TM    DIRATTR-DIRNAME(R3),ATTRSCTR                             11350000
         BNO   *+8                                                      11351000
         LA    R14,DIRREALS-DIRNAME(R3)                                 11352000
         MVC   INSERT#2(8),0(R14)                                       11353000
         TR    INSERT#2(8),TRLINE                                       11354000
         LA    R1,L827$2                                                11355000
         CLC   0(8,R14),DIRNAME    CORRECT MEMBER NAME?                 11356000
         BE    *+8                 YES, BRANCH                          11357000
         BAL   R2,VERMBR           NO, MESSAGE                          11358000
         SPACE 1                                                        11359000
VERP47   L     R3,DIRPTRS                                               11360000
         LA    R1,L823$1           RLD/CONTROL MISMATCH                 11361000
         CLC   DIRATTR4(1),DIRATTR4-DIRNAME(R3)                         11362000
         BE    *+8                                                      11363000
         BAL   R2,VERMBR                                                11364000
         SPACE 1                                                        11365000
         MVI   DOUBLE+0,DIRRMANY                                        11366000
         MVI   DOUBLE+1,DIRRMANY                                        11367000
         NC    DOUBLE+0(1),DIRATTR3                                     11368000
         NC    DOUBLE+1(1),DIRATTR3-DIRNAME(R3)                         11369000
         LA    R1,L821$1           RMODE BITS DO NOT CORRESPOND         11370000
         CLC   DOUBLE(1),DOUBLE+1  EQUAL?                               11371000
         BE    *+8                 YES, BRANCH                          11372000
         BAL   R2,VERMBR           NO, ERROR                            11373000
         SPACE 1                                                        11374000
         MVI   DOUBLE+0,DIRAM31+DIRAM64                            @D02
         MVI   DOUBLE+1,DIRAM31+DIRAM64                            @D02
         NC    DOUBLE+0(1),DIRATTR3                                     11377000
         NC    DOUBLE+1(1),DIRATTR3-DIRNAME(R3)                         11378000
         LA    R1,L822$1           AMODE BITS DO NOT CORRESPOND         11379000
         CLC   DOUBLE(1),DOUBLE+1  EQUAL?                               11380000
         BE    *+8                 YES, BRANCH                          11381000
         BAL   R2,VERMBR           NO, ERROR                            11382000
         B     VERP44                                                   11383000
         SPACE 1                                                        11384000
* END OF MEMBERS                                                        11385000
VERP48   TM    DIRNAME,X'80'       ALIAS FIRST MEMBER?                  11386000
         BNO   VERP73              NO, BRANCH                           11387000
         CLI   INSERT#1,0          ANY MAIN ENTRY FOUND?                11388000
         BNE   VERP73              YES, BRANCH                          11389000
         TSMSG L860                ORPHAN MEMBER                        11390000
         TM    FLAGSCC,RECFMU      LOAD MODULE?                         11391000
         BNO   VERP73              NO, BRANCH                           11392000
         MVC   INSERT#1(8),DIRREAL                                      11393000
         SPACE 1                                                        11394000
         TM    DIRATTR,ATTRSCTR   SCATTER LOADED?                       11395000
         BNO   *+10               NO, BRANCH                            11396000
         MVC   INSERT#1(8),DIRREALS                                     11397000
         TSMSG L861$1                                                   11398000
         B     VERP73                                                   11399000
         SPACE 3                                                        11400000
* DIRECTORY TTR SORT COMPLETE -- CHECK FOR ORPHAN MEMBERS, APPARENT     11401000
* ALIAS MEMBERS AND ALIAS MEMBERS WITH INCORRECT MAIN MEMBER POINTERS   11402000
VERP50   LA    R1,L400                                                  11403000
         ST    R4,#MEMLAST         SAVE THE END POINTER                 11404000
         ICM   R3,B'1111',#MEMPTR  FIRST MEMBER                         11405000
         MVI   #MEMPTR,0           CLEAR THE MEMBER FLAG                11406000
         OI    #VERSTND,X'02'      NO MORE MEMBER NAME CHECKING         11407000
         LR    R5,R3                                                    11408000
         TM    8+3(R3),X'80'       ALIAS ENTRY?                         11409000
         BO    VERP54              YES, BRANCH                          11410000
         B     VERP58+4                                                 11411000
         SPACE 1                                                        11412000
VERP52   LA    R3,16(,R5)          NEXT TABLE ENTRY                     11413000
         MVI   #MEMPTR,0           CLEAR THE MEMBER FLAG                11414000
         CR    R3,R4               DONE?                                11415000
         BE    VERP66              YES, BRANCH                          11416000
         LR    R5,R3                                                    11417000
         SPACE 1                                                        11418000
         TM    8+3(R3),X'80'       ALIAS ENTRY?                         11419000
         BNO   VERP58+4            NO, BRANCH                           11420000
VERP54   LA    R1,L860             YES, THIS IS AN ORPHAN               11421000
         MVC   MEMNAME(8),0(R3)                                         11422000
         BAL   R2,VERMBR                                                11423000
         NI    8+3(R3),X'FF'-X'80' TURN OFF THE ALIAS BIT (ORPHAN)      11424000
         TM    FLAGSCC,RECFMU      LOAD MODULE?                         11425000
         BNO   VERP52              NO, BRANCH                           11426000
         XC    DIRUSER,DIRUSER                                          11427000
         MVC   DIRNAME,0(R3)       MEMBER NAME                          11428000
         BLDL  INDCB,BLDLLIST                                           11429000
         LTR   R15,R15             ANY BLDL ERROR?                      11430000
         BP    IOERROR             YES, I/O ERROR                       11431000
         SPACE 1                                                        11432000
         MVC   DIRFLAG(DIREND-DIRFLAG),DIRFLAG+2                        11433000
         MVC   INSERT#1(8),DIRREAL                                      11434000
         SPACE 1                                                        11435000
         TM    DIRATTR,ATTRSCTR   SCATTER LOADED?                       11436000
         BNO   *+10               NO, BRANCH                            11437000
         MVC   INSERT#1(8),DIRREALS                                     11438000
         TSMSG L861$1                                                   11439000
         B     VERP52                                                   11440000
         SPACE 2                                                        11441000
VERP58   LA    R5,16(,R5)          NEXT POTENTIAL ALIAS ENTRY           11442000
         MVI   #MEMPTR,0           CLEAR THE MEMBER FLAG                11443000
         CR    R5,R4               DONE?                                11444000
         BE    VERP66              YES, BRANCH                          11445000
         CLC   8(3,R3),16+8(R5)    TTR FOR AN ALIAS?                    11446000
         BNE   VERP52              NO, BRANCH                           11447000
         TM    16+8+3(R5),X'80'    ALIAS FLAG SET?                      11448000
         BNO   VERP64              NO, APPARENT ALIAS                   11449000
         SPACE 1                                                        11450000
         TM    FLAGSCC,RECFMU      LOAD MODULE?                         11451000
         BNO   VERP58              NO, BRANCH                           11452000
         XC    DIRUSER,DIRUSER                                          11453000
         MVC   DIRNAME,16(R5)      MEMBER NAME                          11454000
         BLDL  INDCB,BLDLLIST                                           11455000
         LTR   R15,R15             ANY BLDL ERROR?                      11456000
         BP    IOERROR             YES, I/O ERROR                       11457000
         SPACE 1                                                        11458000
         MVC   DIRFLAG(DIREND-DIRFLAG),DIRFLAG+2                        11459000
         LA    R1,DIRREAL          NAME OF CORRESPONDING MAIN           11460000
         TM    DIRATTR,ATTRSCTR    SCATTER LOADED?                      11461000
         BNO   *+8                 NO, BRANCH                           11462000
         LA    R1,DIRREALS         YES, USE THIS NAME INSTEAD           11463000
         SPACE 1                                                        11464000
         CLC   0(8,R1),0(R3)       CORRECT NAME RECORDED?               11465000
         BE    VERP60              YES, BRANCH                          11466000
         MVI   MTHIGHL,8           MEMBER NAME 1                        11467000
         MVI   MTHIGHL+4,8         MEMBER NAME 2                        11468000
         MVC   INSERT#1(8),0(R3)                                        11469000
         MVC   INSERT#2(8),0(R1)                                        11470000
         TR    INSERT#2(8),TRLINE                                       11471000
         LA    R1,L820$2                                                11472000
         MVC   MEMNAME(8),16(R5)                                        11473000
         BAL   R2,VERMBR                                                11474000
         SPACE 1                                                        11475000
VERP60   CLC   15(1,R3),16+15(R5)  MATCHING RLD/CONTROL COUNTS?         11476000
         BE    VERP62              YES, BRANCH                          11477000
         MVC   INSERT#1(8),16(R5)                                       11478000
         MVC   MEMNAME(8),0(R3)                                         11479000
         LA    R1,L823$1           NO, RLD/CONTROL MISMATCH             11480000
         BAL   R2,VERMBR                                                11481000
         SPACE 1                                                        11482000
VERP62   MVI   DOUBLE,DIRRMANY       BIT TO TEST                        11483000
         MVI   DOUBLE+1,DIRRMANY     BIT TO TEST                        11484000
         NC    DOUBLE(1),16+11(R5)   ALIAS RMODE BIT                    11485000
         NC    DOUBLE+1(1),11(R3)    MAIN RMODE BIT                     11486000
         CLC   DOUBLE(1),DOUBLE+1    RMODE BITS EQUAL?                  11487000
         BE    VERP63                YES, BRANCH                        11488000
         MVC   INSERT#1(8),16(R5)                                       11489000
         MVC   MEMNAME(8),0(R3)                                         11490000
         LA    R1,L821$1             NO, RMODE DOES NOT MATCH           11491000
         BAL   R2,VERMBR                                                11492000
         SPACE 1                                                        11493000
VERP63   MVI   DOUBLE,DIRAM31+DIRAM64    BITS TO TEST              @D02
         MVI   DOUBLE+1,DIRAM31+DIRAM64  BITS TO TEST              @D02
         NC    DOUBLE(1),16+11(R5)   ALIAS AMODE BITS                   11496000
         NC    DOUBLE+1(1),11(R3)    MAIN AMODE BIT                     11497000
         CLC   DOUBLE(1),DOUBLE+1    AMODE BITS EQUAL?                  11498000
         BE    VERP58                YES, BRANCH                        11499000
         MVC   INSERT#1(8),16(R5)                                       11500000
         MVC   MEMNAME(8),0(R3)                                         11501000
         LA    R1,L822$1             NO, AMODE DOES NOT MATCH           11502000
         BAL   R2,VERMBR                                                11503000
         B     VERP58                                                   11504000
         SPACE 1                                                        11505000
VERP64   MVC   INSERT#1(8),16(R5)  MEMBER NAME INSERTED                 11506000
         MVC   MEMNAME(8),0(R3)                                         11507000
         LA    R1,L864$1                                                11508000
         BAL   R2,VERMBR                                                11509000
         OI    16+8+3(R5),X'80'    TURN ON ALIAS BIT (APPARENT ALIAS)   11510000
         B     VERP58                                                   11511000
         SPACE 3                                                        11512000
* END OF DIRECTORY CHECK, NOW PERFORM ANY INPUT CHECK                   11513000
VERP66   MVI   STARTTR+2,X'01'     TTR=000001 (START OF DIRECTORY)      11514000
         TM    #VERUPDT,4+2        SINGLE MEMBER CHECK?                 11515000
         BO    VERP73              YES, BRANCH                          11516000
         SPACE 1                                                        11517000
VERP68   L     R15,=A(EXCP)        READ THE DIRECTORY RECORDS           11518000
         BALR  R14,R15                                                  11519000
         B     *+4(R15)            PROCESS RETURN CODE                  11520000
         B     VERP70                00 - SUCCESSFUL READ               11521000
         B     VERP72                04 - END OF MEMBER                 11522000
         B     VERP72                08 - END OF DATA SET               11523000
         B     IOERROR               12 - I/O ERROR                     11524000
         SPACE 2                                                        11525000
VERP70   L     R0,LS               LENGTH OF RECORD (DD OF RKDD)        11526000
         ICM   R0,B'0100',=X'08'   KEY LENGTH OF RECORD (K OF RKDD)     11527000
         BAL   R2,VERCOMP          DATA IS RETAINED IN THE OUTPUT       11528000
         B     VERP68              READ ALL DIRECTORY BLOCKS            11529000
         SPACE 1                                                        11530000
VERP72   SR    R0,R0               LENGTH OF RECORD & KEY (KDD OF RKDD) 11531000
         BAL   R2,VERCOMP          DATA IS RETAINED IN THE OUTPUT       11532000
         OI    ##ADRPA#,$Q         ENTER QUIET MODE PROCESSING          11533000
         CLI   CURMBB,0            MULTI-EXTENT DIRECTORY?              11534000
         BE    VERP73              NO, BRANCH                           11535000
         MESSAGE MSGBLANK          YES, ERROR MESSAGE                   11536000
         MESSAGE MSGBLANK                                               11537000
         TSMSG L870                                                     11538000
         SPACE 1                                                        11539000
VERP73   ICM   R6,B'1111',#MEMPTR  FIRST MEMBER                         11540000
         TM    #VERUPDT,4+2        SINGLE MEMBER CHECK?                 11541000
         BNO   *+8                 NO, BRANCH                           11542000
         NI    8+3(R6),FF-X'80'    YES, READ THIS MEMBER                11543000
         CLI   #VERREAD,X'02'      NOINPUT REQUESTED?                   11544000
         BE    VERP99              YES, BRANCH                          11545000
         B     VERP74+4                                                 11546000
         SPACE 2                                                        11547000
VERP74   LA    R6,16(,R6)          NEXT TABLE ENTRY                     11548000
         MVI   RLDCOUNT,X'FF'      ASSUME NO RLD/CONTROL IS FOUND       11549000
         C     R6,#MEMLAST         DONE?                                11550000
         BE    VERP97              YES, BRANCH                          11551000
         TM    8+3(R6),X'80'       ALIAS ENTRY?                         11552000
         BO    VERP74              YES, BRANCH                          11553000
         MVI   #MEMPTR,0           CLEAR THE MEMBER FLAG                11554000
         MVC   MEMNAME(8),0(R6)    INITIALIZE THE MEMBER NAME           11555000
         XC    #MEMCNT(4),#MEMCNT  COUNT OF INPUT LOGICAL RECORDS       11556000
         LA    R5,3                ALLOW 3 PERMANENT ERRORS/MEMBER      11557000
         SPACE 1                                                        11558000
         CLC   8(3,R6),DS1LSTAR    BEYOND END OF DATA MARKER?           11559000
         BNL   VERP90              YES, DONE                            11560000
         MVC   STARTTR(3),8(R6)    NO, FIRST DISK ADDRESS TO READ       11561000
         SPACE 3                                                        11562000
VERP76   L     R15,=A(EXCP)                                             11563000
         BALR  R14,R15                                                  11564000
         B     *+4(R15)            PROCESS RETURN CODE                  11565000
         B     VERP80                00 - SUCCESSFUL READ               11566000
         B     VERP92                04 - END OF MEMBER                 11567000
         B     VERP90                08 - END OF DATA SET               11568000
         B     VERP78                12 - I/O ERROR                     11569000
         SPACE 2                                                        11570000
*  PERMANENT I/O ERROR  -- SIMULATE END OF MEMBER                       11571000
VERP78   LA    R1,L991$1           OUTPUT THE I/O ERROR MESSAGE         11572000
         BAL   R2,VERMBR                                                11573000
         B     VERP92                                                   11574000
         SPACE 2                                                        11575000
VERP80   LR    R3,R0               BUFFER START                         11576000
         L     R5,LS               BLOCK LENGTH                         11577000
         C     R5,#VERMAX          GREATER THAN MAXIMUM?                11578000
         BNH   *+8                 NO, BRANCH                           11579000
         ST    R5,#VERMAX          YES, SAVE NEW MAXIMUM                11580000
         L     R0,#VERCBLK         NUMBER                               11581000
         A     R0,=F'1'                  OF PHYSICAL                    11582000
         ST    R0,#VERCBLK                          BLOCKS              11583000
         L     R0,#VERCBLC         NUMBER                               11584000
         AR    R0,R5                     OF PHYSICAL                    11585000
         ST    R0,#VERCBLC                          CHARACTERS          11586000
         LR    R0,R5               LENGTH OF RECORD & KEY (KDD OF RKDD) 11587000
         BAL   R2,VERCOMP          DATA IS RETAINED IN THE OUTPUT       11588000
         CH    R5,BLKSI            BLKSIZE VALID?                       11589000
         BNH   VERP81              YES, BRANCH                          11590000
         TM    #MEMPTR,#MEMBLKE    BLKSIZE SIZE ERROR NOTED?            11591000
         BO    VERP81              YES, BRANCH                          11592000
         OI    #MEMPTR,#MEMBLKE    BLKSIZE ERROR NOTED NOW              11593000
         CVD   R5,DOUBLE                                                11594000
         MVC   INSERT#1(8),=X'4020206B20212040'                         11595000
         ED    INSERT#1(7),DOUBLE+5                                     11596000
         LA    R1,L812$1           BLKSIZE ERROR                        11597000
         BAL   R2,VERMBR                                                11598000
         SPACE 1                                                        11599000
VERP81   TM    FLAGSCC,RECFMF      FIXED FORMAT?                        11600000
         BNO   VERP82              NO, BRANCH                           11601000
         LH    R14,LRECL           CURRENT LRECL                        11602000
         TM    #MEMPTR,#MEMDIVE    BLKSIZE/LRECL ERROR NOTED?           11603000
         BO    VERP82              YES, BRANCH                          11604000
         LR    R0,R5               BLOCK LENGTH                         11605000
         SRDA  R0,32                                                    11606000
         DR    R0,R14              BLKSIZE/LRECL                        11607000
         LTR   R0,R0               ANY REMAINDER?                       11608000
         BZ    VERP82              YES, BRANCH                          11609000
         OI    #MEMPTR,#MEMDIVE    BLKSIZE/LRECL ERROR NOTED NOW        11610000
         CVD   R5,DOUBLE                                                11611000
         MVC   INSERT#1(8),=X'4020206B20212040'                         11612000
         ED    INSERT#1(7),DOUBLE+5                                     11613000
         LA    R1,L814$1           BLKSIZE/LRECL ERROR                  11614000
         BAL   R2,VERMBR                                                11615000
         LH    R14,LRECL           CURRENT LRECL                        11616000
         SPACE 1                                                        11617000
VERP82   LR    R1,R5                                                    11618000
         AR    R5,R3               END OF BUFFER                        11619000
         BCTR  R5,0                END OF BUFFER -1                     11620000
         TM    FLAGSCC,RECFMF      RECFM=F?                             11621000
         LH    R4,LRECL                                                 11622000
         BO    VERP88              YES, BRANCH                          11623000
         TM    FLAGSCC,RECFMU      RECFM=U?                             11624000
         LR    R4,R1                                                    11625000
         BO    VERP87              YES, BRANCH                          11626000
         TM    FLAGSCC,RECFMV      RECFM=V?                             11627000
         BNO   VERP88              NO, ASSUME RECFM=U                   11628000
         AH    R3,=H'4'            SKIP BLOCK LENGTH WORD               11629000
         B     VERP86                                                   11630000
         SPACE 3                                                        11631000
VERP84   BXLE  R3,R4,VERP86        GET THE NEXT LOGICAL RECORD          11632000
         B     VERP76              END OF BLOCK, BRANCH                 11633000
         SPACE 2                                                        11634000
VERP86   TM    FLAGSCC,RECFMV      RECFM=V?                             11635000
         BNO   VERP88              NO, BRANCH                           11636000
         SR    R4,R4                                                    11637000
         ICM   R4,B'0011',0(R3)    RECORD LENGTH +4                     11638000
         LR    R14,R4              RECORD LENGTH +4                     11639000
         AH    R3,=H'4'            SKIP RECORD LENGTH WORD              11640000
         SH    R4,=H'4'            RECORD LENGTH VALID?                 11641000
         BNM   VERP88              YES, BRANCH                          11642000
         TM    #MEMPTR,#MEMLRL0    LRECL ERROR NOTED?                   11643000
         BO    VERP76              YES, BRANCH                          11644000
         OI    #MEMPTR,#MEMLRL0    LRECL ERROR NOTED                    11645000
         MVI   MTHIGHL,1           LENGTH OF MESSAGE                    11646000
         LA    R14,240(,R14)       RECORD LENGTH IN DISPLAY             11647000
         STC   R14,INSERT#1        PLACE IN THE MESSAGE                 11648000
         LA    R1,L811$1           LRECL TOO SMALL                      11649000
         BAL   R2,VERMBR                                                11650000
         B     VERP76                                                   11651000
         SPACE 2                                                        11652000
VERP87   CLI   RLDCOUNT,X'FF'      ANY RLD/CONTROL RECORD YET?          11653000
         BNE   VERP88              YES, BRANCH                          11654000
         TM    0(R3),X'F0'         TEST, ESD, IDR OR SCATTER RECORD?    11655000
         BM    VERP88              YES, BRANCH                          11656000
         MVC   RLDCOUNT(1),3(R3)   NO, FIRST RLD/CONTROL ENTRY          11657000
         SPACE 2                                                        11658000
VERP88   L     R1,#MEMCNT          ANOTHER                              11659000
         LA    R1,1(,R1)                  OUTPUT                        11660000
         ST    R1,#MEMCNT                       RECORD                  11661000
         L     R0,#VERCLOG         NUMBER                               11662000
         A     R0,=F'1'                  OF LOGICAL                     11663000
         ST    R0,#VERCLOG                         RECORDS              11664000
         CH    R14,LRECL           VALID LRECL VALUE?                   11665000
         BNH   VERP84              YES, BRANCH                          11666000
         TM    FLAGSCC,RECFMU      RECFM=U?                             11667000
         BO    VERP84              YES, BRANCH                          11668000
         TM    #MEMPTR,#MEMLRLE    LRECL ERROR NOTED?                   11669000
         BO    VERP84              YES, BRANCH                          11670000
         OI    #MEMPTR,#MEMLRLE    LRECL ERROR HAS BEEN NOTED           11671000
         CVD   R14,DOUBLE                                               11672000
         MVC   INSERT#1(8),=X'4020206B20212040'                         11673000
         ED    INSERT#1(7),DOUBLE+5                                     11674000
         LA    R1,L813$1           LRECL TOO LARGE                      11675000
         BAL   R2,VERMBR                                                11676000
         B     VERP84                                                   11677000
         SPACE 2                                                        11678000
VERP90   MVI   #MEMCNT,X'FF'              END OF DATA SET               11679000
         SPACE 2                                                        11680000
VERP92   SR    R0,R0               LENGTH OF RECORD & KEY (KDD OF RKDD) 11681000
         BAL   R2,VERCOMP          DATA IS RETAINED IN THE OUTPUT       11682000
         OC    12(3,R6),12(R6)            ANY USER TTR?                 11683000
         BZ    VERP93                     NO, BRANCH                    11684000
         STM   R14,R12,12(R13)            CONVERT CCHHR TO TTR          11685000
         LA    R2,CURMBB                  CCHHR TO CONVERT              11686000
         L     R1,INDCB+(DCBDEBAD-IHADCB) DEB ADDRESS                   11687000
         L     R15,ADDRRLTV               ADDRESS OF CCHHR->TTR CONVERT 11688000
         LR    R3,R13                     ADDRESS OF SAVE AREA          11689000
         BALR  R14,R15                    CALL CONVERT ROUTINE          11690000
         LR    R13,R3                     RESTORE SAVE AREA ADDRESS     11691000
         ST    R0,12+4+4(R13)             RESULT TTR RETURNED IN R0     11692000
         LM    R14,R12,12(R13)            RESTORE REGISTERS             11693000
         CLM   R0,B'1110',12(R6)          TTR ACTUALLY INPUT?           11694000
         BH    VERP93                     YES, BRANCH                   11695000
         LA    R1,L871                    NO, ERROR MESSAGE             11696000
         BAL   R2,VERMBR                                                11697000
         SPACE 1                                                        11698000
VERP93   OC    #MEMCNT+1(3),#MEMCNT+1  ANY RECORDS?                     11699000
         BNZ   VERP94                  YES, BRANCH                      11700000
         LA    R1,L510                 NO, NULL MEMBER WARNING          11701000
         BAL   R2,VERMBR                                                11702000
         SPACE 2                                                        11703000
VERP94   CLI   15(R6),X'FF'        OS/VS LINKAGE EDITOR?                11704000
         BE    VERP96              NO, BRANCH                           11705000
         CLC   15(1,R6),RLDCOUNT   RLD/CONTROL COUNTS MATCH?            11706000
         BE    VERP96              YES, BRANCH                          11707000
         LA    R1,L826             NO, ERROR MESSAGE                    11708000
         BAL   R2,VERMBR                                                11709000
         SPACE 2                                                        11710000
VERP96   CLI   #MEMCNT,X'FF'       END OF DATA SET?                     11711000
         BNE   VERP74              NO, BRANCH                           11712000
         MESSAGE MSGBLANK                                               11713000
         TSMSG L006                YES, STATUS MESSAGE                  11714000
         SPACE 2                                                        11715000
VERP97   TM    #VERSTAT,2          STATISTICS DESIRED?                  11716000
         BO    NEWCMD              NO, BRANCH                           11717000
         MESSAGE MSGBLANK                                               11718000
         MVI   MTHIGHL,10                                               11719000
         TM    FLAGSCC,RECFMU      RECFM=U?                             11720000
         BO    VERP98              YES, BRANCH                          11721000
         L     R0,#VERCLOG         NUMBER OF LOGICAL RECORDS INPUT      11722000
         CVD   R0,DOUBLE                                                11723000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    11724000
         ED    INSERT#1(10),DOUBLE+4                                    11725000
         TSMSG L110$1                                                   11726000
         SPACE 1                                                        11727000
VERP98   L     R2,#VERCBLK         NUMBER OF PHYSICAL BLOCKS INPUT      11728000
         CVD   R2,DOUBLE                                                11729000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    11730000
         ED    INSERT#1(10),DOUBLE+4                                    11731000
         TSMSG L111$1                                                   11732000
         SPACE 1                                                        11733000
         LTR   R2,R2               ANY RECORDS?                         11734000
         BNP   VERP98B             NO, BRANCH                           11735000
         L     R1,#VERMAX          MAXIMUM CHARACTERS/BLOCK             11736000
         CVD   R1,DOUBLE                                                11737000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    11738000
         ED    INSERT#1(10),DOUBLE+4                                    11739000
         TSMSG L112$1                                                   11740000
         SR    R0,R0                                                    11741000
         L     R1,#VERCBLC         NUMBER OF CHARACTERS READ            11742000
         SRL   R2,1                AMOUNT FOR ROUNDING                  11743000
         AR    R1,R2                                                    11744000
         D     R0,#VERCBLK         AVERAGE CHARACTERS/BLOCK             11745000
         CVD   R1,DOUBLE                                                11746000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    11747000
         ED    INSERT#1(10),DOUBLE+4                                    11748000
         TSMSG L113$1                                                   11749000
         SPACE 1                                                        11750000
VERP98B  TM    #VERUPDT,4+2        SINGLE MEMBER CHECK?                 11751000
         BO    NEWCMD              YES, DONE                            11752000
         LH    R0,DS1LSTAR         GET TT OF LAST TRACK USED            11753000
         S     R0,#VERCTRK         LESS THE AMOUNT AFTER THE COMPRESS   11754000
         BNM   *+6                 ZERO OR MORE, BRANCH                 11755000
         SR    R0,R0               NEGATIVE, ERROR (USE ZERO)           11756000
         CVD   R0,DOUBLE           NUMBER OF WHOLE COMPRESSED TRACKS    11757000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    11758000
         ED    INSERT#1(10),DOUBLE+4                                    11759000
         TSMSG L114$1                                                   11760000
         B     VERP99B                                                  11761000
         SPACE 2                                                        11762000
VERP99   TM    #VERSTAT,2          STATISTICS DESIRED?                  11763000
         BO    NEWCMD              NO, BRANCH                           11764000
         TM    #VERUPDT,4+2        SINGLE MEMBER CHECK?                 11765000
         BO    NEWCMD              YES, DONE                            11766000
         MESSAGE MSGBLANK                                               11767000
         SPACE 1                                                        11768000
VERP99B  MVI   MTHIGHL,10          TEN BYTES OF INSERTED MESSAGE        11769000
         L     R1,#MEMLAST         LAST MEMBER POINTER                  11770000
         L     R2,#MEMPTR          START OF MEMBER LIST                 11771000
         LA    R2,0(,R2)           CLEAR HIGH-ORDER DIGIT               11772000
         SR    R1,R2               (END+1 - START) * 16                 11773000
         SRL   R1,4                DIVIDE BY 16                         11774000
         CVD   R1,DOUBLE                                                11775000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    11776000
         ED    INSERT#1(10),DOUBLE+4                                    11777000
         TSMSG L115$1                                                   11778000
         MESSAGE MSGBLANK                                               11779000
         B     NEWCMD                                                   11780000
         SPACE 2                                                        11781000
VERMBR   ST    R2,#SAVEREG         SAVE REGISTER                        11782000
         ST    R1,MSGTEXT1         SAVE FOR LATER OUTPUT                11783000
         LA    R1,MEMNAME          ASSUME DATA SET CHECK                11784000
         TM    #VERUPDT,4+2        MEMBER NAME CHECK?                   11785000
         BNO   *+8                 NO, BRANCH                           11786000
         LA    R1,DIRNAME          YES, USE DIRECTORY NAME              11787000
         CLC   #VERMEM(8),0(R1)    MEMBER NAME DISPLAYED?               11788000
         BE    VERMBR20            YES, BRANCH                          11789000
         MVC   #VERMEM(8),0(R1)    MEMBER NAME DISPLAYED                11790000
         SPACE 1                                                        11791000
         MVC   MSGTEXT2(136),MSGBL132                                   11792000
         MVC   MSGTEXT2+4(2),=C'**'                                     11793000
         MVC   MSGTEXT2+4+3(8),##SUBCOM                                 11794000
         TM    DSORG,DS1DSGPO      PARTITIONED?                         11795000
         BNO   VERMBR10            NO, BRANCH                           11796000
         MESSAGE MSGBLANK          ONE BLANK LINE                       11797000
         MVC   MSGTEXT2+4+3+8+1(8),#VERMEM                              11798000
         TR    MSGTEXT2+4+3+8+1(8),TRLINE                               11799000
         MVC   DOUBLE(8),#VERMEM                                        11800000
         LA    R1,7                                                     11801000
         LA    R14,DOUBLE+8                                             11802000
         SPACE 1                                                        11803000
VERMBR02 BCTR  R14,0               SCAN                                 11804000
         CLI   0(R14),X'40'            BACKWARDS                        11805000
         BNE   *+8                              FOR FIRST               11806000
         BCT   R1,VERMBR02                               NON-BLANK      11807000
         SPACE 1                                                        11808000
         CLI   #VERMEM,C'0'        NUMERIC FIRST CHARACTER?             11809000
         BNL   VERMBR04            YES, NON-STANDARD                    11810000
         TRT   DOUBLE(*-*),TRTMEM  <<EXECUTED>>                         11811000
         EX    R1,*-6              VALID CHARACTERS?                    11812000
         BZ    VERMBR10            YES, BRANCH                          11813000
         SPACE 1                                                        11814000
VERMBR04 MVC   MSGTEXT2+4+3+8+1+8+2(2),=C'X'''                          11815000
         UNPK  MSGTEXT2+4+3+8+1+8+2+2(9),#VERMEM(5)                     11816000
         UNPK  MSGTEXT2+4+3+8+1+8+2+2+8(9),#VERMEM+4(5)                 11817000
         TR    MSGTEXT2+4+3+8+1+8+2+2(8+8),TRTABLE                      11818000
         MVI   MSGTEXT2+4+3+8+1+8+2+2+8+8,C''''                         11819000
         TM    #VERSTND,X'02'          STANDARD NAME CHECKING?          11820000
         BNZ   VERMBR10                NO, BRANCH                       11821000
         MVC   MSGTEXT2+48(24),=CL24'NON-STANDARD MEMBER NAME'          11822000
         MESSAGE MSGTEXT2          MEMBER HEADER MESSAGE                11823000
         L     R2,#SAVEREG         RESTORE REGISTER                     11824000
         BR    R2                                                       11825000
         SPACE 1                                                        11826000
VERMBR10 MESSAGE MSGTEXT2          MEMBER HEADER MESSAGE                11827000
         SPACE 1                                                        11828000
VERMBR20 L     R1,MSGTEXT1         MESSAGE IDENTIFIER OR MESSAGE        11829000
         LTR   R1,R1               ANY MESSAGE?                         11830000
         BZ    VERMBR30            NO, BRANCH                           11831000
         TSMSG (R1)                                                     11832000
VERMBR30 MVI   MTHIGHL,8           RESET THE MESSAGE LENGTH             11833000
         L     R2,#SAVEREG         RESTORE REGISTER                     11834000
         BR    R2                                                       11835000
         SPACE 2                                                        11836000
VERCOMP  ST    R0,#VERCREG                                              11837000
         SPACE 1                                                        11838000
VERCOMP2 L     R0,#VERCREG                                              11839000
         L     R1,#VERCREC                                              11840000
         A     R1,=F'1'            CURRENT COMPRESS RECORD              11841000
         ST    R1,#VERCREC                                              11842000
         ICM   R0,B'1000',#VERCREC+3  RECORD NUMBER IN RKDD (R OF RKDD) 11843000
         SPACE 1                                                        11844000
         TRKCALC FUNCTN=TRKBAL,TYPE=BYTEUCB+1,REGSAVE=YES,             X11845000
               BALANCE=#VERCBAL+2,RKDD=(0),MF=(E,PARMLIST)              11846000
         SPACE 1                                                        11847000
         LTR   R15,R15             FIT ON CURRENT TRACK?                11848000
         BZ    VERCOMPX            YES, BRANCH                          11849000
         SPACE 1                                                        11850000
         L     R1,#VERCTRK                                              11851000
         A     R1,=F'1'            START A NEW TRACK IN OUTPUT          11852000
         ST    R1,#VERCTRK                                              11853000
         MVI   #VERCREC+3,0        RECORD ZERO                          11854000
         B     VERCOMP2            TRY AGAIN                            11855000
         SPACE 1                                                        11856000
VERCOMPX ST    R0,#VERCBAL         SAVE THE TRACK BALANCE               11857000
         BR    R2                                                       11858000
         EJECT                                                          11859000
VERS00   OI    ##ADRPA#,$Q         ENTER QUIET MODE PROCESSING          11860000
         SPACE 1                                                        11861000
         MVC   MEMNAME(8),BLANKS   INITIALIZE THE MEMBER NAME           11862000
         MVC   DSNMEMQ(8),MEMNAME  MEMBER NAME TO CHECK                 11863000
         BAL   R2,ENQMTEST         MEMBER IN USE?                       11864000
         B     *+8                 YES, BRANCH                          11865000
         B     VERS40              NO, BRANCH                           11866000
         MVC   INSERT#1(8),INSERT#2  JOBNAME                            11867000
         TSMSG L851$1                                                   11868000
         SPACE 2                                                        11869000
VERS40   CLI   #VERREAD,X'02'      NOINPUT REQUESTED?                   11870000
         BE    VERS99              YES, BRANCH                          11871000
         SPACE 2                                                        11872000
         MVI   #MEMPTR,0           CLEAR THE MEMBER FLAG                11873000
         XC    #MEMCNT(4),#MEMCNT  COUNT OF INPUT LOGICAL RECORDS       11874000
         MVI   STARTTR+2,X'01'     TTR=000001 (START OF DATA SET)       11875000
         SPACE 2                                                        11876000
VERS76   L     R15,=A(EXCP)                                             11877000
         BALR  R14,R15                                                  11878000
         B     *+4(R15)            PROCESS RETURN CODE                  11879000
         B     VERS80                00 - SUCCESSFUL READ               11880000
         B     VERS90                04 - END OF FILE                   11881000
         B     VERS92                08 - END OF DATA SET               11882000
         B     VERS78                12 - I/O ERROR                     11883000
         SPACE 2                                                        11884000
*  PERMANENT I/O ERROR  -- SIMULATE END OF DATA SET                     11885000
VERS78   MVI   MTHIGHL,6           LENGTH OF THE TTR INSERT             11886000
*        MVC   INSERT#1(6),INSERT#1        FIRST PARAMETER              11887000
         TSMSG L991$1              OUTPUT THE I/O ERROR MESSAGE         11888000
         MVI   MTHIGHL,8                   RESET TO EIGHT               11889000
         B     VERS97                                                   11890000
         SPACE 2                                                        11891000
VERS80   LR    R3,R0               BUFFER START                         11892000
         L     R5,LS               BLOCK LENGTH                         11893000
         C     R5,#VERMAX          GREATER THAN MAXIMUM?                11894000
         BNH   *+8                 NO, BRANCH                           11895000
         ST    R5,#VERMAX          YES, SAVE NEW MAXIMUM                11896000
         L     R0,#VERCBLK         NUMBER                               11897000
         A     R0,=F'1'                  OF PHYSICAL                    11898000
         ST    R0,#VERCBLK                          BLOCKS              11899000
         L     R0,#VERCBLC         NUMBER                               11900000
         AR    R0,R5                     OF PHYSICAL                    11901000
         ST    R0,#VERCBLC                          CHARACTERS          11902000
         CH    R5,BLKSI            BLKSIZE VALID?                       11903000
         BNH   VERS81              YES, BRANCH                          11904000
         TM    #MEMPTR,#MEMBLKE    BLKSIZE SIZE ERROR NOTED?            11905000
         BO    VERS81              YES, BRANCH                          11906000
         OI    #MEMPTR,#MEMBLKE    BLKSIZE ERROR NOTED NOW              11907000
         CVD   R5,DOUBLE                                                11908000
         MVC   INSERT#1(8),=X'4020206B20212040'                         11909000
         ED    INSERT#1(7),DOUBLE+5                                     11910000
         TSMSG L812$1                                                   11911000
         SPACE 1                                                        11912000
VERS81   TM    FLAGSCC,RECFMF      FIXED FORMAT?                        11913000
         BNO   VERS82              NO, BRANCH                           11914000
         LH    R14,LRECL           CURRENT LRECL                        11915000
         TM    #MEMPTR,#MEMDIVE    BLKSIZE/LRECL ERROR NOTED?           11916000
         BO    VERS82              YES, BRANCH                          11917000
         LR    R0,R5               BLOCK LENGTH                         11918000
         SRDA  R0,32                                                    11919000
         DR    R0,R14              BLKSIZE/LRECL                        11920000
         LTR   R0,R0               ANY REMAINDER?                       11921000
         BZ    VERS82              YES, BRANCH                          11922000
         OI    #MEMPTR,#MEMDIVE    BLKSIZE/LRECL ERROR NOTED NOW        11923000
         CVD   R5,DOUBLE                                                11924000
         MVC   INSERT#1(8),=X'4020206B20212040'                         11925000
         ED    INSERT#1(7),DOUBLE+5                                     11926000
         TSMSG L814$1                                                   11927000
         LH    R14,LRECL           CURRENT LRECL                        11928000
         SPACE 1                                                        11929000
VERS82   LR    R1,R5                                                    11930000
         AR    R5,R3               END OF BUFFER                        11931000
         BCTR  R5,0                END OF BUFFER -1                     11932000
         TM    FLAGSCC,RECFMF      RECFM=F?                             11933000
         LH    R4,LRECL                                                 11934000
         BO    VERS88              YES, BRANCH                          11935000
         TM    FLAGSCC,RECFMU      RECFM=U?                             11936000
         LR    R4,R1                                                    11937000
         BO    VERS88              YES, BRANCH                          11938000
         TM    FLAGSCC,RECFMV      RECFM=V?                             11939000
         BNO   VERS88              NO, ASSUME RECFM=U                   11940000
         AH    R3,=H'4'            SKIP BLOCK LENGTH WORD               11941000
         B     VERS86                                                   11942000
         SPACE 3                                                        11943000
VERS84   BXLE  R3,R4,VERS86        GET THE NEXT LOGICAL RECORD          11944000
         B     VERS76              END OF BLOCK, BRANCH                 11945000
         SPACE 2                                                        11946000
VERS86   TM    FLAGSCC,RECFMV      RECFM=V?                             11947000
         BNO   VERS88              NO, BRANCH                           11948000
         SR    R4,R4                                                    11949000
         ICM   R4,B'0011',0(R3)    RECORD LENGTH +4                     11950000
         LR    R14,R4              RECORD LENGTH +4                     11951000
         AH    R3,=H'4'            SKIP RECORD LENGTH WORD              11952000
         SH    R4,=H'4'            RECORD LENGTH VALID?                 11953000
         BP    VERS88              YES, BRANCH                          11954000
         TM    #MEMPTR,#MEMLRL0    LRECL ERROR NOTED?                   11955000
         BO    VERS76              YES, BRANCH                          11956000
         OI    #MEMPTR,#MEMLRL0    LRECL ERROR NOTED                    11957000
         MVI   MTHIGHL,1           LENGTH OF MESSAGE                    11958000
         LA    R14,240(,R14)       RECORD LENGTH IN DISPLAY             11959000
         STC   R14,INSERT#1        PLACE IN THE MESSAGE                 11960000
         TSMSG L811$1                                                   11961000
         MVI   MTHIGHL,8                   RESET TO EIGHT               11962000
         B     VERS76              YES, BRANCH                          11963000
         SPACE 2                                                        11964000
VERS88   L     R1,#MEMCNT          ANOTHER                              11965000
         LA    R1,1(,R1)                  OUTPUT                        11966000
         ST    R1,#MEMCNT                       RECORD                  11967000
         L     R0,#VERCLOG         NUMBER                               11968000
         A     R0,=F'1'                  OF LOGICAL                     11969000
         ST    R0,#VERCLOG                         RECORDS              11970000
         CH    R14,LRECL           VALID LRECL VALUE?                   11971000
         BNH   VERS84              YES, BRANCH                          11972000
         TM    FLAGSCC,RECFMU      RECFM=U?                             11973000
         BO    VERS84              YES, BRANCH                          11974000
         TM    #MEMPTR,#MEMLRLE    LRECL ERROR NOTED?                   11975000
         BO    VERS84              YES, BRANCH                          11976000
         OI    #MEMPTR,#MEMLRLE    LRECL ERROR HAS BEEN NOTED           11977000
         CVD   R14,DOUBLE                                               11978000
         MVC   INSERT#1(8),=X'4020206B20212040'                         11979000
         ED    INSERT#1(7),DOUBLE+5                                     11980000
         TSMSG L813$1                                                   11981000
         B     VERS84                                                   11982000
         SPACE 2                                                        11983000
VERS90   MESSAGE MSGBLANK                                               11984000
         TSMSG L005                       END OF FILE                   11985000
         MESSAGE MSGBLANK                                               11986000
         B     VERS76                     LOOP                          11987000
         SPACE 2                                                        11988000
VERS92   MESSAGE MSGBLANK                                               11989000
         TSMSG L006                       END OF DATA SET               11990000
         SPACE 2                                                        11991000
VERS97   MVI   MTHIGHL,10                                               11992000
         TM    FLAGSCC,RECFMU      RECFM=U?                             11993000
         BO    VERS98              YES, BRANCH                          11994000
         L     R0,#VERCLOG         NUMBER OF LOGICAL RECORDS INPUT      11995000
         CVD   R0,DOUBLE                                                11996000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    11997000
         ED    INSERT#1(10),DOUBLE+4                                    11998000
         TSMSG L110$1                                                   11999000
         SPACE 1                                                        12000000
VERS98   L     R2,#VERCBLK         NUMBER OF PHYSICAL BLOCKS INPUT      12001000
         CVD   R2,DOUBLE                                                12002000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    12003000
         ED    INSERT#1(10),DOUBLE+4                                    12004000
         TSMSG L111$1                                                   12005000
         SPACE 1                                                        12006000
         LTR   R2,R2               ANY RECORDS?                         12007000
         BNP   VERS99              NO, BRANCH                           12008000
         L     R1,#VERMAX          MAXIMUM CHARACTERS/BLOCK             12009000
         CVD   R1,DOUBLE                                                12010000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    12011000
         ED    INSERT#1(10),DOUBLE+4                                    12012000
         TSMSG L112$1                                                   12013000
         SR    R0,R0                                                    12014000
         L     R1,#VERCBLC         NUMBER OF CHARACTERS READ            12015000
         SRL   R2,1                AMOUNT FOR ROUNDING                  12016000
         AR    R1,R2                                                    12017000
         D     R0,#VERCBLK         AVERAGE CHARACTERS/BLOCK             12018000
         CVD   R1,DOUBLE                                                12019000
         MVC   INSERT#1(10),=X'40206B2020206B202120'                    12020000
         ED    INSERT#1(10),DOUBLE+4                                    12021000
         TSMSG L113$1                                                   12022000
         B     NEWCMD                                                   12023000
         SPACE 2                                                        12024000
VERS99   MESSAGE MSGBLANK                                               12025000
         LA    R1,L116                                                  12026000
         B     MSGNEW                                                   12027000
         AIF ('&CISP' EQ 'NO SPF').MA00760                         @D01
         COPY  DIALOG70                                                 12028000
.MA00760 ANOP  ,                                                   @D01
PDSMAIN  CSECT                                                          12029000
         TITLE 'P D S  --  PDS CHANGE                          1/15/85' 12030000
*********************************************************************** 12031000
***      CHANGE SUBCOMMAND                                          *** 12032000
*********************************************************************** 12033000
*                                                                       12034000
         SPACE 1                                                        12035000
CHANGE   L     R1,$DSN+8                ALLOCATION STATUS ROUTINE       12036000
         ST    R1,##ADRCMD              EXECUTED AFTER OPEN OF DATA SET 12037000
         MVI   ##ADRCM#,CONTINUE        FLAG TO CONTINUE                12038000
         SPACE 2                                                        12039000
CHANGE2  NI    FLAGSFF,FF-FCHANGE       DATA SET WAS CHANGED            12040000
         LA    R0,RESTART0              ABEND RECOVERY ADDRESS          12041000
         ST    R0,RECOVER                                               12042000
         AIF ('&CISP' EQ 'NO SPF').MA00780                         @D01
         OI    SPFLAG3,SPFCHN           SIGNAL ISPMODE         SS SEP84 12043000
.MA00780 ANOP  ,                                                   @D01
         BAL   R2,SHUTSTW2              DELETE ANY DATA SET ENQUEUES    12044000
         BAL   R2,CLOSEIT               CLOSE THE DATA SET              12045000
         BAL   R2,DEALLDCB              FREE THE DATA SET               12046000
         TM    FLAGSAA,FOPTIONS         ANY OPERANDS?                   12047000
         BO    RESTART0                 YES, BRANCH                     12048000
         SPACE 2                                                        12049000
         OI    FLAGSBB,FNOTFILE         NO FILE NAME NOW                12050000
         CLI   SAVDSN+1+2,0             ANY OTHER DSNAME?               12051000
         BE    RESTART0                 NO, DONE                        12052000
         SPACE 2                                                        12053000
         XC    SAVDSN+1(SAVLEN),DSNLEN  EXCHANGE                        12054000
         XC    DSNLEN(SAVLEN),SAVDSN+1          OLD AND NEW             12055000
         XC    SAVDSN+1(SAVLEN),DSNLEN                     DSNAMES      12056000
         MVC   DSPALLOC,SAVDSN          GET PREVIOUS DISPOSITION        12057000
         MVC   SAVDSN(1),DSPREQST       SAVE REQUESTED DISPOSITION      12058000
         MVC   DSPREQST,DSPALLOC        GET PREVIOUS DISPOSITION        12059000
         B     RESTART0                 BRANCH TO REALLOCATE            12060000
         TITLE 'P D S  --  PDS KLEAR                           1/15/85' 12061000
*********************************************************************** 12062000
***      KLEAR   SUBCOMMAND  (SCREEN CLEAR FOR 3270 SCREENS)        *** 12063000
*********************************************************************** 12064000
*                                                                       12065000
         SPACE 1                                                        12066000
KLEAR    LA    R2,NEWCMD           A K OR KLEAR COMMAND WAS ENTERED     12067000
CLEAR    ICM   R0,B'1111',PAGESIZE 3270 DISPLAY SCREEN?                 12068000
         BZ    CLEAR2              NO, JUST WRITE A BLANK LINE          12069000
         AIF ('&CISP' EQ 'NO SPF').MA00800                         @D01
         TM    SPFLAG0,SPFDON      ISPMODE ON?                          12070000
         BO    CLEAR2              YES, JUST WRITE A BLANK LINE         12071000
.MA00800 ANOP  ,                                                   @D01
         AIF   (&MVT).MA00820                                      @D01
         L     R1,16               --> CVT                              12072000
         L     R1,0(,R1)           --> TCB WORDS                        12073000
         L     R1,8(,R1)           --> CURRENT USER ASCB                12074000
         L     R1,X'6C'(,R1)       --> ASXB                             12075000
         L     R1,X'14'(,R1)       --> LWA                              12076000
         CLC   X'94'+1(3,R1),=F'0' SESSION MANAGER TMP ACTIVE?          12077000
         BNE   CLEAR2              YES, JUST WRITE A BLANK LINE         12078000
.MA00820 ANOP  ,                                                   @D01
         AIF ('&CONVTAM' EQ 'TCAMONLY').NCONV10                         12079000
         STFSMODE ON               TURN ON FULLSCREEN MODE              12080000
         LTR   R15,R15             Was STFSMODE successful?        @D01
         BNZ   CLEAR2              No, just write blank line       @D01
.NCONV10 ANOP                                                           12081000
         SPACE 1                                                        12082000
         AIF ('&CONVTAM' EQ 'VTAMONLY').NCONV20                         12083000
         LA    R0,12               SET SIZE FOR TPUT                    12084000
         LA    R1,=X'F1115D7E114040133C404000'                          12085000
         ICM   R1,B'1000',=X'03'   FULLSCR OPTION BITS                  12086000
         TPUT  (1),(0),R           FULL SCREEN TPUT TO CLEAR THE SCREEN 12087000
.NCONV20 ANOP                                                           12088000
         SPACE 1                                                        12089000
CLEAR1   TCLEARQ INPUT             CLEAR INPUT QUEUE FOR SYNCRONIZATION 12090000
         AIF ('&CONVTAM' EQ 'TCAMONLY').NCONV30                         12091000
         STLINENO LINE=1,MODE=OFF  TURN OFF FULL SCREEN MODE            12092000
.NCONV30 ANOP                                                           12093000
         SPACE 1                                                        12094000
         STFSMODE OFF              TURN OFF FULL SCREEN MODE            12095000
         AIF   (&MVT).MA00840                                      @D01
         STTMPMD  OFF              WAKE UP SESSION MANAGER              12096000
.MA00840 ANOP  ,                                                   @D01
         BR    R2                                                       12097000
         SPACE 1                                                        12098000
CLEAR2   MESSAGE MSGBLANK          WRITE A BLANK LINE ONLY              12099000
         BR    R2                                                       12100000
         TITLE 'P D S  --  PDS HEXC -- HEXADECIMAL CONVERSION  1/15/85' 12101000
*                                                                       12102000
*        ROUTINE TO HEXADECIMAL INPUT TO BINARY                         12103000
*                                                                       12104000
         SPACE 1                                                        12105000
*R5          START OF STRING                                            12106000
*R1          LENGTH OF STRING                                           12107000
*MSGTEXT1    PROMPTING MESSAGE FOR ANY ERROR                            12108000
*MSGTEXT2+0  LENGTH OF RESULT                                           12109000
*MSGTEXT2+1  MAXIMUM LENGTH OF RESULT                                   12110000
*MSGTEXT2+4  RESULTANT STRING                                           12111000
*R0          RESULT IN BINARY (UP TO FOUR BYTES)                        12112000
*R2          RETURN REGISTER                                            12113000
         SPACE 1                                                        12114000
HEXC     LA    R3,1(,R1)            STRING LENGTH +1                    12115000
         N     R3,=F'-2'            NEXT EVEN NUMBER                    12116000
         SR    R15,R15              ZERO                                12117000
         LA    R4,MSGTEXT2+4        WHERE OUTPUT GOES                   12118000
         LA    R0,2                 PAIRWISE COUNTER                    12119000
         BCTR  R5,0                 PREPARE FOR THE FIRST ADD           12120000
         CR    R1,R3                EVEN LENGTH ORIGINALLY?             12121000
         SRL   R3,1                                                     12122000
         STC   R3,MSGTEXT2          (STRING LENGTH +1)/2                12123000
         BNE   HEXC20               NO, BRANCH                          12124000
         SPACE 1                                                        12125000
HEXC10   LA    R5,1(,R5)            NEXT CHARACTER                      12126000
         IC    R15,0(,R5)           GET A BYTE TO CONVERT               12127000
         CLI   0(R5),C'0'                                               12128000
         BL    *+12                 0-9?                                12129000
         CLI   0(R5),C'9'                                               12130000
         BNH   HEXC20               YES, BRANCH                         12131000
         SPACE 1                                                        12132000
         LA    R15,9(,R15)          NO, ADJUST LOW DIGIT 1-5 TO A-F     12133000
         CLI   0(R5),C'A'           BELOW AN A?                         12134000
         BL    HEXC50               YES, INVALID                        12135000
         CLI   0(R5),C'F'           ABOVE AN F?                         12136000
         BH    HEXC50               YES, INVALID                        12137000
         SPACE 1                                                        12138000
HEXC20   SLL   R15,28               SHIFT                               12139000
         SLDL  R14,4                GET A GOOD DIGIT                    12140000
         BCT   R0,HEXC10            DO THE NEXT DIGIT OF A PAIR         12141000
         LA    R0,2                 PAIRWISE COUNTER                    12142000
         STC   R14,0(,R4)           SAVE AN OUTPUT CHARACTER            12143000
         LA    R4,1(,R4)            ANOTHER OUTPUT CHARACTER            12144000
         BCT   R3,HEXC10            DO ALL DIGITS                       12145000
         SPACE 2                                                        12146000
         CLC   MSGTEXT2(1),MSGTEXT2+1  TOO MANY DIGITS?                 12147000
         BH    HEXC40                  YES, INVALID                     12148000
         ICM   R0,B'1111',MSGTEXT2+4   RESULT REGISTER                  12149000
         CLI   MSGTEXT2,3              LENGTH:3                         12150000
         BH    4(R2)                     ABOVE, DONE                    12151000
         SRL   R0,8                                                     12152000
         BE    4(R2)                     EQUAL, RETURN                  12153000
         SRL   R0,8                                                     12154000
         CLI   MSGTEXT2,1              LENGTH:1                         12155000
         BH    4(R2)                     ABOVE, DONE                    12156000
         SRL   R0,8                                                     12157000
         B     4(R2)                     EQUAL, RETURN                  12158000
         SPACE 3                                                        12159000
HEXC40   TSMSG L840                 STRING IS TOO LONG                  12160000
         B     HEXC60                                                   12161000
         SPACE 1                                                        12162000
HEXC50   TSMSG L841                 INVALID HEXADECIMAL DIGITS          12163000
         SPACE 1                                                        12164000
HEXC60  $PUTGET MSGTEXT1,ATTN=0(R2) SECOND PART OF MESSAGE              12165000
         L     R5,ADDRCBUF          ENTERED DATA                        12166000
         LH    R1,0(,R5)            LENGTH OF STRING                    12167000
         LA    R5,4(,R5)            START OF DATA IN THE STRING         12168000
         SH    R1,=H'5'             VALID MACHINE LENGTH?               12169000
         LA    R3,0(R5,R1)          LAST BYTE OF INPUT STRING           12170000
         BZ    HEXC90               MAYBE, CHECK FURTHER                12171000
         BNP   HEXC60               NO, NULL STRING -- PROMPT AGAIN     12172000
         SPACE 1                                                        12173000
HEXC70   CLI   0(R3),X'40'          SCAN                                12174000
         BNE   HEXC80                   BACKWARDS                       12175000
         BCTR  R3,0                              FOR A                  12176000
         BCT   R1,HEXC70                               NON-BLANK        12177000
         B     HEXC90               POSSIBLE STRING -- CHECK            12178000
         SPACE 1                                                        12179000
HEXC80   CLI   0(R5),X'40'          SCAN                                12180000
         BNE   HEXC90                   FORWARDS                        12181000
         LA    R5,1(,R5)                        FOR A                   12182000
         BCT   R1,HEXC80                              NON-BLANK         12183000
         SPACE 1                                                        12184000
HEXC90   CLI   0(R5),X'40'          REAL STRING?                        12185000
         BE    HEXC60               NO, PROMPT AGAIN                    12186000
         MVI   MSGTEXT2+4,X'40'     BLANKS FOR                          12187000
         MVC   MSGTEXT2+5(40),MSGTEXT2+4      UPPER-CASING INPUTS       12188000
         OC    0(*-*,R5),MSGTEXT2+4 <<EXECUTED>>                        12189000
         EX    R1,*-6               UPPER-CASE THE INPUT DATA           12190000
         LA    R1,1(,R1)            ACTUAL STRING LENGTH                12191000
         B     HEXC                 PARSE THIS NEW STRING               12192000
         TITLE 'P D S  --  PDS YES/NO PROMPTING ROUTINE        1/15/85' 12193000
*                                                                       12194000
*        ROUTINE TO PROMPT FOR A YES OR NO ANSWER                       12195000
*                                                                       12196000
         SPACE 1                                                        12197000
YESNO    TM    FLAGSGG,FPROMCON          PROMPTING TURNED OFF?          12198000
         BO    4(R2)                     YES, SIMULATE A YES RESPONSE   12199000
YESNO1   TM    FLAGSEE,FBKGRND+FNOTTERM  INPUT FROM THE TERMINAL?       12200000
         BNZ   4(R2)                     NO, SIMULATE A YES RESPONSE    12201000
         TM    FLAGSBB,FONESHOT          ONE SUBCOMMAND ONLY?           12202000
         BO    4(R2)                     YES, ALL DONE                  12203000
         ST    R1,YESNOSV                PROMPTING MESSAGE ADDRESS      12204000
         SPACE 1                                                        12205000
YESNO2   L     R1,YESNOSV              PROMPTING MESSAGE ADDRESS        12206000
        $PUTGET (R1),ATTN=NEWCMD       PROMPT FOR DESIRED ACTION        12207000
         TM    FLAGSEE,FNOTTERM        INPUT FROM THE TERMINAL?         12208000
         BZ    YESNO4                  YES, BRANCH                      12209000
         OI    FLAGSBB,FCMD            NO, PDS SUBCOMMAND AVAILABLE     12210000
         B     4(R2)                   SIMULATE A YES RESPONSE          12211000
         SPACE 1                                                        12212000
YESNO4   TM    FLAGSBB,FNULL           NULL REPLY?                      12213000
         BO    YESNO2                  YES, TRY AGAIN                   12214000
         L     R1,ADDRCBUF                                              12215000
         LH    R14,0(,R1)              TOTAL NUMBER OF BYTES IN MESSAGE 12216000
         SH    R14,=H'4'               LESS LENGTH OF COUNT FIELDS      12217000
         SPACE 1                                                        12218000
YESNO6   CLI   4(R1),X'40'             BLANK?                           12219000
         BNE   YESNO8                  NO, BRANCH                       12220000
         LA    R1,1(,R1)               TRY THE NEXT BYTE                12221000
         BCT   R14,YESNO6              ANY NON-BLANK?                   12222000
         B     YESNO2                  NO, TRY AGAIN                    12223000
         SPACE 1                                                        12224000
YESNO8   OI    4(R1),X'40'             UPPER-CASE THE RESULT            12225000
         CLI   4(R1),C'N'              CHECK REPLY                      12226000
         BER   R2                      "N", RETURN AT +0                12227000
         SPACE 1                                                        12228000
         CLI   4(R1),C'Y'              VALID REPLY?                     12229000
         BNE   YESNO2                  NO, ASK AGAIN                    12230000
         B     4(,R2)                  "Y", RETURN AT +4                12231000
         TITLE 'P D S  --  PDS DATE CONVERSION ROUTINE         1/15/85' 12232000
*                                                                       12233000
*        DATE CONVERSION ROUTINE -- CHANGES FORMAT YYDDDF TO MMDDYY     12234000
*                                                                       12235000
         SPACE 1                                                        12236000
CONVDATE ST    R14,R14SAVE                                              12237000
         MVC   DAYTABLE,DAYMONTH                                        12238000
         XC    DOUBLE,DOUBLE                                            12239000
         MVC   0(3,R15),=X'456799' INVALID DATE IS 45/67/99             12240000
         SR    R14,R14             SETUP FOR LEAP YEAR TEST             12241000
         IC    R14,0(,R1)                                               12242000
         SLL   R14,4                                                    12243000
         ST    R14,DOUBLE+4                                             12244000
         OI    DOUBLE+7,X'0F'                                           12245000
         LR    R14,R1                                                   12246000
         CVB   R0,DOUBLE           GET YEAR IN BINARY                   12247000
         SR    R1,R1                                                    12248000
         SRDL  R0,2                SHIFT OFF REMAINDER OF YEAR/4        12249000
         LTR   R1,R1               THIS A LEAP YEAR?                    12250000
         BNZ   *+8                 NO, BRANCH                           12251000
         MVI   DAYTABLE+1,29       YES, FEB HAS 29 DAYS                 12252000
         SPACE 1                                                        12253000
         MVC   2(1,R15),0(R14)     YEAR RECORD CREATED                  12254000
         MVC   DOUBLE+6(2),1(R14)                                       12255000
         TM    DOUBLE+7,X'0C'      VALID SIGN?                          12256000
         BNO   DAYSKIP             NO, DON'T 0C7                        12257000
         CVB   R1,DOUBLE           GET RELATIVE DAYS IN BINARY          12258000
         SPACE 1                                                        12259000
         LA    R14,DAYTABLE                                             12260000
         SR    R0,R0                                                    12261000
DAYLOOP  IC    R0,0(R14)           DAYS THIS MONTH                      12262000
         SR    R1,R0               WITHIN THIS MONTH?                   12263000
         BNP   DAYNOW                                                   12264000
         LA    R14,1(R14)                                               12265000
         B     DAYLOOP                                                  12266000
         SPACE 1                                                        12267000
DAYNOW   AR    R1,R0               GET DAY OF THE MONTH                 12268000
         LA    R0,10                                                    12269000
         MR    R0,R0                                                    12270000
         CVD   R1,DOUBLE                                                12271000
         MVC   1(1,R15),DOUBLE+6                                        12272000
         LA    R1,DAYTABLE-1                                            12273000
         SR    R14,R1                                                   12274000
         LA    R1,10                                                    12275000
         MR    R0,R14                                                   12276000
         CVD   R1,DOUBLE                                                12277000
         MVC   0(1,R15),DOUBLE+6                                        12278000
         SPACE 1                                                        12279000
DAYSKIP  L     R14,R14SAVE                                              12280000
         BR    R14                                                      12281000
         TITLE 'P D S  --  PDS GROUP DISPLAY ROUTINE           1/15/85' 12282000
*                                                                       12283000
*        GROUP NAME DISPLAY -- UPDATES THE PDS300A MESSAGE              12284000
*                                                                       12285000
         SPACE 1                                                        12286000
DEFGROUP TM    DSORG,DS1DSGPO                  PARTITIONED?             12287000
         BNOR  R14                             NO, RETURN               12288000
         CLI   MEMBERD,0                       ANY DEFAULT YET?         12289000
         BER   R14                             NO, RETURN               12290000
         ST    R14,R14SAVE                     RETURN ADDRESS           12291000
         LA    R0,17                           MAX CHARACTERS           12292000
         L     R1,MSGENTPT                     WHERE TO START OUTPUT    12293000
         MVC   0(17,R1),MSGBL132+4             BLANK THE OUTPUT         12294000
         L     R14,PMEMMIN                     FIRST ELEMENT            12295000
         C     R14,PMEMMAX                     MEMBER LIST?             12296000
         BH    DEFGR10                         NO, BRANCH               12297000
         MVI   0(R1),C'('                      START OF MEMBER LIST     12298000
         LA    R1,1(,R1)                       NEXT CHARACTER           12299000
         BCTR  R0,0                            ONE LESS CHARACTER       12300000
         SPACE 1                                                        12301000
DEFGR10  MVI   0(R1),C':'                      ASSUME COLON SEPARATOR   12302000
         TM    MEMBERD,FMEMBER1+FMEMBER2       ANY MEMBERS?             12303000
         BZ    DEFGR90                         NO, ASSUME ALL MEMBERS   12304000
         MVC   0(8,R1),MEMBERD+1+2             ASSUME A SINGLE MEMBER   12305000
         TM    MEMBERD,FMEM#MEM                MEMBER GROUP?            12306000
         BNO   DEFGR90                         NO, DONE                 12307000
         SPACE 1                                                        12308000
         SR    R14,R14                                                  12309000
         ICM   R14,B'0011',MEMBERD+1           MACHINE LENGTH OF MEMBER 12310000
         BNZ   DEFGR20                         MORE THAN ZERO, BRANCH   12311000
         CLI   0(R1),X'00'                     NULL FIRST OPERAND?      12312000
         BNE   DEFGR20                         NO, BRANCH               12313000
         TM    MEMBERD,FMEMRANG                RANGE?                   12314000
         BO    DEFGR30                         YES, BRANCH              12315000
         SPACE 1                                                        12316000
DEFGR20  AH    R14,=H'1'                       ACTUAL LENGTH            12317000
         SR    R0,R14                          OK?                      12318000
         BNP   DEFGR90                         YES, BRANCH              12319000
         AR    R1,R14                          NEXT CHARACTER START     12320000
         SPACE 1                                                        12321000
DEFGR30  MVI   0(R1),C':'                      ASSUME RANGE             12322000
         TM    MEMBERD,FMEMRANG                CORRECT?                 12323000
         BO    *+8                             YES, BRANCH              12324000
         MVI   0(R1),C'/'                      NO, PATTERN              12325000
         TM    MEMBERD,FMEMBER2                ANY MEMBER 2?            12326000
         BNO   DEFGR90                         NO, BRANCH               12327000
         MVC   1(8,R1),MEMBERD+1+2+8           ADD THE SECOND NAME      12328000
         SPACE 1                                                        12329000
DEFGR90  L     R1,MSGENTPT                     WHERE TO START OUTPUT    12330000
         TR    0(17,R1),TRLINE                 TRANSLATE TO PRINTABLE   12331000
         L     R14,R14SAVE                     RETURN ADDRESS           12332000
         BR    R14                                                      12333000
         TITLE 'P D S  --  PDS PARSE CLEANUP ROUTINE           1/15/85' 12334000
*                                                                       12335000
*        PARSE CLEANUP ROUTINE                                          12336000
*                                                                       12337000
         SPACE 1                                                        12338000
FREEPDL  IKJRLSA ADDRANSR            RELEASE THE STORAGE                12339000
         SPACE 1                                                        12340000
         XC    ADDRANSR,ADDRANSR                                        12341000
         BR    R2                                                       12342000
         SPACE 2                                                        12343000
PACKMAX  LH    R15,4(,R1)             NUMBER OF DIGITS                  12344000
         S     R15,=F'1'              ANY CODED?                        12345000
         BM    4(R14)                 NO, RETURN AT +4                  12346000
         L     R1,0(,R1)              POINT TO INPUT STRING             12347000
         EX    R15,PACKNUMB           PACK ALL THE DIGITS               12348000
         CVB   R1,DOUBLE              CONVERT TO BINARY                 12349000
         BR    R14                    RETURN AT +0                      12350000
PACKNUMB PACK  DOUBLE(8),0(*-*,R1)    <<EXECUTED>>                      12351000
         AIF ('&CISP' EQ 'NO SPF').MA00860                         @D01
         TITLE 'P D S  --  INITIALIZATION OF SPF ENVIRONMENT   1/15/85' 12352000
*                                                                       12353000
*        CALL SPF; REQUEST SPF TO CALL PDS RECURSIVELY AS A DIALOG      12354000
*                                                                       12355000
         SPACE 1                                                        12356000
SPFRECUR OI    FLAGSFF,FSPFERR          SPF ERROR FLAG                  12357000
         MVI   ##ADRCM#,CONTINUE+EDITOR+FABEND                          12358000
         BAL   R2,CLOSEIT               NEED TO CLOSE BEFORE SPF        12359000
         BAL   R2,DEALLDCB              AND FREE THE DATA SET           12360000
         MVC   ISPFTEXT+4(L'ISPF),ISPF        ISPF   PGM(PDS45678) P... 12361000
         MVC   ISPFTEXT+ISPFPGM+4(8),PDSNAME  PDS COMMAND NAME          12362000
         CVD   R7,ISPFTEXT+4+ISPFPARM         ADD STORAGE ADDRESS       12363000
         LA    R1,L'ISPF+4              LENGTH OF STRING PASSED TO SPF  12364000
         SLL   R1,16                    CLEAR BOTTOM TWO BYTES          12365000
         ST    R1,ISPFTEXT              SAVE STRING TOTAL LENGTH        12366000
*        MESSAGE ISPFTEXT               DELETE * TO OUTPUT COMMAND      12367000
         SPACE 1                                                        12368000
         MVI   ISPFTEXT+3,8             OFFSET OF PGM(... PARAMETER     12369000
         LA    R1,ISPFTEXT              START OF PARAMETER LIST         12370000
         ST    R1,ADDRTEXT              COMMAND ADDRESS                 12371000
         SPACE 1                                                        12372000
         LA    R1,ADDRTEXT              START OF CPPL PARAMETERS        12373000
         ATTACH EPLOC=ISPF,ECB=SPFECB,SZERO=NO,SHSPV=78,              XX12374000
               SF=(E,ATTACHS1)                                          12375000
         ST    R1,SPFTCB                TCB ADDRESS FOR THE SUBTASK     12376000
         WAIT  ECB=SPFECB               WAIT FOR COMPLETION             12377000
         DETACH SPFTCB                  REMOVE THIS SUBTASK             12378000
         NI    FLAGSFF,FF-FSPFCALL      SPF FLAG TURNED OFF             12379000
         SR    R5,R5                                                    12380000
         CLC   ##SUBCOM(8),$END         END SUBCOMMAND?                 12381000
         BE    RETURN8                  YES, DONE                       12382000
         OI    FLAGSFF,FSPFERR          SPF ERROR                       12383000
         B     RESTART0                 REALLOCATE THE FILE AND REOPEN  12384000
.MA00860 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS LOGGING OF SESSION DATA         1/15/85' 12385000
         SPACE 1                                                        12386000
LOGDATA  L     R0,RECOVER                   CURRENT RECOVERY ADDRESS    12387000
         LA    R15,FIRST4K                  SECOND WORK AREA BASE       12388000
         STM   R14,R8,LOGREGS-FIRST4K(R15)  SAVE ENTRY REGISTERS        12389000
         LA    R0,LOGD90                    LOCAL RECOVERY ADDRESS      12390000
         ST    R0,RECOVER                                               12391000
         MVC   MSGLAST(80),MSGBL132+4       BLANK                       12392000
         LH    R14,0(,R1)                   LENGTH OF MESSAGE           12393000
         SH    R14,=H'5'                    MACHINE LENGTH VALID?       12394000
         BM    LOGD96                       NO, DO NOT LOG              12395000
         CH    R14,=H'79'                                               12396000
         BNH   *+8                          LINE LENGTH=MIN(80,ACTUAL)  12397000
         LH    R14,=H'79'                                               12398000
         MVC   MSGLAST(*-*),4(R1)          <<EXECUTED>>                 12399000
         EX    R14,*-6                     MOVE IN THE PROMPT           12400000
         LA    R0,MSGLAST                      OUTPUT THE MESSAGE       12401000
         TM    DCBRECFM-IHADCB+LOGDCB,DCBRECV  RECFM=V?                 12402000
         BNO   LOGD40                          NO, BRANCH               12403000
         CLC   0(2,R1),DCBLRECL-IHADCB+LOGDCB  LRECL OK?                12404000
         BNH   *+10                            YES, BRANCH              12405000
         MVC   0(2,R1),DCBLRECL-IHADCB+LOGDCB  NO, REDUCE LRECL         12406000
         LR    R0,R1                                                    12407000
         SPACE 1                                                        12408000
LOGD40   NI    FLAGSFF,FF-FLOGWRT           TURN OFF FOR AN ERROR       12409000
         PUT   LOGDCB,(0)                                               12410000
         OI    FLAGSFF,FLOGWRT              TURN ON -- IT IS OK         12411000
         B     LOGD96                                                   12412000
         SPACE 1                                                        12413000
LOGD90   LA    R15,FIRST4K        RECOVERY: SECOND WORK AREA BASE       12414000
         LM    R14,R8,LOGREGS-FIRST4K(R15)  RESET ENTRY REGISTERS       12415000
         MVI   CONTOPTN,0                   TURN OFF RECORDING          12416000
         MVI   OPENLIST,X'80'                                           12417000
         CLOSE (LOGDCB),MF=(E,OPENLIST)                                 12418000
         TSMSG L081                         NOTE THE CLOSE              12419000
***TEST  OI    ATTNECB,X'40'                MARK AS AN ATTENTION        12420000
LOGD96   LA    R15,FIRST4K                  SECOND WORK AREA BASE       12421000
         LM    R14,R1,LOGREGS-FIRST4K(R15)  RESET CHANGED REGISTERS     12422000
         ST    R0,RECOVER                   RESET THE RECOVERY ADDRESS  12423000
         BR    R14                                                      12424000
         TITLE 'P D S  --  PDS ATTACH EXTERNAL SUBCOMMANDS     1/15/85' 12425000
*                                                                       12426000
*        ATTACH EXTERNAL PDS SUBCOMMANDS                                12427000
*                                                                       12428000
         SPACE 3                                                        12429000
ATTACH   LA    R0,NEWSTAX                 ABEND RECOVERY (EXCEPT EDIT)  12430000
         ST    R0,RECOVER                                               12431000
         SPACE 1                                                        12432000
ATTACH2  OI    ##ADRCM#,EXTERNAL          AN EXTERNAL SUBCOMMAND        12433000
         MVI   SUBSECB,0                  CLEAR THE ATTENTION ECB       12434000
         SPACE 2                                                        12435000
         AIF   (&MVT).MA00880                                      @D01
         ATTACH EPLOC=(3),ECB=SUBSECB,SZERO=NO,SHSPV=78,              XX12436000
               TERM=YES,ESTAI=(STAEEXIT,(7)),SF=(E,ATTACHS2)            12437000
         AGO   .NA00880                                            @D01
.MA00880 ANOP  ,                                                   @D01
         ATTACH EPLOC=(3),ECB=SUBSECB,SZERO=NO,SHSPV=78,           @D01+
               STAI=(STAEEXIT,(7)),SF=(E,ATTACHS2)                 @D01
.NA00880 ANOP  ,                                                   @D01
         SPACE 2                                                        12438000
         ST    R1,SUBSTCB                 SUBTASK TCB ADDRESS           12439000
         WAIT  ECB=SUBSECB                WAIT FOR COMPLETION           12440000
         SPACE 2                                                        12441000
         NI    ##ADRCM#,FF-EXTERNAL       BACK IN PDS NOW               12442000
         AIF   (&MVT).MA00900                                      @D01
         XC    M99RBPTR(40),M99RBPTR      CLEAR THE WORK AREA           12443000
         LA    R1,M99RBPTR                MARK ITS DATA SETS FOR REUSE  12444000
         USING S99RBP,R1                                                12445000
         SPACE 1                                                        12446000
         LA    R4,M99RB                                                 12447000
         USING S99RB,R4                                                 12448000
         ST    R4,S99RBPTR                                              12449000
         OI    S99RBPTR,S99RBPND          MARK END OF LIST              12450000
         SPACE 1                                                        12451000
         LA    R5,M99TUPL                                               12452000
         USING S99TUPL,R5                                               12453000
         MVI   S99RBLN,20                 LENGTH 20                     12454000
         MVI   S99VERB,S99VRBRI           REMOVE IN-USE VERB            12455000
         ST    R5,S99TXTPP                POINT TO TEXT POINTER         12456000
         SPACE 1                                                        12457000
         LA    R3,M99TUNIT                                              12458000
         USING S99TUNIT,R3                                              12459000
         ST    R3,S99TUPTR                POINT TO TEXT UNITS           12460000
         OI    S99TUPTR,S99TUPLN          MARK END OF LIST              12461000
         MVI   S99TUKEY+1,1               KEY=1                         12462000
         MVI   S99TUNUM+1,1               NUMBER=1                      12463000
         MVI   S99TULNG+1,4               LENGTH OF TEXT=4              12464000
         MVC   S99TUPAR(4),SUBSTCB        SUBTASK TCB ADDRESS           12465000
         SPACE 1                                                        12466000
         DYNALLOC                                                       12467000
         AGO   .NA00900                                            @D01
.MA00900 ANOP  ,                                                   @D01
         XC    DAIR2C,DAIR2C       Zero DAIR block                 @D01
         LA    R15,DAIR2C          Point to DAIR block             @D01
         USING DAPB2C,R15          Addressability                  @D01
         MVI   DA2CCD+1,X'2C'      Entry code = mark not-in-use    @D01
         XC    DA2CFLG,DA2CFLG     Mark as not-in-use              @D01
         MVC   DA2CTCB,SUBSTCB      all TCB's data sets            @D01
         LA    R1,PARMLIST         Point to DAIR parameter list    @D01
         USING DAPL,R1             Address of DAIR parameter list  @D01
         MVC   DAPLUPT,ADDRUPT     Set UPT address in parm list    @D01
         MVC   DAPLECT,ADDRECT     Set ECT address in parm list    @D01
         MVC   DAPLECB,ATTNECB     Set ECB address in parm list    @D01
         MVC   DAPLPSCB,ADDRPSCB   Set PSCB address in parm list   @D01
         XC    ATTNECB,ATTNECB     Clear ECB                       @D01
         ST    R15,DAPLDAPB        Set parm block address in plist @D01
         DROP  R15                 End parm block addressability   @D01
         L     R15,ADDRDAIR        Get address of DAIR             @D01
         BALR  R14,R15             Go to DAIR                      @D01
         DROP  R1                  End parm list addressability    @D01
.NA00900 ANOP  ,                                                   @D01
         SPACE 2                                                        12468000
         ICM   R1,B'1111',SUBSTCB         NEED TO BE DETACHED?          12469000
         BZR   R2                         NO, DONE                      12470000
         MVC   FULLWORD(4),SUBSTCB        PREPARE FOR THE XC            12471000
         XC    SUBSTCB(4),SUBSTCB         DO NOT DETACH AGAIN           12472000
         DETACH FULLWORD                  REMOVE THIS SUBTASK           12473000
         BR    R2                         DONE                          12474000
         AIF   (&MVT).MA00920                                      @D01
         DROP  R1,R3,R4,R5                                              12475000
.MA00920 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS ATTENTION EXIT ROUTINE          1/15/85' 12476000
***                                                                     12477000
***      ATTENTION EXIT ROUTINE                                         12478000
***                                                                     12479000
         SPACE 1                                                        12480000
ATTNEXIT ENTER ATTNEXIT                                                 12481000
         MVC   PMEMHOLD(4),PMEMCURR      SAVE MEMBER LIST POSTION       12482000
         MVC   PMEMHOLD(1),FLAGSAA       SAVE MEMBER GROUP FLAG         12483000
         NI    FLAGSAA,FF-FMEM#MEM       TERMINATE ANY MEMBER GROUP     12484000
         MVC   PMEMCURR(4),=XL4'FFFFFF'  TERMINATE ANY MEMBER LIST      12485000
         TM    ATTNECB,2+1             PARSE OR "ENTER OPTIONS"?        12486000
         BO    ATTNPOST                YES, "ENTER OPTIONS" -- BRANCH   12487000
         SPACE 2                                                        12488000
         TM    ##ADRPA#,$A+$D          BROWSE, ISPF OR EDIT?            12489000
         BNO   ATTN$A                  NO, BRANCH                       12490000
         STAX  ,                       CANCEL THE ATTENTION EXIT        12491000
         B     ATTNDONE                                                 12492000
         SPACE 2                                                        12493000
ATTN$A   TM    ##ADRPA#,$A             ATTENTIONS ACCEPTED?             12494000
         BZ    ATTNPTGT                YES, BRANCH                      12495000
         MVI   ATTNECB,0               CLEAR THE ECB                    12496000
         TSMSG L481                                                     12497000
         B     ATTNDONE                                                 12498000
         SPACE 2                                                        12499000
ATTNPTGT TM    ATTNECB,X'40'           PREVIOUS ATTENTION CLEARED?      12500000
         BNZ   ATTNLOOP                NO, BRANCH                       12501000
         TCLEARQ INPUT                 SYNCRONIZE INPUT QUEUE AGAIN     12502000
         OI    FLAGSII,FATTNPRO        FLAG FOR PROMPT INPUT ONLY       12503000
         L     R2,R14PTGT              $PUTGET IS NOT RECURSIVE         12504000
        $PUTGET MSGENTDS               PROMPT WITH "ENTER OPTIONS"      12505000
         ST    R2,R14PTGT              $PUTGET IS NOT RECURSIVE         12506000
         TM    FLAGSBB,FNULL           NULL LINE ENTERED?               12507000
         BO    ATTNBACK                YES, UNDO ATTENTION              12508000
         OI    FLAGSBB,FCMD            NO, INDICATE COMMAND AVAILABLE   12509000
         B     ATTNPOST                                                 12510000
ATTNBACK MVC   PMEMCURR(4),PMEMHOLD    RESET MEMBER LIST POSTION        12511000
         TM    PMEMHOLD,FMEM#MEM       MEMBER GROUP IN PROGRESS?        12512000
         BNO   ATTNDONE                NO, BRANCH                       12513000
         OI    FLAGSAA,FMEM#MEM        RESET ANY MEMBER GROUP           12514000
         B     ATTNDONE                                                 12515000
         SPACE 2                                                        12516000
ATTNPOST LA    R1,ATTNECB              ASSUME THIS IS INTERNAL TO PDS   12517000
         TM    ##ADRCM#,EXTERNAL       CORRECT?                         12518000
         BZ    ATTNPOS2                YES, BRANCH                      12519000
         L     R2,SUBSTCB              SUBTASK TCB ADDRESS              12520000
         STATUS STOP,TCB=(2)           STOP THE SUBTASK                 12521000
         LA    R1,SUBSECB              SUBCOMMAND ECB                   12522000
ATTNPOS2 POST  (1)                     NOTIFY OF ATTENTION ENTERED      12523000
         XC    PARMLIST(28),PARMLIST   CLEAR THE STACK PARAMETER LIST   12524000
         LA    R1,PARMLIST                                              12525000
         L     R14,ADDRUPT                                              12526000
         L     R15,ADDRECT                                              12527000
         LA    R0,PARMLIST+24                                           12528000
         STM   R14,R0,IOPLUPT-IOPL(R1) FOR IOPLUPT, IOPLECT & IOPLECB   12529000
         L     R15,ADDRSTCK            STACK ROUTINE START              12530000
         STACK PARM=PARMLIST+16,DELETE=ALL,MF=(E,(1)),ENTRY=(15)        12531000
         SPACE 1                                                        12532000
ATTNDONE SR    R15,R15                 ATTENTION PROCESSED              12533000
         EXIT                                                           12534000
         SPACE 1                                                        12535000
ATTNLOOP MVI   ATTNECB,0               CLEAR THE ATTENTION ECB FOR NOW  12536000
         TSMSG L470                    POSSIBLE LOOP MESSAGE            12537000
         OI    ##ADRPA#,$Q             NO ABEND MSG, QUIET MODE         12538000
         DC    H'0'                    *** S0C1 ABEND TO RESTART PDS ** 12539000
         SPACE 2                                                        12540000
ATTNNULL BR    14                      JUST RETURN TO THE RETURN        12541000
         TITLE 'P D S  --  PDS ESTAE EXIT ROUTINE              1/15/85' 12542000
STAEINIT LA    R15,4                                                    12543000
         BR    R14                      RETURN                          12544000
         SPACE 1                                                        12545000
         USING *,R15                    TEMPORARY BASE                  12546000
STAEEXIT CH    R0,STAECD                WORK AREA PROVIDED?             12547000
         BNE   STAE10                   YES, BRANCH                     12548000
         SR    R15,R15                  NO RETRY TO BE ATTEMPTED        12549000
         BR    R14                      RETURN                          12550000
         DROP  R15                                                      12551000
STAECD   DC    H'12'                                                    12552000
         SPACE 1                                                        12553000
STAE10   STM   R14,R12,12(R13)          SAVE REGISTERS                  12554000
         LR    R5,R1                    SDWA POINTER                    12555000
         USING SDWA,R5                                                  12556000
         L     R7,SDWAPARM              WORK AREA ADDRESS               12557000
         LA    R15,STAESAVE             STAE SAVE AREA                  12558000
         ST    R13,4(,R15)                                              12559000
         ST    R15,8(,R13)                                              12560000
         LR    R13,R15                                                  12561000
         LM    R9,R12,BASES                                             12562000
         MVC   INSERT#1,MSGABE          ABEND MESSAGE                   12563000
         L     R0,SDWAABCC              ABEND CODE                      12564000
         SRDL  R0,12                    SHIFT USER ABEND TO R1          12565000
         ST    R0,FULLWORD              SYSTEM ABEND CODE               12566000
         UNPK  INSERT#1(5),FULLWORD+2(3)                                12567000
         TR    INSERT#1(4),TRTABLE                                      12568000
         MVI   INSERT#1,C'S'                                            12569000
         MVI   INSERT#1+4,X'40'                                         12570000
         SRL   R1,20                    USER ABEND                      12571000
         CVD   R1,DOUBLE                                                12572000
         UNPK  INSERT#1+MSGABEUS(5),DOUBLE+5(3)                         12573000
         MVI   INSERT#1+MSGABEUS+4,X'40'                                12574000
         MVC   INSERT#1+MSGABEPG(8),SDWANAME  PROGRAM NAME              12575000
         TR    INSERT#1+MSGABEPG(8),TRLINE    MAKE DISPLAYABLE          12576000
         SR    R0,R0                                                    12577000
         SR    R1,R1                                                    12578000
         ICM   R0,B'0111',SDWANXTP            NEXT INSTRUCTION          12579000
         ICM   R1,B'0111',SDWAEPA+1           ENTRY POINT ADDRESS       12580000
         SPACE 1                                                        12581000
         TM    FLAGSJJ,FTSOCMD                TSOCMD VERIFICATION?      12582000
         BNO   STAE12                         NO, BRANCH                12583000
         L     R1,=V(VTSOCMD)                 YES, ACTUAL START         12584000
         MVC   INSERT#1+MSGABEPG(8),=CL8'VTSOCMD'                       12585000
         SPACE 1                                                        12586000
STAE12   TM    FLAGSJJ,FSUBCMD                SUBCMD VERIFICATION?      12587000
         BNO   STAE14                         NO, BRANCH                12588000
         L     R1,=V(VSUBCMD)                 YES, ACTUAL START         12589000
         MVC   INSERT#1+MSGABEPG(8),=CL8'VSUBCMD'                       12590000
         SPACE 1                                                        12591000
STAE14   NI    FLAGSJJ,FF-FTSOCMD-FSUBCMD     RESET ESTAE FLAGS         12592000
         SR    R0,R1                          OFFSET TO ERROR POSITIVE? 12593000
         BP    STAE16                         YES, BRANCH               12594000
         AR    R0,R1                          NO, USE ERROR LOCATION    12595000
         SR    R1,R1                                                    12596000
         SPACE 1                                                        12597000
STAE16   CLI   INSERT#1+MSGABEPG,C'.'         UNPRINTABLE NAME?         12598000
         BNE   STAE20                         NO, BRANCH                12599000
         MVC   INSERT#1+MSGABEAT-1(27),INSERT#1+MSGABEAT-2              12600000
         AR    R0,R1                          YES, USE ERROR LOCATION   12601000
         SPACE 1                                                        12602000
STAE20   ST    R0,FULLWORD                                              12603000
         UNPK  INSERT#1+MSGABEAT(7),FULLWORD+1(4)                       12604000
         TR    INSERT#1+MSGABEAT(6),TRTABLE                             12605000
         MVI   INSERT#1+MSGABEAT+6,X'40'                                12606000
         CLC   INSERT#1+2(2),=C'3E'           S*3E ABEND?               12607000
         BE    STAE60                         YES, IGNORE THIS ABEND    12608000
         TM    ##ADRPA#,$Q                    QUIET MODE?               12609000
         BO    STAE30                         YES, BRANCH               12610000
         L     R2,MTADDR-1                    SAVE CURRENT PARM#1       12611000
         LA    R1,INSERT#1                    START OF THIS INSERT      12612000
         ST    R1,MTADDR-1                    TELL IKJEFF02             12613000
         MVI   MTHIGHL,MSGABEND-MSGABE        LENGTH FOR THIS MESSAGE   12614000
         TSMSG L999$1                         ABEND ERROR MESSAGE       12615000
         ST    R2,MTADDR-1                    RESET CURRENT PARM#1      12616000
         SPACE 1                                                        12617000
         TCLEARQ INPUT                        CLEAR ANY INPUT           12618000
         XC    PARMLIST(28),PARMLIST          CLEAR THE STACK           12619000
         LA    R1,PARMLIST                    AREA FOR STACK PARM LIST  12620000
         SPACE 1                                                        12621000
         L     R2,ADDRUPT                                               12622000
         L     R3,ADDRECT                                               12623000
         LA    R4,PARMLIST+24                                           12624000
         STM   R2,R4,IOPLUPT-IOPL(R1)         IOPLUPT, IOPLECT, IOPLECB 12625000
         SPACE 2                                                        12626000
         L     R15,ADDRSTCK                   STACK ROUTINE             12627000
         STACK PARM=PARMLIST+16,DELETE=ALL,MF=(E,(1)),ENTRY=(15)        12628000
         SPACE 1                                                        12629000
         NI    FLAGSAA,FF-FMEM#MEM            TURN OFF ANY MEMBER GROUP 12630000
         MVC   PMEMCURR(4),=XL4'FFFFFF'       TERMINATE ANY MEMBER LIST 12631000
         SPACE 2                                                        12632000
STAE30   LR    R1,R5                    SDWA START                      12633000
         STM   R0,R15,SDWASRSV          RESET THE RETURN REGISTERS      12634000
         LR    R0,R7                    MAIN SAVE AREA ADDRESS          12635000
         AIF ('&CISP' EQ 'NO SPF').MA00940                         @D01
         TM    FLAGSFF,FSPFCALL         SPF INITIALIZED?                12636000
         BNO   *+8                      NO, BRANCH                      12637000
         LA    R0,SPFMAIN               SAVEAREA WHEN PDS IS A DIALOGUE 12638000
.MA00940 ANOP  ,                                                   @D01
         ST    R0,SDWASR13              RESET REGISTER 13               12639000
         SR    R2,R2                                                    12640000
         ICM   R2,B'0111',RECOVER+1     ANY ABEND RECOVERY ADDRESS?     12641000
         BZ    STAE60                   NO, BRANCH                      12642000
         TM    ##ADRPA#,$Q              QUIET MODE?                     12643000
         BO    STAE32                   YES, BRANCH                     12644000
         TM    FLAGSGG,FRECVCON         STAE RECOVERY DISALLOWED?       12645000
         BO    STAE60                   YES, BRANCH                     12646000
         SPACE 1                                                        12647000
STAE32   TM    ##ADRCM#,EXTERNAL        EXTERNAL SUBCOMMAND?            12648000
         BO    STAE40                   YES, BRANCH                     12649000
         TM    ##ADRCM#,CONTINUE+FABEND CONTINUE THROUGH RECOVERY?      12650000
         BO    STAE35                   YES, BRANCH                     12651000
         NI    ##ADRCM#,FF-CONTINUE     TURN OFF ANY CONTINUATION       12652000
STAE35   LR    R1,R5                    PDS ABENDED !!!                 12653000
         AIF   (NOT &MVT).MA00960                                  @D01
         LA    R2,STAE90           Get retry stub address          @D01
.MA00960 ANOP  ,                                                   @D01
         L     R13,4(,R13)                                              12654000
         SETRP REGS=(14,12),RC=4,RETADDR=(2),RETREGS=YES,FRESDWA=YES    12655000
         SPACE 2                                                        12656000
STAE40   DS    0H                                                  @D01
         POST  SUBSECB                  NOTIFY ATTENTION ENTERED   @D01 12657000
         NI    FLAGSAA,FF-FMEM#MEM      TURN OFF ANY MEMBER GROUP  @D01
         MVC   PMEMCURR(4),=XL4'FFFFFF' TERMINATE ANY MEMBER LIST  @D01
         L     R13,4(,R13)                                         @D01
         LR    R1,R5                    SDWA POINTER               @D01
         SETRP REGS=(14,12),RC=16       NO RECOVERY                @D01
         SPACE 1                                                        12658000
STAE60   NI    FLAGSAA,FF-FMEM#MEM      TURN OFF ANY MEMBER GROUP       12659000
         MVC   PMEMCURR(4),=XL4'FFFFFF' TERMINATE ANY MEMBER LIST       12660000
         L     R13,4(,R13)                                              12661000
         LR    R1,R5                    SDWA POINTER                    12662000
         SETRP REGS=(14,12),RC=0        NO RECOVERY                     12663000
         AIF   (NOT &MVT).MA00980                                  @D01
         SPACE 1                                                   @D01
*---------------------------------------------------------------*  @D01
*        Stub retry routine for STAE.  Load the retry           *  @D01
*        registers from the work area and branch to the         *  @D01
*        real retry address.                                    *  @D01
*---------------------------------------------------------------*  @D01
         PUSH  USING               Preserve USING status           @D01
         DROP  ,                   End all addressability          @D01
STAE90   DS    0H                  Retry routine                   @D01
         USING STAE90,R15          Temporary addressability        @D01
         USING SDWA,R1             Addressability for SDWA         @D01
         L     R7,SDWAPARM         Restore main work area pointer  @D01
         USING WORKAREA,R7         Address work area               @D01
         DROP  R1                  End SDWA addressability         @D01
         FREEMAIN R,A=(1),LV=104   Free SDWA storage               @D01
         LM    R0,R14,SDWASRSV     Restore registers               @D01
         POP   USING               Restore normal USINGs           @D01
         MVC   STAEPARM,STAELIST   Copy model parm list            @D01
         STAE  STAEEXIT,CT,        Restablish                      @D01+
               PARAM=(R7),          recovery                       @D01+
               MF=(E,STAEPARM)       environment                   @D01
         L     R15,RECOVER         Get resume address              @D01
         BR    R15                 Go to it                        @D01
         LTORG ,                   Literal pool                    @D01
.MA00980 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS MEMBER IN USE CHECKING          1/15/85' 12664000
*                                                                       12665000
*        MEMBER IN USE CHECKS                                           12666000
*                                                                       12667000
         SPACE 2                                                        12668000
ENQMTEST MVC   PARMLIST(4),ENQTEST     INITIALIZE ENQUEUE PARAMTERS     12669000
         ENQ   (SPFEDIT,DSNAME,E,52,SYSTEMS),RET=TEST,MF=(E,PARMLIST)   12670000
         LTR   R15,R15                 MEMBER IN USE?                   12671000
         BZ    4(,R2)                  NO, SKIP ONE INSTRUCTION         12672000
         SPACE 1                                                        12673000
         AIF   (NOT &MVT).MA01000                                  @D01
         AIF ('&MVSLEV' LT 'MVS13X').NMVS13A                            12674000
         XC    PARMLIST(48),PARMLIST                                    12675000
         GQSCAN AREA=(WORKTBL,296),RESNAME=(SPFEDIT,DSNAME,52),        X12676000
               REQLIM=1,SCOPE=ALL,MF=(E,PARMLIST)                       12677000
         CH    R15,=H'4'               ALLOCATED?                       12678000
         BE    4(,R2)                  NO, RETURN                       12679000
         LA    R1,L862                 ERROR?                           12680000
         BH    MSGNEWXX                YES, TERMINATE                   12681000
         LH    R14,WORKTBL+RIBVLEN-RIB         VARIABLE SECTION LENGTH  12682000
         LA    R14,WORKTBL+RIBEND-RIB(R14)     START OF RIB ENTRY       12683000
         MVC   INSERT#2(8),RIBEJBNM-RIBE(R14)  JOBNAME                  12684000
         AGO   .GOTQCB                                                  12685000
.NMVS13A ANOP                                                           12686000
         MVC   INSERT#2(8),=CL8'????????'  NAME IF NOT ON SP 1.3 SYSTEM 12687000
         L     R14,16                  --> CVT                          12688000
         LA    R14,640(,R14)           --> FIRST QCB                    12689000
***TEST  LA    R14,TESTQCB  ***TEST    --> TEST STRUCTURE               12690000
         SPACE 1                                                        12691000
ENQ2     ICM   R14,B'0111',1(R14)      ANY MORE MAJORS?                 12692000
         BZ    ENQDONE                 NO, USE ????????                 12693000
         CLC   16(8,R14),SPFEDIT       SPFEDIT MAJOR?                   12694000
         BNE   ENQ2                    NO, CONTINUE LOOKING             12695000
         SPACE 1                                                        12696000
         LA    R14,8(,R14)             POINT TO START OF MINOR LIST     12697000
ENQ4     ICM   R14,B'0111',1(R14)      ANY MORE MINORS?                 12698000
         BZ    ENQDONE                 NO, USE ????????                 12699000
         CLI   16(R14),52              SAME LENGTH?                     12700000
         BNE   ENQ4                    NO, NO MATCH                     12701000
         CLC   DSNAME(52),20(R14)      THE SAME MINOR?                  12702000
         BNE   ENQ4                    NO, BRANCH                       12703000
         SPACE 1                                                        12704000
         L     R1,8(,R14)              FIRST (AND ONLY) QEL             12705000
         MVC   INSERT#2-2(2),14(R1)    ASID VALUE                       12706000
         L     R1,16                   --> CVT                          12707000
         L     R14,556(,R1)            --> ASVT                         12708000
         LA    R15,520(,R14)           --> ENTRY ADDRESS -4             12709000
         L     R0,516(,R14)            NUMBER OF ASID'S                 12710000
         SPACE 1                                                        12711000
ENQ6     LA    R15,4(,R15)             NEXT ENTRY                       12712000
         TM    0(R15),X'80'            IN USE?                          12713000
         BO    ENQ8                    NO, BRANCH                       12714000
         L     R1,0(,R15)              --> ASCB                         12715000
         CLC   INSERT#2-2(2),36(R1)    THIS ASCB?                       12716000
         BE    ENQ10                   YES, BRANCH                      12717000
ENQ8     BCT   R0,ENQ6                 CHECK ALL ACTIVE ASID'S          12718000
         B     ENQDONE                 NOT FOUND, USE ????????          12719000
         SPACE 1                                                        12720000
ENQ10    ICM   R15,B'1111',172(R1)     INITIATED PROGRAM JOBNAME        12721000
         BNP   ENQ12                   NO, BRANCH                       12722000
         MVC   INSERT#2(8),0(R15)      YES, GET THE JOBNAME             12723000
         B     ENQDONE                                                  12724000
ENQ12    ICM   R15,B'1111',176(R1)     JOBNAME FOR START/MOUNT/LOGON    12725000
         BNP   ENQ14                   NO, CANNOT LOCATE                12726000
         MVC   INSERT#2(8),0(R15)      YES, GET THE JOBNAME             12727000
         B     ENQDONE                                                  12728000
ENQ14    MVC   INSERT#2(8),=CL8'SYSTEM'                                 12729000
         ICM   R15,B'1111',56(R1)      CSCB?                            12730000
         BNP   ENQDONE                 NO, BRANCH                       12731000
         MVC   INSERT#2(8),8(R15)      YES, GET THE JOBNAME             12732000
         SPACE 3                                                        12733000
         AGO   .GOTQCB      ***TEST                                     12734000
         B     ENQDONE                                                  12735000
         LA    R14,TESTQCB             --> TEST STRUCTURE               12736000
TESTQCB  DC    A(TESTQCB2)                                              12737000
TESTQCB2 DC    A(TESTQCB3),A(0),A(MINOR1),A(0),CL8'SYSDSN'              12738000
TESTQCB3 DC    A(00000000),A(0),A(MINOR2),A(0),CL8'SPFEDIT'             12739000
MINOR1   DC    CL2'NOT USED'                                            12740000
MINOR2   DC    A(MINOR3),A(0),A(TESTQEL1),A(0),AL1(52),AL3(0)           12741000
         DC    CL44'HABL.LIB.CNTL',CL8'XXXXXXXX'                        12742000
MINOR3   DC    A(0),A(0),A(TESTQEL2),A(0),AL1(52),AL3(0)                12743000
         DC    CL44'HABL.LIB.CNTL',CL8'PDSMAIN'                         12744000
TESTQEL1 DC    A(0),A(0),A(0),AL2(0),AL2(1)                             12745000
TESTQEL2 DC    A(0),A(0),A(0),AL2(0),AL2(2)                             12746000
         SPACE 3                                                        12747000
.GOTQCB  ANOP                                                           12748000
.MA01000 ANOP  ,                                                   @D01
ENQDONE  DS    0H                                                       12749000
         MVI   MTHIGHL,8               EIGHT CHARACTER MEMBER NAME      12750000
         MVI   MTHIGHL+4,8             EIGHT CHARACTER JOBNAME          12751000
         MVC   INSERT#1(8),DSNMEMQ     MEMBER IN USE                    12752000
         LA    R1,L850$2               ERROR MESSAGE                    12753000
         TM    ##ADRPA#,$Q             QUIET MODE CHECK?                12754000
         BOR   R2                      YES, RETURN                      12755000
         TSMSG (R1)                    YES, MESSAGE                     12756000
         BR    R2                                  AND ERROR RETURN     12757000
         TITLE 'P D S  --  PDS STANDARD MESSAGES               1/15/85' 12758000
*                                                                       12759000
*        SUBCOMMAND MESSAGE SUBROUTINES                                 12760000
*                                                                       12761000
         SPACE 3                                                        12762000
NOMEMBER LA    R1,L853$1              MSG - (MEMBER) NOT FOUND          12763000
         MVC   INSERT#1(8),DIRNAME                                      12764000
         B     MSGNEW                                                   12765000
         SPACE 3                                                        12766000
BADMEMB  LA    R1,L854$1              MSG - (MEMBER) IS AN INVALID NAME 12767000
         MVC   INSERT#1(8),DIRNAME                                      12768000
         B     MSGNEW                                                   12769000
         SPACE 3                                                        12770000
MEMEXIST LA    R1,L852$1              MSG - (MEMBER) EXISTS             12771000
         MVC   INSERT#1(8),DIRNAME                                      12772000
         B     MSGNEW                                                   12773000
         SPACE 3                                                        12774000
INVABBR  LA    R1,L930$1              MSG - (SUBCOM.) INVALID ABBREV.   12775000
         MVC   INSERT#1(8),##SUBCOM                                     12776000
         LA    R3,1(,R3)              ACTUAL SUBCOMMAND NAME LENGTH     12777000
         STC   R3,MTHIGHL                                               12778000
         B     MSGNEW                                                   12779000
         SPACE 3                                                        12780000
IOERROR  LA    R1,L836                MSG - I/O ERROR IN DIRECTORY      12781000
         B     MSGNEWXX                                                 12782000
         SPACE 3                                                        12783000
FULLDIR  LA    R1,L855                MSG - DIRECTORY IS FULL           12784000
         SPACE 2                                                        12785000
MSGNEWXX NI    FLAGSAA,FF-FMEM#MEM       TURN OFF ANY MEMBER GROUP      12786000
         MVC   PMEMCURR(4),=XL4'FFFFFF'  TERMINATE ANY MEMBER LIST      12787000
         SPACE 2                                                        12788000
MSGNEW   TSMSG (R1)                   OUTPUT THE MESSAGE REFERRED TO    12789000
         B     NEWCMD                   AND GET A NEW SUBCOMMAND        12790000
         TITLE 'P D S  --  PDS IKJEFF02 SETUP PROCESSING       1/15/85' 12791000
*                                                                       12792000
*        IKJEFF02 SETUP PROCESSING                                      12793000
*                                                                       12794000
         SPACE 1                                                        12795000
TSMSGRT  CLI   0(R1),C'0'               IKJEFF02 CALL?                  12796000
         BL    MESSAGE0                 NO, BRANCH                      12797000
         ST    R14,R14PUTT              SAVE RETURN ADDRESS             12798000
         MVC   MTMSGID+1(3),0(R1)       MESSAGE IDENTIFIER              12799000
         TR    INSERT#1(8),TRLINE       TRANSLATE ANY MEMBER NAME       12800000
         CLI   0(R1),C'4'               WARNING OR ERROR MESSAGE?       12801000
         BL    TSMSGRT5                 NO, BRANCH                      12802000
         LA    R0,3*5/3                 NUMBER OF MESSAGES TO SAVE      12803000
         LA    R15,ERRORMSG-3           START OF MESSAGES -3            12804000
         SPACE 1                                                        12805000
TSMSGRT2 LA    R15,3(,R15)              NEXT SAVED MESSAGE ID           12806000
         CLC   0(3,R15),0(R1)           THIS MESSAGE?                   12807000
         BE    TSMSGRT5                 YES, BRANCH                     12808000
         CLI   0(R15),X'00'             EMPTY SLOT?                     12809000
         BNE   TSMSGRT3                 NO, BRANCH                      12810000
         MVC   0(3,R15),0(R1)           YES, SAVE THIS MESSAGE ID       12811000
         B     TSMSGRT5                                                 12812000
TSMSGRT3 BCT   R0,TSMSGRT2              CONTINUE FOR ALL POSITIONS      12813000
         MVC   ERRORMSG(3*5),ERRORMSG+3 SLIDE UP BY ONE ENTRY           12814000
         MVC   ERRORMSG+3*5-3(3),0(R1)  SAVE THIS NEW ENTRY             12815000
         SPACE 1                                                        12816000
TSMSGRT5 LA    R15,PARTADDR-4           PARTITIONED SEARCH LIST -4      12817000
         L     R1,PARTADDR              INITIALIZE FOR THE LOOP         12818000
TSMSGRT7 LA    R15,4(,R15)              NEXT LIST ENTRY                 12819000
         LR    R0,R1                    SAVE FOR OVERRUN                12820000
         L     R1,0(,R15)               POINTER IN MSGCSECT             12821000
         CLI   0(R1),X'40'              END OF MSGCSECT?                12822000
         BE    TSMSGRT9                 YES, BRANCH                     12823000
         CLC   1(3,R1),MTMSGID+1        IN THIS PARTITION ELEMENT?      12824000
         BNH   TSMSGRT7                 NO, BRANCH                      12825000
         SPACE 1                                                        12826000
TSMSGRT9 ST    R0,MTCSECTP              START OF MESSAGE CSECT          12827000
         LA    R1,MTPLPTR               START OF PARAMETER LIST         12828000
         L     R15,ADDRFF02             START OF IKJEFF02               12829000
         BALR  R14,R15                  FORMAT THIS MESSAGE             12830000
         SPACE 1                                                        12831000
         L     R14,R14PUTT              LOAD RETURN ADDRESS             12832000
         AIF   (NOT &MVT).MA01010                                  @D01
         BR    R14                      RETURN                     @D01
         AGO   .NA01010                                            @D01
.MA01010 ANOP  ,                                                   @D01
         L     R1,MTEXTRCT              ADDRESS OF EXTRACTED MESSAGE    12833000
         CLC   4(3,R1),=C'PDS'          PDS ROUTINE MESSAGE?            12834000
         BNE   MESSAGE0                 NO, BRANCH                      12835000
         AIF ('&CISP' EQ 'NO SPF').MA01020                         @D01
         TM    SPFLAG0,SPFDON           SPF DISPLAY MODE ON    SS SEP84 12836000
         BO    MESSAGE0                 YES, WANT MSGIDS       SS SEP84 12837000
.MA01020 ANOP  ,                                                   @D01
         L     R15,ADDRUPT              ADDRESS OF THE UPT              12838000
         TM    UPTSWS-UPT(R15),UPTMID   MESSAGE ID DESIRED?             12839000
         BO    MESSAGE0                 YES, BRANCH                     12840000
         LH    R0,0(,R1)                CURRENT LENGTH                  12841000
         SH    R0,=H'8'                 LESS EIGHT                      12842000
         SLL   R0,16                    SHIFT TO CORRECT POSITION       12843000
         ST    R0,8(,R1)                STORE OVER MESSAGE-ID           12844000
         LA    R1,8(,R1)                POINT TO NEW LENGTH WORD        12845000
         B     MESSAGE0                                                 12846000
.NA01010 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS MESSAGE/PUTLINE PROCESSING      1/15/85' 12847000
*                                                                       12848000
*        MESSAGE PROCESSING (MULTILEVEL MESSAGES HAVE BEEN DISABLED)    12849000
*                                                                       12850000
         SPACE 1                                                        12851000
MESSTXT1 LA    R1,MSGTEXT1              OUTPUT MSGTEXT1                 12852000
         SPACE 1                                                        12853000
MESSAGE0 ST    R14,R14PUTM              SAVE LINKAGE REGISTER           12854000
        $PUTLINE (R1),ATTN=NEWCMD       DEFAULT INTERRUPT ADDRESS       12855000
         L     R14,R14PUTM              RESTORE LINKAGE REGISTER        12856000
         BR    R14                      RETURN                          12857000
         SPACE 3                                                        12858000
*                                                                       12859000
*        PUTLINE PROCESSING                                             12860000
*                                                                       12861000
         SPACE 1                                                        12862000
$PUTLINE TM    ATTNECB,X'40'          ATTN OCCUR?                       12863000
         BOR   R14                    YES, IMMEDIATE RETURN             12864000
         ST    R14,R14PUTL                                              12865000
         TM    FLAGSFF,FLOGWRT        LOG RECORDING?                    12866000
         BNO   PUTLINE1               NO, BRANCH                        12867000
         ST    R14,R14PUTL2           SECONDARY PUTLINE RETURN ADDRESS  12868000
         L     R14,R14PUTM                                              12869000
         ST    R14,R14PUTL2+4                                           12870000
         BAL   R14,LOGDATA            YES, LINK TO LOG ROUTINE          12871000
         L     R14,R14PUTL2+4                                           12872000
         ST    R14,R14PUTM            LINKAGE FOR MESSAGE0              12873000
         L     R14,R14PUTL2                                             12874000
         ST    R14,R14PUTL                                              12875000
PUTLINE1 DS    0H                                                       12876000
         SPACE 1                                                        12877000
         AIF ('&CISP' EQ 'NO SPF').MA01040                         @D01
         TM    SPFLAG0,SPFDON         DIALOG DISPLAY MODE      SS JUL84 12878000
         BZ    SPFNO1                 NO                       SS JUL84 12879000
         MVI   SPFLAG1,SPFPUTL        FUNCTION TYPE            SS JUL84 12880000
         L     R15,=V(ISPDSPY)                                 SS JUL84 12881000
         TM    ##ADRCM#,EXTERNAL      EXTERNAL SUBCOMMAND?    ABL NOV84 12882000
         BNOR  R15                    NO, CALL ISPMODE        ABL NOV84 12883000
         CLC   4(6,R1),=C'PDS999'     PDS ABEND MESSAGE?      ABL NOV84 12884000
         BNER  R15                    NO, CALL ISPMODE        ABL NOV84 12885000
*** ISPMODE CANNOT ISSUE THIS ERROR MESSAGE ???               ABL NOV84 12886000
SPFNO1   DS    0H                                              SS JUL84 12887000
.MA01040 ANOP  ,                                                   @D01
         SPACE 1                                                        12888000
         LR    R0,R1                  SAVE DATA LINE POINTER            12889000
         LA    R1,PARMLIST                                              12890000
         USING IOPL,R1                                                  12891000
         L     R14,ADDRUPT                                              12892000
         L     R15,ADDRECT                                              12893000
         STM   R14,R15,IOPLUPT       INITIALIZE IOPLUPT AND IOPLECT     12894000
         SPACE 1                                                        12895000
         LA    R15,ATTNECB                                              12896000
         ST    R15,IOPLECB           INITIALIZE IOPLECB                 12897000
         DROP  R1                                                       12898000
         SPACE 1                                                        12899000
         L     R15,ADDRPUTL                                             12900000
         SPACE 2                                                        12901000
         PUTLINE PARM=PUTLPARM,ENTRY=(15),MF=(E,(1)),                  X12902000
               OUTPUT=((0),TERM,SINGLE,DATA),                          X12903000
               TERMPUT=(EDIT,WAIT,NOHOLD,NOBREAK)                       12904000
         SPACE 2                                                        12905000
         L     R14,R14PUTL           RETURN ADDRESS (+0 OR +4)          12906000
         TM    ATTNECB,X'40'         ATTN OCCUR?                        12907000
         BOR   R14                   YES, RETURN AT +0                  12908000
         SPACE 2                                                        12909000
         CH    R15,=H'4'             PUTLINE ERROR SIGNALLED?           12910000
         BNH   4(R14)                NO, RETURN AT +4                   12911000
         SPACE 2                                                        12912000
         LA    R1,PUTLINER           ERROR MESSAGE                      12913000
         LA    R0,L'PUTLINER         ERROR MESSAGE LENGTH               12914000
         TPUT  (1),(0),R             PUTLINE FAILED                     12915000
         SPACE 2                                                        12916000
         L     R1,PUTLPARM+4         START OF OUTPUT MESSAGE            12917000
         LA    R1,4(,R1)             LESS LENGTH CODE                   12918000
         LA    R0,79                 FIRST 79 BYTES                     12919000
         TPUT  (1),(0),R             INVALID OUTPUT TEXT                12920000
         SPACE 2                                                        12921000
         NOP   NEWCMD                LOCATION FOR TEST COMMAND          12922000
         DC    H'0'                  FORCE AN ABEND CLEANUP             12923000
         SPACE 2                                                        12924000
PUTLINER DC    C'*** PUTLINE FAILED, RC > 4; DATA WAS:'                 12925000
         TITLE 'P D S  --  PDS PUTGET PROCESSING               1/15/85' 12926000
*                                                                       12927000
*        PUTGET PROCESSING                                              12928000
*                                                                       12929000
         SPACE 1                                                        12930000
$PUTGET  TM    ATTNECB,X'40'         ATTN OCCUR?                        12931000
         BOR   R14                   YES, IMMEDIATE RETURN              12932000
         LA    R0,1                  ONLY ONE SEGMENT                   12933000
         STM   R0,R1,PUTOLD1                                            12934000
         ST    R14,R14PTGT                                              12935000
         TM    FLAGSFF,FLOGWRT       LOG RECORDING?                     12936000
         BNO   PUTGT01               NO, BRANCH                         12937000
         ST    R14,R14PUTL2+8                                           12938000
         BAL   R14,LOGDATA           YES, LINK TO LOG ROUTINE           12939000
         L     R14,R14PUTL2+8                                           12940000
         ST    R14,R14PTGT                                              12941000
         L     R1,PUTOLD1+4          PROMPT MESSAGE                     12942000
PUTGT01  DS    0H                                                       12943000
         SPACE 1                                                        12944000
         AIF ('&CISP' EQ 'NO SPF').MA01060                         @D01
         TM    SPFLAG0,SPFDON         DIALOG DISPLAY MODE      SS JUL84 12945000
         BZ    SPFNO2                 NO                       SS JUL84 12946000
         MVI   SPFLAG1,SPFPTGET       FUNCTION TYPE            SS JUL84 12947000
         L     R15,=V(ISPDSPY)                                 SS JUL84 12948000
         BR    R15                                             SS JUL84 12949000
SPFNO2   DS    0H                                              SS JUL84 12950000
.MA01060 ANOP  ,                                                   @D01
         NI    FLAGSBB,FF-FNULL                                         12951000
         SPACE 1                                                        12952000
         LA    R0,1                  ONLY ONE SEGMENT                   12953000
         STM   R0,R1,PUTOLD1                                            12954000
         SPACE 2                                                        12955000
PUTGT02  LA    R1,PARMLIST                                              12956000
         L     R14,ADDRUPT                                              12957000
         L     R15,ADDRECT                                              12958000
         LA    R0,ATTNECB                                               12959000
         STM   R14,R0,IOPLUPT-IOPL(R1)  INITIALIZE IOPLUPT, IOPLECT,    12960000
*                                                  AND IOPLECB          12961000
         L     R15,ADDRPTGT                                             12962000
         LA    R14,PTGTPARM             LOAD PARM ADDRESS               12963000
         MVI   00(R14),X'10'            SINGLE LEVEL                    12964000
         MVI   01(R14),X'80'            MODE MESSAGE                    12965000
         MVI   08(R14),X'00'            PUTGET                          12966000
         MVI   10(R14),X'80'            TGET EDIT                       12967000
         LA    R0,PUTOLD1               ADDRESS OF OUTPUT               12968000
         ST    R0,4(,R14)                                               12969000
         SPACE 1                                                        12970000
         TM    FLAGSII,FATTNPRO         ATTENTION PROCESSING?           12971000
         BNO   PUTGT04                  NO, BRANCH                      12972000
         MVI   08(R14),X'10'            TERM PROCESSING                 12973000
         NI    FLAGSII,FF-FATTNPRO      NOT ATTENTION PROCESSING        12974000
         SPACE 1                                                        12975000
PUTGT04  PUTGET PARM=PTGTPARM,MF=(E,(1)),ENTRY=(15),                   X12976000
               TERMPUT=(EDIT,WAIT,NOHOLD,NOBREAK)                       12977000
         STC   R15,PARMLIST          SAVE RETURN CODE                   12978000
         NI    FLAGSEE,FF-FNOTTERM   ASSUME INPUT WAS FROM THE TERMINAL 12979000
         CLI   PARMLIST,4            CORRECT?                           12980000
         BNE   *+8                   YES, BRANCH                        12981000
         OI    FLAGSEE,FNOTTERM      NO, NOT FROM THE TERMINAL          12982000
         SPACE 1                                                        12983000
         CLI   PARMLIST,12           PUTGET STATUS:                     12984000
         BH    EXIT8N                  ERROR -- BRANCH                  12985000
         BL    PUTGT10                 SUCCESSFUL, STACK OR ATTENTION   12986000
         L     R1,ADDRECT              STACK, 2ND-LEVEL MSG., NO PAUSE  12987000
         OI    ECTMSGF-ECT(R1),X'80' IGNORE SECOND LEVEL MESSAGES AND   12988000
         B     PUTGT02               GET THE DATA FROM THE STACK        12989000
         SPACE 3                                                        12990000
PUTGT10  SR    R15,R15               ASSUME RETURN AT +0                12991000
         TM    ATTNECB,X'40'         ATTN OCCUR?                        12992000
         BO    PUTGT80               YES, BRANCH                        12993000
         SPACE 1                                                        12994000
         LA    R1,PTGTPARM           PUTGET PARM AREA START             12995000
         L     R1,PGPBIBUF-PGPB(R1)  INPUT BUFFER ADDRESS               12996000
         SPACE 2                                                        12997000
         LH    R14,0(,R1)            SUBCOMMAND LENGTH                  12998000
         CH    R14,=H'256'           MORE THAN PDS'S LIMIT?             12999000
         BNH   *+8                   NO, BRANCH                         13000000
         LH    R14,=H'256'           YES, USE THE CURRENT LIMIT         13001000
         BCTR  R14,0                 MACHINE LENGTH OF THIS LINE        13002000
         MVC   PUTGETBF(*-*),0(R1)   <<EXECUTED>>                       13003000
         EX    R14,*-6               SAVE THE ENTERED LINE              13004000
         SPACE 2                                                        13005000
         LH    R0,0(R1)              BUFFER LENGTH                      13006000
         ICM   R0,B'1000',=X'01'     SUBPOOL IS 1                       13007000
         SPACE 1                                                        13008000
         FREEMAIN R,LV=(0),A=(1)     RELEASE THE INPUT BUFFER           13009000
         SPACE 2                                                        13010000
         LA    R1,PUTGETBF           ADDRESS OF INPUT LINE              13011000
         ST    R1,ADDRCBUF           SAVE THE LINE ADDRESS              13012000
         SPACE 1                                                        13013000
         TM    FLAGSFF,FLOGWRT       LOG RECORDING?                     13014000
         BNO   PUTGT70               NO, BRANCH                         13015000
         L     R14,R14PTGT                                              13016000
         ST    R14,R14PUTL2+12                                          13017000
         L     R1,ADDRCBUF           USER RESPONSE                      13018000
         BAL   R14,LOGDATA           YES, LINK TO LOG ROUTINE           13019000
         L     R14,R14PUTL2+12                                          13020000
         ST    R14,R14PTGT                                              13021000
         SPACE 2                                                        13022000
PUTGT70  LA    R15,4                 ASSUME RETURN AT +4                13023000
         CH    R15,PUTGETBF          A NULL LINE?                       13024000
         BL    PUTGT80               NO, BRANCH                         13025000
         OI    FLAGSBB,FNULL         YES, INDICATE A NULL LINE          13026000
         SPACE 2                                                        13027000
PUTGT80  L     R14,R14PTGT                                              13028000
         B     0(R14,R15)                                               13029000
         TITLE 'P D S  --  PDS DATA SET ALLOCATION             1/15/85' 13030000
*                                                                       13031000
*        DATA SET ALLOCATION SUBROUTINE                                 13032000
*                                                                       13033000
         SPACE 2                                                        13034000
ALLOCATE CSECT                                                          13035000
         USING *,R8                                                     13036000
         LR    R8,R15                                                   13037000
         ST    R14,R14SAVE             SAVE LINKAGE REGISTER            13038000
         SPACE 2                                                        13039000
DYNA010  NI    FLAGSCC,FF-FPERMDS      CLEAR PERMANENT STATUS           13040000
         SPACE 2                                                        13041000
         AIF   (&MVT).MA01080                                      @D01
         XC    M99RBPTR(40),M99RBPTR    CLEAR THE WORK AREA             13042000
         LA    R1,M99RBPTR              DYNAMIC ALLOCATION              13043000
         USING S99RBP,R1                                                13044000
         SPACE 1                                                        13045000
         LA    R4,M99RB                                                 13046000
         USING S99RB,R4                                                 13047000
         ST    R4,S99RBPTR                                              13048000
         OI    S99RBPTR,S99RBPND        MARK END OF LIST                13049000
         SPACE 1                                                        13050000
         LA    R5,M99TUPL                                               13051000
         USING S99TUPL,R5                                               13052000
         MVI   S99RBLN,20               LENGTH 20                       13053000
         MVI   S99VERB,S99VRBAL         ALLOCATE                        13054000
         ST    R5,S99TXTPP              POINT TO TEXT POINTERS          13055000
         LA    R3,WORKTBL                        START OF TEXT          13056000
         SPACE 1                                                        13057000
         MVC   0(L'ALLDDNAM,R3),ALLDDNAM         SPECIFY DDNAME TEXT    13058000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13059000
         LA    R3,L'ALLDDNAM(,R3)                START OF NEXT TEXT     13060000
         SPACE 1                                                        13061000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13062000
         MVC   0(L'ALLDSORG,R3),ALLDSORG         SPECIFY DSORG TEXT     13063000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13064000
         LA    R3,L'ALLDSORG(,R3)                START OF NEXT TEXT     13065000
         SPACE 1                                                        13066000
         TM    FLAGSBB,FNOTFILE                  FILENAME ENTERED?      13067000
         BO    DYNA080                           NO, BRANCH             13068000
         SPACE 1                                                        13069000
         MVI   S99VERB,S99VRBIN                  REQUEST INFORMATION    13070000
         MVI   WORKTBL+1,X'01'                   SPECIFY DDNAME KEY     13071000
         MVC   WORKTBL+6(8),DDNAMEH              SPECIFY DDNAME         13072000
         MVC   DDNAME(8),DDNAMEH                 SAVE DDNAME            13073000
         MVI   WORKTBL+6+8+1,X'0A'               REQUEST DSORG          13074000
         SPACE 1                                                        13075000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13076000
         MVC   0(L'ALLDSNAM,R3),ALLDSNAM         SPECIFY DSNAME TEXT    13077000
         MVI   1(R3),X'05'                       REQUEST DSNAME KEY     13078000
         MVC   6(44,R3),MSGBL132+4               BLANK DSNAME           13079000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13080000
         OI    S99TUPTR,X'80'                    MARK END OF LIST       13081000
         SPACE 1                                                        13082000
         DYNALLOC                                                       13083000
         SPACE 1                                                        13084000
         LTR   R15,R15                           ANY PROBLEM?           13085000
         BNZ   DYNA400                           YES, BRANCH            13086000
         SPACE 1                                                        13087000
         MVC   DSNLEN(46),4(R3)                  GET DSN AND LENGTH     13088000
         MVC   DSORG(2),WORKTBL+20               SAVE RETURNED DSORG    13089000
         MVC   VOLUME(8),BLANKS                  SAVE RETURNED DSORG    13090000
         MVI   VOLALLOC,X'40'                    VOLUME IS NOT KNOWN    13091000
         L     R1,X'21C'                         --> CURRENT TCB        13092000
         L     R1,X'00C'(,R1)                    --> TIOT               13093000
         LA    R15,24                            OFFSET TO TIOENTRY     13094000
         SPACE 1                                                        13095000
DYNA060  LA    R1,0(R15,R1)                      NEXT ENTRY             13096000
         CLI   0(R1),0                           END OF TIOT?           13097000
         BE    DYNA200                           YES, BRANCH            13098000
         SR    R15,R15                                                  13099000
         IC    R15,0(,R1)                                               13100000
         CLC   4(8,R1),DDNAME                    THIS DDNAME?           13101000
         BNE   DYNA060                           NO, BRANCH             13102000
         SPACE 1                                                        13103000
         L     R14,16(,R1)                       POINT TO UCB           13104000
         TM    18(R14),X'20'                     DASD?                  13105000
         BO    DYNA070                           YES, BRANCH            13106000
         TSMSG L843                              NO, ERROR MESSAGE      13107000
         B     DYNA440                                                  13108000
         SPACE 1                                                        13109000
DYNA070  MVC   VOLUME(6),28(R14)                 SAVE VOLUME NAME       13110000
         MVC   VOLALLOC(6),28(R14)               SAVE VOLUME NAME       13111000
         LA    R1,0(R15,R1)                      NEXT ENTRY             13112000
         CLC   4(8,R1),BLANKS                    CONCATENATED ENTRY?    13113000
         BNE   DYNA200                           NO, BRANCH             13114000
         MVI   MTHIGHL,8                                                13115000
         MVC   INSERT#1(8),DDNAME                DDNAME IN ERROR        13116000
         TSMSG L844$1                                                   13117000
         B     DYNA440                                                  13118000
         SPACE 3                                                        13119000
DYNA080  LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13120000
         MVC   0(L'ALLVOLUM,R3),ALLVOLUM         SPECIFY VOLUME TEXT    13121000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13122000
         LA    R0,L'ALLVOLUM(,R3)                START OF NEXT TEXT     13123000
         SPACE 1                                                        13124000
         CLI   VOLUME,X'40'                      ANY VOLUME SPECIFIED?  13125000
         BE    DYNA100                           NO, BRANCH             13126000
         MVI   1(R3),X'10'                       CONVERT TO SPECIFY     13127000
         MVC   6(6,R3),VOLUME                    SPECIFY VOLUME         13128000
         LA    R3,L'ALLVOLUM(,R3)                START OF NEXT TEXT     13129000
         SPACE 1                                                        13130000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13131000
         MVC   0(L'ALLUNIT,R3),ALLUNIT           SPECIFY UNIT TEXT      13132000
         MVC   6(8,R3),=CL8'&DAUNIT'             COVER ANY UNIT    @D01
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13134000
         LA    R0,L'ALLUNIT(,R3)                 START OF NEXT TEXT     13135000
         SPACE 1                                                        13136000
DYNA100  LR    R3,R0                             NEXT TEXT POINTER      13137000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13138000
         MVC   0(L'ALLPERM,R3),ALLPERM           SPECIFY PERMANENT      13139000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13140000
         LA    R3,L'ALLPERM(,R3)                 START OF NEXT TEXT     13141000
         SPACE 1                                                        13142000
         CLI   PASSWORD,X'41'                    ANY PASSWORD?          13143000
         BL    DYNA140                           NO, BRANCH             13144000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13145000
         MVC   0(L'ALLPASSW,R3),ALLPASSW         SPECIFY PASSWORD TEXT  13146000
         MVC   6(8,R3),PASSWORD                  SPECIFY DDNAME         13147000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13148000
         LA    R3,L'ALLPASSW(,R3)                START OF NEXT TEXT     13149000
         SPACE 1                                                        13150000
DYNA140  LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13151000
         MVC   0(L'ALLDSNAM,R3),ALLDSNAM         SPECIFY DSNAME TEXT    13152000
         MVC   4(46,R3),DSNLEN                   SPECIFY DSNAME         13153000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13154000
         LA    R3,L'ALLDSNAM+44(,R3)             START OF NEXT TEXT     13155000
         SPACE 1                                                        13156000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13157000
         MVC   0(L'ALLALLOC,R3),ALLALLOC         SPECIFY DISP TEXT      13158000
         MVC   6(1,R3),DSPALLOC                  SPECIFY DISPOSITION    13159000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13160000
         LA    R3,L'ALLALLOC(,R3)                START OF NEXT TEXT     13161000
         SPACE 1                                                        13162000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13163000
         MVC   0(L'ALLNORM,R3),ALLNORM           SPECIFY NORMAL TEXT    13164000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13165000
         LA    R3,L'ALLNORM(,R3)                 START OF NEXT TEXT     13166000
         SPACE 1                                                        13167000
         LA    R5,4(,R5)                         NEXT POINTER ELEMENT   13168000
         MVC   0(L'ALLANORM,R3),ALLANORM         SPECIFY ABNORMAL TEXT  13169000
         ST    R3,S99TUPTR                       POINT TO TEXT UNIT     13170000
         OI    S99TUPTR,X'80'                    MARK END OF LIST       13171000
         SPACE 1                                                        13172000
         DYNALLOC                                                       13173000
         SPACE 2                                                        13174000
         DROP  R1,R4,R5                                                 13175000
         LTR   R15,R15                  SUCCESSFUL?                     13176000
         BNZ   DYNA400                  NO, BRANCH                      13177000
         MVC   DDNAME,WORKTBL+6         SAVE DDNAME                     13178000
         MVC   DSORG(2),WORKTBL+20      SAVE DSORG                      13179000
         MVC   VOLALLOC(6),VOLUME       SET THE VOLUME SPECIFIED        13180000
         CLI   VOLUME,X'40'             ANY VOLUME?                     13181000
         BNE   *+10                     YES, BRANCH                     13182000
         MVC   VOLALLOC(6),WORKTBL+28   GET THE ALLOCATED VOLUME NAME   13183000
         AGO   .NA01080                                            @D01
.MA01080 ANOP  ,                                                   @D01
*---------------------------------------------------------------*  @D01
*        Allocate data set using DAIR.  The "FILE()" form       *  @D01
*        of allocation is not suppored.                         *  @D01
*---------------------------------------------------------------*  @D01
         LA    R6,DAIR08               POINT TO THE DAIR BLOCK     @D01 08320000
         XC    DAIR08,DAIR08                                       @D01 08321000
         USING DAPB08,R6                                           @D01 08322000
         MVI   DA08CD+1,X'08'          DATA SET ALLOCATION CODE    @D01 08323000
         SPACE 1                                                   @D01 08324000
         LA    R0,DSNLEN               ADDR OF DSNAME FIELD        @D01 08325000
         ST    R0,DA08PDSN                                         @D01 08326000
         SPACE 1                                                   @D01 08327000
         MVC   DA08PSWD,PASSWORD       PASSWORD                    @D01 08328000
         MVC   DA08DDN,BLANKS          NO DDNAME                   @D01 08329000
         MVC   DA08SER,VOLUME          VOLUME SPECIFIED (OR BLANK) @D01 08330000
         MVC   DA08MNM,BLANKS          NO MEMBER NAME              @D01 08331000
         MVC   DA08UNIT,BLANKS         NO UNIT REQUESTED           @D01 08332000
         CLI   VOLUME,X'40'            VOLUME SERIAL SPECIFIED?    @D01 08333000
         BE    *+10                    NO, BRANCH (CATALOG LOOKUP) @D01 08334000
         MVC   DA08UNIT,=CL8'&DAUNIT'  YES, DEFAULT UNIT           @D06 08335000
         SPACE 1                                                   @D01 08336000
*                                      DISP=(SHR,KEEP,KEEP)        @D01 08337000
         MVC   DA08DSP1,DSPALLOC         OR DISP=(OLD,KEEP,KEEP)   @D01 08338000
         MVI   DA08DPS2,DA08KEEP                                   @D01 08339000
         MVI   DA08DPS3,DA08KEP                                    @D01 08340000
**       OI    DA08CTL,DA08PERM         MUST BE SPECIFICALLY UNALC @D01 08341000
         SPACE 2                                                   @D01 08342000
         LA    R1,PARMLIST              DYNALLOC PARAMETER LIST    @D01 08343000
         USING DAPL,R1                                             @D01 08344000
         SPACE 1                                                   @D01 08345000
         L     R2,ADDRUPT          Get UPT address                 @D01 08346000
         L     R3,ADDRECT          Get ECT address                 @D01 08347000
         LA    R4,ATTNECB          Get address of ECB              @D01 08348000
         L     R5,ADDRPSCB         Get PSCB address                @D01 08349000
***      LA    R6,DAIR08           Get DAIR parm block address     @D01 08350000
         STM   R2,R6,DAPLUPT       Set DAPLUPT, DAPLECT, DAPLECB,  @D01
*                                      DAPLPSCB and DAPLDAPB       @D01 08352000
         SPACE 2                                                   @D01 08353000
         MVI   ATTNECB,0           Clear ECB                       @D01 08354000
         L     R15,ADDRDAIR        Get DAIR address                @D01 08355000
         BALR  R14,R15             Link to DAIR                    @D01 08356000
         LTR   R15,R15             Successful?                     @D01
         BNZ   DYNA400             No, branch                      @D01
         MVC   DDNAME,DA08DDN      Save DD name                    @D01
         MVC   WORKTBL+6(8),DA08DDN  Save DD name                  @D01
         MVC   DSORG(1),DA08DSO    Save DSORG                      @D01
         MVI   DSORG+1,X'00'       DSORG byte two                  @D01
         MVC   VOLALLOC(6),VOLUME  Set specified volume            @D01
         CLI   VOLUME,X'40'        Was volume specified?           @D01
         BNE   *+10                Yes, branch                     @D01
         MVC   VOLALLOC(6),DA08SER Get allocated volume name       @D01
.NA01080 ANOP  ,                                                   @D01
         SPACE 1                                                        13184000
         CLC   DDNAME(3),=C'SYS00000'     TEMPORARY TYPE DDNAME?        13185000
         BNE   DYNA200                    NO, BRANCH                    13186000
         NC    WORKTBL+6(8),=C'SYS00000'  TURN OFF NUMERIC DIGITS       13187000
         CLC   WORKTBL+6(8),=C'SYS00000'  TEMPORARY TYPE DDNAME?        13188000
         BE    *+8                        YES, BRANCH                   13189000
DYNA200  OI    FLAGSCC,FPERMDS            NO, MARK AS "PERMANENT"       13190000
         SPACE 1                                                        13191000
         DEVTYPE DDNAME,DEVTYPE,DEVTAB  GET DEVICE DEPENDENT DATA       13192000
         SPACE 1                                                        13193000
         L     R14,OBTAIN               OBTAIN FLAGS                    13194000
         LA    R15,DSNAME               ADDRESS OF DSNAME               13195000
         LA    R0,VOLALLOC              VOLUME SERIAL                   13196000
         LA    R1,DS1FMTID              OUTPUT START ADDRESS            13197000
         STM   R14,R1,PARMLIST          SAVE CAMLIST PARAMETERS         13198000
         OBTAIN PARMLIST                GET THE FORMAT 1 DSCB           13199000
         SPACE 1                                                        13200000
         LTR   R15,R15                  SUCESSFUL OBTAIN?               13201000
         BZ    DYNA260                  YES, BRANCH                     13202000
         SPACE 1                                                        13203000
*     IF THE DSNAME IS AN ALIAS ENTRY IN A VSAM CATALOG, A LOCATE       13204000
*     WILL PUT THE TRUE NAME IN THE DSNAME FIELD -- ISSUE A LOCATE,     13205000
*     AND TRY THE OBTAIN AGAIN.                                         13206000
         MVC   WORKTBL(44),DSNAME       COPY DSNAME TO ANOTHER AREA     13207000
         L     R14,LOCATE                                               13208000
         LA    R15,WORKTBL              ACTUAL DSNAME                   13209000
         SR    R0,R0                    NO CVOL VALUE                   13210000
         LA    R1,MSGTEXT1              LOCATE WORK AREA                13211000
         STM   R14,R1,PARMLIST          SAVE CAMLIST PARAMETERS         13212000
         LOCATE PARMLIST                                                13213000
         LTR   15,15                    SUCCESSFUL LOCATE?              13214000
         BNZ   DYNA240                  NO, ERROR                       13215000
         SPACE 1                                                        13216000
         L     R14,OBTAIN               OBTAIN FLAGS                    13217000
         LA    R15,WORKTBL              ACTUAL DSNAME                   13218000
         LA    R0,VOLALLOC              VOLUME SERIAL                   13219000
         LA    R1,DS1FMTID              OUTPUT START ADDRESS            13220000
         STM   R14,R1,PARMLIST          SAVE CAMLIST PARAMETERS         13221000
         OBTAIN PARMLIST                GET THE FORMAT 1 DSCB           13222000
         SPACE 1                                                        13223000
         LTR   R15,R15                  SUCCESSFUL OBTAIN?              13224000
         BZ    DYNA260                  YES, BRANCH                     13225000
DYNA240  MVI   VOLALLOC,X'40'           NO, SET BACK TO BLANK           13226000
         SPACE 2                                                        13227000
DYNA260  TM    DSORG,DS1DSGPO           PARTITIONED?                    13228000
         BO    DYNA300                  YES, BRANCH                     13229000
         SPACE 2                                                        13230000
         LA    R1,X'100'                TTR=1                           13231000
         ST    R1,DIRTTR                SAVE FOR LATTER                 13232000
         TM    ##ADRCM#,EDITOR          EDIT, BROWSE, TSOEDIT OR FSE?   13233000
         BO    DYNA300                  YES, BRANCH                     13234000
         TSMSG L530                     OUTPUT A WARNING MESSAGE        13235000
         SPACE 2                                                        13236000
DYNA300  L     R14,R14SAVE              RETURN AT                       13237000
         B     4(R14)                            +4 (SUCCESSFUL)        13238000
         SPACE 2                                                        13239000
DYNA400  CLC   DSNAMEH(3),=C'END'       WAS "END" ENTERED BY THE USER?  13240000
         BNE   DYNA410                  NO, BRANCH                      13241000
         TM    DSNAMEH+3,X'FF'-X'40'    WITH A FOLLOWING BLANK OR NULL? 13242000
         BZ    DYNA900                  YES, TERMINATE THE PROGRAM      13243000
         SPACE 1                                                        13244000
DYNA410  DS    0H                                                  @D01
         ST    R15,DAIRRC               RETURN CODE                     13246000
         LA    R15,DAIRRC               POINTER TO RETURN CODE          13247000
         LA    R0,ADDRFF02              POINTER TO A(IKJEFF02)          13248000
         AIF   (&MVT).MA01100                                      @D01
         LA    R14,M99RB                POINTER TO SVC 99 BLOCK    @D01 13245000
         LA    R1,=AL2(DFSVC99)         POINTER TO INVOCATION TYPE      13249000
         AGO   .NA01100                                            @D01
.MA01100 ANOP  ,                                                   @D01
         LA    R14,PARMLIST             POINTER TO DAIR PARM LIST  @D01
         LA    R1,=AL2(DFDAIR)          POINTER TO INVOCATION TYPE @D01
.NA01100 ANOP  ,                                                   @D01
         L     R2,ADDRCPPL              POINTER TO THE CPPL             13250000
         STM   R14,R2,DFDAPLP           INITIALIZE DFDAPLP, DFDRCP,     13251000
*                                         DFJEFF02, DFIDP AND DFCPPLP   13252000
         SPACE 1                                                        13253000
         LINK  EP=IKJEFF18,MF=(E,DFPARMS)                               13254000
         LTR   R15,R15                  PROBLEM WITH IKJEFF18?          13255000
         BZ    DYNA440                  NO, BRANCH                      13256000
         SPACE 2                                                        13257000
DYNA420  CVD   R15,DOUBLE                                               13258000
         MVI   MTHIGHL,4                                                13259000
         MVC   INSERT#1(4),=X'40202120'                                 13260000
         ED    INSERT#1(4),DOUBLE+6                                     13261000
         MVI   INSERT#1,C'='                                            13262000
         TSMSG L835$1                                                   13263000
         SPACE 1                                                        13264000
DYNA440  TM    FLAGSBB,FONESHOT         ONE SUBCOMMAND ONLY?            13265000
         BO    DYNA900                  YES, TERMINATE                  13266000
         CLI   DSPREQST,ALLOOLD         DISP=OLD REQUESTED?             13267000
         BE    DYNA500                  YES, ATTEMPT RETRY              13268000
         CLI   DSPALLOC,ALLOMOD         MOD ALLOCATION ATTEMPT?         13269000
         BE    DYNA444                  YES, BRANCH                     13270000
         CLI   DSPALLOC,ALLOOLD         OLD ALLOCATION ATTEMPT?         13271000
         BNE   DYNA500                  NO, REALLOCATE                  13272000
         SPACE 1                                                        13273000
DYNA444  MVI   DSPALLOC,ALLOSHR         YES, RETRY WITH DISP=SHR        13274000
         NI    FLAGSAA,FF-FMEM#MEM      TURN OFF MEMBER GROUPS          13275000
         NI    ##ADRCM#,FF-CONTINUE     TURN OFF THE CONTINUED FLAG     13276000
         B     DYNA010                                                  13277000
         SPACE 2                                                        13278000
DYNA500 $PUTGET PDS381A,ATTN=DYNA900    DATA SET RECOVERY ROUTINE       13279000
         SPACE 2                                                        13280000
         TM    FLAGSBB,FNULL            USER WANT ANOTHER DATA SET?     13281000
         BO    DYNA500                  NULL REPLY, ASK AGAIN           13282000
         SPACE 1                                                        13283000
         MVC   DSNLEN(SAVLEN),SAVDSN+1  RESET THE DATA SET NAME         13284000
         MVC   FULLWORD(4),##ADRCMD     SAVE CONTINUATION INFORMATION   13285000
         MVC   ##SUBCOM(PTW),$CHA       PCL FOR SUBCOMMAND NAME         13286000
         L     R15,=A(PARSE)            PARSE ADDRESS                   13287000
         BALR  R14,R15                  INVOKE PARSE                    13288000
         B     DYNA900                  EXIT - PARSE FAILURE            13289000
         MVC   ##ADRCMD(4),FULLWORD     CONTINUATION INFORMATION        13290000
         B     DYNA010                  RETRY ALLOCATION                13291000
         SPACE 2                                                        13292000
DYNA900  L     R14,R14SAVE              ERROR EXIT - NOT ALLOCATED      13293000
         BR    R14                                                      13294000
ALLDDNAM DC    X'0055000100084040404040404040'                          13295000
ALLDSORG DC    X'0057000100020000'                                      13296000
ALLVOLUM DC    X'005D00010006404040404040'                              13297000
ALLUNIT  DC    X'0015000100084040404040404040'                          13298000
ALLPERM  DC    X'00520000'                                              13299000
ALLPASSW DC    X'0050000100084040404040404040'                          13300000
ALLDSNAM DC    X'00020001002C'                                          13301000
ALLALLOC DC    X'00040001000108'                                        13302000
ALLNORM  DC    X'00050001000108'                                        13303000
ALLANORM DC    X'00060001000108'                                        13304000
ALLOOLD  EQU   X'01'                                                    13305000
ALLOMOD  EQU   X'02'                                                    13306000
ALLOSHR  EQU   X'08'                                                    13307000
PDSMAIN  CSECT                                                          13308000
         TITLE 'P D S  --  PDS DATA SET UNALLOCATION           1/15/85' 13309000
*                                                                       13310000
*        FREE DATA SET NO LONGER REQUIRED                               13311000
*                                                                       13312000
         SPACE 2                                                        13313000
DEALLDCB MVI   VOLALLOC,X'40'     ** CONDITIONAL FREE OF FILE           13314000
         TM    FLAGSCC,FPERMDS    DATA SET PERMANENTLY ALLOCATED?       13315000
         BOR   R2                 YES, SKIP EXPLICIT FREE               13316000
         SPACE 2                                                        13317000
DEALLOCZ CLC   DDNAME(8),SYSPROC        SYSPROC DDNAME?                 13318000
         BER   R2                       YES, QUIT                       13319000
         AIF   (&MVT).MA01120                                      @D01
         XC    M99RBPTR(40),M99RBPTR    CLEAR THE WORK AREA             13320000
         LA    R1,M99RBPTR              DYNAMIC ALLOCATION              13321000
         USING S99RBP,R1                                                13322000
         SPACE 1                                                        13323000
         LA    R4,M99RB                                                 13324000
         USING S99RB,R4                                                 13325000
         ST    R4,S99RBPTR                                              13326000
         OI    S99RBPTR,S99RBPND        MARK END OF LIST                13327000
         SPACE 1                                                        13328000
         LA    R5,M99TUPL                                               13329000
         USING S99TUPL,R5                                               13330000
         MVI   S99RBLN,20               LENGTH 20                       13331000
         MVI   S99VERB,S99VRBUN         UNALLOCATE                      13332000
         ST    R5,S99TXTPP              POINT TO TEXT POINTERS          13333000
         LA    R3,WORKTBL               START OF TEXT                   13334000
         SPACE 1                                                        13335000
         MVC   0(L'UNADDNAM,R3),UNADDNAM                                13336000
         MVC   6(8,R3),DDNAME           SPECIFY DDNAME                  13337000
         ST    R3,S99TUPTR              POINT TO TEXT UNIT              13338000
         LA    R3,L'UNADDNAM(,R3)       START OF NEXT TEXT              13339000
         SPACE 1                                                        13340000
         CLC   DDNAME(8),SYSHELP        SYSHELP DDNAME?                 13341000
         BE    UNA100                   YES, BRANCH                     13342000
         SPACE 1                                                        13343000
         LA    R5,4(,R5)                NEXT POINTER ELEMENT            13344000
         MVC   0(L'UNAPERM,R3),UNAPERM  UNALLOC "PERM" TOO              13345000
         ST    R3,S99TUPTR              POINT TO TEXT UNIT              13346000
         LA    R3,L'ALLDSORG(,R3)       START OF NEXT TEXT              13347000
         SPACE 1                                                        13348000
UNA100   OI    S99TUPTR,X'80'           MARK END OF LIST                13349000
         SPACE 1                                                        13350000
         DYNALLOC                                                       13351000
         SPACE 2                                                        13352000
         DROP  R1,R4,R5                                                 13353000
         LTR   R15,R15                  SUCCESSFUL?                     13354000
         BNZR  R2                       NO, RETURN                      13355000
         BR    R2                       RETURN                          13356000
         SPACE 1                                                        13357000
UNADDNAM DC    X'0001000100084040404040404040'                          13358000
UNAPERM  DC    X'00070000'                                              13359000
         AGO   .NA01120                                            @D01
.MA01120 ANOP  ,                                                   @D01
*---------------------------------------------------------------*  @D01
*        Unallocate data set using DAIR.                        *  @D01
*---------------------------------------------------------------*  @D01
         LA    R6,DAIR18           Point to unallocate parm block  @D01
         USING DAPB18,R6           Address unallocate parm block   @D01
         XC    DAIR18,DAIR18       Clear parm block to zeroes      @D01
         MVI   DA18CD+1,X'18'      Entry code = unallocate         @D01
         MVC   DA18DDN,DDNAME      Set DD name to free             @D01
         CLC   DDNAME(8),SYSHELP   Is DD name SYSHELP?             @D01
         BE    UNA100              Yes, branch                     @D01
         OI    DA18CTL,DA18PERM    No, unallocate "PERM"           @D01
UNA100   LA    R1,PARMLIST         Point to DAPL                   @D01
         USING DAPL,R1             Addressability for DAPL         @D01
         L     R3,ADDRUPT          Get UPT address                 @D01
         ST    R3,DAPLUPT          Put it in DAIR parm block       @D01
         L     R3,ADDRECT          Get ECT address                 @D01
         LA    R4,ATTNECB          Get address of ECB              @D01
         L     R5,ADDRPSCB         Get PSCB address                @D01
***      LA    R6,DAIR18           Get DAIR parm block address     @D01
         STM   R3,R6,DAPLECT       Set DAPLECT, DAPLECB,           @D01
*                                      DAPLPSCB AND DAPLDAPB       @D01
         MVI   ATTNECB,0           Clear ECB                       @D01
         L     R15,ADDRDAIR        Get DAIR address                @D01
         BALR  R14,R15             Link to DAIR to free the file   @D01
         DROP  R1                  End DAPL addressability         @D01
         DROP  R6                  End parm block addressability   @D01
         LTR   R15,R15             Was unallocate successful?      @D01
         BNZR  R2                  No, the hell with it            @D01
         BR    R2                  Yes, return                     @D01
.NA01120 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS OPEN/CLOSE STOW ROUTINES        1/15/85' 13360000
*                                                                       13361000
*        OPEN/CLOSE STOW SUBROUTINES                                    13362000
*                                                                       13363000
         SPACE 3                                                        13364000
OPENSTOW NI    FLAGSCC,FF-FBLDLOK                BLDL IS INVALID NOW    13365000
         TM    DCBOFLGS-IHADCB+STOWDCB,DCBOFOPN  STOW DCB OPEN?         13366000
         BO    4(R2)                             YES, EXIT              13367000
         SPACE 1                                                        13368000
         BAL   R6,RESERVE                        RESERVE THE DEVICE     13369000
         SPACE 1                                                        13370000
         MVI   OPENLIST,X'80'                                           13371000
         OPEN  (STOWDCB,OUTPUT),MF=(E,OPENLIST)  OPEN IT FOR OUTPUT NOW 13372000
         TM    DCBOFLGS-IHADCB+STOWDCB,DCBOFOPN  STOW DCB OPEN?         13373000
         BO    4(R2)                             YES, BRANCH            13374000
         SPACE 1                                                        13375000
         TSMSG L831                              STOW DID NOT OPEN      13376000
         BR    R2                                ERROR RETURN           13377000
         SPACE 3                                                        13378000
SHUTSTOW TM    FLAGSEE,FBKGRND                   BACKGROUND MODE?       13379000
         BOR   R2                                YES, RESERVE IS OK     13380000
         SPACE 2                                                        13381000
SHUTSTW2 TM    DCBOFLGS-IHADCB+STOWDCB,DCBOFOPN  STOW DCB OPEN?         13382000
         BNO   DEQ                               NO, BRANCH             13383000
         SPACE 1                                                        13384000
         CLI   DSPALLOC,ALLOOLD                  EXCLUSIVE USE?         13385000
         BE    DEQ                               YES, BRANCH            13386000
         CLI   DSPALLOC,ALLOMOD                  EXCLUSIVE USE?         13387000
         BE    DEQ                               YES, BRANCH            13388000
         SPACE 1                                                        13389000
         MVI   OPENLIST,X'80'                                           13390000
         CLOSE (STOWDCB),MF=(E,OPENLIST)         CLOSE IT NOW           13391000
         SPACE 2                                                        13392000
         B     DEQ                               RELEASE ANY ENQUEUES   13393000
         TITLE 'P D S  --  PDS RESERVE ROUTINE                 1/15/85' 13394000
*                                                                       13395000
*        UCB RESERVE ROUTINE                                            13396000
*                                                                       13397000
         SPACE 1                                                        13398000
RESERVE  CLI   DSPALLOC,ALLOOLD            EXCLUSIVE USE?               13399000
         BER   R6                          YES, RETURN                  13400000
         CLI   DSPALLOC,ALLOMOD            EXCLUSIVE USE?               13401000
         BER   R6                          YES, RETURN                  13402000
         SPACE 1                                                        13403000
         CLI   RESERVET,C'R'               ALREADY RESERVED?            13404000
         BER   R6                          YES, RETURN                  13405000
         MVI   RESERVET,C'R'               MARK AS RESERVED             13406000
         SPACE 2                                                        13407000
         MVC   PARMLIST(4),RESERVEL        LIST FORM OF RESERVE         13408000
         RESERVE (SPFEDIT,DSNAME,E,44,SYSTEMS),RET=HAVE,UCB=UCBADDR,  XX13409000
               MF=(E,PARMLIST)                                          13410000
         SPACE 2                                                        13411000
         TM    FLAGSCC,RECFMU              LOAD LIBRARY?                13412000
         BNOR  R6                          NO, RETURN                   13413000
         SPACE 2                                                        13414000
         L     R1,UCBADDR                  UCB ADDRESS                  13415000
         TM    UCBTYP+1(R1),UCBRR          SHARED DEVICE?               13416000
         BNO   RESERVE2                    NO, BRANCH                   13417000
         MVC   PARMLIST(4),RESERVEL        LIST FORM OF RESERVE         13418000
         RESERVE (SYSIEWLP,DSNAME,E,44,SYSTEMS),RET=HAVE,UCB=UCBADDR, XX13419000
               MF=(E,PARMLIST)                                          13420000
         BR    R6                                                       13421000
         SPACE 5                                                        13422000
RESERVE2 MVC   PARMLIST(4),ENQHAVE         LIST FORM OF RESERVE         13423000
         ENQ   (SYSIEWLP,DSNAME,E,44,SYSTEM),RET=HAVE,MF=(E,PARMLIST)   13424000
         BR    R6                                                       13425000
         TITLE 'P D S  --  PDS DEQ ROUTINE                     1/15/85' 13426000
*                                                                       13427000
*        UCB DEQ ROUTINE                                                13428000
*                                                                       13429000
         SPACE 1                                                        13430000
DEQ      CLI   DSPALLOC,ALLOOLD            EXCLUSIVE USE?               13431000
         BER   R2                          YES, RETURN                  13432000
         CLI   DSPALLOC,ALLOMOD            EXCLUSIVE USE?               13433000
         BER   R2                          YES, RETURN                  13434000
         SPACE 1                                                        13435000
         CLI   RESERVET,C'R'               RESERVED?                    13436000
         BNER  R2                          NO, RETURN                   13437000
         MVI   RESERVET,0                  NO LONGER RESERVED           13438000
         SPACE 2                                                        13439000
         MVC   PARMLIST(4),DEQSYSS         LIST FORM, DEQ "SYSTEMS"     13440000
         DEQ   (SPFEDIT,DSNAME,44,SYSTEMS),RET=HAVE,UCB=UCBADDR,       X13441000
               MF=(E,PARMLIST)                                          13442000
         SPACE 2                                                        13443000
         TM    FLAGSCC,RECFMU              LOAD LIBRARY?                13444000
         BNOR  R2                          NO, RETURN                   13445000
         SPACE 2                                                        13446000
         L     R1,UCBADDR                  UCB ADDRESS                  13447000
         TM    UCBTYP+1(R1),UCBRR          SHARED DEVICE?               13448000
         BNO   DEQ2                        NO, BRANCH                   13449000
         MVC   PARMLIST(4),DEQSYSS         LIST FORM, DEQ "SYSTEMS"     13450000
         DEQ   (SYSIEWLP,DSNAME,44,SYSTEMS),RET=HAVE,UCB=UCBADDR,      X13451000
               MF=(E,PARMLIST)                                          13452000
         BR    R2                                                       13453000
         SPACE 5                                                        13454000
DEQ2     MVC   PARMLIST(4),DEQSYS          LIST FORM, DEQ "SYSTEM"      13455000
         DEQ   (SYSIEWLP,DSNAME,44,SYSTEM),RET=HAVE,MF=(E,PARMLIST)     13456000
         BR    R2                                                       13457000
         TITLE 'P D S  --  PDS OPEN EXIT                       1/15/85' 13458000
         USING IHADCB,R1                                                13459000
OPENEXIT TM    ##ADRCM#,FIXOPEN                FIXPDS DCB MODIFICATION? 13460000
         BNO   OPENEXT2                        NO, BRANCH               13461000
         MVC   DCBRECFM(1),#RECFM+3            NEW RECORD FORMAT        13462000
         MVC   DCBLRECL(2),#LRECL+2            NEW LRECL                13463000
         MVC   DCBBLKSI(2),#BLKSI+2            NEW BLKSIZE              13464000
         MVI   DCBKEYLE,0                      RESET THE KEY LENGTH     13465000
         SPACE 1                                                        13466000
OPENEXT2 MVC   RECFM(1),DCBRECFM               SAVE RECORD FORMAT BYTE  13467000
         NI    FLAGSCC,FF-RECFMU-RECFMV-RECFMF CLEAR TEST BITS          13468000
         XI    FLAGSCC,RECFMU                  ASSUME RECFM=U           13469000
         TM    DCBRECFM,DCBRECU                CORRECT?                 13470000
         BO    OPENEXT4                        YES, BRANCH              13471000
         XI    FLAGSCC,RECFMU+RECFMV           ASSUME RECFM=V           13472000
         TM    DCBRECFM,DCBRECV                CORRECT?                 13473000
         BO    OPENEXT4                        YES, BRANCH              13474000
         XI    FLAGSCC,RECFMV+RECFMF           ASSUME RECFM=F           13475000
         NI    DCBRECFM,FF-DCBRECSB            DROP ANY S OF RECFM=FBS  13476000
         TM    DCBRECFM,DCBRECF                CORRECT?                 13477000
         BO    OPENEXT4                        YES, BRANCH              13478000
         XI    FLAGSCC,RECFMV                  NO, INDICATE UNKNOWN     13479000
         SPACE 1                                                        13480000
OPENEXT4 CLC   BLKSI(2),ZERO                   HAVE ANY LRECL?          13481000
         BNER  R14                             YES, RETURN              13482000
         MVC   LRECL,DCBLRECL                  SAVE LRECL               13483000
         MVC   BLKSI,DCBBLKSI                  SAVE BLOCKSIZE           13484000
         BR    R14                                                      13485000
         TITLE 'P D S  --  PDS DIRECTORY READ SUBROUTINE       1/15/85' 13486000
*                                                                       13487000
*        DIRECTORY READ SUBROUTINE                                      13488000
*                                                                       13489000
         SPACE 1                                                        13490000
READDIR  ST    R14,R14READD                                             13491000
         NI    FLAGSEE,FF-FDIREND      END OF DIRECTORY TO COME YET     13492000
         CLI   STARTTR+2,X'01'         TTR=000001 (START OF DIRECTORY)? 13493000
         BNE   DEBLOCK                 NO, BRANCH                       13494000
         SPACE 1                                                        13495000
         XC    TOTBLOCK(LTOT),TOTBLOCK CLEAR THE TOTALS AREA            13496000
         LA    R1,L875                 ASSUME NO DIRECTORY BLOCKS       13497000
         CLC   DS1LSTAR(3),ZERO        CORRECT?                         13498000
         BE    READDIRE                YES, ERROR EXIT                  13499000
         SPACE 2                                                        13500000
READDIR1 L     R15,=A(EXCP)        READ THE DIRECTORY RECORDS           13501000
         BALR  R14,R15                                                  13502000
         B     *+4(R15)                PROCESS RETURN CODE              13503000
         B     READDIR2                 00 - GOOD READ                  13504000
         B     READDIR4                 04 - END OF MEMBER              13505000
         B     READDIR4                 08 - END OF DATA SET            13506000
         B     IOERROR                  12 - I/O ERROR IN DIRECTORY     13507000
         SPACE 2                                                        13508000
READDIR2 LA    R1,L876                 ASSUME INVALID DIRECTORY BLOCK   13509000
         CLC   LS+2(2),=H'256'         CORRECT?                         13510000
         BNE   READDIRE                YES, ERROR EXIT                  13511000
         LH    R14,TOTTRKS                                              13512000
         LA    R14,1(,R14)                                              13513000
         CLC   TOTCCHH,CURMBB+3        SWITCH TRACKS?                   13514000
         BE    *+8                     NO, BRANCH                       13515000
         STH   R14,TOTTRKS             YES, UPDATE TRACK COUNT          13516000
         MVC   TOTCCHH,CURMBB+3        NEW CCHH QUANTITY                13517000
         SPACE 1                                                        13518000
         LH    R14,TOTBLOCK                                             13519000
         LA    R14,1(R14)                                               13520000
         STH   R14,TOTBLOCK                                             13521000
         TM    FLAGSEE,FDIREND         USAGE AND LAST MEMBER FOUND?     13522000
         BO    READDIR1                YES, BRANCH                      13523000
         SPACE 1                                                        13524000
         LH    R14,TOTUSED                                              13525000
         LA    R14,1(R14)                                               13526000
         STH   R14,TOTUSED                                              13527000
         MVI   TOTTHISM+1,0                                             13528000
         SPACE 1                                                        13529000
         LR    R15,R0                   BUFFER ADDRESS                  13530000
         LA    R0,2                                                     13531000
         LH    R1,0(,R15)                                               13532000
         BCTR  R1,0                                                     13533000
         LA    R1,0(R1,R15)                                             13534000
         STM   R15,R1,DIRPTRS                                           13535000
         SPACE 8                                                        13536000
DEBLOCK  LM    R15,R1,DIRPTRS                                           13537000
         BXH   R15,R0,READDIR1         INDEX TO NEXT MEMBER NAME        13538000
         STM   R15,R1,DIRPTRS                                           13539000
         SPACE 1                                                        13540000
         CLI   0(R15),X'FF'            LAST MEMBER?                     13541000
         BE    READDIR3                YES                              13542000
         SPACE 1                                                        13543000
         MVC   MEMNAME(12),0(R15)      SAVE FIRST 12 BYTES OF ENTRY     13544000
         SPACE 1                                                        13545000
         LH    R0,TOTTHISM                                              13546000
         A     R0,=F'1'                                                 13547000
         STH   R0,TOTTHISM                                              13548000
         CH    R0,TOTMAXM                                               13549000
         BNH   *+8                                                      13550000
         STH   R0,TOTMAXM              MAX DIRECTORY ENTRIES IN A BLOCK 13551000
         SPACE 1                                                        13552000
         IC    R14,11(,R15)                                             13553000
         N     R14,=XL4'0000001F'                                       13554000
         LA    R0,12(R14,R14)                                           13555000
         STM   R15,R1,DIRPTRS                                           13556000
         SPACE 2                                                        13557000
         TM    MEMFLAG,X'80'           ALIAS?                           13558000
         LA    R14,TOTMEMR             ASSUME NOT                       13559000
         BZ    *+8                     CORRECT?                         13560000
         LA    R14,TOTMEMA             NO, ALIAS                        13561000
         SPACE 1                                                        13562000
         LH    R15,0(,R14)                                              13563000
         LA    R15,1(,R15)                                              13564000
         STH   R15,0(,R14)                                              13565000
         SPACE 1                                                        13566000
         CLC   ##SUBCOM(8),$USA        USAGE SUBCOMMAND?                13567000
         BE    DEBLOCK                 YES, CONTINUE TO DEBLOCK         13568000
         LA    R15,4                   NO, GET THE EXIT OFFSET          13569000
         B     READDIR5                                                 13570000
         SPACE 2                                                        13571000
READDIR3 OI    FLAGSEE,FDIREND         FLAG LAST MEMBER FOUND           13572000
         CLC   ##SUBCOM(8),$USA        USAGE SUBCOMMAND?                13573000
         BE    READDIR1                YES, CONTINUE READING            13574000
         B     READDIR4                NO, EXIT WITH LAST MEMBER        13575000
         SPACE 2                                                        13576000
READDIRE TSMSG (R1)                    DIRECTORY ERROR                  13577000
         MVI   STARTTR+2,X'00'         RESET THE START TTR              13578000
         SPACE 2                                                        13579000
READDIR4 SR    R15,R15                 END OF DIRECTORY OR LAST MEMBER  13580000
         SPACE 1                                                        13581000
READDIR5 L     R14,R14READD                                             13582000
         B     0(R14,R15)                                               13583000
         TITLE 'P D S  --  PDS EXCP READ SUBROUTINE            1/15/85' 13584000
*                                                                       13585000
*        EXCP SUBROUTINE                                                13586000
*                                                                       13587000
         SPACE 1                                                        13588000
EXCP     CSECT                                                          13589000
         USING *,R8                                                     13590000
         ST    R14,R14EXCP                                              13591000
         ST    R8,R8EXCP                                                13592000
         LR    R8,R15                                                   13593000
         LH    R1,IODONE                    ANOTHER                     13594000
         LA    R1,1(,R1)                           INPUT                13595000
         STH   R1,IODONE                                ENTRY           13596000
         LA    R1,IODIRCUR                  ASSUME DIRECTORY BLOCKS     13597000
         TM    FLAGSII,FDIRGRP              DIRECTORY READ?             13598000
         BO    *+8                          YES, BRANCH                 13599000
         LA    R1,IOBUFCUR                  NO, I/O BUFFER CONTROL      13600000
         ST    R1,ICONTROL                                              13601000
         ICM   R0,B'1111',STARTTR           NEW TTR ADDRESS?            13602000
         BNZ   EXCPNTTR                     YES, BRANCH                 13603000
         TM    FLAGSII,FDIRGRP              DIR. GROUP TO BE INPUT?     13604000
         BNO   EXCPCONT                     NO, BRANCH                  13605000
         MVC   IOBSEEK(LIOBDIR),IODIR1+4+12 RESTORE INPUT STATUS        13606000
         B     EXCPCONT                                                 13607000
         SPACE 2                                                        13608000
EXCPNTTR LH    R1,IODONEW                   ANOTHER                     13609000
         LA    R1,1(,R1)                           TTR                  13610000
         STH   R1,IODONEW                             CHANGE            13611000
         L     R0,STARTTR                                               13612000
         SRL   R0,8                                                     13613000
         BCTR  R0,0                         REDUCE INITIAL TTR BY ONE   13614000
         SLL   R0,8                                                     13615000
         SPACE 1                                                        13616000
         STM   R15,R12,12+4(R13)            CONVERT TTR TO MBBCCHHR     13617000
         L     R1,INDCB+(DCBDEBAD-IHADCB)   DEB ADDRESS                 13618000
         LA    R2,IOBSEEK                   RETURN CCHHR                13619000
         L     R15,ADDRCNVT                 TTR TO MBBCCHHR CONVERTER   13620000
         LR    R3,R13                       SAVE ADDRESS OF SAVE AREA   13621000
         BALR  R14,R15                                                  13622000
         LR    R13,R3                       RESTORE SAVE AREA ADDRESS   13623000
         LM    R15,R12,12+4(R13)            RESTORE REGISTERS           13624000
         SPACE 1                                                        13625000
         XC    STARTTR,STARTTR              ZERO THE TTR                13626000
         CLC   IOBSEEK(8),LSTARMBB          LESS THAN DS1LSTAR?         13627000
         BL    EXCP1                        YES, BRANCH                 13628000
         TM    DSORG+1,DS1ACBM              VSAM DATA SET?              13629000
         BO    EXCP1                        YES, IGNORE DS1LSTAR        13630000
         TM    DSORG,DS1DSGIS               ISAM DATA SET?              13631000
         BO    EXCP1                        YES, IGNORE DS1LSTAR        13632000
         TM    DSORG,DS1DSGPO               PARTITIONED DATA SET?       13633000
         BNO   EXCPEND8                     NO, NO WARNING MESSAGE      13634000
         TSMSG L872                         OUTPUT A WARNING MESSAGE    13635000
         B     EXCPEND8                     TERMINATE I/O FOR THIS      13636000
         SPACE 1                                                        13637000
EXCP1    L     R1,INDCB+(DCBDEBAD-IHADCB)   DEB ADDRESS                 13638000
         LA    R1,16(,R1)                   CURRENT EXTENT POINTER - 16 13639000
         SR    R15,R15                                                  13640000
EXCP2    LA    R1,16(,R1)                   NEXT EXTENT POINTER         13641000
         CLM   R15,B'0001',IOBSEEK          THIS EXTENT?                13642000
         LA    R15,1(,R15)                                              13643000
         BNE   EXCP2                        NO, BRANCH                  13644000
         B     EXCPINIT                     YES, DO THE FIRST READ      13645000
         SPACE 2                                                        13646000
*    INITIALIZE CCHHR, SECTOR NUMBER AND READ IN THE LENGTH OF RECORD 1 13647000
EXCPXTNT SR    R1,R1                        AFTER THE FIRST EXTENT      13648000
         IC    R1,IOBSEEK                                               13649000
         A     R1,=F'1'                                                 13650000
         STC   R1,IOBSEEK                   INCREMENT EXTENT NUMBER     13651000
         CH    R1,NUMEXT                    WITHIN THE EXTENTS?         13652000
         BNL   EXCPEND8                     NO, NO FINAL EOF RECORDED   13653000
         L     R1,CUREXT                                                13654000
         LA    R1,16(,R1)                   CURRENT EXTENT ENTRY        13655000
         MVC   IOBSEEK+3(4),6(R1)           INITIAL CCHH                13656000
         MVI   IOBSEEK+7,0                  INITIAL R=0                 13657000
         SPACE 3                                                        13658000
EXCPINIT ST    R1,CUREXT                    UPDATE FOR LATER            13659000
         MVI   SNO,0                        SET SECTOR NUMBER=ZERO      13660000
         L     R1,ICONTROL                  CURRENT BUFFER START        13661000
         MVI   0(R1),X'40'                  MARK AS A NEW ADDRESS       13662000
         MVI   4(R1),X'FE'                  INVALIDATE THE EXTENT       13663000
         SPACE 1                                                        13664000
EXCPREST LA    1,CCW1A                                                  13665000
         ST    1,IOBCCW                     CHANNEL PROGRAM ADDRESS     13666000
         MVI   IOECB,0                      ZERO THE ECB                13667000
         EXCP  IOB                                                      13668000
         WAIT  ECB=IOECB                                                13669000
         MVC   IOBCCW,EXCPCCWI              CHANNEL PROGRAM ADDRESS     13670000
         CLI   IOECB,X'7F'                  GOOD READ?                  13671000
         BNE   EXCPERRA                     NO, INITIAL READ FAILED     13672000
         SPACE 2                                                        13673000
EXCPCONT TM    ATTNECB,X'40'                ATTENTION SIGNALLED?        13674000
         BO    NEWCMD                       YES, BRANCH                 13675000
         SPACE 1                                                        13676000
         MVC   CURMBB(8),IOBSEEK            DISK ADDRESS OF THIS RECORD 13677000
         MVC   LS+2(2),DATALN               BLOCK LENGTH FOR THIS READ  13678000
         CLI   IOECB,X'42'                  EXTENT VIOLATION LAST TIME? 13679000
         BE    EXCPXTNT                     YES, DO THE NEXT EXTENT     13680000
         CLI   IOECB,X'7F'                  PREVIOUS READ OK?           13681000
         BNE   EXCPREST                     NO, RETRY WITH OTHER EXCP   13682000
         SPACE 3                                                        13683000
*   CHECK FOR READ MULTIPLE                                             13684000
EXCPEXCP TM    FLAGSEE,FDOUBCON+FFULLTRK+FDISKTRK  MULTIPLE DESIRED?    13685000
         BNZ   EXCPDOUB                            NO, BRANCH           13686000
         TM    FLAGSII,FSINGLE              SINGLE BUFFERING REQUIRED?  13687000
         BO    EXCPDOUB                     YES, BRANCH                 13688000
         TM    RECFM,DCBRECTO               TRACK OVERFLOW DATA SET?    13689000
         BO    EXCPDOUB                     YES, BRANCH                 13690000
         L     R1,ICONTROL                  CONTROL WORDS ADDRESS       13691000
         CLI   0(R1),X'40'                  DEGRADED BUFFERING?         13692000
         BL    EXCPDOUB                     YES, BRANCH                 13693000
         LH    R14,IOLOGUSE                 COUNT OF SAVED I/O'S        13694000
         LA    R14,1(,R14)                                              13695000
         CLI   4(R1),X'FE'                  NEW TTR?                    13696000
         BE    EXCPTRK                      YES, BRANCH                 13697000
         L     R15,0(,R1)                   CURRENT DATA ADDRESS        13698000
         CLC   4(4,R1),0(R15)               ANY LOGICAL DATA RECORDS?   13699000
         BE    EXCPLOG                      YES, BRANCH                 13700000
         SPACE 1                                                        13701000
EXCPTRK  MVI   CCW3,X'5E'              READ MULTIPLE COUNT, KEY, DATA   13702000
         L     R14,IOBUFF1                  STANDARD BUFFER ADDRESS     13703000
         TM    FLAGSII,FDIRGRP              DIRECTORY GROUP INPUT?      13704000
         BNO   *+8                          NO, BRANCH                  13705000
         L     R14,IODIR1                   DIRECTORY BUFFER ADDRESS    13706000
         STCM  R14,B'0111',CCW3+1           UPDATE READ BUFFER ADDRESS  13707000
         ST    R14,EXCPBUFF                 EXCP BUFFER ADDRESS         13708000
         SR    R15,R15                                                  13709000
         ICM   R15,B'0011',DEVTMAXT         ZERO FILL AND LENGTH        13710000
         STCM  R15,B'0011',CCW3+6           UPDATE READ LENGTH          13711000
         SR    R0,R0                        NULL SOURCE                 13712000
         SR    R1,R1                        NULL SOURCE                 13713000
         MVCL  R14,R0                       FILL WITH PAD 0 FROM R1     13714000
         SR    R0,R0                                                    13715000
         IC    R0,IOBSEEK+7                                             13716000
         BCTR  R0,0                                                     13717000
         STC   R0,IOBSEEK+7                 REDUCE IOBSEEK BY ONE       13718000
         MVI   SNO,0                        SECTOR ZERO                 13719000
         MVC   CCW4(8),CCWTIC                                           13720000
         LA    R1,CCW5                      USE A TIC                   13721000
         STCM  R1,B'0111',CCW4+1                                        13722000
         MVI   IOECB,0                      CLEAR IOECB                 13723000
         EXCP  IOB                          INITIATE TRACK I/O          13724000
         WAIT  ECB=IOECB                    WAIT FOR COMPLETION         13725000
         LH    R14,IOPHYTRK                                             13726000
         LA    R14,1(,R14)                  COUNT OF PHYSICAL TRACKS    13727000
         STH   R14,IOPHYTRK                                             13728000
         L     R1,ICONTROL                  CONTROL WORDS ADDRESS       13729000
         L     R15,EXCPBUFF                 START OF DATA               13730000
         ST    R15,0(,R1)                   SAVE FOR LATER              13731000
         MVC   4(4,R1),0(R15)               SAVE CCHH OF CCHHRKDL       13732000
         LH    R14,IOLOGUSE                 COUNT OF SAVED I/O'S        13733000
         MVC   0(1,R1),IOECB                SAVE THE ECB                13734000
         MVI   IOECB,X'7F'                  ASSUME GOOD READ            13735000
         TM    FLAGSII,FDIRGRP              DIRECTORY GROUP INPUT?      13736000
         BNO   *+10                         NO, BRANCH                  13737000
         MVC   IODIR1+4+12(LIOBDIR),IOBSEEK SAVE IOBSEEK INFORMATION    13738000
         SPACE 1                                                        13739000
         CLI   0(R1),X'7F'                  CORRECT?                    13740000
         BE    EXCPLOG                      YES, BRANCH                 13741000
         CLI   0(R1),X'42'                  NEW EXTENT (NEXT TRACK)?    13742000
         BE    EXCPLOG                      YES, BRANCH                 13743000
         MVC   IOBSEEK(8),CURMBB            RESTORE THE DISK ADDRESS    13744000
         MVI   0(R1),0                      DEGRADED I/O BUFFERING      13745000
         TM    ##ADRPA#,$Q                  QUIET MODE?                 13746000
         BO    EXCPDOUB                     YES, BRANCH                 13747000
         TSMSG L892                                                     13748000
         B     EXCPDOUB                     DO NORMAL INPUTS            13749000
         SPACE 2                                                        13750000
EXCPLOG  STH   R14,IOLOGUSE                 COUNT OF SAVED I/O'S        13751000
         L     R14,0(,R1)                   START OF NEXT RECORD        13752000
         MVC   CURMBB+3(5),0(R14)           CURRENT MBBCCHHR            13753000
         SR    R15,R15                                                  13754000
         IC    R15,5(,R14)                  KEY LENGTH                  13755000
         SR    R0,R0                                                    13756000
         ICM   R0,B'0011',6(R14)            DATA LENGTH                 13757000
         ST    R0,LS                                                    13758000
         LA    R14,8(R14,R15)               START OF ACTUAL DATA        13759000
         ST    R14,EXCPBUFF                                             13760000
         AR    R14,R0                                                   13761000
         STCM  R14,B'0111',1(R1)            NEXT DATA ADDRESS           13762000
         MVI   IOECB,X'7F'                  ASSUME NORMAL INPUT         13763000
         CLC   0(4,R14),4(R1)               SAME TRACK ADDRESS?         13764000
         BE    *+10                         YES, BRANCH                 13765000
         MVC   IOECB(1),0(R1)               RESET THE IOECB             13766000
         B     EXCPFIN                                                  13767000
         SPACE 3                                                        13768000
* CHECK FOR DOUBLE BUFFERING                                            13769000
EXCPDOUB MVC   CCW3(8),CCWREAD              READ KEY AND DATA           13770000
         L     R1,IOBUFF1                   STANDARD BUFFER ADDRESS     13771000
         TM    FLAGSII,FDIRGRP              DIRECTORY GROUP INPUT?      13772000
         BNO   *+8                          NO, BRANCH                  13773000
         L     R1,IODIR1                    DIRECTORY BUFFER ADDRESS    13774000
         MVC   0(8,R1),IOBSEEK+3            SAVE THE CCHHRKDD DATA      13775000
         LA    R1,8(,R1)                    SKIP PAST CCHHRKDD BYTES    13776000
         STCM  R1,B'0111',CCW3+1            UPDATE READ BUFFER ADDRESS  13777000
         TM    RECFM,DCBRECTO               TRACK OVERFLOW DATA SET?    13778000
         BO    EXCPSING                     YES, BRANCH                 13779000
         TM    FLAGSEE,FDOUBCON+FFULLTRK    CONTROL SINGLE?             13780000
         BO    EXCPSING                     YES, BRANCH                 13781000
         TM    FLAGSII,FSINGLE+FNOTDOUB     THEN/ELSE(DELETE), RESTORE? 13782000
         BNZ   EXCPSING                     YES, BRANCH                 13783000
         MVC   CCW4(8),CCWREAD              INITIALIZE SECOND READ CCW  13784000
         MVI   CCW4,X'9E'                   MT READ COUNT, KEY, DATA    13785000
         L     R14,IODIR2                   ASSUME DIRECTORY INPUT      13786000
         TM    FLAGSII,FDIRGRP              CORRECT?                    13787000
         BO    *+8                          YES, BRANCH                 13788000
         L     R14,IOBUFF2                  NO, NORMAL INPUT            13789000
         STCM  R14,B'0111',CCW4+1                                       13790000
         SPACE 1                                                        13791000
         L     R1,ICONTROL                                              13792000
         CLI   0(R1),X'3F'                  GOOD READ?                  13793000
         BE    EXCPSEC                      YES, BRANCH                 13794000
         CLI   0(R1),X'02'                  NEW EXTENT NEXT TIME?       13795000
         BE    EXCPSEC                      YES, BRANCH                 13796000
         SPACE 1                                                        13797000
         MVI   IOECB,0                      ZERO THE ECB                13798000
         EXCP  IOB                                                      13799000
         WAIT  ECB=IOECB                                                13800000
         TM    FLAGSII,FDIRGRP              DIRECTORY GROUP INPUT?      13801000
         BNO   *+10                         NO, BRANCH                  13802000
         MVC   IODIR1+4+12(LIOBDIR),IOBSEEK SAVE IOBSEEK INFORMATION    13803000
         SPACE 1                                                        13804000
         L     R1,ICONTROL                                              13805000
         MVC   0(1,R1),IOECB                SAVE THE ECB                13806000
         NI    0(R1),FF-X'40'               REDUCE BY X'40'             13807000
         MVI   IOECB,X'7F'                  ASSUME A GOOD READ          13808000
         L     R14,CCW3                     LOAD FIRST BUFFER ADDRESS   13809000
         SH    R14,=H'8'                    BACK UP TO CCHHRKDD         13810000
         CLI   0(R1),X'3F'                  GOOD READ?                  13811000
         BE    EXCPSEC2                     YES, BRANCH                 13812000
         LA    R15,CCW5                     IF SECOND FAILED            13813000
         CLI   0(R1),X'02'                  NEW EXTENT?                 13814000
         BNE   EXCPDOU2                     NO, BRANCH                  13815000
         C     R15,IOBCSW                   FAILED ON:                  13816000
         BH    EXCPXTNT                       FIRST, BRANCH             13817000
         BE    EXCPSEC1                       SECOND, MARK NEXT INPUT   13818000
         B     EXCPSEC2                       THIRD, MARK AFTER NEXT    13819000
         SPACE 1                                                        13820000
EXCPDOU2 TM    IOBCSW+4,X'01'               X'41', END OF FILE?         13821000
         BNO   EXCPDOU4                     NO, BRANCH                  13822000
         MVI   0(R1),X'3F'                  YES, READ NEXT RECORD       13823000
         C     R15,IOBCSW                   FAILED ON FIRST?            13824000
         BNH   EXCPSEC2                     NO, BRANCH                  13825000
         MVI   0(R1),0                      READ THE NEXT BLOCK         13826000
         MVC   IOBSEEK+3(5),0(R14)          CURRENT MBBCCHHR            13827000
         SR    R0,R0                                                    13828000
         IC    R0,IOBSEEK+7                 R OF MBBCCHHR               13829000
         AH    R0,=H'1'                     NEXT R                      13830000
         STC   R0,IOBSEEK+7                 UPDATE FOR NEXT READ        13831000
         TM    FLAGSII,FDIRGRP              DIRECTORY GROUP INPUT?      13832000
         BNO   EXCPSEC2                     NO, BRANCH                  13833000
         MVC   IODIR1+4+12(8),IOBSEEK       SAVE IOBSEEK INFORMATION    13834000
         B     EXCPSEC2                                                 13835000
         SPACE 1                                                        13836000
EXCPDOU4 MVI   0(R1),0                      READ THE NEXT BLOCK         13837000
         MVC   IOBSEEK+3(5),0(R14)          CURRENT MBBCCHHR            13838000
         SR    R0,R0                                                    13839000
         IC    R0,IOBSEEK+7                 R OF MBBCCHHR               13840000
         AH    R0,=H'1'                     NEXT R                      13841000
         STC   R0,IOBSEEK+7                 UPDATE FOR NEXT READ        13842000
         TM    FLAGSII,FDIRGRP              DIRECTORY GROUP INPUT?      13843000
         BNO   *+10                         NO, BRANCH                  13844000
         MVC   IODIR1+4+12(8),IOBSEEK       SAVE IOBSEEK INFORMATION    13845000
         SPACE 1                                                        13846000
         C     R15,IOBCSW                   FAILED ON FIRST?            13847000
         BNH   EXCPSEC2                     NO, BRANCH                  13848000
         MVI   IOECB,X'41'                  PERMANENT I/O ERROR         13849000
         MVC   IOBSEEK(8),CURMBB            RESET THE SEEK ADDRESS      13850000
         B     EXCPERR                                                  13851000
         SPACE 2                                                        13852000
EXCPSEC  LH    R14,IOLOGUSE                                             13853000
         LA    R14,1(,R14)                                              13854000
         STH   R14,IOLOGUSE                                             13855000
         L     R14,CCW4                     LOAD SECOND BUFFER ADDRESS  13856000
EXCPSEC1 MVC   IOECB(1),0(R1)               RESET THE ECB               13857000
         OI    IOECB,X'40'                  ADD X'40'                   13858000
         MVI   0(R1),0                      READ THE NEXT BLOCK         13859000
         SPACE 1                                                        13860000
EXCPSEC2 MVC   CURMBB+3(5),0(R14)           CURRENT MBBCCHHR            13861000
         SR    R15,R15                                                  13862000
         IC    R15,5(,R14)                  KEY LENGTH                  13863000
         SR    R0,R0                                                    13864000
         ICM   R0,B'0011',6(R14)            DATA LENGTH                 13865000
         ST    R0,LS                                                    13866000
         LA    R14,8(R14,R15)               START OF ACTUAL DATA        13867000
         ST    R14,EXCPBUFF                                             13868000
         B     EXCPFIN                                                  13869000
         SPACE 3                                                        13870000
*  IF ALL ELSE FAILS, TRY SINGLE BUFFERING                              13871000
EXCPSING MVC   CCW4(8),CCWTIC               USE A TIC                   13872000
         LA    R1,CCW5                                                  13873000
         STCM  R1,B'0111',CCW4+1            WHERE TO TIC                13874000
         SPACE 1                                                        13875000
         MVI   IOECB,0                      ZERO THE ECB                13876000
         EXCP  IOB                                                      13877000
         WAIT  ECB=IOECB                                                13878000
         TM    FLAGSII,FDIRGRP              DIRECTORY GROUP?            13879000
         BNO   *+10                         NO, BRANCH                  13880000
         MVC   IODIR1+4+12(LIOBDIR),IOBSEEK SAVE IOBSEEK INFORMATION    13881000
         SPACE 1                                                        13882000
         L     R1,ICONTROL                                              13883000
         MVI   0(R1),0                                                  13884000
         L     R14,CCW3                     POINT TO OUTPUT BUFFER      13885000
         SH    R14,=H'8'                    BACK UP TO CCHHRKDD         13886000
         CLI   IOECB,X'41'                  X'42' OR X'7F'?             13887000
         BH    EXCPSIN2                     YES, BRANCH                 13888000
         TM    IOBCSW+4,X'01'               X'41', END OF FILE?         13889000
         BNO   EXCPERR                      NO, BRANCH                  13890000
         SPACE 1                                                        13891000
EXCPSIN2 MVC   CURMBB+3(5),0(R14)           CURRENT MBBCCHHR            13892000
         SR    R15,R15                                                  13893000
         IC    R15,5(,R14)                  KEY LENGTH                  13894000
         SR    R0,R0                                                    13895000
         ICM   R0,B'0011',6(R14)            DATA LENGTH                 13896000
         ST    R0,LS                                                    13897000
         LA    R14,8(R14,R15)               START OF ACTUAL DATA        13898000
         ST    R14,EXCPBUFF                                             13899000
         SPACE 1                                                        13900000
         TM    RECFM,DCBRECTO               RECORD OVERFLOW DATA SET?   13901000
         BNO   EXCPFIN                      NO, BRANCH                  13902000
         CLI   IOBSEEK+7,2                  THIS R OF CCHHR=2?          13903000
         BNE   EXCPFIN                      NO, BRANCH                  13904000
         CLI   CURMBB+7,1                   THIS R OF CCHHR=1?          13905000
         BE    EXCPFIN                      YES, BRANCH                 13906000
         SPACE 1                                                        13907000
*  TRACK OVERFLOW RECORDS READ OK: HOWEVER, THE LENGTH                  13908000
*       IS SET TO THE FIRST SEGMENT OF A SPLIT RECORD.                  13909000
         AR    R14,R0                                                   13910000
         ICM   R0,B'0011',6(R14)            LENGTH OF SECOND SEGMENT    13911000
         L     R1,LS                        LENGTH OF FIRST SEGMENT     13912000
         AR    R1,R0                                                    13913000
         ST    R1,LS                        COMBINED RECORD LENGTH      13914000
         LA    R1,8(,R14)                   START OF SECOND SEGMENT     13915000
         LR    R15,R14                      END OF FIRST SEGMENT        13916000
         LR    R14,R0                       LENGTH TO MOVE              13917000
         MVCL  R14,R0                       SLIDE DOWN BY 8 BYTES       13918000
         L     R0,LS                                                    13919000
         SPACE 3                                                        13920000
EXCPFIN  LTR   R0,R0                        END OF FILE?                13921000
         BZ    EXCPFIN2                     YES, BRANCH                 13922000
         CLI   IOECB,X'42'                  EXTENT PROBLEM (NEXT TIME)? 13923000
         BE    EXCPEND0                     YES, QUIT                   13924000
EXCPFIN2 TM    DSORG+1,DS1ACBM              VSAM DATA SET?              13925000
         BO    EXCPFIN4                     YES, IGNORE DS1LSTAR        13926000
         TM    DSORG,DS1DSGIS               ISAM DATA SET?              13927000
         BO    EXCPFIN4                     YES, IGNORE DS1LSTAR        13928000
         CLC   CURMBB(8),LSTARMBB           CURRENT:DS1LSTAR            13929000
         BH    EXCPEND8                       HIGH, END OF DATA SET     13930000
         BL    EXCPFIN4                       LOW, GOOD READ            13931000
         TM    DSORG,DS1DSGPO                 EQUAL, PARTITIONED?       13932000
         BO    EXCPEND8                              YES, END OF DATA   13933000
         SPACE 1                                                        13934000
EXCPFIN4 LTR   R0,R0                        END OF MEMBER OR DATA SET?  13935000
         BP    EXCPEND0                     NO, BRANCH                  13936000
         TM    DSORG,DS1DSGPS+DS1DSGDA      DSORG=PS OR DA?             13937000
         BM    EXCPEND8                     YES, END OF DATA SET        13938000
         TM    DSORG+1,DS1ACBM              VSAM DATA SET?              13939000
         BO    EXCPEND8                     YES, END OF DATA SET        13940000
         B     EXCPEND4                     END OF MEMBER               13941000
         SPACE 3                                                        13942000
EXCPERRA SR    R0,R0                        FIRST READ OF EXTENT ERROR  13943000
         IC    R0,IOBSEEK+7                                             13944000
         A     R0,=F'1'                                                 13945000
         STC   R0,IOBSEEK+7                 ADD 1 TO R OF MBBCCHHR      13946000
         TM    ##ADRPA#,$Q                  QUIET MODE I/O?             13947000
         BO    EXCPERR+6                    YES, BRANCH                 13948000
         MESSAGE MSGBLANK                                               13949000
         TSMSG L990                         INITIALIZATION READ FAILED  13950000
         B     EXCPERR+6                                                13951000
         SPACE 1                                                        13952000
EXCPERR  MVC   IOBSEEK(8),CURMBB            CURRENT MBBCCHHR            13953000
         STM   R2,R12,28(R13)               PERMANENT I/O ERROR         13954000
         LA    R2,IOBSEEK                                               13955000
         L     R1,INDCB+(DCBDEBAD-IHADCB)   CONVERT MBBCCHHR TO TTR     13956000
         L     R15,ADDRRLTV                                             13957000
         LR    R3,R13                                                   13958000
         BALR  R14,R15                                                  13959000
         LR    R13,R3                                                   13960000
         LM    R2,R12,28(R13)                                           13961000
         STCM  R0,B'1110',MSGTEXT1+20       TTR OF THIS ERROR           13962000
         UNPK  INSERT#1(7),MSGTEXT1+20(4)                               13963000
         TR    INSERT#1(6),TRTABLE                                      13964000
         MVC   INSERT#1+6(2),BLANKS                                     13965000
         LA    R15,12                   *** PERMANENT I/O ERROR         13966000
         TM    ##ADRPA#,$Q                  QUIET MODE I/O?             13967000
         BO    EXCPENDZ                     YES, BRANCH                 13968000
         MESSAGE MSGBLANK                                               13969000
         TSMSG L991$1                                                   13970000
         LA    R15,12                   *** PERMANENT I/O ERROR         13971000
         B     EXCPENDZ                                                 13972000
         SPACE 5                                                        13973000
EXCPEND8 LA    R15,8                    *** END OF DATA SET             13974000
         B     EXCPENDZ                                                 13975000
EXCPEND4 LA    R15,4                    *** END OF MEMBER OR ISAM AREA  13976000
         B     EXCPENDZ                                                 13977000
EXCPEND0 SR    R15,R15                  *** SUCCESSFUL READ             13978000
         L     R0,EXCPBUFF              EXCP BUFFER ADDRESS             13979000
EXCPENDZ L     R8,R8EXCP                                                13980000
         L     R14,R14EXCP                                              13981000
         BR    R14                                                      13982000
PDSMAIN  CSECT                                                          13983000
         TITLE 'P D S  --  PDS CLOSE DCB ROUTINE               1/15/85' 13984000
*                                                                       13985000
*        CLOSE DCB'S                                                    13986000
*                                                                       13987000
CLOSEIT  MVI   FLAGSII,0               CLEAR THE I/O FLAGS              13988000
         SPACE 1                                                        13989000
         MVI   OPENLIST,0                                               13990000
         MVI   OPENLIST+4,X'80'                                         13991000
         CLOSE (INDCB,,STOWDCB),MF=(E,OPENLIST)                         13992000
         MVC   BLKSI(2),ZERO           CLEAR THE BLOCKSIZE              13993000
         SPACE 1                                                        13994000
         BR    R2                                                       13995000
         TITLE 'P D S  --  PDS PARSE PROCESSING ROUTINE        1/15/85' 13996000
*                                                                       13997000
*        PARSE INTERFACE SUBROUTINE                                     13998000
*                                                                       13999000
         SPACE 1                                                        14000000
PARSE    CSECT                                                          14001000
         USING *,R8                                                     14002000
         ST    R8,R8PARSE                                               14003000
         ST    R14,R14PARSE                                             14004000
         LR    R8,R15                                                   14005000
         CLC   ##ADRPCL+1(3),$CHA+13    PARSE FOR NEW DATA SET?         14006000
         BNE   PARSE2                   NO, BRANCH                      14007000
         STAX  ,                        YES, CANCEL ANY PREVIOUS STAX   14008000
PARSE2   BAL   R2,FREEPDL               FREE ANY PREVIOUS PARSE STORAGE 14009000
         SPACE 1                                                        14010000
         LA    R15,PARMPARS             AREA FOR PARSE PARAMETERS       14011000
         USING PPL,R15                  BASE FOR PARSE PARAMETER LIST   14012000
         SPACE 1                                                        14013000
         L     R1,ADDRUPT                                               14014000
         L     R2,ADDRECT                                               14015000
         LA    R3,ATTNECB                                               14016000
         L     R4,##ADRPCL                                              14017000
         LA    R5,ADDRANSR                                              14018000
         L     R6,ADDRCBUF                                              14019000
***      LA    R7,MAINSAVE                                              14020000
         SPACE 1                                                        14021000
         TM    ##ADRPC#,@S+@G       NON-PARTITIONED AND MEMBER NEEDED?  14022000
         BNO   PARSE4               NO, BRANCH                          14023000
         SPACE 1                                                        14024000
*    THE FOLLOWING 6 LINES OF CODE ADD A MEMBER PARAMETER WHEN          14025000
*      REQUIRED FOR NON-PARTITIONED DATA SET SUBCOMMAND PARSE.          14026000
         LH    R14,2(,R6)           OFFSET FOR OPERANDS                 14027000
         A     R14,=F'-2'           LESS TWO                            14028000
         STH   R14,2(,R6)           UPDATE THE OFFSET                   14029000
         LA    R14,0(R6,R14)        POINT TO THE NEW OPERAND            14030000
         MVI   4(R14),C'Z'          DUMMY MEMBER NAME                   14031000
         MVI   5(R14),X'40'         SEPARATOR CHARACTER                 14032000
         SPACE 1                                                        14033000
PARSE4   STM   R1,R7,PPLUPT         INITIALIZE PPLUPT, PPLECT, PPLECB   14034000
*                                   PPLPCL, PPLANS, PPLCBUF AND PPLUWA  14035000
         DROP  R15                                                      14036000
         LR    R1,R15                                                   14037000
         MVI   ATTNECB,1            FLAG -- CAN BE ATTENTIONED          14038000
         SPACE 2                                                        14039000
         L     R15,ADDRPARS         INVOKE                              14040000
         BALR  R14,R15                    PARSE                         14041000
         STC   R15,R14PARSE                                             14042000
         MVI   ATTNECB,0            CLEAR ATTENTION ECB                 14043000
         EJECT                                                          14044000
         L     R6,ADDRANSR             PARSE RESULT BASE REGISTER       14045000
         LA    R1,PARSECHK             PARSE CLEANUP ROUTINE            14046000
         ST    R1,PARSNEXT             SAVE FOR EXIT VECTOR             14047000
         MVC   PARSPOST(6),PARSEXIT    SET UP THE CODE VECTOR           14048000
         LTR   R15,R15                 GOOD PARSE?                      14049000
         BNZ   PARSEXIT                NO, BRANCH                       14050000
         SPACE 1                                                        14051000
         ICM   R8,B'0111',##ADRPAR+1   ANY PROCESSING ROUTINE?          14052000
         BNZR  R8                      YES, BRANCH                      14053000
         SPACE 3                                                        14054000
PARSEXIT L     R8,PARSNEXT             LOAD THE REENTRY ADDRESS         14055000
         BR    R8                      LINK TO THE ROUTINE              14056000
         SPACE 3                                                        14057000
         USING *,R8                                                     14058000
*** PARSE POST PROCESSING OF OPERANDS IS COMPLETE                       14059000
PARSECHK SR    R15,R15                                                  14060000
         IC    R15,R14PARSE                                             14061000
         SPACE 1                                                        14062000
         LA    R14,MAXPARSE         RETURN CODE LIMIT                   14063000
         CR    R15,R14              RETURN CODE WITHIN LIMITS?          14064000
         BH    PARSEBAD             NO, ERROR                           14065000
         SPACE 1                                                        14066000
         LA    R3,4                 OFFSET OF RETURN IF SUCCESSFUL      14067000
         B     *+4(R15)             PROCESS RETURN CODE                 14068000
PARSERET B     PARSEOK                00 - SUCCESSFUL                   14069000
         B     EXIT8N                 04 - PARSE UNABLE TO PROMPT       14070000
         B     PARSERR                08 - USER ENTERED ATTENTION       14071000
         B     PARSEBAD               12 - INVALID PARAMETERS           14072000
         B     PARSEBAD               16 - PARSE INTERNAL FAILURE       14073000
         B     EXIT8N                 20 - VALIDITY CHECK ERROR         14074000
MAXPARSE EQU   *-PARSERET                                               14075000
         SPACE 2                                                        14076000
PARSEBAD DS    0H                                                  @D01
         AIF   (&MVT).MA01140                                      @D01
         LA    R1,GFPARMS                                          @D01 14077000
         ST    R1,GFPARMP           SAVE ADDRESS OF PARMLIST            14078000
         L     R0,ADDRFF02          ADDRESS OF IKJEFF02                 14079000
         STM   R15,R0,GFRCODE       SAVE GFRCODE AND GF02PTR            14080000
         LA    R1,GFPARSE                                               14081000
         STH   R1,GFCALLID          SAVE CALLER-ID FOR PARSE            14082000
         L     R0,ADDRCPPL          CPPL                                14083000
         LA    R1,ATTNECB           ATTENTION ECB                       14084000
         STM   R0,R1,GFCPPLP        SAVE GFCPPLP AND GFECBP             14085000
         MVI   ATTNECB,0            CLEAR THE ECB                       14086000
         LINK  EP=IKJEFF19,MF=(E,GFPARMP)                               14087000
         CLI   R14PARSE,X'4'        USER ENTER ATTENTION?               14088000
         BE    PARSERR              YES, BRANCH -- IGNORE COMMAND       14089000
         LTR   R15,R15              ERROR MESSAGE OUTPUT?               14090000
         BZ    EXIT8N               YES, BRANCH                         14091000
.MA01140 ANOP  ,                                                   @D01
         CVD   R15,DOUBLE                                               14092000
         MVI   MTHIGHL,4                                                14093000
         MVC   INSERT#1(4),=X'40202120'                                 14094000
         ED    INSERT#1(4),DOUBLE+6                                     14095000
         MVI   INSERT#1,C'='                                            14096000
         LA    R1,L834$1                                                14097000
         B     EXIT8M                                                   14098000
         SPACE 1                                                        14099000
PARSERR  SR    R3,R3                RETURN AT OFFSET 0                  14100000
         SPACE 1                                                        14101000
PARSEOK  BAL   R2,FREEPDL           FREE PARSE STORAGE                  14102000
         L     R8,R8PARSE           ORIGINAL BASE REGISTER              14103000
         L     R14,R14PARSE         EXIT BASE ADDRESS                   14104000
         B     0(R3,R14)            EXIT FROM PARSE AT +0 OR +4         14105000
         USING PDLATTR,R6                                               14106000
         USING *,R8                                                     14107000
ZATTRIB  MVC   #ALIAOPT(1),INFOALIA+1     SAVE ALIASINFO/NOALIASINFO    14108000
         MVC   #LKEDOPT(1),INFOLKED+1     SAVE LKEDDATE/NOLKEDDATE      14109000
         MVC   #RLDERR(1),LKEDRLDF+1      SAVE RLDFIX/NORLDFIX          14110000
         MVC   #SSIOPT(1),LKEDSSIK+1      SAVE SSI/NOSSI                14111000
         CLI   LKEDNONE+1,X'01'           NONE ATTRIBUTE USED?          14112000
         BNE   ZATTR10                    NO, BRANCH                    14113000
         MVI   #AUTHOPT,2                 SIMULATE "NOAUTH"             14114000
         MVI   #PAGEOPT,2                 SIMULATE "NOPAGE"             14115000
         MVI   #RMODE,1                   SIMULATE "RMODE24"            14116000
         MVI   #AMODE,1                   SIMULATE "AMODE24"            14117000
         OI    #ATTRNO,ATTRREUS+ATTRRENT+ATTRLOAD  "NO" REUS/RENT/LOAD  14118000
         OI    #ATTRNO+1,ATTRREFR+ATTRNE  "NOREFR" AND "EDIT"           14119000
         OI    #ATTRYES,ATTREXEC          "EXEC"                        14120000
         OI    #ATTRYES+1,ATTRNODC        "NODC"                        14121000
         SPACE 2                                                        14122000
ZATTR10  ICM   R1,B'0001',LKEDAUTH+1    AUTH/NOAUTH                     14123000
         BZ    *+8                                                      14124000
         STCM  R1,B'0001',#AUTHOPT                                      14125000
         ICM   R1,B'0001',LKEDPAGE+1    PAGE/NOPAGE                     14126000
         BZ    *+8                                                      14127000
         STCM  R1,B'0001',#PAGEOPT                                      14128000
         ICM   R1,B'0001',LKEDRMOD+1    RMODE24/RMODEANY                14129000
         BZ    *+8                                                      14130000
         STCM  R1,B'0001',#RMODE                                        14131000
         ICM   R1,B'0001',LKEDAMOD+1    AMODE 24/31/ANY/64         @D02
         BZ    *+8                                                      14133000
         STCM  R1,B'0001',#AMODE                                        14134000
         SPACE 2                                                        14135000
ZATTR30  CLI   LKEDREUS+1,X'01'       REUSABLE ATTRIBUTE STATUS:        14136000
         BL    ZATTR34                  NONE, BRANCH                    14137000
         BH    ZATTR32                  "NO" FORM, BRANCH               14138000
         OI    #ATTRYES,ATTRREUS        "REUS"                          14139000
         NI    #ATTRNO,FF-ATTRREUS      MAKE SURE NEGATIVE IS OFF       14140000
         B     ZATTR34                                                  14141000
ZATTR32  OI    #ATTRNO,ATTRREUS         "NOREUS"                        14142000
         SPACE 1                                                        14143000
ZATTR34  CLI   LKEDREFR+1,X'01'       REFRESHABLE ATTRIBUTE STATUS:     14144000
         BL    ZATTR40                  NONE, BRANCH                    14145000
         BH    ZATTR36                  "NO" FORM, BRANCH               14146000
         OI    #ATTRYES+1,ATTRREFR      "REFR"                          14147000
         NI    #ATTRNO+1,FF-ATTRREFR    MAKE SURE NEGATIVE IS OFF       14148000
         B     ZATTR40                                                  14149000
ZATTR36  OI    #ATTRNO+1,ATTRREFR       "NOREFR"                        14150000
         SPACE 1                                                        14151000
ZATTR40  CLI   LKEDRENT+1,X'01'       REENTRANT ATTRIBUTE STATUS:       14152000
         BL    ZATTR44                  NONE, BRANCH                    14153000
         BH    ZATTR42                  "NO" FORM, BRANCH               14154000
         OI    #ATTRYES,ATTRRENT        "RENT"                          14155000
         NI    #ATTRNO,FF-ATTRRENT      MAKE SURE NEGATIVE IS OFF       14156000
         B     ZATTR44                                                  14157000
ZATTR42  OI    #ATTRNO,ATTRRENT         "NORENT"                        14158000
         SPACE 1                                                        14159000
ZATTR44  CLI   LKEDEXEC+1,X'01'       EXECUTABLE ATTRIBUTE STATUS:      14160000
         BL    ZATTR50                  NONE, BRANCH                    14161000
         BH    ZATTR46                  "NO" FORM, BRANCH               14162000
         OI    #ATTRYES,ATTREXEC        "EXEC"                          14163000
         NI    #ATTRNO,FF-ATTREXEC      MAKE SURE NEGATIVE IS OFF       14164000
         B     ZATTR50                                                  14165000
ZATTR46  OI    #ATTRNO,ATTREXEC         "NOEXEC"                        14166000
         SPACE 1                                                        14167000
ZATTR50  CLI   LKEDLOAD+1,X'01'       LOADABLE ATTRIBUTE STATUS:        14168000
         BL    ZATTR54                  NONE, BRANCH                    14169000
         BH    ZATTR52                  "NO" FORM, BRANCH               14170000
         OI    #ATTRYES,ATTRLOAD        "LOAD"                          14171000
         NI    #ATTRNO,FF-ATTRLOAD      MAKE SURE NOLOAD IS OFF         14172000
         B     ZATTR54                                                  14173000
ZATTR52  OI    #ATTRNO,ATTRLOAD         "NOLOAD"                        14174000
         SPACE 1                                                        14175000
ZATTR54  CLI   LKEDEDIT+1,X'01'       NOT EDITABLE ATTRIBUTE STATUS:    14176000
         BL    ZATTR60                  NONE, BRANCH                    14177000
         BH    ZATTR56                  "NO" FORM, BRANCH               14178000
         OI    #ATTRNO+1,ATTRNE        "EDIT"  -- BIT MUST BE REVERSED  14179000
         B     ZATTR60                                                  14180000
ZATTR56  OI    #ATTRYES+1,ATTRNE        "NOEDIT"                        14181000
         NI    #ATTRNO+1,FF-ATTRNE     MAKE SURE EDIT IS OFF            14182000
         SPACE 1                                                        14183000
ZATTR60  CLI   LKEDDC+1,X'01'         DC ATTRIBUTE STATUS:              14184000
         BL    ZATTR70                  NONE, BRANCH                    14185000
         BH    ZATTR62                  "NO" FORM, BRANCH               14186000
         OI    #ATTRNO+1,ATTRNODC       "DC"                            14187000
         NI    #ATTRYES+1,FF-ATTRNODC   MAKE SURE NODC IS OFF           14188000
         B     ZATTR70                                                  14189000
ZATTR62  OI    #ATTRYES+1,ATTRNODC      "NODC"                          14190000
         SPACE 1                                                        14191000
ZATTR70  TM    LKEDSSI+6,X'80'      STRING CODED?                       14192000
         BNO   ZATTR99              NO, DONE                            14193000
         L     R5,LKEDSSI           NEW STRING ADDRESS                  14194000
         LH    R1,LKEDSSI+4         LENGTH OF STRING                    14195000
         LTR   R1,R1                NULL STRING CODED?                  14196000
         BNP   ZATTR99              YES, DONE                           14197000
         MVI   MSGTEXT2+1,4         MAXIMUM OF 4 DIGITS                 14198000
         MVC   MSGTEXT1,PDS385A     SSI MESSAGE                         14199000
         BAL   R2,HEXC              CONVERT TO BINARY                   14200000
         B     NEWCMD50             ATTENTION -- IGNORE THE REST        14201000
         STCM  R0,B'1111',#SSITEXT  SAVE THE RESULTING TTR              14202000
         SPACE 2                                                        14203000
ZATTR99  OC    #ZAPOPT(14),#ZAPOPT    ANY LINKAGE EDITOR ATTRIBUTES?    14204000
         BZ    *+8                    NO, BRANCH                        14205000
         MVI   #OPTOPT,FF             YES, SET A FLAG FOR LATER         14206000
         CLI   #SSIOPT,0              ANY SSI CHANGE?                   14207000
         BE    *+8                    NO, BRANCH                        14208000
         MVI   #OPTOPT,X'F0'          YES, SET A FLAG FOR LATER         14209000
         XC    #ATTRNO(2),=F'-1'      INVERT THE #ATTRNO BITS           14210000
         B     PARSPOST                                                 14211000
         SPACE 2                                                        14212000
         USING PDLCOMPA,R6                                              14213000
         USING *,R8                                                     14214000
ZCOMPARE TM    PCLCOSTR+6,X'80'     STRING CODED?                       14215000
         BNO   PARSPOST             NO, DONE                            14216000
         LH    R2,PCLCOSTR+4        LENGTH OF STRING                    14217000
         LTR   R2,R2                NULL STRING CODED?                  14218000
         BZ    PARSPOST             YES, DONE                           14219000
         CH    R2,=H'40'            LENGTH(STRING)>=40?                 14220000
         BL    *+8                  NO, BRANCH                          14221000
         LH    R2,=H'40'            YES, USE 40 AS A MAXIMUM LENGTH     14222000
         MVC   MSGLINE(40),MSGBL132+4  BLANK THE TEXT AREA              14223000
         STH   R2,#COMMDSZ          SAVE ACTUAL LENGTH                  14224000
         L     R1,PCLCOSTR          NEW STRING ADDRESS                  14225000
         BCTR  R2,0                 MACHINE LENGTH                      14226000
         MVC   MSGLINE(*-*),0(R1)   <<EXECUTED>>                        14227000
         EX    R2,*-6               MOVE IN ANY OTHER OPERANDS          14228000
         B     PARSPOST                                                 14229000
         SPACE 2                                                        14230000
         USING PDLCOMPR,R6                                              14231000
         USING *,R8                                                     14232000
ZCOMPRES MVC   #CMXFLAG(1),CMXLIST+1     SAVE SUMMARY/LIST/NOLIST       14233000
         MVC   #CMXSHR(1),CMXSHARE+1     SAVE SHR                       14234000
         B     PARSPOST                                                 14235000
         SPACE 2                                                        14236000
         USING PDLCONT,R6                                               14237000
         USING *,R8                                                     14238000
ZCONTROL MVC   #OUT+0(1),PALINCON+1                                     14239000
         MVC   #OUT+1(1),PTRANCON+1                                @D05
**       MVC   #OUT+1(1),PSAVEOP+1                                 @D05 14240000
         MVC   #OUT+2(1),PLKEDCON+1                                     14241000
         MVC   #OUT+3(1),PPROMCON+1                                     14242000
         MVC   #OUT+4(1),PRECVCON+1                                     14243000
         MVC   #OUT+5(1),PDOUBCON+1                                     14244000
         MVC   #OUT+7(1),PIMMCON+1                                      14245000
         MVC   #OUT+10(1),CLOGTYPE+1      SYSOUT/NOSYSOUT/DSNAME/NODSN  14246000
         MVC   #OUT+11(1),CLOGDISP+1      OLD/SHR/MOD/NEW               14247000
         AIF   (&MVT).MA01160                                      @D01
         MVC   #OUT+12(1),CLOGFORM+1      FORM/NOFORM                   14248000
         MVC   #OUT+13(1),CLOGDEST+1      DEST/NODEST                   14249000
.MA01160 ANOP  ,                                                   @D01
         MVC   #OUT+30(80),MSGBL132+4     CLEAR THE OPERANDS            14250000
         AIF   (NOT &MVT).MA01180                                  @D01
         CLI   #OUT+10,X'01'       Invalid choice?                 @D01
         BE    ZCONT004            Branch if so                    @D01
         CLI   #OUT+10,X'02'       Invalid choice?                 @D01
         BNE   ZCONT006            Branch if not                   @D01
ZCONT004 DS    0H                                                  @D01
         MVI   #OUT+10,X'00'       Clear invalid choice            @D01
ZCONT006 DS    0H                                                  @D01
.MA01180 ANOP  ,                                                   @D01
         AIF   (&MVT).MA01200                                      @D01
         LH    R15,CDESTT+4               LENGTH OF STRING              14251000
         STH   R15,#OUT+14                14,15                         14252000
         S     R15,=F'1'                  ANY DATA?                     14253000
         BM    ZCONT010                   NO, BRANCH                    14254000
         L     R1,CDESTT                                                14255000
         MVC   #OUT+30(*-*),0(R1)         <<EXECUTED>> 30-37            14256000
         EX    R15,*-6                    MOVE IT IN                    14257000
         SPACE 1                                                        14258000
ZCONT010 LH    R15,CFORMT+4               LENGTH OF STRING              14259000
         STH   R15,#OUT+16                16,17                         14260000
         S     R15,=F'1'                  ANY DATA?                     14261000
         BM    ZCONT020                   NO, BRANCH                    14262000
         L     R1,CFORMT                                                14263000
         MVC   #OUT+38(*-*),0(R1)         <<EXECUTED>> 38-41            14264000
         EX    R15,*-6                    MOVE IT IN                    14265000
         SPACE 1                                                        14266000
ZCONT020 LH    R15,CSYSOUTT               LENGTH OF STRING              14267000
         S     R15,=F'1'                  ANY DATA?                     14268000
         BM    ZCONT030                   NO, BRANCH                    14269000
         L     R1,CSYSOUTT                                              14270000
         MVC   CONTSYS(1),0(R1)           <<EXECUTED>>                  14271000
.MA01200 ANOP  ,                                                   @D01
         SPACE 1                                                        14272000
ZCONT030 L     R15,CDSNAMET               ADDRESS OF DSNAME             14273000
         LH    R14,CDSNAMET+4             LENGTH OF DSNAME              14274000
         STH   R14,#OUT+18                18,19                         14275000
         S     R14,=F'1'                  ANY DATA?                     14276000
         BM    PARSPOST                   NO, BRANCH                    14277000
         MVC   #OUT+44(*-*),0(R15)        <<EXECUTED>> 44-87            14278000
         EX    R14,*-6                    MOVE IT IN                    14279000
         AIF   (NOT &MVT).MA01220                                  @D01
         SPACE 1                                                   @D01
         TM    CDSNAMET+6,X'40'    Data set name in quotes?        @D01
         BNZ   ZCONT032            Fully qualified if so           @D01
* need to qualify dsn
         MVC   #OUT+42(2),#OUT+18  Copy DSN length to work area;   @D01
*                                  temporarily uses 42,43          @D01
         LA    R5,PARMLIST         Point to default parm list      @D01
         USING DFPL,R5             Addressability for DFPL         @D01
         L     R0,ADDRUPT          Get UPT address                 @D01
         L     R1,ADDRECT          Get ECT address                 @D01
         LA    R2,ATTNECB          Get ECB address                 @D01
         LA    R3,PARMLIST+16      Point to area for parm block    @D01
         STM   R0,R3,DFPLUPT       Initialize DFPLUPT, DFPLECT,    @D01
*                                             DFPLECB and DFPLDFPB @D01
         USING DFPB,R3             Address default parm block      @D01
         LA    R14,#OUT+42         Point to DSN length/DSN         @D01
         L     R15,ADDRPSCB        Get PSCB address                @D01
         LA    R0,DOUBLE           Point to default qualifier      @D01
         STM   R14,R0,DFPBDSN      Initialize DFPBDSN, DFPBPSCB,   @D01
*                                             and DFPBQUAL         @D01
         MVI   DFPBCNTL,DFPBUID    Prefix with userid              @D01
         MVI   DFPBCODE,DFPB04     Entry code X'04' -- can prompt  @D01
         MVC   DOUBLE(8),BLANKS    Blank default qualifier         @D01
         LA    R1,PARMLIST         Address of default parm list    @D01
         L     R15,ADDRDEFT        Get default routine address     @D01
         BALR  R14,R15             Call it                         @D01
         DROP  R3                  End parm block addressability   @D01
         DROP  R5                  End DFPL addressability         @D01
         MVC   #OUT+18(2),#OUT+42  Copy qualified DSN length       @D01
ZCONT032 DS    0H                                                  @D01
.MA01220 ANOP  ,                                                   @D01
         SPACE 1                                                        14280000
         TM    CDSNAMET+14,X'80'          ANY MEMBER?                   14281000
         BZ    ZCONT034                   NO, BRANCH                    14282000
         L     R15,CDSNAMET+8             ADDRESS OF DSNAME             14283000
         LH    R14,CDSNAMET+12            LENGTH OF MEMBER              14284000
         STH   R14,#OUT+20                20,21                         14285000
         S     R14,=F'1'                  ANY DATA?                     14286000
         BM    PARSPOST                   NO, BRANCH                    14287000
         MVC   #OUT+88(*-*),0(R15)        <<EXECUTED>> 88-95            14288000
         EX    R14,*-6                    MOVE IT IN                    14289000
         SPACE 1                                                        14290000
ZCONT034 TM    CDSNAMET+22,X'80'          ANY PASSWORD?                 14291000
         BZ    PARSPOST                   NO, BRANCH                    14292000
         L     R15,CDSNAMET+16            ADDRESS OF DSNAME             14293000
         LH    R14,CDSNAMET+20            LENGTH OF MEMBER              14294000
         STH   R14,#OUT+22                22,23                         14295000
         S     R14,=F'1'                  ANY DATA?                     14296000
         BM    PARSPOST                   NO, BRANCH                    14297000
         MVC   #OUT+96(*-*),0(R15)        <<EXECUTED>> 96-103           14298000
         EX    R14,*-6                    MOVE IT IN                    14299000
         B     PARSPOST                                                 14300000
         SPACE 2                                                        14301000
         USING PDLDELET,R6                                              14302000
         USING *,R8                                                     14303000
ZDELETE  MVC   #DELFLAG(1),PCLDELAL+1                                   14304000
         B     PARSPOST                                                 14305000
         SPACE 2                                                   @D04
         USING PDLDIR,R6                                           @D04
         USING *,R8                                                @D04
ZDIRENTR MVC   #DIRSHOR(1),PCLSHOR+1                               @D04
         B     PARSPOST                                            @D04
         SPACE 2                                                        14306000
         USING PDLDSNA,R6                                               14307000
         USING *,R8                                                     14308000
ZDSNAMES NI    FLAGSJJ,FF-FDSNTSO-FDSNJCL  CLEAR THE FLAGS              14309000
         OC    FLAGSJJ(1),PCLDSN+1         SET THE FALL FLAGS           14310000
         B     PARSPOST                                                 14311000
         SPACE 2                                                        14312000
         USING PDLEDIT,R6                                               14313000
         USING *,R8                                                     14314000
ZEDIT    MVC   #SPFOLD(1),SPFNEWOP+1       SAVE ANY OLD/NEW OPTION      14315000
         CLI   SPFNEWOP+1,X'02'            "OLD"?                       14316000
         BNE   *+8                         NO, BRANCH                   14317000
         OI    ##ADRPC#,@B                 YES, MUST EXIST              14318000
         SPACE 1                                                        14319000
         TM    SPFMACRO+6,X'80'            ANY MACRO NAME?              14320000
         BNO   PARSPOST                    NO, BRANCH                   14321000
         LH    R15,SPFMACRO+4              LENGTH OF NAME               14322000
         S     R15,=F'1'                   MACHINE LENGTH VALID?        14323000
         BM    PARSPOST                    NO, BRANCH                   14324000
         MVC   #SPFMACR,BLANKS             INITIALIZE THE MACRO NAME    14325000
         L     R1,SPFMACRO                 PARTIAL IDRDATA DATA         14326000
         MVC   #SPFMACR(*-*),0(R1)         <<EXECUTED>>                 14327000
         EX    R15,*-6                     MOVE INTO STORAGE            14328000
         B     PARSPOST                                                 14329000
         SPACE 2                                                        14330000
         USING PDLFIND,R6                                               14331000
         USING *,R8                                                     14332000
ZFIND    TM    FINDSTRG+6,X'80'     STRING CODED?                       14333000
         BNO   PARSPOST             NO, ASSUME OK                       14334000
         L     R5,FINDSTRG          NEW STRING ADDRESS                  14335000
         LH    R2,FINDSTRG+4        LENGTH OF STRING                    14336000
FINDTEST LTR   R2,R2                NULL STRING CODED?                  14337000
         BNP   FINDCHK              YES, CHECK FORMAT                   14338000
         BCTR  R5,0                 BACK UP ONE                         14339000
         OI    0(R5),X'40'          UPPER CASE THE DELIMITER            14340000
         CLI   0(R5),C'X'           POSSIBLE HEX STRING?                14341000
         BNE   FINDCHAR             NO, BRANCH                          14342000
         LA    R1,L841              BAD HEX STRING MESSAGE              14343000
         LA    R3,1(,R2)            STRING LENGTH +1                    14344000
         N     R3,=F'-2'            NEXT EVEN NUMBER                    14345000
         SR    R15,R15              ZERO                                14346000
         LA    R4,MSGTEXT2+4        WHERE OUTPUT GOES                   14347000
         LA    R0,2                 PAIRWISE COUNTER                    14348000
         CR    R2,R3                EVEN LENGTH ORIGINALLY?             14349000
         SRL   R3,1                 (STRING LENGTH +1)/2                14350000
         ST    R3,MSGTEXT2          (STRING LENGTH +1)/2                14351000
         BNE   FINDHEX2             NO, BRANCH                          14352000
         SPACE 1                                                        14353000
FINDHEX1 LA    R5,1(,R5)            NEXT CHARACTER                      14354000
         OI    0(R5),X'40'          UPPER CASE THE HEX CHARACTER        14355000
         IC    R15,0(,R5)           GET A BYTE TO CONVERT               14356000
         CLI   0(R5),C'0'                                               14357000
         BL    *+12                 0-9?                                14358000
         CLI   0(R5),C'9'                                               14359000
         BNH   FINDHEX2             YES, BRANCH                         14360000
         LA    R15,9(,R15)          NO, ADJUST LOW DIGIT 1-5 TO A-F     14361000
         CLI   0(R5),C'A'           BELOW AN A?                         14362000
         BL    FINDNEWS             YES, INVALID                        14363000
         CLI   0(R5),C'F'           ABOVE AN F?                         14364000
         BH    FINDNEWS             YES, INVALID                        14365000
         SPACE 1                                                        14366000
FINDHEX2 SLL   R15,28               SHIFT                               14367000
         SLDL  R14,4                GET A GOOD DIGIT                    14368000
         BCT   R0,FINDHEX1          DO THE NEXT DIGIT OF A PAIR         14369000
         LA    R0,2                 PAIRWISE COUNTER                    14370000
         STC   R14,0(,R4)           SAVE AN OUTPUT CHARACTER            14371000
         LA    R4,1(,R4)            ANOTHER OUTPUT CHARACTER            14372000
         BCT   R3,FINDHEX1          DO ALL DIGITS                       14373000
         SPACE 1                                                        14374000
         LA    R5,MSGTEXT2+4-1      START OF CONVERTED STRING -1        14375000
         L     R2,MSGTEXT2          LENGTH OF CONVERTED STRING          14376000
         CH    R2,=H'16'            VALID LENGTH?                       14377000
         BH    FINDNEWS             NO, BRANCH                          14378000
         STH   R2,FINDLTH           SAVE ACTUAL LENGTH                  14379000
         BCTR  R2,0                 MACHINE LENGTH                      14380000
         MVC   FINDSTR(*-*),1(R5)   <<EXECUTED>>                        14381000
         EX    R2,*-6               SAVE THE NEW STRING                 14382000
         B     FINDCHK                                                  14383000
         SPACE 2                                                        14384000
FINDCHAR LA    R1,L842              INVALID LENGTH MESSAGE              14385000
         CH    R2,=H'16'            VALID LENGTH?                       14386000
         BH    FINDNEWS             NO, BRANCH                          14387000
         STH   R2,FINDLTH           SAVE ACTUAL LENGTH                  14388000
         BCTR  R2,0                 MACHINE LENGTH                      14389000
         MVC   FINDSTR(*-*),1(R5)   <<EXECUTED>>                        14390000
         EX    R2,*-6               SAVE THE NEW STRING                 14391000
         CLI   FINDASIS+1,1            ASIS REQUESTED?                  14392000
         BE    FINDCHK                 YES, BRANCH                      14393000
         OC    FINDSTR(16),MSGBL132+4  NO, UPPER CASE THE DATA          14394000
         B     FINDCHK                                                  14395000
         SPACE 2                                                        14396000
FINDNEWS TSMSG (R1)                 INVALID LENGTH STRING -- REENTER    14397000
FINDNEW0 LA    R2,NEWCMD            EXIT ADDRESS FOR ATTENTION          14398000
        $PUTGET PDS380A,ATTN=NEWCMD50  SECOND PART OF MESSAGE           14399000
         L     R5,ADDRCBUF          ENTERED DATA                        14400000
         LH    R2,0(,R5)            LENGTH OF STRING                    14401000
         SH    R2,=H'5'             VALID MACHINE LENGTH?               14402000
         LA    R1,4(R5,R2)          LAST BYTE OF INPUT STRING           14403000
         BZ    FINDNEW3             MAYBE, CHECK FURTHER                14404000
         BNP   FINDNEW0             NO, NULL STRING -- PROMPT AGAIN     14405000
         SPACE 1                                                        14406000
FINDNEW1 CLI   0(R1),X'40'          SCAN                                14407000
         BNE   FINDNEW2                 BACKWARDS                       14408000
         BCTR  R1,0                              FOR A                  14409000
         BCT   R2,FINDNEW1                             NON-BLANK        14410000
         B     FINDNEW3             POSSIBLE STRING -- CHECK            14411000
         SPACE 1                                                        14412000
FINDNEW2 CLI   4(R5),X'40'          SCAN                                14413000
         BNE   FINDNEW3                 FORWARDS                        14414000
         LA    R5,1(,R5)                        FOR A                   14415000
         BCT   R2,FINDNEW2                            NON-BLANK         14416000
         SPACE 1                                                        14417000
FINDNEW3 CLI   4(R5),X'40'          REAL STRING?                        14418000
         BE    FINDNEW0             NO, PROMPT AGAIN                    14419000
         CLI   FINDASIS+1,1         ASIS REQUESTED?                     14420000
         BE    FINDNEW4             YES, BRANCH                         14421000
         OC    4(*-*,R5),MSGBL132+4 <<EXECUTED>>                        14422000
         EX    R2,*-6               UPPER-CASE DATA AND DELIMITERS      14423000
         SPACE 1                                                        14424000
FINDNEW4 OI    4(R5),X'40'          UPPER-CASE THE FIRST DELIMITER      14425000
         MVC   0(1,R5),0(R1)        ENDING CHARACTER                    14426000
         OI    0(R5),X'40'          UPPER-CASE THE LAST DELIMITER       14427000
         CLC   0(1,R5),4(R5)        SAME DELIMITERS?                    14428000
         BNE   *+6                  NO, BRANCH                          14429000
         BCTR  R2,0                 YES, ALLOW FOR LAST DELIMITER       14430000
         LA    R5,5(,R5)            FIRST CHARACTER OF STRING           14431000
         B     FINDTEST             PARSE THIS NEW STRING               14432000
         SPACE 2                                                        14433000
FINDCHK  CLI   FINDLIST+1,1           FINDLIST SPECIFIED?               14434000
         BNE   FINDCHK1               NO, BRANCH                        14435000
         OI    ##ADRPA#,$F            YES, TURN ON THE FLAG             14436000
         SPACE 1                                                        14437000
FINDCHK1 CLI   FINDFMT+1,0            WAS A FORMAT SPECIFIED?           14438000
         BE    FINDCHK2               NO, BRANCH                        14439000
         NI    HFLAGSDD,FF-NONUM-SNUM-BLOCK-DUMP-LBLOCK-LDUMP           14440000
         LH    R15,FINDFMT            FORMAT REQUESTED                  14441000
         A     R15,=F'-2'             LESS 2 -- NEGATIVE?               14442000
         BM    FINDCHK2               YES, BRANCH                       14443000
         LA    R1,1                   SHIFT VALUE                       14444000
         SLL   R1,0(R15)              SHIFT INTO POSITION               14445000
         OI    HFLAGSDD,*-*           <<EXECUTED>>                      14446000
         EX    R1,*-4                 MOVE INTO FLAG BYTE               14447000
         SPACE 1                                                        14448000
FINDCHK2 LA    R1,FMAXLENC            MAXLEN                            14449000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14450000
         ST    R1,#MAXLEN             SAVE RESULT                       14451000
         SPACE 1                                                        14452000
         LA    R1,FMAXINC             MAXIN                             14453000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14454000
         ST    R1,#MAXIN              SAVE RESULT                       14455000
         SPACE 1                                                        14456000
         LA    R1,FMAXOUTC            MAXOUT                            14457000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14458000
         ST    R1,#MAXOUT             SAVE RESULT                       14459000
         SPACE 1                                                        14460000
         LA    R1,FSKIPRC             SKIPREC                           14461000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14462000
         ST    R1,#SKIPREC            SAVE RESULT                       14463000
         SPACE 1                                                        14464000
         LA    R1,FSKIPCC             SKIPCOL                           14465000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14466000
         ST    R1,#SKIPCOL            SAVE RESULT                       14467000
         SPACE 1                                                        14468000
         LH    R1,FTHENCC             THEN ACTION NUMBER                14469000
         SLA   R1,2                   ACTION SPECIFIED                  14470000
         L     R1,THENTBL(R1)         THEN ACTION POINTER               14471000
         ST    R1,#ACTIONT            NOTE FOR LATER                    14472000
         OC    FLAGSII(1),#ACTIONT    SET POSSIBLE FSINGLE FLAG         14473000
         AIF ('&CISP' EQ 'NO SPF').MA01240                         @D01
         OC    SPFLAG3(1),#ACTIONT    SET POSSIBLE INVALID    ABL OCT84 14474000
.MA01240 ANOP  ,                                                   @D01
         SPACE 1                                                        14475000
FINDCHK3 LH    R1,FELSECC             ELSE ACTION NUMBER                14476000
         SLA   R1,2                   ACTION SPECIFIED                  14477000
         L     R1,THENTBL(R1)         ELSE ACTION POINTER               14478000
         ST    R1,#ACTIONE            NOTE FOR LATER                    14479000
         OC    FLAGSII(1),#ACTIONE    SET POSSIBLE FSINGLE FLAG         14480000
         AIF ('&CISP' EQ 'NO SPF').MA01260                         @D01
         OC    SPFLAG3(1),#ACTIONE    SET POSSIBLE INVALID    ABL OCT84 14481000
.MA01260 ANOP  ,                                                   @D01
         SPACE 1                                                        14482000
         TM    FINDOFF+6,X'80'        OFFSET CODED?                     14483000
         BNO   FINDCHK4               NO, DONE                          14484000
         L     R5,FINDOFF             OFFSET ADDRESS                    14485000
         LH    R1,FINDOFF+4           LENGTH OF OFFSET                  14486000
         LTR   R1,R1                  NULL STRING CODED?                14487000
         BNP   FINDCHK4               YES, DONE                         14488000
         MVI   MSGTEXT2+1,3           MAXIMUM OF 3 DIGITS               14489000
         MVC   MSGTEXT1,PDS384A       OFFSET INVALID MESSAGE            14490000
         BAL   R2,HEXC                CONVERT TO BINARY                 14491000
         B     NEWCMD50               ATTENTION -- IGNORE THE REST      14492000
         STCM  R0,B'0111',#LISTOFF+1  SAVE THE RESULTING OFFSET         14493000
         SPACE 1                                                        14494000
FINDCHK4 LH    R15,FDUMPCS+4          LENGTH OF BLOCK/DUMP STRING       14495000
         STC   R15,#MODLEN                                              14496000
         S     R15,=F'1'              ANY STRING?                       14497000
         BM    PARSPOST               NO, BRANCH                        14498000
         L     R1,FDUMPCS             ADDRESS OF BLOCK/DUMP STRING      14499000
         MVC   #MODTXT(*-*),0(R1)     <<EXECUTED>>                      14500000
         EX    R15,*-6                SAVE THE STRING FOR LATER         14501000
         B     PARSPOST                                                 14502000
         SPACE 2                                                        14503000
         USING PDLFIX,R6                                                14504000
         USING *,R8                                                     14505000
ZFIXPDS  MVC   #FIXOPT(1),PCLFIXOP+1  SAVE FIXPDS MAIN KEYWORD OPTION   14506000
         MVC   #FIXOPT2(1),PCLRELOP+1 SAVE FIXPDS RELEASE/RELSAVE/MAXSP 14507000
         SPACE 1                                                        14508000
         SR    R1,R1                                                    14509000
         ICM   R1,B'0001',RTYPE+1   ANY GENERAL DATA TYPE?              14510000
         BZ    ZFIX010              NO, BRANCH                          14511000
         MH    R1,=H'22'            INDEX VALUE                         14512000
         LA    R3,RTABLE-22-22(R1)  CURRENT ENTRY -22                   14513000
         MVC   #RECFM+3(1),22+1(R3) RECFM                               14514000
         MVC   #LRECL+2(2),22+2(R3) LRECL                               14515000
         IC    R1,BYTEUCB+1         DEVICE INDEX                        14516000
         LA    R0,X'00000001'       Get 2311 device type           @D01
         CR    R0,R1                Is device 2311?                @D01
         BNE   ZFIX003              Branch if not                  @D01
         XR    R1,R1                Get index                      @D01
         ICM   R1,1,RTYPE+1          of data type                  @D01
         BCTR  R1,0                   minus 1                      @D01
         AR    R1,R1                   times 2                     @D01
         LA    R3,RBLK2311(R1)          and point to block size    @D01
         B     ZFIX005              Go move block size             @D01
         SPACE 1                                                   @D01
*  2311 block sizes                                                @D01
RBLK2311 DC    AL2(3625)            2311 block size for LOAD       @D01
         DC    AL2(0800)            2311 block size for OBJECT     @D01
         DC    AL2(3625)            2311 block size for CLIST      @D01
         DC    AL2(0800)            2311 block size for CNTL       @D01
         DC    AL2(0800)            2311 block size for ASM        @D01
         SPACE 1                                                   @D01
ZFIX003  DS    0H                                                  @D01
         LA    R0,X'0000000E'       MAXIMUM DEFINED INDEX               14517000
         CR    R1,R0                ABOVE 3380?                         14518000
         BNH   *+6                  NO, BRANCH                          14519000
         LR    R1,R0                YES, USE 3380 DATA                  14520000
         AR    R1,R1                DEVICE INDEX * 2 (FOR TABLE ENTRY)  14521000
         LA    R3,22+4-12(R3,R1)    POINT TO DEVICE BLOCKSIZE           14522000
ZFIX005  DS    0H                                                  @D01
         MVC   #BLKSI+2(2),0(R3)    BLKSIZE                             14523000
         SPACE 1                                                        14524000
ZFIX010  LH    R1,RRECFMZI          RECORD FORMAT INDEX (0 IF NONE)     14525000
         LA    R1,RECFMVAL(R1)      INDEX TO CORRESPONDING DCBRECFM     14526000
         CLI   0(R1),X'00'          DEFAULT RECFM VALUE?                14527000
         BE    *+10                 YES, BRANCH                         14528000
         MVC   #RECFM+3(1),0(R1)    NO, NEW RECORD FORMAT               14529000
         SPACE 1                                                        14530000
         LA    R1,RDIRZI            NUMBER OF DIRECTORY BLOCKS          14531000
         BAL   R14,PACKMAX          CONVERT TO BINARY                   14532000
         ST    R1,#NEWDIR           SAVE RESULT IF CODED                14533000
         SPACE 1                                                        14534000
         LA    R1,RLRECLZI          LRECL DESIRED                       14535000
         BAL   R14,PACKMAX          CONVERT TO BINARY                   14536000
         ST    R1,#LRECL            SAVE RESULT IF CODED                14537000
         SPACE 1                                                        14538000
         LA    R1,RBLKSIZI          BLOCKSIZE DESIRED                   14539000
         BAL   R14,PACKMAX          CONVERT TO BINARY                   14540000
         ST    R1,#BLKSI            SAVE RESULT IF CODED                14541000
         SPACE 1                                                        14542000
         LA    R1,RRESV             RESERVE COUNT                       14543000
         BAL   R14,PACKMAX          CONVERT TO BINARY                   14544000
         ST    R1,#FIXRES           SAVE RESULT IF CODED                14545000
         B     PARSPOST                                                 14546000
         SPACE 2                                                        14547000
         USING PDLHIST,R6                                               14548000
         USING *,R8                                                     14549000
ZHISTORY MVC   #ZAPOPT(1),PCLHZAPK+1    SAVE THE ZAP OPTION             14550000
         MVC   #USEROPT(1),PCLHUSRK+1   SAVE THE USER OPTION            14551000
         MVC   #TRANOPT(1),PCLHTRNK+1   SAVE THE TRAN OPTION            14552000
         MVC   #LKEDOPT(1),PCLHLKDK+1   SAVE THE LKED OPTION            14553000
         SPACE 1                                                        14554000
         TM    PCLHMOD+6,X'80'        ANY MODULE NAME FILTERING?        14555000
         BNO   ZHIST10                NO, BRANCH                        14556000
         LH    R15,PCLHMOD+4          LENGTH OF MODULE NAME             14557000
         STC   R15,#MODLEN            SAVE FOR LATER                    14558000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14559000
         BM    ZHIST10                NO, BRANCH                        14560000
         L     R1,PCLHMOD             PARTIAL MODULE NAME               14561000
         MVC   #MODTXT(*-*),0(R1)     <<EXECUTED>>                      14562000
         EX    R15,*-6                MOVE INTO STORAGE                 14563000
         SPACE 3                                                        14564000
ZHIST10  TM    PCLHTRN+6,X'80'        ANY TRANSLATOR NAME FILTERING?    14565000
         BNO   ZHIST20                NO, BRANCH                        14566000
         LH    R15,PCLHTRN+4          LENGTH OF NAME                    14567000
         STC   R15,#TRANLEN           SAVE FOR LATER                    14568000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14569000
         BM    ZHIST20                NO, BRANCH                        14570000
         L     R1,PCLHTRN             PARTIAL TRANSLATOR NAME           14571000
         MVC   #TRANTXT(*-*),0(R1)    <<EXECUTED>>                      14572000
         EX    R15,*-6                MOVE INTO STORAGE                 14573000
         SPACE 1                                                        14574000
ZHIST20  TM    PCLHZAP+6,X'80'        ANY ZAP IDRDATA NAME FILTERING?   14575000
         BNO   ZHIST30                NO, BRANCH                        14576000
         LH    R15,PCLHZAP+4          LENGTH OF NAME                    14577000
         STC   R15,#ZAPLEN            SAVE FOR LATER                    14578000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14579000
         BM    ZHIST30                NO, BRANCH                        14580000
         L     R1,PCLHZAP             PARTIAL IDRDATA DATA              14581000
         MVC   #ZAPTXT(*-*),0(R1)     <<EXECUTED>>                      14582000
         EX    R15,*-6                MOVE INTO STORAGE                 14583000
         SPACE 1                                                        14584000
ZHIST30  TM    PCLHUSR+6,X'80'        ANY USER IDRDATA FILTERING?       14585000
         BNO   ZHIST40                NO, BRANCH                        14586000
         LH    R15,PCLHUSR+4          LENGTH OF NAME                    14587000
         STC   R15,#USERLEN           SAVE FOR LATER                    14588000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14589000
         BM    ZHIST40                NO, BRANCH                        14590000
         L     R1,PCLHUSR             PARTIAL IDRDATA DATA              14591000
         MVC   #USERTXT(*-*),0(R1)    <<EXECUTED>>                      14592000
         EX    R15,*-6                MOVE INTO STORAGE                 14593000
         SPACE 1                                                        14594000
ZHIST40  TM    PCLHLKD+6,X'80'        ANY LKED IDRDATA FILTERING?       14595000
         BNO   PARSPOST               NO, BRANCH                        14596000
         LH    R15,PCLHLKD+4          LENGTH OF NAME                    14597000
         STC   R15,#LKEDLEN           SAVE FOR LATER                    14598000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14599000
         BM    PARSPOST               NO, BRANCH                        14600000
         L     R1,PCLHLKD             PARTIAL IDRDATA DATA              14601000
         MVC   #LKEDTXT(*-*),0(R1)    <<EXECUTED>>                      14602000
         EX    R15,*-6                MOVE INTO STORAGE                 14603000
         B     PARSPOST                                                 14604000
         SPACE 2                                                        14605000
         USING PDLIFTTR,R6                                              14606000
         USING *,R8                                                     14607000
ZIF      MVC   #ALIAOPT(1),IFLKALIA+1   ALIAS/NOALIAS                   14608000
         MVC   #SSIOPT(1),IFLKSSI+1     SSI/NOSSI                       14609000
         MVC   #AUTHOPT(1),IFLKAUTH+1   AUTH/NOAUTH                     14610000
         MVC   #PAGEOPT(1),IFLKPAGE+1   PAGE/NOPAGE                     14611000
         MVC   #VSLKED(1),IFLKVSLE+1    VSLKED/NOVSLKED                 14612000
         MVC   #RMODE(1),IFRMODE+1      RMODE24/RMODEANY                14613000
         MVC   #AMODE(1),IFAMODE+1      AMODE24/AMODE31/AMODEANY/NOA... 14614000
         MVC   #USERIDO(1),IFTUSERK+1   USERID/NOUSERID/NOTUSERID       14615000
         MVC   #LOADERR(1),IFLOADER+1   LOADERR/NOLOADERR               14616000
         MVC   #LKEDERR(1),IFLKEDER+1   LKEDERR/NOLKEDERR               14617000
         MVC   #IOERROR(1),IFIOERR+1    IOERR/NOIOERR                   14618000
         MVC   #BLOCKER(1),IFBLKERR+1   BLOCKERR/NOBLOCKERR             14619000
         MVC   #LRECLER(1),IFLRECLE+1   LRECLERR/NOLRECLERR             14620000
         MVC   #NULL(1),IFNULL+1        NULL/NONULL                     14621000
         MVC   #AALIAS(1),IFAALIAS+1    APPARENTALIAS/NOAPPARENTALIAS   14622000
         MVC   #ORPHAN(1),IFORPHAN+1    ORPHAN/NOORPHAN                 14623000
         MVC   #SPFEDIT(1),IFSPFEDT+1   SPFEDIT/NOSPFEDIT               14624000
         MVC   #NAMEERR(1),IFNAMERR+1   NAMEERR/NONAMEERR               14625000
         MVC   #ATTRHI(3),=F'-1'        INITIALIZE THE SECOND TTR VALUE 14626000
         SPACE 1                                                        14627000
ZIF380   CLI   IFLKREUS+1,X'01'       REUSABLE ATTRIBUTE STATUS:        14628000
         BL    ZIF384                   NONE, BRANCH                    14629000
         BH    ZIF382                   "NO" FORM, BRANCH               14630000
         OI    #ATTRYES,ATTRREUS        "REUS"                          14631000
         B     ZIF384                                                   14632000
ZIF382   OI    #ATTRNO,ATTRREUS         "NOREUS"                        14633000
         SPACE 1                                                        14634000
ZIF384   CLI   IFLKREFR+1,X'01'       REFRESHABLE ATTRIBUTE STATUS:     14635000
         BL    ZIF400                   NONE, BRANCH                    14636000
         BH    ZIF386                   "NO" FORM, BRANCH               14637000
         OI    #ATTRYES+1,ATTRREFR      "REFR"                          14638000
         B     ZIF400                                                   14639000
ZIF386   OI    #ATTRNO+1,ATTRREFR       "NOREFR"                        14640000
         SPACE 1                                                        14641000
ZIF400   CLI   IFLKRENT+1,X'01'       REENTRANT ATTRIBUTE STATUS:       14642000
         BL    ZIF404                   NONE, BRANCH                    14643000
         BH    ZIF402                   "NO" FORM, BRANCH               14644000
         OI    #ATTRYES,ATTRRENT        "RENT"                          14645000
         B     ZIF404                                                   14646000
ZIF402   OI    #ATTRNO,ATTRRENT         "NORENT"                        14647000
         SPACE 1                                                        14648000
ZIF404   CLI   IFLKEXEC+1,X'01'       EXECUTABLE ATTRIBUTE STATUS:      14649000
         BL    ZIF420                   NONE, BRANCH                    14650000
         BH    ZIF406                   "NO" FORM, BRANCH               14651000
         OI    #ATTRYES,ATTREXEC        "EXEC"                          14652000
         B     ZIF420                                                   14653000
ZIF406   OI    #ATTRNO,ATTREXEC         "NOEXEC"                        14654000
         SPACE 1                                                        14655000
ZIF420   CLI   IFLKLOAD+1,X'01'       LOADABLE ATTRIBUTE STATUS:        14656000
         BL    ZIF424                   NONE, BRANCH                    14657000
         BH    ZIF422                   "NO" FORM, BRANCH               14658000
         OI    #ATTRYES,ATTRLOAD        "LOAD"                          14659000
         B     ZIF424                                                   14660000
ZIF422   OI    #ATTRNO,ATTRLOAD         "NOLOAD"                        14661000
         SPACE 1                                                        14662000
ZIF424   CLI   IFLKEDIT+1,X'01'       NOT EDITABLE ATTRIBUTE STATUS:    14663000
         BL    ZIF440                   NONE, BRANCH                    14664000
         BH    ZIF426                   "NO" FORM, BRANCH               14665000
         OI    #ATTRNO+1,ATTRNE        "EDIT"  -- BIT MUST BE REVERSED  14666000
         B     ZIF440                                                   14667000
ZIF426   OI    #ATTRYES+1,ATTRNE        "NOEDIT"                        14668000
         SPACE 1                                                        14669000
ZIF440   CLI   IFLKLKED+1,X'01'       LINKAGE EDITOR ATTRIBUTE:         14670000
         BL    ZIF444                   NEITHER, BRANCH                 14671000
         BH    ZIF442                   NULL FORM, BRANCH               14672000
         OI    #ATTRYES+1,ATTRFLEV      "FLEVEL"                        14673000
         B     ZIF444                                                   14674000
ZIF442   OI    #ATTRNO+1,ATTRFLEV       "NOFLEVEL"                      14675000
         SPACE 1                                                        14676000
ZIF444   CLI   IFLKOVER+1,X'01'       OVERLAY ATTRIBUTE STATUS:         14677000
         BL    ZIF460                   NONE, BRANCH                    14678000
         BH    ZIF446                   "NO" FORM, BRANCH               14679000
         OI    #ATTRYES,ATTROVLY        "OVERLAY"                       14680000
         B     ZIF460                                                   14681000
ZIF446   OI    #ATTRNO,ATTROVLY         "NOOVERLAY"                     14682000
         SPACE 1                                                        14683000
ZIF460   CLI   IFLKTEST+1,X'01'       TEST ATTRIBUTE STATUS:            14684000
         BL    ZIF464                   NONE, BRANCH                    14685000
         BH    ZIF462                   "NO" FORM, BRANCH               14686000
         OI    #ATTRYES,ATTRTEST        "TEST"                          14687000
         B     ZIF464                                                   14688000
ZIF462   OI    #ATTRNO,ATTRTEST         "NOTEST"                        14689000
         SPACE 1                                                        14690000
ZIF464   CLI   IFLKSCTR+1,X'01'       SCATTER ATTRIBUTE STATUS:         14691000
         BL    ZIF480                   NONE, BRANCH                    14692000
         BH    ZIF466                   "NO" FORM, BRANCH               14693000
         OI    #ATTRYES,ATTRSCTR        "SCTR"                          14694000
         B     ZIF480                                                   14695000
ZIF466   OI    #ATTRNO,ATTRSCTR         "NOSCTR"                        14696000
         SPACE 1                                                        14697000
ZIF480   CLI   IFLKDC+1,X'01'         DOWNWARD COMPATIBLE ATTRIBUTE:    14698000
         BL    ZIF484                   NONE, BRANCH                    14699000
         BH    ZIF482                   "NO" FORM, BRANCH               14700000
         OI    #ATTRNO+1,ATTRNODC       "DC" -- BIT IS REVERSED         14701000
         B     ZIF484                                                   14702000
ZIF482   OI    #ATTRYES+1,ATTRNODC      "NODC"                          14703000
         SPACE 1                                                        14704000
ZIF484   TM    IFTUSER+6,X'80'        ANY USERID NAME FILTERING?        14705000
         BNO   ZIF500                 NO, BRANCH                        14706000
         LH    R15,IFTUSER+4          LENGTH OF USERID NAME             14707000
         STC   R15,#USERIDL           SAVE FOR LATER                    14708000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14709000
         BM    ZIF500                 NO, BRANCH                        14710000
         L     R1,IFTUSER             PARTIAL USERID NAME               14711000
         MVC   #USERTXT(*-*),0(R1)    <<EXECUTED>>                      14712000
         EX    R15,*-6                MOVE INTO STORAGE                 14713000
         SPACE 1                                                        14714000
ZIF500   MVC   #ZAPOPT(1),IFTLZAPK+1   SAVE ZAP/NOZAP                   14715000
         MVC   #USEROPT(1),IFTLUSRK+1  SAVE USER/NOUSER                 14716000
         MVC   #TRANOPT(1),IFTLTRNK+1  SAVE TRAN/NOTRAN                 14717000
         MVC   #LKEDOPT(1),IFTLKEDK+1  SAVE LKED/NOLKED                 14718000
         MVC   #MODOPT(1),IFTLMODK+1   SAVE MODULE/NOMODULE             14719000
         MVC   #RLDERR(1),IFRLDERR+1   SAVE RLDERR/NORLDERR             14720000
         MVC   #RLD0(1),IFRLD0+1       SAVE RLDZERO/NORLDZERO           14721000
         MVC   #APFERR(1),IFAPFERR+1   SAVE APFERR/NOAPFERR             14722000
         SPACE 1                                                        14723000
         TM    IFTLKED+6,X'80'        ANY LINKAGE EDITOR FILTERING?     14724000
         BNO   ZIF502                 NO, BRANCH                        14725000
         LH    R15,IFTLKED+4          LENGTH OF LKED NAME               14726000
         STC   R15,#LKEDLEN           SAVE FOR LATER                    14727000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14728000
         BM    ZIF502                 NO, BRANCH                        14729000
         L     R1,IFTLKED             PARTIAL MODULE NAME               14730000
         MVC   #LKEDTXT(*-*),0(R1)    <<EXECUTED>>                      14731000
         EX    R15,*-6                MOVE INTO STORAGE                 14732000
         SPACE 1                                                        14733000
ZIF502   TM    IFTLMOD+6,X'80'        ANY MODULE NAME FILTERING?        14734000
         BNO   ZIF504                 NO, BRANCH                        14735000
         LH    R15,IFTLMOD+4          LENGTH OF MODULE NAME             14736000
         STC   R15,#MODLEN            SAVE FOR LATER                    14737000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14738000
         BM    ZIF504                 NO, BRANCH                        14739000
         L     R1,IFTLMOD             PARTIAL MODULE NAME               14740000
         MVC   #MODTXT(*-*),0(R1)     <<EXECUTED>>                      14741000
         EX    R15,*-6                MOVE INTO STORAGE                 14742000
         SPACE 1                                                        14743000
ZIF504   TM    IFTLTRN+6,X'80'        ANY TRANSLATOR NAME FILTERING?    14744000
         BNO   ZIF506                 NO, BRANCH                        14745000
         LH    R15,IFTLTRN+4          LENGTH OF NAME                    14746000
         STC   R15,#TRANLEN           SAVE FOR LATER                    14747000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14748000
         BM    ZIF506                 NO, BRANCH                        14749000
         L     R1,IFTLTRN             PARTIAL TRANSLATOR NAME           14750000
         MVC   #TRANTXT(*-*),0(R1)    <<EXECUTED>>                      14751000
         EX    R15,*-6                MOVE INTO STORAGE                 14752000
         SPACE 1                                                        14753000
ZIF506   TM    IFTLZAP+6,X'80'        ANY ZAP IDRDATA NAME FILTERING?   14754000
         BNO   ZIF508                 NO, BRANCH                        14755000
         LH    R15,IFTLZAP+4          LENGTH OF NAME                    14756000
         STC   R15,#ZAPLEN            SAVE FOR LATER                    14757000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14758000
         BM    ZIF508                 NO, BRANCH                        14759000
         L     R1,IFTLZAP             PARTIAL IDRDATA DATA              14760000
         MVC   #ZAPTXT(*-*),0(R1)     <<EXECUTED>>                      14761000
         EX    R15,*-6                MOVE INTO STORAGE                 14762000
         SPACE 1                                                        14763000
ZIF508   TM    IFTLUSR+6,X'80'        ANY USER IDRDATA FILTERING?       14764000
         BNO   ZIF540                 NO, BRANCH                        14765000
         LH    R15,IFTLUSR+4          LENGTH OF NAME                    14766000
         STC   R15,#USERLEN           SAVE FOR LATER                    14767000
         S     R15,=F'1'              MACHINE LENGTH VALID?             14768000
         BM    ZIF540                 NO, BRANCH                        14769000
         L     R1,IFTLUSR             PARTIAL IDRDATA DATA              14770000
         MVC   #USERTXT(*-*),0(R1)    <<EXECUTED>>                      14771000
         EX    R15,*-6                MOVE INTO STORAGE                 14772000
         SPACE 3                                                        14773000
ZIF540   TM    IFTTTR+6,X'80'       STRING CODED?                       14774000
         BNO   ZIF560               NO, DONE                            14775000
         L     R5,IFTTTR            NEW STRING ADDRESS                  14776000
         LH    R1,IFTTTR+4          LENGTH OF STRING                    14777000
         LTR   R1,R1                NULL STRING CODED?                  14778000
         BNP   ZIF560               YES, DONE                           14779000
         MVI   MSGTEXT2+1,3         MAXIMUM OF 3 DIGITS                 14780000
         MVC   MSGTEXT1,PDS382A     FIRST TTR MESSAGE                   14781000
         BAL   R2,HEXC              CONVERT TO BINARY                   14782000
         B     NEWCMD50             ATTENTION -- IGNORE THE REST        14783000
         STCM  R0,B'0111',#ATTRLO   SAVE THE RESULTING TTR              14784000
         SPACE 2                                                        14785000
         TM    IFTTTR+8+6,X'80'     STRING CODED?                       14786000
         BNO   ZIF560               NO, DONE                            14787000
         L     R5,IFTTTR+8          NEW STRING ADDRESS                  14788000
         LH    R1,IFTTTR+8+4        LENGTH OF STRING                    14789000
         LTR   R1,R1                NULL STRING CODED?                  14790000
         BNP   ZIF560               YES, DONE                           14791000
         MVC   MSGTEXT1,PDS383A     SECOND TTR MESSAGE                  14792000
         BAL   R2,HEXC              CONVERT TO BINARY                   14793000
         B     NEWCMD50             ATTENTION -- IGNORE THE REST        14794000
         STCM  R0,B'0111',#ATTRHI   SAVE THE RESULTING TTR              14795000
         SPACE 2                                                        14796000
ZIF560   MVI   #OPTOPT,X'80'          PARSE WAS CALLED FOR IF           14797000
         LA    R1,IFABOSUB            ABOVE(COUNT)                      14798000
         BAL   R14,PACKMAX            ANY RESULT?                       14799000
         B     ZIF600                 YES, BRANCH                       14800000
         B     ZIF620                 NO, BRANCH                        14801000
ZIF600   ST    R1,#IFABOVE            SAVE RESULT                       14802000
         OI    #IFABOVE,X'80'         MARK AS ENTERED                   14803000
         SPACE 1                                                        14804000
ZIF620   LA    R1,IFBELSUB            BELOW(COUNT)                      14805000
         BAL   R14,PACKMAX            ANY RESULT?                       14806000
         B     ZIF640                 YES, BRANCH                       14807000
         B     ZIF700                 NO, BRANCH                        14808000
ZIF640   ST    R1,#IFBELOW            SAVE RESULT                       14809000
         OI    #IFBELOW,X'80'         MARK AS ENTERED                   14810000
         SPACE 1                                                        14811000
ZIF700   LA    R1,IFMODSUB              CHANGED(DATE:                   14812000
         BAL   R14,PACKMAX              ANY RESULT?                     14813000
         B     ZIF720                   YES, BRANCH                     14814000
         B     ZIF740                   NO, BRANCH                      14815000
ZIF720   MVC   #IFMODIF(3),DOUBLE+5     SAVE RESULT                     14816000
         MVC   #IFMODIF+3(3),DOUBLE+5   IF SECOND IS MISSING, USE FIRST 14817000
         SPACE 1                                                        14818000
ZIF740   LA    R1,IFMODSUB+8            CHANGED(:DATE                   14819000
         BAL   R14,PACKMAX              ANY RESULT?                     14820000
         B     ZIF760                   YES, BRANCH                     14821000
         B     ZIF800                   NO, BRANCH                      14822000
ZIF760   MVC   #IFMODIF+3(3),DOUBLE+5   SAVE RESULT                     14823000
         OI    #IFMODIF+2,X'0F'         IF FIRST IS MISSING, USE 00000F 14824000
         SPACE 1                                                        14825000
ZIF800   LA    R1,IFCRESUB              CREATED(DATE:                   14826000
         BAL   R14,PACKMAX              ANY RESULT?                     14827000
         B     ZIF820                   YES, BRANCH                     14828000
         B     ZIF840                   NO, BRANCH                      14829000
ZIF820   MVC   #IFCREIF(3),DOUBLE+5     SAVE RESULT                     14830000
         MVC   #IFCREIF+3(3),DOUBLE+5   IF SECOND IS MISSING, USE FIRST 14831000
         SPACE 1                                                        14832000
ZIF840   LA    R1,IFCRESUB+8            CREATED(:DATE                   14833000
         BAL   R14,PACKMAX              ANY RESULT?                     14834000
         B     ZIF860                   YES, BRANCH                     14835000
         B     ZIF900                   NO, BRANCH                      14836000
ZIF860   MVC   #IFCREIF+3(3),DOUBLE+5   SAVE RESULT                     14837000
         OI    #IFCREIF+2,X'0F'         IF FIRST IS MISSING, USE 00000F 14838000
         SPACE 1                                                        14839000
ZIF900   TM    IFTSSI+6,X'80'       STRING CODED?                       14840000
         BNO   ZIF980               NO, DONE                            14841000
         L     R5,IFTSSI            NEW STRING ADDRESS                  14842000
         LH    R1,IFTSSI+4          LENGTH OF STRING                    14843000
         LTR   R1,R1                NULL STRING CODED?                  14844000
         BNP   ZIF980               YES, DONE                           14845000
         MVI   MSGTEXT2+1,4         MAXIMUM OF 4 DIGITS                 14846000
         MVC   MSGTEXT1,PDS385A     SSI MESSAGE                         14847000
         BAL   R2,HEXC              CONVERT TO BINARY                   14848000
         B     NEWCMD50             ATTENTION -- IGNORE THE REST        14849000
         STCM  R0,B'1111',#SSITEXT  SAVE THE RESULTING TTR              14850000
         SPACE 2                                                        14851000
ZIF980   TM    FLAGSCC,RECFMU         LOAD MODULE?                      14852000
         BNO   ZIF990                 NO, BRANCH                        14853000
         OC    #IFCREIF(6),#IFCREIF   ANY CREATION DATE CHECK?          14854000
         BZ    ZIF984                 NO, BRANCH                        14855000
         OI    #OPTOPT,X'02'          YES, SET A FLAG FOR LATER         14856000
         MVC   FULLWORD(3),#IFCREIF   FIRST FIELD                       14857000
         LA    R1,FULLWORD                                              14858000
         LA    R15,#IFCREIF                                             14859000
         BAL   R14,CONVDATE           CONVERT YYDDDF TO MMDDYY          14860000
         ICM   R1,B'0100',#IFCREIF+2  GET YY                            14861000
         ICM   R1,B'0011',#IFCREIF    GET MMDD                          14862000
         STCM  R1,B'0111',#IFCREIF    SAVE AS YYMMDD                    14863000
         MVC   FULLWORD(3),#IFCREIF+3 GET SECOND FIELD                  14864000
         LA    R1,FULLWORD                                              14865000
         LA    R15,#IFCREIF+3                                           14866000
         BAL   R14,CONVDATE           CONVERT YYDDDF TO MMDDYY          14867000
         ICM   R1,B'0100',#IFCREIF+5  GET YY                            14868000
         ICM   R1,B'0011',#IFCREIF+3  GET MMDD                          14869000
         STCM  R1,B'0111',#IFCREIF+3  SAVE AS YYMMDD                    14870000
         SPACE 1                                                        14871000
ZIF984   OC    #IFMODIF(6),#IFMODIF   ANY MODIFICATION DATE CHECK?      14872000
         BZ    ZIF990                 NO, BRANCH                        14873000
         OI    #OPTOPT,X'02'          YES, SET A FLAG FOR LATER         14874000
         MVC   FULLWORD(3),#IFMODIF   FIRST FIELD                       14875000
         LA    R1,FULLWORD                                              14876000
         LA    R15,#IFMODIF                                             14877000
         BAL   R14,CONVDATE           CONVERT YYDDDF TO MMDDYY          14878000
         ICM   R1,B'0100',#IFMODIF+2  GET YY                            14879000
         ICM   R1,B'0011',#IFMODIF    GET MMDD                          14880000
         STCM  R1,B'0111',#IFMODIF    SAVE AS YYMMDD                    14881000
         MVC   FULLWORD(3),#IFMODIF+3 SECOND FIELD                      14882000
         LA    R1,FULLWORD                                              14883000
         LA    R15,#IFMODIF+3                                           14884000
         BAL   R14,CONVDATE           CONVERT YYDDDF TO MMDDYY          14885000
         ICM   R1,B'0100',#IFMODIF+5  GET YY                            14886000
         ICM   R1,B'0011',#IFMODIF+3  GET MMDD                          14887000
         STCM  R1,B'0111',#IFMODIF+3  SAVE AS YYMMDD                    14888000
         SPACE 1                                                        14889000
ZIF990   L     R6,ADDRANSR            RESET THE PDL BASE ADDRESS        14890000
         OC    #ATTRYES(13),#ATTRYES  ANY LINKAGE EDITOR ATTRIBUTES?    14891000
         BZ    *+8                    NO, BRANCH                        14892000
         OI    #OPTOPT,X'01'          YES, SET A FLAG FOR LATER         14893000
         OC    #ZAPOPT(6),#ZAPOPT     ZAP/USER/TRAN/LKED/MODULE/RLDERR? 14894000
         BZ    *+8                    NO, BRANCH                        14895000
         OI    #OPTOPT,X'02'+X'01'    YES, SET A FLAG FOR LATER         14896000
         OC    #IOERROR(4),#IOERROR   IOERROR/BLOCKERR/LRECLERR/NULL?   14897000
         BZ    *+8                    NO, BRANCH                        14898000
         OI    #OPTOPT,X'04'          YES, SET A FLAG FOR LATER         14899000
         SPACE 1                                                        14900000
         LH    R1,IFTHENCC            THEN ACTION NUMBER                14901000
         SLA   R1,2                   ACTION SPECIFIED                  14902000
         L     R1,THENTBL(R1)         THEN ACTION POINTER               14903000
         ST    R1,#ACTIONT            NOTE FOR LATER                    14904000
         OC    FLAGSII(1),#ACTIONT    SET POSSIBLE FSINGLE FLAG         14905000
         AIF ('&CISP' EQ 'NO SPF').MA01280                         @D01
         OC    SPFLAG3(1),#ACTIONT    SET POSSIBLE INVALID    ABL OCT84 14906000
.MA01280 ANOP  ,                                                   @D01
         SPACE 1                                                        14907000
         LH    R1,IFELSECC            ELSE ACTION NUMBER                14908000
         SLA   R1,2                   ACTION SPECIFIED                  14909000
         L     R1,THENTBL(R1)         ELSE ACTION POINTER               14910000
         ST    R1,#ACTIONE            NOTE FOR LATER                    14911000
         OC    FLAGSII(1),#ACTIONE    SET POSSIBLE FSINGLE FLAG         14912000
         AIF ('&CISP' EQ 'NO SPF').MA01300                         @D01
         OC    SPFLAG3(1),#ACTIONE    SET POSSIBLE INVALID    ABL OCT84 14913000
.MA01300 ANOP  ,                                                   @D01
         B     PARSPOST                                                 14914000
         SPACE 2                                                        14915000
         AIF ('&CISP' EQ 'NO SPF').MA01320                         @D01
         USING PDLISPF,R6                                               14916000
         USING *,R8                                                     14917000
ZISPF    TM    PCLISSTR+6,X'80'     STRING CODED?                       14918000
         BNO   PARSPOST             NO, DONE                            14919000
         LH    R2,PCLISSTR+4        LENGTH OF STRING                    14920000
         LTR   R2,R2                NULL STRING CODED?                  14921000
         BZ    PARSPOST             YES, DONE                           14922000
         CH    R2,=H'256'           LENGTH(STRING)>=256?                14923000
         BL    *+8                  NO, BRANCH                          14924000
         LH    R2,=H'256'           YES, USE 256 AS A MAXIMUM LENGTH    14925000
         STH   R2,#COMMDSZ          SAVE ACTUAL LENGTH                  14926000
         L     R1,PCLISSTR          NEW STRING ADDRESS                  14927000
         BCTR  R2,0                 MACHINE LENGTH                      14928000
         MVC   MSGLINE(*-*),0(R1)   <<EXECUTED>>                        14929000
         EX    R2,*-6               MOVE IN ANY OTHER OPERANDS          14930000
         B     PARSPOST                                                 14931000
         SPACE 2                                                        14932000
         USING PDLISPM,R6                                               14933000
         USING *,R8                                                     14934000
ZISPM    LA    R2,FIRST4K                                               14935000
         LA    R1,ISCHKMAX                     CHKMAX(COUNT)            14936000
         BAL   R14,PACKMAX                     ANY RESULT?              14937000
         STCM  R1,B'0011',SPFCKSZ-FIRST4K(R2)  YES, SAVE                14938000
         SPACE 1                                                        14939000
         LA    R1,ISCMDMAX                    CMDMAX(COUNT)             14940000
         BAL   R14,PACKMAX                    ANY RESULT?               14941000
         STCM  R1,B'0011',SPFMAX-FIRST4K(R2)  YES, SAVE                 14942000
         SPACE 1                                                        14943000
         LH    R1,SPFMAX-FIRST4K(R2)          CMDMAX(COUNT)             14944000
         S     R1,=F'1'                       VALID?                    14945000
         BNP   ZISPM010                       NO, BRANCH                14946000
         CH    R1,SPFCKSZ-FIRST4K(R2)         BELOW CHECKPOINT SIZE?    14947000
         BNL   ZISPM010                       NO, BRANCH                14948000
         STH   R1,SPFCKSZ-FIRST4K(R2)         SET NEW CHECKPOINT SIZE   14949000
         SPACE 1                                                        14950000
ZISPM010 LA    R1,ISTBLMAX                     TBLMAX(COUNT)            14951000
         BAL   R14,PACKMAX                     ANY RESULT?              14952000
         STCM  R1,B'0011',SPFSIZE-FIRST4K(R2)  YES, SAVE                14953000
         B     PARSPOST                                                 14954000
.MA01320 ANOP  ,                                                   @D01
         SPACE 2                                                        14955000
         USING PDLLIST,R6                                               14956000
         USING *,R8                                                     14957000
ZLIST    CLI   LISTFMT+1,0            WAS A FORMAT SPECIFIED?           14958000
         BE    LISTCHK2               NO, QUIT                          14959000
         NI    HFLAGSDD,FF-NONUM-SNUM-BLOCK-DUMP-LBLOCK-LDUMP           14960000
         LH    R15,LISTFMT            FORMAT REQUESTED                  14961000
         A     R15,=F'-2'             LESS 2 -- NEGATIVE?               14962000
         BM    LISTCHK2               YES, BRANCH                       14963000
         LA    R1,1                   SHIFT VALUE                       14964000
         SLL   R1,0(R15)              SHIFT INTO POSITION               14965000
         OI    HFLAGSDD,*-*           <<EXECUTED>>                      14966000
         EX    R1,*-4                 OR INTO FLAG BYTE                 14967000
         SPACE 1                                                        14968000
LISTCHK2 LA    R1,LMAXLENC            MAXLEN                            14969000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14970000
         ST    R1,#MAXLEN             SAVE RESULT                       14971000
         SPACE 1                                                        14972000
         LA    R1,LMAXINC             MAXIN                             14973000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14974000
         ST    R1,#MAXIN              SAVE RESULT                       14975000
         SPACE 1                                                        14976000
         LA    R1,LMAXOUTC            MAXOUT                            14977000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14978000
         ST    R1,#MAXOUT             SAVE RESULT                       14979000
         SPACE 1                                                        14980000
         LA    R1,LSKIPRC             SKIPREC                           14981000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14982000
         ST    R1,#SKIPREC            SAVE RESULT                       14983000
         SPACE 1                                                        14984000
         LA    R1,LSKIPCC             SKIPCOL                           14985000
         BAL   R14,PACKMAX            CONVERT TO BINARY                 14986000
         ST    R1,#SKIPCOL            SAVE RESULT                       14987000
         SPACE 1                                                        14988000
         TM    LISTOFF+6,X'80'        OFFSET CODED?                     14989000
         BNO   LISTCHK3               NO, DONE                          14990000
         L     R5,LISTOFF             OFFSET ADDRESS                    14991000
         LH    R1,LISTOFF+4           LENGTH OF OFFSET                  14992000
         LTR   R1,R1                  NULL STRING CODED?                14993000
         BNP   LISTCHK3               YES, DONE                         14994000
         MVI   MSGTEXT2+1,3           MAXIMUM OF 3 DIGITS               14995000
         MVC   MSGTEXT1,PDS384A       OFFSET INVALID MESSAGE            14996000
         BAL   R2,HEXC                CONVERT TO BINARY                 14997000
         B     NEWCMD50               ATTENTION -- IGNORE THE REST      14998000
         STCM  R0,B'0111',#LISTOFF+1  SAVE THE RESULTING OFFSET         14999000
         SPACE 1                                                        15000000
LISTCHK3 LH    R15,LDUMPCS+4          LENGTH OF BLOCK/DUMP STRING       15001000
         STC   R15,#MODLEN                                              15002000
         S     R15,=F'1'              ANY STRING?                       15003000
         BM    PARSPOST               NO, BRANCH                        15004000
         L     R1,LDUMPCS             ADDRESS OF BLOCK/DUMP STRING      15005000
         MVC   #MODTXT(*-*),0(R1)     <<EXECUTED>>                      15006000
         EX    R15,*-6                SAVE THE STRING FOR LATER         15007000
         B     PARSPOST                                                 15008000
         SPACE 2                                                        15009000
         USING PDLMAP,R6                                                15010000
         USING *,R8                                                     15011000
ZMAP     MVC   #MAPOPT(1),PCLMAPOP+1  SAVE ANY PROCESSING OPTIONS       15012000
         TM    PCLMMOD+6,X'80'        ANY MODULE NAME FILTERING?        15013000
         BNO   PARSPOST               NO, BRANCH                        15014000
         LH    R15,PCLMMOD+4          LENGTH OF MODULE NAME             15015000
         STC   R15,#MODLEN            SAVE FOR LATER                    15016000
         S     R15,=F'1'              MACHINE LENGTH VALID?             15017000
         BM    PARSPOST               NO, BRANCH                        15018000
         L     R1,PCLMMOD             PARTIAL MODULE NAME               15019000
         MVC   #MODTXT(*-*),0(R1)     <<EXECUTED>>                      15020000
         EX    R15,*-6                MOVE INTO STORAGE                 15021000
         B     PARSPOST                                                 15022000
         SPACE 2                                                        15023000
         AIF ('&CISP' EQ 'NO SPF').MA01340                         @D01
         USING PDLMEML,R6                                               15024000
         USING *,R8                                                     15025000
ZMEMLIST CLI   MEMLRES+1,1              RESET?                          15026000
         BNE   *+8                      NO, BRANCH                      15027000
         OI    SPFLAG3,SPFCHN           YES, SIGNAL ISPMODE             15028000
         B     PARSPOST                                                 15029000
.MA01340 ANOP  ,                                                   @D01
         SPACE 2                                                        15030000
         USING PDLOUT,R6                                                15031000
         USING *,R8                                                     15032000
ZOUTCOPY MVC   #OUTOPTN(1),OUTOPTN+1     SAVE TEXT/NOTEXT               15033000
         CLI   OUTCLOS+1,1               CLOSE REQUESTED?               15034000
         BNE   *+8                       NO, BRANCH                     15035000
         MVI   #OUT,1                    YES, FLAG FOR LATER            15036000
         CLI   OUTECHO+1,1               ECHO/NOECHO?                   15037000
         BL    ZOUT010                   NO, BRANCH                     15038000
         OI    FLAGSFF,FNOECHO           ASSUME NO ECHO IS DESIRED      15039000
         CLI   OUTECHO+1,2               CORRECT?                       15040000
         BE    ZOUT010                   YES, BRANCH                    15041000
         NI    FLAGSFF,FF-FNOECHO        NO, ECHO IS DESIRED            15042000
         SPACE 1                                                        15043000
ZOUT010  CLI   #OUTOPTN,1                TEXT('STRING')?                15044000
         BNE   ZOUT020                   NO, BRANCH                     15045000
         MVC   MSGLINE(40),MSGBL132+4    CLEAR INITIALLY                15046000
         LH    R2,OUTTEXT+4              LENGTH OF STRING               15047000
         LTR   R2,R2                     NULL STRING CODED?             15048000
         BZ    ZOUT020                   YES, DONE                      15049000
         CH    R2,=H'40'                 LENGTH(STRING)>=40?            15050000
         BL    *+8                       NO, BRANCH                     15051000
         LH    R2,=H'40'                 YES, USE 40 INSTEAD            15052000
         L     R1,OUTTEXT                NEW STRING ADDRESS             15053000
         AGO   .TESTRNG                  ***TEST (STRING VS QSTRING)    15054000
         BCTR  R2,0                      MACHINE LENGTH                 15055000
         LA    R15,0(R2,R1)              POINT TO LAST BYTE             15056000
         CLI   0(R15),C')'               ENDING PARENTHESIS             15057000
         BNE   *+8                       NO, BRANCH                     15058000
         S     R2,=F'1'                  YES, DROP THIS BYTE            15059000
         BCTR  R15,0                     POINT TO LAST BYTE             15060000
         CLC   0(1,R1),0(R15)            ENDING DELIMITER?              15061000
         BNE   *+8                       NO, BRANCH                     15062000
         S     R2,=F'1'                  YES, DROP THIS BYTE            15063000
         LA    R1,1(,R1)                 POINT PAST THE FIRST QUOTE     15064000
.TESTRNG ANOP                                                           15065000
         S     R2,=F'1'                  GOOD STRING TO MOVE?           15066000
         BM    ZOUT020                   NO, SKIP THE MOVE              15067000
         MVC   MSGLINE(*-*),0(R1)        <<EXECUTED>>                   15068000
         EX    R2,*-6                    MOVE IN THE TEXT               15069000
         SPACE 1                                                        15070000
ZOUT020  CLI   OUTASS+1,1                ALIAS/NOALIAS?                 15071000
         BL    PARSPOST                  NO, BRANCH                     15072000
         OI    FLAGSEE,FOUTASS           ASSUME ALIAS IS DESIRED        15073000
         CLI   OUTASS+1,1                CORRECT?                       15074000
         BE    PARSPOST                  YES, BRANCH                    15075000
         NI    FLAGSEE,FF-FOUTASS        NO, NOALIAS IS DESIRED         15076000
         B     PARSPOST                                                 15077000
         SPACE 2                                                        15078000
         USING PDLPRINT,R6                                              15079000
         USING *,R8                                                     15080000
ZPRINTOF TM    PCLPRSTR+6,X'80'     STRING CODED?                       15081000
         BNO   PARSPOST             NO, DONE                            15082000
         LH    R2,PCLPRSTR+4        LENGTH OF STRING                    15083000
         LTR   R2,R2                NULL STRING CODED?                  15084000
         BZ    PARSPOST             YES, DONE                           15085000
         CH    R2,=H'40'            LENGTH(STRING)>=40?                 15086000
         BL    *+8                  NO, BRANCH                          15087000
         LH    R2,=H'40'            YES, USE 40 AS A MAXIMUM LENGTH     15088000
         STH   R2,#COMMDSZ          SAVE ACTUAL LENGTH                  15089000
         MVC   MSGLINE(40),MSGBL132+4  CLEAR INITIALLY                  15090000
         L     R1,PCLPRSTR          NEW STRING ADDRESS                  15091000
         BCTR  R2,0                 MACHINE LENGTH                      15092000
         MVC   MSGLINE(*-*),0(R1)   <<EXECUTED>>                        15093000
         EX    R2,*-6               MOVE IN ANY OTHER OPERANDS          15094000
         B     PARSPOST                                                 15095000
         SPACE 2                                                        15096000
         USING PDLRENAM,R6                                              15097000
         USING *,R8                                                     15098000
ZRENAME  MVC   #RENSWAP(1),PCLRENSW+1    SAVE SWAP/NOSWAP               15099000
         MVC   #RENRANG(1),PCLRENGP+1    SAVE GROUP/NOGROUP             15100000
         CLI   #RENRANG,1                GROUP OPTION?                  15101000
         BNE   PARSPOST                  NO, BRANCH                     15102000
         NI    ##ADRPC#,FF-@B            YES, NO BLDL REQUIRED          15103000
         B     PARSPOST                                                 15104000
         SPACE 2                                                        15105000
         USING PDLRESTO,R6                                              15106000
         USING *,R8                                                     15107000
         AGO   .MA01360                                            @D01
ZRESTORE TM    FLAGSGG,FPROMCON            PROMPTING OFF?               15108000
         BNO   *+8                         NO, BRANCH                   15109000
         OI    #RESFLAG,#RESFPRO*4         YES, SET A FLAG              15110000
         CLI   PCLRSREP+1,X'01'            REPEAT?                      15111000
         BNE   *+8                         NO, BRANCH                   15112000
         OI    #RESFLAG,#RESFREP+#RESFDIS  YES, SET FLAGS               15113000
         CLI   PCLRSDIS+1,X'01'            DISPLAY?                     15114000
         BNE   *+8                         NO, BRANCH                   15115000
         OI    #RESFLAG,#RESFDIS           YES, SET A FLAG              15116000
         CLI   PCLRSPRO+1,X'01'            PROMPT?                      15117000
         BNE   *+8                         NO, BRANCH                   15118000
         OI    #RESFLAG,#RESFPRO+#RESFDIS  YES, SET FLAGS               15119000
         SPACE 1                                                        15120000
         CLI   PCLRSDIS+1,X'02'            NODISPLAY?                   15121000
         BNE   *+8                         NO, BRANCH                   15122000
         NI    #RESFLAG,FF-#RESFDIS        YES, TURN IT OFF             15123000
         CLI   PCLRSPRO+1,X'02'            NOPROMPT?                    15124000
         BNE   *+8                         NO, BRANCH                   15125000
         OI    #RESFLAG,#RESFPRO*2         YES, SET A FLAG              15126000
         SPACE 1                                                        15127000
         TM    PCLREST+6,X'80'             ANY RESTORE LIKE OPERAND?    15128000
         BNO   PARSPOST                    NO, BRANCH                   15129000
         LH    R15,PCLREST+4               LENGTH OF NAME               15130000
         S     R15,=F'1'                   MACHINE LENGTH VALID?        15131000
         BM    PARSPOST                    NO, BRANCH                   15132000
         MVC   #RESTLIK,BLANKS             INITIALIZE THE MEMBER NAME   15133000
         L     R1,PCLREST                  PARTIAL IDRDATA DATA         15134000
         MVC   #RESTLIK(*-*),0(R1)         <<EXECUTED>>                 15135000
         EX    R15,*-6                     MOVE INTO STORAGE            15136000
         B     PARSPOST                                                 15137000
.MA01360 ANOP  ,                                                   @D01
ZRESTORE OI    #RESFLAG,#RESFDIS+#RESFPRO                          @D01
*                                     Default DISPLAY and PROMPT   @D01
         TM    FLAGSGG,FPROMCON       Is prompting off?            @D01
         BNO   *+8                    No, branch                   @D01
         OI    #RESFLAG,#RESFPRO*4    Yes, set a flag              @D01
         CLI   PCLRSREP+1,X'01'       REPEAT?                      @D01
         BNE   *+8                    No, branch                   @D01
         OI    #RESFLAG,#RESFREP      Else set REPEAT flag         @D01
         CLI   PCLRSDIS+1,X'02'       NODISPLAY?                   @D01
         BNE   *+8                    No, branch                   @D01
         NI    #RESFLAG,FF-#RESFDIS   Else turn off DISPLAY flag   @D01
         CLI   PCLRSPRO+1,X'02'       NOPROMPT?                    @D01
         BNE   *+8                    No, branch                   @D01
         XI    #RESFLAG,#RESFPRO*2+#RESFPRO                        @D01
*                                     Yes, set flags               @D01
         SPACE 1                                                   @D01
ZREST020 TM    PCLREST+6,X'80'        Amy RESTORE LIKE operand?    @D01
         BNO   ZREST030               No, branch                   @D01
         LH    R15,PCLREST+4          Length of name               @D01
         S     R15,=F'1'              Machine length valid?        @D01
         BM    ZREST030               No, branch                   @D01
         MVC   #RESTLIK,BLANKS        Initialize the member name   @D01
         L     R1,PCLREST             Partial IDRDATA data         @D01
         MVC   #RESTLIK(*-*),0(R1)    <<executed>>                 @D01
         EX    R15,*-6                Move into storage            @D01
         SPACE 1                                                   @D01
ZREST030 MVI   #RESTNUM+3,5           Set default line count = 5   @D01
         LA    R1,PCLRNUM             Count(number)                @D01
         BAL   R14,PACKMAX            Convert to binary            @D01
         ST    R1,#RESTNUM            Save result                  @D01
         B     PARSPOST               Continue                     @D01
         SPACE 2                                                        15138000
         USING PDLTSOED,R6                                              15139000
         USING *,R8                                                     15140000
ZTSOEDIT MVC   #EDITOLD(1),PCLEDOP+1   SAVE SPECIFIED OLD/NEW OPTION    15141000
         CLI   PCLEDOP+1,X'02'         "OLD"?                           15142000
         BNE   ZTSOEDI2                NO, BRANCH                       15143000
         OI    ##ADRPC#,@B             YES, MUST EXIST                  15144000
ZTSOEDI2 MVC   #EDITNON(1),PCLNON+1    NONUM OPTION                     15145000
         MVC   #EDITASI(1),PCLASIS+1   ASIS OPTION                      15146000
         MVC   #EDITTYP+2(2),PCLTYPE   EDIT TYPE FIELD                  15147000
         B     PARSPOST                                                 15148000
         SPACE 2                                                        15149000
         USING PDLVERIF,R6                                              15150000
         USING *,R8                                                     15151000
ZVERIFY  MVC   #VERLOAD(1),VERLOAD+1    SAVE LOAD/NOLOAD OPTION         15152000
         MVC   #VERSTND(1),VERNAME+1    SAVE NAME/NONAME OPTION         15153000
         MVC   #VERREAD(1),VERINPUT+1   SAVE INPUT/NOINPUT OPTION       15154000
         MVC   #VERUPDT(1),VERUPDT+1    SAVE UPDATE/NOUPDATE OPTION     15155000
         MVC   #VERSTAT(1),VERSTATS+1   SAVE STATS/NOSTATS OPTION       15156000
         B     PARSPOST                                                 15157000
         SPACE 2                                                        15158000
         USING MAINPDL,R6                                               15159000
         USING *,R8                                                     15160000
ZMAINPDL MVC   VOLUME,BLANKS        INITIALIZE VOLUME NAME              15161000
         TM    VOLNAME+6,X'80'      ANY NAME REQUESTED?                 15162000
         BNO   MAINPDL2             NO, BRANCH                          15163000
         LH    R15,VOLNAME+4        LENGTH OF NAME                      15164000
         S     R15,=F'1'            VALID?                              15165000
         BM    MAINPDL2             NO, BRANCH                          15166000
         L     R1,VOLNAME           ADDRESS OF NAME                     15167000
         MVC   VOLUME(*-*),0(R1)    <<EXECUTED>>                        15168000
         EX    R15,*-6              MOVE IN THE NAME                    15169000
         SPACE 1                                                        15170000
MAINPDL2 MVI   DSPALLOC,ALLOSHR     ASSUME DISP=SHR                     15171000
         MVI   DSPREQST,ALLOSHR     ASSUME DISP=SHR                     15172000
         CLI   OPTDISP+1,1          CORRECT?                            15173000
         BNE   MAINPDL4             NO, BRANCH                          15174000
         MVI   DSPALLOC,ALLOOLD     DISP=OLD                            15175000
         MVI   DSPREQST,ALLOOLD     DISP=OLD                            15176000
         DROP  R6                                                       15177000
         SPACE 1                                                        15178000
MAINPDL4 TM    FLAGSBB,FQUOTE       QUOTED DATA SET NAME?               15179000
         BO    PARSPOST             YES, BRANCH                         15180000
         CLI   VOLUME,X'40'         ANY VOLUME NAME SPECIFIED?          15181000
         BNE   PARSPOST             YES, ASSUME NO CATALOG USE          15182000
*  NEED TO FULLY QUALIFY THE DATA SET NAME                              15183000
         USING DFPL,R6                                                  15184000
         LA    R6,PARMLIST          START OF DFPL PARAMETER LIST        15185000
         L     R1,ADDRUPT                                               15186000
         L     R2,ADDRECT                                               15187000
         LA    R3,ATTNECB                                               15188000
         LA    R4,PARMLIST+16                                           15189000
         STM   R1,R4,DFPLUPT        INITIALIZE DFPLUPT, DFPLECT,        15190000
*                                              DFPLECB AND DFPLDFPB     15191000
         USING DFPB,R6                                                  15192000
         LR    R6,R4                                                    15193000
         LA    R1,DSNLEN            DSNAME LENGTH, DSNAME               15194000
         L     R2,ADDRPSCB          PSCB                                15195000
         LA    R3,DOUBLE            BLANK DEFAULT QUALIFIER             15196000
         AIF   (&MVT).MA01380                                      @D01
         SR    R4,R4                NO USER CATALOG                     15197000
         LA    R5,PASSWORD                                              15198000
         STM   R1,R5,DFPBDSN        INITIALIZE DFPBDSN, DFPBPSCB,       15199000
*                                     DFPBQUAL, DFBCAT AND DFPBPSWD     15200000
         MVI   DFPBCNTL,DFPBRET     ADD LOW-LEVEL QUALIFIER             15201000
         AGO   .NA01380                                            @D01
.MA01380 ANOP  ,                                                   @D01
         STM   R1,R3,DFPBDSN        Initialize DFPBDSN, DFPBPSCB   @D01
*                                     and DFPBQUAL                 @D01
         MVI   DFPBCNTL,DFPBUID     Prefix with userid             @D01
.NA01380 ANOP  ,                                                   @D01
         MVI   DFPBCODE,DFPB04      ENTRY CODE X'04'                    15202000
         MVC   DOUBLE(8),BLANKS     BLANK DEFAULT QUALIFIER             15203000
         DROP  R6                                                       15204000
         SPACE 1                                                        15205000
         LA    R1,PARMLIST          ADDRESS OF PARM LIST                15206000
         L     R15,ADDRDEFT         DEFAULT ROUTINE ADDRESS             15207000
         BALR  R14,R15                                                  15208000
         B     PARSPOST                                                 15209000
         TITLE 'P D S  --  PDS PARSE VALIDITY CHECKING         1/15/85' 15210000
*                                                                       15211000
*        CREATED/CHANGED VALIDITY CHECK SUBROUTINE                      15212000
*                                                                       15213000
         SPACE 1                                                        15214000
VRTDATE  ENTER VALCHECK                                                 15215000
         LA    R15,4              ASSUME PROMPTING IS REQUIRED          15216000
         SPACE 1                                                        15217000
         L     R1,0(,R6)          ADDR OF FIRST PARAMETER               15218000
         L     R2,8(,R6)          ADDR OF FIRST PARAMETER               15219000
         CLI   5(R6),5            FIVE DIGITS?                          15220000
         BNE   VRTDBAD            NO, ERROR                             15221000
         CLI   5(R1),C'0'         ZERO LAST DIGIT?                      15222000
         BE    VRTDBAD            YES, ERROR                            15223000
         CLC   2(3,R1),=C'366'    ABOVE 366?                            15224000
         BH    VRTDBAD            YES, ERROR                            15225000
         TM    8+6(R6),X'80'      SECOND PARAMETER PRESENT?             15226000
         BNO   VRTDOK             NO, BRANCH                            15227000
         CLI   8+5(R6),5          FIVE DIGITS?                          15228000
         BNE   VRTDBAD            NO, ERROR                             15229000
         CLC   0(5,R1),0(R2)      LESS THAN OR EQUAL?                   15230000
         BH    VRTDBAD            NO, ERROR                             15231000
         CLI   5(R2),C'0'         ZERO LAST DIGIT?                      15232000
         BE    VRTDBAD            YES, ERROR                            15233000
         CLC   2(3,R1),=C'366'    ABOVE 366?                            15234000
         BH    VRTDBAD            YES, ERROR                            15235000
         SPACE 1                                                        15236000
VRTDOK   SR    R15,R15            VALID -- ALL DONE                     15237000
VRTDBAD  EXIT                                                           15238000
         EJECT                                                          15239000
*                                                                       15240000
*        INPUT DATA SET VALIDITY CHECK EXIT                             15241000
*                                                                       15242000
         SPACE 3                                                        15243000
VRTDSN   ENTER VALCHECK                                                 15244000
         OI    FLAGSBB,FQUOTE+FNOTFILE  ASSUME QUOTED AND NOT FILE(...  15245000
         MVC   SAVDSN+1(SAVLEN),DSNLEN  SAVE PREVIOUS DSNAME            15246000
         MVC   SAVDSN(1),DSPREQST       SAVE DISPOSITION FOR LATER      15247000
         MVC   PASSWORD,BLANKS                                          15248000
         SPACE 1                                                        15249000
         L     R15,0(R6)                ADDR OF DSNAME                  15250000
         CLI   0(R15),C'*'              ASTERISK DSNAME?                15251000
         BE    NOFILE                   YES, BRANCH                     15252000
         MVC   DSNAME(L'DSNAME),MSGBL132+4                              15253000
         LH    R14,4(R6)                LENGTH OF DSNAME                15254000
         STH   R14,DSNLEN                                               15255000
         BCTR  R14,0                                                    15256000
         MVC   DSNAME(*-*),0(R15)       <<EXECUTED>>                    15257000
         EX    R14,*-6                  MOVE DSNAME TO AREA             15258000
         L     R1,ADDRUPT               ADDRESS OF THE UPT              15259000
         SR    R14,R14                                                  15260000
         AIF   (&MVT).MA01400                                      @D01
         IC    R14,UPTPREFL-UPT(R1)     LENGTH OF USERID                15261000
         AGO   .NA01400                                            @D01
.MA01400 ANOP  ,                                                   @D01
         IC    R14,PSCBUSRL-PSCB(R1)    LENGTH OF USERID           @D01
.NA01400 ANOP  ,                                                   @D01
         MVC   DSNAMEH(4),DSNAME        FIRST FOUR BYTES OF DSNAME      15262000
         LTR   R14,R14                  VALID LENGTH?                   15263000
         BZ    *+6                      NO, BRANCH                      15264000
         BCTR  R14,0                    MACHINE LENGTH                  15265000
         AIF   (&MVT).MA01420                                      @D01
         CLC   DSNAME(*-*),UPTPREFX-UPT(R1) <<EXECUTED>>                15266000
         AGO   .NA01420
.MA01420 ANOP  ,                                                   @D01
         CLC   DSNAME(*-*),PSCBUSER-PSCB(R1) <<EXECUTED>>          @D01
.NA01420 ANOP  ,                                                   @D01
         EX    R14,*-6                      START WITH USERID?          15267000
         LR    R1,R15                       ADDRESS OF DSNAME           15268000
         BNE   *+14                         NO, BRANCH                  15269000
         LA    R1,2(R14,R15)                DATA AFTER PERIOD           15270000
         MVC   DSNAMEH(4),0(R1)         FIRST FOUR BYTES OF DSNAME      15271000
         SPACE 1                                                        15272000
         OI    FLAGSBB,FQUOTE+FNOTFILE  ASSUME QUOTED AND NOT FILE(...  15273000
         TM    6(R6),X'40'              QUOTED?                         15274000
         BO    NOFILE                   YES, BRANCH                     15275000
         XI    FLAGSBB,FQUOTE           NO, RESET THE BIT               15276000
         AIF   (&MVT).MA01440                                      @D01
         TM    14(R6),X'80'             FILE(FILENAME) SUPPLIED?        15277000
         BZ    NOMEMB                   NO, BRANCH                      15278000
         CLC   0(1,R1),=C'FILE'         CORRECT FILE IDENTIFIER?        15279000
         BNE   NOFILE                   NO, BRANCH                      15280000
         CLI   1(R1),C'('               AND A (?                        15281000
         BE    GOTFILE                  YES, BRANCH                     15282000
         TM    1(R1),FF-X'40'           AND A BLANK OR NULL?            15283000
         BZ    GOTFILE                  YES, BRANCH                     15284000
         CLC   0(2,R1),=C'FILE'         CORRECT FILE IDENTIFIER?        15285000
         BNE   NOFILE                   NO, BRANCH                      15286000
         CLI   2(R1),C'('               AND A (?                        15287000
         BE    GOTFILE                  YES, BRANCH                     15288000
         TM    2(R1),FF-X'40'           AND A BLANK OR NULL?            15289000
         BZ    GOTFILE                  YES, BRANCH                     15290000
         CLC   0(3,R1),=C'FILE'         CORRECT FILE IDENTIFIER?        15291000
         BNE   NOFILE                   NO, BRANCH                      15292000
         CLI   3(R1),C'('               AND A (?                        15293000
         BE    GOTFILE                  YES, BRANCH                     15294000
         TM    3(R1),FF-X'40'           AND A BLANK OR NULL?            15295000
         BZ    GOTFILE                  YES, BRANCH                     15296000
         CLC   0(4,R1),=C'FILE'         CORRECT FILE IDENTIFIER?        15297000
         BNE   NOFILE                   NO, BRANCH                      15298000
         CLI   4(R1),C'('               AND A (?                        15299000
         BE    GOTFILE                  YES, BRANCH                     15300000
         TM    4(R1),FF-X'40'           AND A BLANK OR NULL?            15301000
         BNZ   NOFILE                   NO, BRANCH                      15302000
GOTFILE  XI    FLAGSBB,FNOTFILE         FILE(FILENAME) SUPPLIED         15303000
         L     R15,8(,R6)               POINT TO FILENAME               15304000
         LH    R14,12(,R6)              LENGTH OF MEMBER NAME           15305000
         BCTR  R14,0                                                    15306000
         MVC   DDNAMEH(8),BLANKS        FILENAME AREA                   15307000
         MVC   DDNAMEH(*-*),0(R15)      <<EXECUTED>>                    15308000
         EX    R14,*-6                  MOVE FILENAME                   15309000
         B     NOMEMB                                                   15310000
         SPACE 2                                                        15311000
.MA01440 ANOP  ,                                                   @D01
NOFILE   TM    14(R6),X'80'             MEMBER SUPPLIED?                15312000
         BZ    NOMEMB                   NO, BRANCH                      15313000
         SPACE 1                                                        15314000
         L     R15,8(,R6)               POINTER TO MEMBER NAME          15315000
         LH    R14,12(,R6)              LENGTH OF MEMBER NAME           15316000
         BCTR  R14,0                                                    15317000
         MVC   MEMBERD+3(8),BLANKS      MEMBER NAME DEFAULT AREA        15318000
         MVC   MEMBERD+3(*-*),0(R15)    <<EXECUTED>>                    15319000
         EX    R14,*-6                  MOVE MEMBER TO AREA             15320000
         STCM  R14,B'0011',MEMBERD+1    MACHINE LENGTH OF MEMBER NAME   15321000
         MVI   MEMBERD,FMEMBER1         JUST ONE MEMBER NAME DEFAULT    15322000
         SPACE 2                                                        15323000
NOMEMB   TM    22(R6),X'80'             PASSWORD SUPPLIED?              15324000
         BZ    VRTDSN99                 NO, BRANCH                      15325000
         SPACE 1                                                        15326000
         L     R15,16(,R6)              POINTER TO PASSWORD             15327000
         LH    R14,20(,R6)              PASSWORD LENGTH                 15328000
         BCTR  R14,0                                                    15329000
         MVC   PASSWORD(*-*),0(R15)     <<EXECUTED>>                    15330000
         EX    R14,*-6                  MOVE PASSWORD TO AREA           15331000
         SPACE 2                                                        15332000
VRTDSN99 SR    R15,R15                                                  15333000
         EXIT                                                           15334000
         EJECT                                                          15335000
*                                                                       15336000
*        MEMBER NAME VALIDITY CHECKING                                  15337000
*                                                                       15338000
         SPACE 3                                                        15339000
VRTMEMBR ENTER VALCHECK                                                 15340000
         SR    R15,R15            ASSUME NOT PARTITIONED                15341000
         TM    ##ADRPC#,@S        CORRECT?                              15342000
         BO    VRTMEMX            YES, EXIT                             15343000
         SPACE 1                                                        15344000
         L     R15,0(R6)          ADDR OF MEMBER NAME                   15345000
         LH    R14,4(R6)          LENGTH OF NAME                        15346000
         TM    ##ADRPC#,@G        NEW DEFAULT MEMBER NAME?              15347000
         BNO   VRTMEMS            NO, BRANCH                            15348000
         MVI   FLAGSAA,FOPTIONS   SET THE OPTIONS FLAG                  15349000
         SPACE 1                                                        15350000
VRTMEMS  BCTR  R14,0              EXECUTE LENGTH                        15351000
         OI    FLAGSAA,FMEMBER2                                         15352000
         TM    FLAGSAA,FMEMBER1   FIRST MEMBER PROCESSED?               15353000
         LA    R6,MEMBER2                                               15354000
         LA    R2,LMEMBER2                                              15355000
         BO    MEM2ND             YES, DO THE SECOND MEMBER NAME        15356000
         XC    0(10,R6),0(R6)     NO, CLEAR MEMBER2, LMEMBER2      @D01
         XI    FLAGSAA,FMEMBER1+FMEMBER2                                15357000
         LA    R6,MEMBER1                                               15358000
         LA    R2,LMEMBER1                                              15359000
MEM2ND   MVC   0(8,R6),BLANKS     BLANK THE MEMBER NAME                 15360000
         SPACE 1                                                        15361000
         TM    FLAGSAA,FMEMBER2   SECOND MEMBER NAME?                   15362000
         BO    VRTSOUT            YES, BRANCH                           15363000
         TM    ##ADRPC#,@G        DEFAULT AND MEMBER GROUPS ALLOWED?    15364000
         BO    VRTM190            YES, BRANCH                           15365000
         TM    ##ADRPA#,$M        PATTERN OR DISPLAY SUBCOMMAND?        15366000
         BNO   VRTSOUT            NO, BRANCH                            15367000
VRTM190  LA    R0,1(,R14)         ACTUAL MEMBER NAME LENGTH             15368000
         LR    R5,R15             START OF MEMBER NAME                  15369000
         LTR   R14,R14            SINGLE CHARACTER NAME?                15370000
         BNZ   VRTM210            NO, BRANCH                            15371000
         CLI   0(R5),C'/'         MEMBER PATTERN REQUEST?               15372000
         BE    VRTBAD             YES, INVALID                          15373000
         CLI   0(R5),C'*'         MEMBER PLACE-HOLDER?                  15374000
         BE    VRTM200            YES, BRANCH                           15375000
         CLI   0(R5),C':'         MEMBER RANGE REQUEST?                 15376000
         BNE   VRTSOUT            NO, BRANCH                            15377000
         NI    FLAGSAA,FF-FMEMBER1        ENTIRE DIRECTORY DESIRED      15378000
         OI    FLAGSAA,FMEM#MEM+FMEMRANG  MEMBER RANGE GROUP DESIRED    15379000
         B     VRTGOOD                                                  15380000
         SPACE 2                                                        15381000
VRTM200  OI    FLAGSAA,FMEMSTAR   MEMBER NAME STAR (*) NOTATION         15382000
         CLI   MEMBERD,X'00'      ANY MEMBER DEFAULT YET?               15383000
         BE    VRTSOUT            NO, JUST USE *                        15384000
         NI    FLAGSAA,FF-FOPTIONS    SET FLAGS FOR NO OPERAND          15385000
         MVC   LMEMBER1(2+8+8+2),MEMBERD+1                              15386000
         NI    FLAGSAA,FF-FMEMBER1-FMEMBER2-FMEM#MEM-FMEMRANG           15387000
         OC    FLAGSAA,MEMBERD    RESET THE FLAG BITS                   15388000
         B     VRTGOOD                                                  15389000
         SPACE 1                                                        15390000
VRTM210  CLI   0(R5),C':'         MEMBER RANGE DESIRED?                 15391000
         BE    VRTM220            YES, BRANCH                           15392000
         CLI   0(R5),C'/'         MEMBER PATTERN DESIRED?               15393000
         BE    VRTM222            YES, BRANCH                           15394000
         LA    R5,1(,R5)          NEXT MEMBER CHARACTER                 15395000
         BCT   R0,VRTM210         CHECK ALL MEMBER CHARACTERS           15396000
         B     VRTSOUT            NOT FOUND -- NORMAL MEMBER NAME       15397000
         SPACE 1                                                        15398000
VRTM220  OI    FLAGSAA,FMEMRANG   MEMBER RANGE DESIRED                  15399000
VRTM222  OI    FLAGSAA,FMEM#MEM   MEMBER GROUP DESIRED                  15400000
         CR    R15,R5             FIRST CHARACTER OF NAME?              15401000
         BNE   VRTM230            NO, BRANCH                            15402000
         LA    R15,1(,R15)        SKIP OVER : OR /                      15403000
         XC    LMEMBER2,LMEMBER2  NO MEMBER 2 YET                       15404000
         TM    FLAGSAA,FMEMRANG   MEMBER RANGE DESIRED?                 15405000
         BNO   VRTM240            NO, BRANCH                            15406000
         MVI   LMEMBER1+1,0       MACHINE LENGTH IS ZERO                15407000
         MVI   MEMBER1,X'00'      DATA IS X'00'                         15408000
         B     VRTMEMS            CONTINE WITH MEMBER2                  15409000
         SPACE 1                                                        15410000
VRTM230  S     R0,=F'1'           ACTUAL LENGTH OF MEMBER2              15411000
         STH   R0,LMEMBER2        SAVE FOR LATER                        15412000
         SR    R14,R0             ACTUAL LENGTH OF MEMBER1              15413000
         LA    R5,1(,R5)          SKIP OVER : OR +                      15414000
         ST    R5,FULLWORD        SAVE FOR LATTER                       15415000
         SPACE 1                                                        15416000
VRTM240  BCTR  R14,0              REDUCE MACHINE LENGTH BY ONE          15417000
         SPACE 2                                                        15418000
VRTSOUT  STH   R14,0(,R2)         STASH LENGTH                          15419000
         SPACE 1                                                        15420000
         LA    R5,0(R14,R15)      POINT TO LAST CHARACTER OF MEMBER     15421000
         LM    R0,R1,BLANKS       HEX MEMBER NAME PADDING               15422000
         SPACE 1                                                        15423000
         CLC   =C'X''',0(R15)     BEGINS WITH X'?                       15424000
         BE    VRTHEX             YES, MUST BE A HEX MEMBER NAME        15425000
         SPACE 1                                                        15426000
         TM    FLAGSAA,FMEMBER2   SECOND MEMBER?                        15427000
         BNO   MEMLEN             NO, BRANCH                            15428000
         CLC   ##SUBCOM(8),$RES   RESTORE SUBCOMMAND?                   15429000
         BNE   MEMLEN             NO, BRANCH                            15430000
         BCTR  R15,0              BACK UP R15                           15431000
         SR    R0,R0              ZERO MEMBER NAME PADDING              15432000
         SR    R1,R1              ZERO MEMBER NAME PADDING              15433000
         B     VRTNULL            CHECK FOR A NULL                      15434000
         SPACE 2                                                        15435000
MEMLEN   CLI   1(R2),7            COMPARE LENGTH > 7?                   15436000
         BNH   VRTCHAR            NO, BRANCH                            15437000
         B     VRTBAD             YES, INVALID MEMBER NAME              15438000
         SPACE 2                                                        15439000
VRTHEX   CLI   0(R5),C''''        A FINAL QUOTE?                        15440000
         BNE   VRTBAD             NO, INVALID HEXADECIMAL               15441000
         BCTR  R5,0               POINT TO PRECEDING CHARACTER          15442000
         LA    R15,1(,R15)        POINT TO FIRST QUOTE                  15443000
         SPACE 1                                                        15444000
VRTNULL  CR    R5,R15             NULL HEX STRING?                      15445000
         BNH   VRTBAD             YES, INVALID SYNTAX                   15446000
         SR    R4,R4              COUNT OF DIGITS                       15447000
         L     R14,=F'-1'         BXH INCREMENT                         15448000
         SPACE 1                                                        15449000
VRTHLOOP IC    R3,0(,R5)          NEXT CHARACTER (REVERSE SCAN)         15450000
         CLI   0(R5),C'0'                                               15451000
         BL    *+12               0-9?                                  15452000
         CLI   0(R5),C'9'                                               15453000
         BNH   VRT0TOF            YES, BRANCH                           15454000
         LA    R3,9(,R3)          NO, ADJUST LOW DIGIT 1-5 TO A-F       15455000
         CLI   0(R5),C'A'                                               15456000
         BL    VRTBAD             A-F?                                  15457000
         CLI   0(R5),C'F'                                               15458000
         BH    VRTBAD             NO, BRANCH                            15459000
         SPACE 1                                                        15460000
VRT0TOF  SLL   R3,28              GET DIGIT IN TOP DIGIT                15461000
         SRDL  R0,4               CREATE ROOM IN R0,R1                  15462000
         OR    R0,R3              ADD TO R0,R1                          15463000
         LA    R4,1(,R4)          ANOTHER DIGIT                         15464000
         BXH   R5,R14,VRTHLOOP    DO ALL DIGITS                         15465000
         SPACE 1                                                        15466000
         LA    R14,1(,R4)         DIGITS+1                              15467000
         SRL   R14,1              (DIGITS+1)/2    -- TRUNCATED          15468000
         BCTR  R14,0              MACHINE COMPARE LENGTH                15469000
         STH   R14,0(,R2)         MACHINE LENGTH AFTER CONVERSION       15470000
         LA    R14,2(R14,R14)     (COMPARE LENGTH+1)*2                  15471000
         CR    R14,R4             EVEN NUMBER OF DIGITS?                15472000
         BE    *+8                YES, BRANCH                           15473000
         SRDL  R0,4               NO, ADJUST BY ONE MORE DIGIT          15474000
         SPACE 1                                                        15475000
         STM   R0,R1,DOUBLE       SAVE CREATED MEMBER NAME              15476000
         LA    R14,7              FULL LENGTH MEMBER NAME               15477000
         LA    R15,DOUBLE         START OF MOVE ADDRESS                 15478000
         SPACE 2                                                        15479000
VRTCHAR  MVC   0(*-*,R6),0(R15)   <<EXECUTED>>                          15480000
         EX    R14,*-6            MOVE IN MEMBER NAME                   15481000
         SPACE 3                                                        15482000
         TM    FLAGSAA,FMEM#MEM   MEMBER GROUP PROCESSING?              15483000
         BNO   VRTGOOD            NO, BRANCH                            15484000
         TM    FLAGSAA,FMEMBER2   SECOND MEMBER PROCESSED?              15485000
         BO    VRTGOOD            YES, BRANCH                           15486000
         LH    R14,LMEMBER2       ACTUAL LENGTH OF MEMBER2              15487000
         L     R15,FULLWORD       START OF MEMBER2                      15488000
         LTR   R14,R14            ANY MEMBER2?                          15489000
         BP    VRTMEMS            YES, BRANCH                           15490000
         SPACE 1                                                        15491000
VRTGOOD  SR    R15,R15                                                  15492000
         TM    ##ADRPC#,@G        NEW DEFAULT MEMBER NAME?              15493000
         BNO   VRTGOOD2           NO, BRANCH                            15494000
         TM    FLAGSII,FMEMFRST   FIRST MEMBER OF A LIST?               15495000
         BZ    VRTGOOD0           YES, BRANCH                           15496000
         L     R1,PMEMMAX         LAST ELEMENT POINTER                  15497000
         LA    R1,20(,R1)         NEXT ELEMENT                          15498000
         ST    R1,PMEMMAX                                               15499000
         OI    FLAGSEE,FMEMLIST   ADDED ELEMENT                         15500000
         MVC   0(20,R1),LMEMBER1  LMEMBER1,MEMBER1,MEMBER2,LMEMBER2     15501000
         MVC   0(1,R1),FLAGSAA    SAVE FLAGSAA TOO                      15502000
         NI    0(R1),FF-FOPTIONS-FINDMSG-FMEMSTAR-FHEAD                 15503000
         MVC   LMEMBER1(20),MEMBERD+1  RESTORE THE FIRST ELEMENT        15504000
         NI    FLAGSAA,FF-FMEM#MEM-FMEMBER1-FMEMBER2-FMEMRANG           15505000
         OC    FLAGSAA(1),MEMBERD                                       15506000
         BAL   R14,DEFGROUP                    ADD DEFAULT GROUP        15507000
         B     VRTMEMX                                                  15508000
         SPACE 1                                                        15509000
VRTGOOD0 OI    FLAGSII,FMEMFRST   FIRST LIST ELEMENT                    15510000
         TM    FLAGSAA,FMEMSTAR   ASTERISK NOTATION?                    15511000
         BO    VRTGOOD1           YES, BRANCH                           15512000
         L     R1,PMEMMIN         NO, MINIMUM ELEMENT ADDRESS           15513000
         SH    R1,=H'20'          POINT TO FIRST -20                    15514000
         ST    R1,PMEMMAX         RESET THE MAX MEMBER POINTER          15515000
         NI    FLAGSEE,FF-FMEMLIST                                      15516000
         SPACE 1                                                        15517000
VRTGOOD1 DS    0H                                                  @D01 15518000
         AIF ('&CISP' EQ 'NO SPF').MA01460                         @D01
         TM    SPFLAG2,SPFPOST            LINE COMMAND?            @D01 15518000
         BO    VRTMEMX                    YES, TERMINATE                15519000
.MA01460 ANOP  ,                                                   @D01
         MVC   MEMBERD+1(2+8+8+2),LMEMBER1  SAVE CURRENT MEMBER NAMES   15520000
         MVC   MEMBERD(1),FLAGSAA           SAVE CURRENT FLAGS          15521000
         NI    MEMBERD,FF-FOPTIONS-FINDMSG-FMEMSTAR-FHEAD               15522000
         BAL   R14,DEFGROUP                    ADD DEFAULT GROUP        15523000
         B     VRTMEMX            TERMINATE                             15524000
         SPACE 2                                                        15525000
VRTGOOD2 TM    ##ADRPA#,$M        DISPLAY OR PATTERN SUBCOMMAND?        15526000
         BNO   VRTGOOD4           NO, BRANCH                            15527000
         TM    FLAGSAA,FMEM#MEM   MEMBER GROUP TO DISPLAY?              15528000
         BNO   VRTGOOD4           NO, BRANCH                            15529000
         XI    FLAGSAA,FMEM#MEM   TURN OFF THE MEMBER GROUP FLAG        15530000
         L     R1,$DIS+8          ASSUME DISPLAY                        15531000
         TM    FLAGSAA,FMEMRANG   CORRECT?                              15532000
         BO    *+8                YES, BRANCH                           15533000
         L     R1,$PAT+8          NO, PATTERN                           15534000
         ST    R1,##ADRCMD        UPDATE THE PROCESSING ADDRESS         15535000
         SPACE 2                                                        15536000
VRTGOOD4 CLC   ##SUBCOM(8),$PAT   NEW DEFAULT PATTERN?                  15537000
         BNE   VRTMEMX            NO, BRANCH                            15538000
         MVC   MEMBERP+1(2+8+8+2),LMEMBER1  SAVE CURRENT MEMBER NAMES   15539000
         MVC   MEMBERP(1),FLAGSAA           SAVE CURRENT FLAGS          15540000
         NI    MEMBERP,FF-FOPTIONS-FINDMSG-FMEMSTAR-FHEAD               15541000
         B     VRTMEMX            TERMINATE                             15542000
         SPACE 2                                                        15543000
VRTBAD   LA    R15,4               INVALID MEMBER NAME -- TRY AGAIN     15544000
         TM    FLAGSAA,FMEMBER2    PROCESSING MEMBER2?                  15545000
         BO    *+8                 YES, BRANCH                          15546000
         NI    FLAGSAA,FF-FMEMBER1 NO, SAY NO MEMBER1 YET               15547000
         NI    FLAGSAA,FF-FMEMBER2 ALWAYS SAY NOT MEMBER2 NOW           15548000
         TM    FLAGSAA,FMEM#MEM    MEMBER GROUP REQUEST?                15549000
         BNO   VRTMEMX             NO, BRANCH                           15550000
         NI    FLAGSAA,FF-FMEM#MEM-FMEMBER1-FMEMBER2-FMEMRANG           15551000
VRTMEMX  EXIT                                                           15552000
         SPACE 2                                                        15553000
PDSMAIN  CSECT                                                          15554000
         TITLE 'P D S  --  PDS END                             1/15/85' 15555000
EXIT12O  LA    R1,L831                  DATA SET DID NOT OPEN           15556000
EXIT12M  TSMSG (R1)                     OUTPUT THE ERROR MESSAGE        15557000
EXIT12N  MVI   RETURNCD+3,12            ERROR CODE 12 (NO CLOSE & FREE) 15558000
         MVC   ##SUBCOM(8),$END         SIMULATE AN END SUBCOMMAND      15559000
         B     RETURN2                                                  15560000
         SPACE 1                                                        15561000
EXIT8M   TSMSG (R1)                     OUTPUT THE ERROR MESSAGE        15562000
EXIT8N   MVI   RETURNCD+3,8             ERROR CODE 8                    15563000
         MVC   ##SUBCOM(8),$END         SIMULATE AN END SUBCOMMAND      15564000
         SPACE 1                                                        15565000
RETURN   TM    FLAGSSS,C'1'             RETURN SEEN AN END BEFORE?      15566000
         BO    RETURN1                  YES, BRANCH                     15567000
         OI    FLAGSSS,X'01'            CONVERT 2 --> 3;  4 --> 5       15568000
         CLI   FLAGSSS,C'0'             RETURN TRAP SET?                15569000
         BH    NEWCMD                   YES, BRANCH                     15570000
         SPACE 1                                                        15571000
RETURN1  BAL   R2,SHUTSTW2              DELETE ANY DATA SET ENQUEUES    15572000
         BAL   R2,CLOSEIT               CLOSE THE DATA SET              15573000
         BAL   R2,DEALLDCB              FREE THE DATA SET TOO           15574000
         AIF ('&CISP' EQ 'NO SPF').MA01480                         @D01
         TM    SPFLAG0,SPFTABLE       DIALOG TABLE UNCLEAN     SS JUL84 15575000
         BZ    SPFNO3                 NO                       SS JUL84 15576000
         MVI   SPFLAG1,SPFCLEAN       FUNCTION TYPE            SS JUL84 15577000
         L     R15,=V(ISPDSPY)                                 SS JUL84 15578000
         BALR  R14,R15                                         SS JUL84 15579000
         NOP   0                      IGNORE RETURN 0          SS JUL84 15580000
SPFNO3   DS    0H                                              SS JUL84 15581000
.MA01480 ANOP  ,                                                   @D01
         SPACE 1                                                        15582000
RETURN2  OI    FLAGSGG,FRECVCON         STAE RECOVERY DISALLOWED        15583000
         ICM   R5,B'1111',RETURNCD      NORMAL EXIT?                    15584000
         BZ    RETURN4                  YES, BRANCH                     15585000
         SPACE 2                                                        15586000
         XC    PARMLIST(6*4),PARMLIST   CLEAR STACK PARAMETER AREA      15587000
         LA    R1,PARMLIST              AREA FOR STACK PARM LIST        15588000
         USING IOPL,R1                                                  15589000
         SPACE 1                                                        15590000
         L     R2,ADDRUPT                                               15591000
         L     R3,ADDRECT                                               15592000
         LA    R4,ATTNECB                                               15593000
         STM   R2,R4,IOPLUPT            INITIALIZE IOPLUPT, IOPLECT,    15594000
         DROP  R1                                                       15595000
         SPACE 2                                                        15596000
         MVI   ATTNECB,0                                                15597000
         L     R15,ADDRSTCK             STACK ROUTINE                   15598000
         STACK PARM=PARMLIST+16,DELETE=ALL,MF=(E,(1)),ENTRY=(15)        15599000
         SPACE 2                                                        15600000
         TCLEARQ INPUT                  CLEAR INPUT BUFFERS             15601000
         SPACE 2                                                        15602000
RETURN4  STAX  ,                        CANCEL ANY OUTSTANDING STAX     15603000
         ESTAE 0                        CANCEL THE ESTAE EXIT           15604000
         SPACE 2                                                        15605000
         TM    DCBOFLGS-IHADCB+QAMDCB,X'10' OUT OPEN?                   15606000
         BNO   RETURN5                      NO, BRANCH                  15607000
         MVI   OPENLIST,X'80'               END OF LIST                 15608000
         CLOSE (QAMDCB),MF=(E,OPENLIST)     CLOSE THE OUT DATA SET      15609000
         SPACE 1                                                        15610000
RETURN5  MVI   CONTOPTN,0                   TURN OFF ANY LOGGING        15611000
         TM    DCBOFLGS-IHADCB+LOGDCB,X'10' LOG OPEN?                   15612000
         BNO   RETURN6                      NO, BRANCH                  15613000
         MVI   OPENLIST,X'80'                                           15614000
         CLOSE (LOGDCB),MF=(E,OPENLIST)                                 15615000
         AIF   (NOT &MVT).MA01500                                  @D01
         SPACE 1                                                   @D01
*---------------------------------------------------------------*  @D01
*        Unallocate the log file using DAIR.                    *  @D01
*---------------------------------------------------------------*  @D01
         XC    DAIR18,DAIR18       Clear parm block to zeroes      @D01
         LA    R2,DAIR18           Point to unallocate parm block  @D01
         USING DAPB18,R2           Address unallocate parm block   @D01
         MVI   DA18CD+1,X'18'      Entry code = unallocate         @D01
         MVC   DA18DDN,LOGDDN      Set DD name to free             @D01
         LA    R3,PARMLIST         Point to DAPL                   @D01
         USING DAPL,R3             Addressability for DAPL         @D01
         L     R14,ADDRUPT         Get UPT address                 @D01
         L     R15,ADDRECT         Get ECT address                 @D01
         LA    R0,ATTNECB          Get address of ECB              @D01
         L     R1,ADDRPSCB         Get PSCB address                @D01
***      LA    R2,DAIR18           Get DAIR parm block address     @D01
         STM   R14,R2,DAPLUPT      Set DAPLUPT, DAPLECT, DAPLECB,  @D01
*                                      DAPLPSCB and DAPLDAPB       @D01
         DROP  R2                  End parm block addresability    @D01
         LR    R1,R3               Set DAPL address for DAIR       @D01
         DROP  R3                  End DAPL addressability         @D01
         L     R15,ADDRDAIR        Get DAIR address                @D01
         BALR  R14,R15             Link to DAIR to free the file   @D01
**** end need to free the log file                                 @D01
.MA01500 ANOP  ,                                                   @D01
         SPACE 2                                                        15616000
RETURN6  DS    0H                                                  @D01
         AIF ('&CISP' EQ 'NO SPF').MA01520                         @D01
         TM    FLAGSFF,FSPFCALL         TERMINATE SPF?             @D01 15617000
         BNO   RETURN8                  NO, BRANCH                      15618000
         NI    FLAGSFF,FF-FSPFCALL      YES, TERMINATE SPF TOO          15619000
         MVC   ##SUBCOM(8),$END         SIMULATE END SUBCOMMAND         15620000
         LA    R1,RETURN8               END COMMAND FINAL CODE          15621000
         ST    R1,##ADRCMD              EXECUTED AFTER OPEN OF DATA SET 15622000
         MVI   ##ADRCM#,CONTINUE        FLAG TO CONTINUE                15623000
         L     R13,4(,R13)              PREVIOUS SAVE AREA              15624000
         LM    R14,R12,12(R13)          SAVE REGISTERS                  15625000
         LA    R15,4                    RC=4 -- SIMULATES RETURN KEY    15626000
         BR    R14                      RETURN TO SPF                   15627000
         SPACE 2                                                        15628000
RETURN8  TM    FLAGSFF,FSPFDIAL         PDS CALLED BY SPF AS A DIALOG?  15629000
         BNO   RETURN12                 NO, BRANCH                      15630000
         LA    R0,=CL8'CONTROL'         FIRST PARAMETER                 15631000
         LA    R1,=CL8'DISPLAY'         SECOND PARAMETER                15632000
         LA    R2,=CL8'REFRESH'         THIRD PARAMETER                 15633000
         STM   R0,R2,MSGTEXT2           SAVE ADDRESSES                  15634000
         OI    MSGTEXT2+8,X'80'         LAST                            15635000
         LA    R1,MSGTEXT2                  PARAMETER                   15636000
         L     R15,ISPLINK                                              15637000
         BALR  R14,R15                  LET SPF KNOW                    15638000
         SPACE 1                                                        15639000
         L     R3,SUBPDIAL              START OF GETMAINED AREA         15640000
         CLC   16+96+64+8(2,R3),=H'32'  EXPANDED I/O WORK AREA?         15641000
         BE    RETURN10                 NO, BRANCH                      15642000
         L     R1,16+96+64(,R3)         START OF NEW I/O WORK AREA      15643000
         LH    R0,16+96+64+8(,R3)       SIZE OF NEW I/O WORK AREA       15644000
         ICM   R0,B'1000',SUBPDIAL      SUBPOOL OF NEW I/O WORK AREA    15645000
         FREEMAIN R,LV=(0),A=(1)                                        15646000
         SPACE 2                                                        15647000
RETURN10 LA    R0,16+96+64+16           LENGTH OF CREATED AREAS         15648000
         CLC   16+96+64+8(2,R3),=H'32'  I/O WORK AREA RELEASE TOO?      15649000
         BNE   *+8                      NO, BRANCH                      15650000
         LA    R0,16+96+64+16+32        LENGTH OF CREATED AREAS         15651000
         ICM   R0,B'1000',SUBPDIAL      SUBPOOL OF CREATED WORK AREAS   15652000
         FREEMAIN R,LV=(0),A=(3)                                        15653000
         SPACE 2                                                        15654000
.MA01520 ANOP  ,                                                   @D01
RETURN12 SR    R0,R0                                                    15655000
         ICM   R0,B'1000',OUTMEMBS      ANY SUBPOOL 22 DATA?            15656000
         BZ    RETURN20                 NO, BRANCH                      15657000
         FREEMAIN R,SP=(0)                                              15658000
         SPACE 2                                                        15659000
RETURN20 L     R1,IOBUFF1               START OF BUFFER AREA            15660000
         L     R0,WORKBUFF                                              15661000
         FREEMAIN R,LV=(0),A=(1)                                        15662000
         SPACE 2                                                        15663000
         LA    R2,ADDRPUTL              FIRST SERVICE ROUTINE ADDRESS   15664000
         LA    R3,MODULEN               FIRST LOAD ADDRESS              15665000
         SPACE 1                                                        15666000
RETURN30 CLI   0(R2),X'D6'              DELETE REQUIRED?                15667000
         BNE   RETURN40                 NO, BRANCH                      15668000
         DELETE  EPLOC=2(R3)                                            15669000
RETURN40 LA    R2,4(,R2)                NEXT SERVICE ADDRESS            15670000
         LA    R3,10(,R3)               NEXT MODULES ADDRESS            15671000
         CLI   0(R3),X'FF'              END OF MODULES?                 15672000
         BNE   RETURN30                 NO, BRANCH                      15673000
         SPACE 2                                                        15674000
         LR    R13,R7                   ADDRESS OF THE FIRST SAVE AREA  15675000
         LR    R15,R5                   RETURN CODE                     15676000
         L     R0,WORKSIZE                                              15677000
         SPACE 1                                                        15678000
         EXIT  LV=(0)                                                   15679000
         TITLE 'P D S  --  PDS PARSE DEFINITIONS               1/15/85' 15680000
*                                                                       15681000
*        P A R S E   C O N T R O L   L I S T                            15682000
*                                                                       15683000
         PRINT NOGEN                                                    15684000
         SPACE 3                                                        15685000
PCLMAIN  IKJPARM DSECT=MAINPDL                                          15686000
         AIF   (&MVT).MA01540                                      @D01
INPUTDSN IKJPOSIT DSTHING,USID,VALIDCK=VRTDSN,                         $15687000
               PROMPT='NAME OF DATA SET',                              $15688000
               HELP=('NAME OF THE DATA SET TO BE PROCESSED')            15689000
         AGO   .NA01540
.MA01540 ANOP  ,                                                   @D01
INPUTDSN IKJPOSIT DSTHING,VALIDCK=VRTDSN,                          @D01+
               PROMPT='NAME OF DATA SET',                          @D01+
               HELP=('NAME OF THE DATA SET TO BE PROCESSED')       @D01
.NA01540 ANOP  ,                                                   @D01
OPTVOL   IKJKEYWD                                                       15690000
         IKJNAME 'VOLUME',SUBFLD=$VOLUME                                15691000
OPTDISP  IKJKEYWD                                                       15692000
         IKJNAME 'OLD'                                                  15693000
         IKJNAME 'SHR'                                                  15694000
$VOLUME  IKJSUBF                                                        15695000
VOLNAME  IKJIDENT 'VOLUME NAME',MAXLNTH=6,FIRST=ALPHANUM,              $15696000
               OTHER=ALPHANUM,PROMPT='VOLUME NAME',                    $15697000
               HELP=('NAME OF THE VOLUME WHERE THE DATA SET RESIDES')   15698000
         IKJENDP                                                        15699000
PRIMOPTN DC    CL2'OL'      "OLD"                                       15700000
         DC    CL2'SH'      "SHR"                                       15701000
         DC    CL2'VO'      "VOLUME"                                    15702000
         DC    X'FF'        END OF MAIN COMMAND TABLE                   15703000
         SPACE 3                                                        15704000
PCLALIAS IKJPARM DSECT=PDLALIAS                                         15705000
PCLAL1   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=19,        $15706000
               PROMPT='CURRENT MEMBER NAME',VALIDCK=VRTMEMBR,          $15707000
               HELP=('NAME OF THE MEMBER TO BE ASSIGNED AN ALIAS')      15708000
PCLAL2   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=19,        $15709000
               PROMPT='ALIAS NAME',VALIDCK=VRTMEMBR,                   $15710000
               HELP=('NAME TO BE ASSIGNED AS AN ALIAS')                 15711000
         IKJENDP                                                        15712000
         SPACE 2                                                        15713000
PCLATTR  IKJPARM DSECT=PDLATTR                                          15714000
PCLAT1   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $15715000
               PROMPT='NAME OF MEMBER',                                $15716000
               HELP=('NAME OF THE MEMBER WHOSE ATTRIBUTES ARE TO BE LIS$15717000
               TED'),VALIDCK=VRTMEMBR                                   15718000
LKEDNONE IKJKEYWD                                                       15719000
         IKJNAME  'NONE'                                                15720000
LKEDREUS IKJKEYWD                                                       15721000
         IKJNAME  'REUS'                                                15722000
         IKJNAME  'NOREUS'                                              15723000
LKEDREFR IKJKEYWD                                                       15724000
         IKJNAME  'REFR'                                                15725000
         IKJNAME  'NOREFR'                                              15726000
LKEDRENT IKJKEYWD                                                       15727000
         IKJNAME  'RENT'                                                15728000
         IKJNAME  'NORENT'                                              15729000
LKEDEXEC IKJKEYWD                                                       15730000
         IKJNAME  'EXEC'                                                15731000
         IKJNAME  'NOEXEC'                                              15732000
LKEDLOAD IKJKEYWD                                                       15733000
         IKJNAME  'LOADONLY'                                            15734000
         IKJNAME  'NOLOADONLY'                                          15735000
LKEDEDIT IKJKEYWD                                                       15736000
         IKJNAME  'EDIT'                                                15737000
         IKJNAME  'NOEDIT'                                              15738000
LKEDDC   IKJKEYWD                                                       15739000
         IKJNAME  'DC'                                                  15740000
         IKJNAME  'NODC'                                                15741000
LKEDAUTH IKJKEYWD                                                       15742000
         IKJNAME  'AUTH'                                                15743000
         IKJNAME  'NOAUTH'                                              15744000
LKEDPAGE IKJKEYWD                                                       15745000
         IKJNAME  'PAGE'                                                15746000
         IKJNAME  'NOPAGE'                                              15747000
LKEDRLDF IKJKEYWD                                                       15748000
         IKJNAME  'RLDFIX'                                              15749000
         IKJNAME  'NORLDFIX'                                            15750000
LKEDRMOD IKJKEYWD                                                       15751000
         IKJNAME  'RMODE24'                                             15752000
         IKJNAME  'RMODEANY'                                            15753000
LKEDAMOD IKJKEYWD                                                       15754000
         IKJNAME  'AMODE24'                                             15755000
         IKJNAME  'AMODE31'                                             15756000
         IKJNAME  'AMODEANY'                                            15757000
         IKJNAME  'AMODE64'                                        @D02
LKEDSSIK IKJKEYWD                                                       15758000
         IKJNAME  'SSI',SUBFLD=LKEDSSIS                                 15759000
         IKJNAME  'NOSSI'                                               15760000
INFOALIA IKJKEYWD                                                       15761000
         AIF   (&MVT).MA01560                                      @D01
         IKJNAME  'A',ALIAS=('ALIASINFO')                               15762000
         IKJNAME  'NOA',ALIAS=('NOALIASINFO')                           15763000
         AGO   .NA01560                                            @D01
.MA01560 ANOP  ,                                                   @D01
         IKJNAME  'ALIASINFO'                                      @D01
         IKJNAME  'NOALIASINFO'                                    @D01
.NA01560 ANOP  ,                                                   @D01
INFOLKED IKJKEYWD                                                       15764000
         IKJNAME  'LKEDDATE'                                            15765000
         IKJNAME  'NOLKEDDATE'                                          15766000
LKEDSSIS IKJSUBF                                                        15767000
LKEDSSI  IKJIDENT 'SSI DATA',FIRST=ALPHANUM,OTHER=ALPHANUM,MAXLNTH=8,  $15768000
               PROMPT='THE NEW OR CHANGED SSI INFORMATION',            $15769000
               HELP=('ONE TO EIGHT BYTES OF HEXADECIMAL SSI DATA')      15770000
         IKJENDP                                                        15771000
         SPACE 2                                                        15772000
PCLBROWS IKJPARM DSECT=PDLBROWS                                         15773000
PCLBR1   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $15774000
               PROMPT='NAME OF MEMBER TO BE BROWSED',VALIDCK=VRTMEMBR, $15775000
               HELP=('NAME OF THE MEMBER FOR THE SPF BROWSE COMMAND')   15776000
         IKJENDP                                                        15777000
         SPACE 2                                                        15778000
PCLCOMPA IKJPARM DSECT=PDLCOMPA                                         15779000
PCLCOMMA IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=19,        $15780000
               PROMPT='OLD MEMBER NAME',VALIDCK=VRTMEMBR,              $15781000
               HELP=('NAME OF THE FIRST MEMBER TO BE COMPARED')         15782000
PCLCOMMB IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=19,        $15783000
               PROMPT='NEW MEMBER NAME',VALIDCK=VRTMEMBR,              $15784000
               HELP=('NAME OF THE SECOND MEMBER TO BE COMPARED')        15785000
PCLCO2   IKJPOSIT SPACE                                                 15786000
PCLCOSTR IKJPOSIT STRING                                                15787000
         IKJENDP                                                        15788000
         SPACE 2                                                        15789000
PCLCOMPR IKJPARM DSECT=PDLCOMPR                                         15790000
CMXLIST  IKJKEYWD                                                       15791000
         AIF   (&MVT).MA01580                                      @D01
         IKJNAME  'S',ALIAS=('SUMMARY')                                 15792000
         AGO   .NA01580                                            @D01
.MA01580 ANOP  ,                                                   @D01
         IKJNAME  'SUMMARY'                                        @D01
.NA01580 ANOP  ,                                                   @D01
         IKJNAME  'LIST'                                                15793000
         IKJNAME  'NOLIST'                                              15794000
CMXSHARE IKJKEYWD                                                       15795000
         IKJNAME  'SHR'                                                 15796000
         IKJENDP                                                        15797000
         SPACE 2                                                        15798000
PCLCONT  IKJPARM DSECT=PDLCONT                                          15799000
PALINCON IKJKEYWD                                                       15800000
         IKJNAME  'ALIASINFO'                                           15801000
         IKJNAME  'NOALIASINFO'                                         15802000
**PSAVEOP IKJKEYWD                                                      15803000
**        IKJNAME  'SAVETEXT'                                      @D05 15804000
**        IKJNAME  'NOSAVETEXT'                                    @D05 15805000
PLKEDCON IKJKEYWD                                                       15806000
         IKJNAME  'LKEDDATE'                                            15807000
         IKJNAME  'NOLKEDDATE'                                          15808000
PTRANCON IKJKEYWD
         IKJNAME  'TRANSLATOR'                                     @D05
         IKJNAME  'NOTRANSLATOR'                                   @D05
PPROMCON IKJKEYWD                                                       15809000
         IKJNAME  'PROMPT'                                              15810000
         IKJNAME  'NOPROMPT'                                            15811000
PRECVCON IKJKEYWD                                                       15812000
         IKJNAME  'RECOVER'                                             15813000
         IKJNAME  'NORECOVER'                                           15814000
PDOUBCON IKJKEYWD                                                       15815000
         AIF   (&MVT).MA01600                                      @D01
         IKJNAME  'D',ALIAS=('DOUBLE')                                  15816000
         IKJNAME  'S',ALIAS=('SINGLE')                                  15817000
         IKJNAME  'M',ALIAS=('MULTIPLE')                                15818000
         AGO   .NA01600                                            @D01
.MA01600 ANOP  ,                                                   @D01
         IKJNAME  'DOUBLE'                                         @D01
         IKJNAME  'SINGLE'                                         @D01
         IKJNAME  'MULTIPLE'                                       @D01
.NA01600 ANOP  ,                                                   @D01
CLOGTYPE IKJKEYWD                                                       15819000
         AIF   (&MVT).MA01620                                      @D01
         IKJNAME  'SYSOUT',SUBFLD=CSYSOUTO                              15820000
         IKJNAME  'NOS',ALIAS=('NOSYSOUT')                              15821000
         IKJNAME  'DSNAME',SUBFLD=CDSNAMEO                              15822000
         IKJNAME  'NODSNAME'                                            15823000
         AGO   .NA01620                                            @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        The following kludge eliminates the SYSOUT/NOSYSOUT     * @D01
*        keyword parameters from the CONTROL command.  Because   * @D01
*        parse signals which of mutually exclusive keyword       * @D01
*        options was selected by returning the index of the      * @D01
*        selected keyword, and because the keywords we want      * @D01
*        to eliminate were originally defined as the first       * @D01
*        two options, we can't simply delete them.  If we        * @D01
*        do that, hardcoded references to the DSNAME/NODSNAME    * @D01
*        options as index numbers 3 and 4 break.  So we replace  * @D01
*        SYSOUT and NOSYSOUT with dummy strings, then overwrite  * @D01
*        the dummy strings with hex values the user can't key    * @D01
*        from the terminal.                                      * @D01
*----------------------------------------------------------------* @D01
.MA01620 ANOP  ,                                                   @D01
         IKJNAME  '@1'                                             @D01
PCLCONT  CSECT ,                                                   @D01
         ORG   *-2                                                 @D01
         DC    XL2'01'                                             @D01
PDSMAIN  CSECT ,                                                   @D01
         IKJNAME  '@2'                                             @D01
PCLCONT  CSECT ,                                                   @D01
         ORG   *-2                                                 @D01
         DC    XL2'02'                                             @D01
PDSMAIN  CSECT ,                                                   @D01
         IKJNAME  'DSNAME',SUBFLD=CDSNAMEO                         @D01
         IKJNAME  'NODSNAME'                                       @D01
         SPACE 1                                                   @D01
.NA01620 ANOP  ,                                                   @D01
CLOGDISP IKJKEYWD                                                       15824000
         IKJNAME  'OLD'                                                 15825000
         IKJNAME  'SHR'                                                 15826000
         IKJNAME  'MOD'                                                 15827000
         IKJNAME  'NEW'                                                 15828000
         AIF   (&MVT).MA01640                                      @D01
CLOGFORM IKJKEYWD                                                       15829000
         IKJNAME  'FORMS',SUBFLD=CFORMO                                 15830000
         IKJNAME  'NOFORMS'                                             15831000
CLOGDEST IKJKEYWD                                                       15832000
         IKJNAME  'DEST',SUBFLD=CDESTO                                  15833000
         IKJNAME  'NODEST'                                              15834000
.MA01640 ANOP  ,                                                   @D01
PIMMCON  IKJKEYWD                                                       15835000
         IKJNAME  'TESTCPUOOP'                                          15836000
         IKJNAME  'TESTABEND'                                           15837000
         IKJNAME  'TESTOUTLOOP'                                         15838000
         IKJNAME  'TESTMSGS'                                            15839000
         IKJNAME  'IOSTATS'                                             15840000
         IKJNAME  'TESTREAD'                                            15841000
         AIF   (&MVT).MA01660                                      @D01
CDESTO   IKJSUBF                                                        15842000
CDESTT   IKJIDENT 'DESTINATION',FIRST=ALPHANUM,OTHER=ALPHANUM,         $15843000
               MAXLNTH=8,PROMPT='DESTINATION NAME',                    $15844000
               HELP=('ONE TO EIGHT CHARACTER SYSOUT DESTINATION')       15845000
CFORMO   IKJSUBF                                                        15846000
CFORMT   IKJIDENT 'FORMS NAME',FIRST=ALPHANUM,OTHER=ALPHANUM,          $15847000
               MAXLNTH=4,PROMPT='FORMS NAME',                          $15848000
               HELP=('ONE TO FOUR CHARACTER FORMS NAME')                15849000
.MA01660 ANOP  ,                                                   @D01
CDSNAMEO IKJSUBF                                                        15850000
         AIF   (&MVT).MA01680                                      @D01
CDSNAMET IKJPOSIT DSNAME,USID,PROMPT='OUTPUT DATA SET NAME',           $15851000
               HELP=('THE NAME OF THE SESSION OUTPUT DATA SET')         15852000
         AGO   .NA01680
.MA01680 ANOP  ,                                                   @D01
CDSNAMET IKJPOSIT DSNAME,PROMPT='OUTPUT DATA SET NAME',            @D01+
               HELP=('THE NAME OF THE SESSION OUTPUT DATA SET')    @D01
.NA01680 ANOP  ,                                                   @D01
CSYSOUTO IKJSUBF                                                        15853000
CSYSOUTT IKJIDENT 'SYSOUT CLASS',FIRST=ALPHANUM,                       $15854000
               MAXLNTH=1,PROMPT='SYSOUT CLASS NAME',                   $15855000
               HELP=('ONE CHARACTER SYSOUT CLASS NAME')                 15856000
         IKJENDP                                                        15857000
         SPACE 2                                                        15858000
PCLDELET IKJPARM DSECT=PDLDELET                                         15859000
PCLS1    IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $15860000
               PROMPT='NAME OF MEMBER TO BE DELETED',VALIDCK=VRTMEMBR, $15861000
               HELP=('NAME OF THE MEMBER TO BE SCRATCHED')              15862000
PCLDELAL IKJKEYWD                                                       15863000
         IKJNAME  'ALIAS'                                               15864000
         IKJNAME  'NOALIAS'                                             15865000
         IKJENDP                                                        15866000
         SPACE 2                                                        15867000
PCLDIR   IKJPARM DSECT=PDLDIR                                           15868000
PCLDIR1  IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $15869000
               PROMPT='NAME OF MEMBER',VALIDCK=VRTMEMBR,HELP=('NAME OF $15870000
               THE MEMBER WHOSE DIRECTORY ENTRY IS TO BE DUMPED')       15871000
PCLSHOR  IKJKEYWD
         IKJNAME  'SHORT'                                          @D04
         IKJNAME  'LONG'                                           @D04
         IKJENDP                                                        15872000
         SPACE 2                                                        15873000
PCLDSNA  IKJPARM DSECT=PDLDSNA                                          15874000
PCLDSN   IKJKEYWD                                                       15875000
         AIF   (&MVT).MA01700                                      @D01
         IKJNAME   'JCL',ALIAS=('BATCH')                                15876000
         IKJNAME   'T',ALIAS=('TSO')                                    15877000
         IKJNAME   'MSG',ALIAS=('TABLE','TBL')                          15878000
         AGO   .NA01700                                            @D01
.MA01700 ANOP  ,                                                   @D01
         IKJNAME   'JCL'                                           @D01
         IKJNAME   'TSO'                                           @D01
         IKJNAME   'MSG'                                           @D01
.NA01700 ANOP  ,                                                   @D01
         IKJENDP                                                        15879000
         SPACE 2                                                        15880000
PCLDSPLY IKJPARM DSECT=PDL1MEM                                          15881000
PCLD1    IKJIDENT 'MEMBER NAME',MAXLNTH=39,                            $15882000
               FIRST=ANY,OTHER=ANY,VALIDCK=VRTMEMBR                     15883000
PCLD2    IKJIDENT 'MEMBER NAME',MAXLNTH=19,                            $15884000
               FIRST=ANY,OTHER=ANY,VALIDCK=VRTMEMBR                     15885000
         IKJENDP                                                        15886000
         SPACE 2                                                        15887000
PCLEDIT  IKJPARM DSECT=PDLEDIT                                          15888000
PCLED1   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $15889000
               PROMPT='NAME OF MEMBER TO BE EDITED',VALIDCK=VRTMEMBR,  $15890000
               HELP=('NAME OF THE MEMBER FOR THE SPF EDIT COMMAND')     15891000
SPFNEWOP IKJKEYWD                                                       15892000
         IKJNAME  'NEW'                                                 15893000
         IKJNAME  'OLD'                                                 15894000
SPFMAC   IKJKEYWD                                                       15895000
         IKJNAME  'MACRO',SUBFLD=SPFMACR                                15896000
SPFMACR  IKJSUBF                                                        15897000
SPFMACRO IKJIDENT 'MACRO NAME',FIRST=ALPHA,OTHER=ALPHANUM,MAXLNTH=8,   $15898000
               PROMPT='MEMBER NAME',HELP=('NAME OF A EDIT MACRO')       15899000
         IKJENDP                                                        15900000
         SPACE 2                                                        15901000
PCLFIND  IKJPARM DSECT=PDLFIND                                          15902000
PCLFIND1 IKJIDENT 'MEMBER NAME',MAXLNTH=39,FIRST=ANY,OTHER=ANY,LIST,   $15903000
               PROMPT='NAME OF MEMBER',VALIDCK=VRTMEMBR,               $15904000
               HELP=('NAME OF THE MEMBER TO BE SEARCHED')               15905000
FINDDLM1 IKJPOSIT DELIMITER                                             15906000
FINDSTRG IKJPOSIT STRING,SQSTRING,ASIS                                  15907000
FINDFMT  IKJKEYWD                                                       15908000
         IKJNAME  'NUM'                   FLAGSDD=X'00'                 15909000
         IKJNAME  'NONUM'                 FLAGSDD=X'01'                 15910000
         IKJNAME  'SNUM'                  FLAGSDD=X'02'                 15911000
         IKJNAME  'LBLOCK'                FLAGSDD=X'04'                 15912000
         IKJNAME  'LDUMP'                 FLAGSDD=X'08'                 15913000
         IKJNAME  'BLOCK'                 FLAGSDD=X'10'                 15914000
         IKJNAME  'DUMP'                  FLAGSDD=X'20'                 15915000
FINDSEC  IKJKEYWD                                                       15916000
         IKJNAME  'MODULE',SUBFLD=FDUMPC                                15917000
FINDOFFT IKJKEYWD                                                       15918000
         IKJNAME  'OFFSET',SUBFLD=FINDOFFS                              15919000
FINDLIST IKJKEYWD                                                       15920000
         IKJNAME  'FIRST'                                               15921000
         IKJNAME  'NOFIRST'                                             15922000
FINDASIS IKJKEYWD                                                       15923000
         IKJNAME  'ASIS'                                                15924000
         IKJNAME  'CAPS'                                                15925000
FMAXLEN  IKJKEYWD                                                       15926000
         IKJNAME  'MAXLEN',SUBFLD=FMAXLENS                              15927000
FMAXIN   IKJKEYWD                                                       15928000
         IKJNAME  'MAXIN',SUBFLD=FMAXINS                                15929000
FMAXOUT  IKJKEYWD                                                       15930000
         IKJNAME  'MAXOUT',SUBFLD=FMAXOUTS                              15931000
FSKIPR   IKJKEYWD                                                       15932000
         IKJNAME  'SKIPREC',SUBFLD=FSKIPRS                              15933000
FSKIPC   IKJKEYWD                                                       15934000
         IKJNAME  'SKIPCOL',SUBFLD=FSKIPCS                              15935000
FTHENC   IKJKEYWD                                                       15936000
         IKJNAME  'THEN',SUBFLD=FTHENCS                                 15937000
FELSEC   IKJKEYWD                                                       15938000
         IKJNAME  'ELSE',SUBFLD=FELSECS                                 15939000
FDUMPC   IKJSUBF                                                        15940000
FDUMPCS  IKJIDENT 'MODULE NAME',MAXLNTH=8,FIRST=ANY,OTHER=ANY,         $15941000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF A MODULE NAME')  15942000
FINDOFFS IKJSUBF                                                        15943000
FINDOFF  IKJIDENT 'MODULE OFFSET',FIRST=ALPHANUM,OTHER=ALPHANUM,       $15944000
               MAXLNTH=6,PROMPT='HEXADECIMAL OFFSET',HELP=('A ONE TO SI$15945000
               X DIGIT HEXADECIMAL OFFSET INTO THE LOAD MODULE')        15946000
FMAXLENS IKJSUBF                                                        15947000
FMAXLENC IKJIDENT 'MAXIMUM LENGTH',FIRST=NUMERIC,OTHER=NUMERIC,        $15948000
               PROMPT='MAXIMUM LENGTH',MAXLNTH=5,                      $15949000
               HELP=('MAXIMUM LENGTH OF EACH INPUT RECORD')             15950000
FMAXINS  IKJSUBF                                                        15951000
FMAXINC  IKJIDENT 'MAXIMUM INPUT',FIRST=NUMERIC,OTHER=NUMERIC,         $15952000
               PROMPT='MAXIMUM INPUT COUNT',MAXLNTH=7,                 $15953000
               HELP=('MAXIMUM NUMBER OF RECORDS TO INPUT')              15954000
FMAXOUTS IKJSUBF                                                        15955000
FMAXOUTC IKJIDENT 'MAXIMUM OUTPUT',FIRST=NUMERIC,OTHER=NUMERIC,        $15956000
               PROMPT='MAXIMUM OUTPUT RECORDS',MAXLNTH=7,              $15957000
               HELP=('MAXIMUM NUMBER OF LINES OR PARTIAL RECORDS TO DIS$15958000
               PLAY')                                                   15959000
FSKIPRS  IKJSUBF                                                        15960000
FSKIPRC  IKJIDENT 'SKIP COUNT',FIRST=NUMERIC,OTHER=NUMERIC,            $15961000
               PROMPT='RECORDS TO SKIP',MAXLNTH=7,                     $15962000
               HELP=('NUMBER OF INPUT RECORDS TO IGNORE')               15963000
FSKIPCS  IKJSUBF                                                        15964000
FSKIPCC  IKJIDENT 'SKIP COLUMNS',FIRST=NUMERIC,OTHER=NUMERIC,          $15965000
               PROMPT='COLUMNS TO SKIP',MAXLNTH=5,                     $15966000
               HELP=('THE NUMBER OF BEGINNING COLUMNS TO IGNORE')       15967000
FTHENCS  IKJSUBF                                                        15968000
FTHENCC  IKJKEYWD                                                       15969000
&NATT    CONDIKJ '&NATT'                                                15970000
&NBRO    CONDIKJ '&NBRO'                                                15971000
&NDIR    CONDIKJ '&NDIR'                                                15972000
&NDEL    CONDIKJ '&NDEL'                                                15973000
&NDSP    CONDIKJ '&NDSP'                                                15974000
&NEDI    CONDIKJ '&NEDI'                                                15975000
&NEND    CONDIKJ '&NEND'                                                15976000
&NFIN    CONDIKJ '&NFIN'                                                15977000
&NFSE    CONDIKJ '&NFSE'                                                15978000
&NHIS    CONDIKJ '&NHIS'                                                15979000
&NLIS    CONDIKJ '&NLIS'                                                15980000
&NMAP    CONDIKJ '&NMAP'                                                15981000
&NMEM    CONDIKJ '&NMEM'                                                15982000
&NMML    CONDIKJ '&NMML'                                                15983000
&NOUT    CONDIKJ '&NOUT'                                                15984000
&NPRI    CONDIKJ '&NPRI'                                                15985000
&NREV    CONDIKJ '&NREV'                                                15986000
&NSPF    CONDIKJ '&NSPF'                                                15987000
&NSUB    CONDIKJ '&NSUB'                                                15988000
&NTSE    CONDIKJ '&NTSE'                                                15989000
&NTSL    CONDIKJ '&NTSL'                                                15990000
&NVER    CONDIKJ '&NVER'                                                15991000
         SPACE 1                                                        15992000
FELSECS  IKJSUBF                                                        15993000
FELSECC  IKJKEYWD                                                       15994000
&NATT    CONDIKJ '&NATT'                                                15995000
&NBRO    CONDIKJ '&NBRO'                                                15996000
&NDIR    CONDIKJ '&NDIR'                                                15997000
&NDEL    CONDIKJ '&NDEL'                                                15998000
&NDSP    CONDIKJ '&NDSP'                                                15999000
&NEDI    CONDIKJ '&NEDI'                                                16000000
&NEND    CONDIKJ '&NEND'                                                16001000
&NFIN    CONDIKJ '&NFIN'                                                16002000
&NFSE    CONDIKJ '&NFSE'                                                16003000
&NHIS    CONDIKJ '&NHIS'                                                16004000
&NLIS    CONDIKJ '&NLIS'                                                16005000
&NMAP    CONDIKJ '&NMAP'                                                16006000
&NMEM    CONDIKJ '&NMEM'                                                16007000
&NMML    CONDIKJ '&NMML'                                                16008000
&NOUT    CONDIKJ '&NOUT'                                                16009000
&NPRI    CONDIKJ '&NPRI'                                                16010000
&NREV    CONDIKJ '&NREV'                                                16011000
&NSPF    CONDIKJ '&NSPF'                                                16012000
&NSUB    CONDIKJ '&NSUB'                                                16013000
&NTSE    CONDIKJ '&NTSE'                                                16014000
&NTSL    CONDIKJ '&NTSL'                                                16015000
&NVER    CONDIKJ '&NVER'                                                16016000
         IKJENDP                                                        16017000
         SPACE 2                                                        16018000
         PRINT GEN                                                      16019000
THENTBL  DC    A(0)                        NO ASSOCIATED THEN/ELSE      16020000
&NATT    COND  DC,A($ATT)                  ATTRIB                       16021000
&NBRO    COND  DC,A($BRO)                  BROWSE                       16022000
&NDIR    COND  DC,A($DIR)                  DIRECTORY                    16023000
     AIF ('&NDEL' EQ '').NDEL120                                        16024000
         DC    AL1(FSINGLE),AL3($DEL)      DELETE                       16025000
.NDEL120 ANOP                                                           16026000
&NDSP    COND  DC,A($DSP)                  DSPRINT                      16027000
&NEDI    COND  DC,A($EDI)                  EDIT                         16028000
&NEND    COND  DC,A($END)                  END                          16029000
&NFIN    COND  DC,A($FIN)                  FIND                         16030000
&NFSE    COND  DC,A($FSE)                  FSE                          16031000
&NHIS    COND  DC,A($HIS)                  HISTORY                      16032000
&NLIS    COND  DC,A($LIS)                  LIST                         16033000
&NMAP    COND  DC,A($MAP)                  MAP                          16034000
&NMEM    COND  DC,A($MEM)                  MEMBERS                      16035000
&NMML    COND  DC,A($MML)                  MEMLIST                      16036000
&NOUT    COND  DC,A($OUT)                  OUTCOPY                      16037000
&NPRI    COND  DC,A($PRI)                  PRINTOFF                     16038000
&NREV    COND  DC,A($REV)                  REVIEW                       16039000
&NSPF    COND  DC,A($SPF)                  SPFEDIT                      16040000
&NSUB    COND  DC,A($SUB)                  SUBMIT                       16041000
&NTSE    COND  DC,A($TSE)                  TSOEDIT                      16042000
&NTSL    COND  DC,A($TSL)                  TSOLIST                      16043000
&NVER    COND  DC,A($VER)                  VERIFY                       16044000
         PRINT NOGEN                                                    16045000
         SPACE 2                                                        16046000
PCLFIX   IKJPARM DSECT=PDLFIX                                           16047000
PCLFIXOP IKJKEYWD                                                       16048000
         IKJNAME  'DCB'                                                 16049000
         IKJNAME  'EXPANDDIR',SUBFLD=RDIRZ                              16050000
         IKJNAME  'RESETDIR',SUBFLD=RDIRZ                               16051000
PCLRELOP IKJKEYWD                                                       16052000
         IKJNAME  'RELEASE'                                             16053000
         IKJNAME  'RELSAVE',SUBFLD=RRES                                 16054000
         IKJNAME  'RELEXTENT'                                           16055000
         IKJNAME  'MAXSPACE'                                            16056000
RTYPE    IKJKEYWD                                                       16057000
         IKJNAME  'LOAD'                                                16058000
         IKJNAME  'OBJECT'                                              16059000
         IKJNAME  'CLIST'                                               16060000
         IKJNAME  'CNTL'                                                16061000
         IKJNAME  'ASM'                                                 16062000
RLRECL   IKJKEYWD                                                       16063000
         IKJNAME  'LRECL',SUBFLD=RLRECLZ                                16064000
RBLKSI   IKJKEYWD                                                       16065000
         AIF   (&MVT).MA01720                                      @D01
         IKJNAME  'BLKSIZE',SUBFLD=RBLKSIZ,                            $16066000
               ALIAS=('BLOCKSIZE','B','BL')                             16067000
         AGO   .NA01720                                            @D01
.MA01720 ANOP  ,                                                   @D01
         IKJNAME  'BLKSIZE',SUBFLD=RBLKSIZ                         @D01
.NA01720 ANOP  ,                                                   @D01
RRECFM   IKJKEYWD                                                       16068000
         IKJNAME  'RECFM',SUBFLD=RRECFMZ                                16069000
RDIRZ    IKJSUBF                                                        16070000
RDIRZI   IKJIDENT 'DIRECTORY BLOCKS',FIRST=NUMERIC,OTHER=NUMERIC,      $16071000
               HELP=('NUMBER OF DIRECTORY BLOCKS'),MAXLNTH=5            16072000
RRES     IKJSUBF                                                        16073000
RRESV    IKJIDENT 'RESERVE TRACKS',FIRST=NUMERIC,OTHER=NUMERIC,        $16074000
               MAXLNTH=5,PROMPT='NUMBER OF TRACKS',                    $16075000
               HELP=('NUMBER OF TRACKS TO RESERVE FOR LATER USE')       16076000
RLRECLZ  IKJSUBF                                                        16077000
RLRECLZI IKJIDENT 'LOGICAL RECORD LENGTH',FIRST=NUMERIC,OTHER=NUMERIC, $16078000
               PROMPT='LOGICAL RECORD LENGTH',MAXLNTH=5,               $16079000
               HELP=('DATA SET LOGICAL RECORD LENGTH DESIRED')          16080000
RBLKSIZ  IKJSUBF                                                        16081000
RBLKSIZI IKJIDENT 'BLOCK SIZE',FIRST=NUMERIC,OTHER=NUMERIC,            $16082000
               PROMPT='BLOCK SIZE',MAXLNTH=5,                          $16083000
               HELP=('DATA SET BLOCKSIZE DESIRED')                      16084000
RRECFMZ  IKJSUBF                                                        16085000
RRECFMZI IKJKEYWD                                                       16086000
         IKJNAME  'F'       X'80'     B'1000 0000'                      16087000
         IKJNAME  'FB'      X'90'     B'1001 0000'                      16088000
         IKJNAME  'FT'      X'A0'     B'1010 0000'                      16089000
         IKJNAME  'FBT'     X'B0'     B'1011 0000'                      16090000
         IKJNAME  'FA'      X'84'     B'1000 0100'                      16091000
         IKJNAME  'FBA'     X'94'     B'1001 0100'                      16092000
         IKJNAME  'FTA'     X'A4'     B'1010 0100'                      16093000
         IKJNAME  'FBTA'    X'B4'     B'1011 0100'                      16094000
         IKJNAME  'FM'      X'82'     B'1000 0010'                      16095000
         IKJNAME  'FBM'     X'92'     B'1001 0010'                      16096000
         IKJNAME  'FTM'     X'A2'     B'1010 0010'                      16097000
         IKJNAME  'FBTM'    X'B2'     B'1011 0010'                      16098000
         IKJNAME  'V'       X'40'     B'0100 0000'                      16099000
         IKJNAME  'VB'      X'50'     B'0101 0000'                      16100000
         IKJNAME  'VT'      X'60'     B'0110 0000'                      16101000
         IKJNAME  'VBT'     X'70'     B'0111 0000'                      16102000
         IKJNAME  'VA'      X'44'     B'0100 0100'                      16103000
         IKJNAME  'VBA'     X'54'     B'0101 0100'                      16104000
         IKJNAME  'VTA'     X'64'     B'0110 0100'                      16105000
         IKJNAME  'VBTA'    X'74'     B'0111 0100'                      16106000
         IKJNAME  'VM'      X'42'     B'0100 0010'                      16107000
         IKJNAME  'VBM'     X'52'     B'0101 0010'                      16108000
         IKJNAME  'VTM'     X'62'     B'0110 0010'                      16109000
         IKJNAME  'VBTM'    X'72'     B'0111 0010'                      16110000
         IKJNAME  'U'       X'C0'     B'1100 0000'                      16111000
         IKJNAME  'UT'      X'E0'     B'1110 0000'                      16112000
         IKJNAME  'UA'      X'C4'     B'1100 0100'                      16113000
         IKJNAME  'UM'      X'C2'     B'1100 0010'                      16114000
         IKJNAME  'UTA'     X'E4'     B'1110 0100'                      16115000
         IKJNAME  'UTM'     X'E2'     B'1110 0010'                      16116000
         IKJENDP                                                        16117000
         SPACE 2                                                        16118000
RECFMVAL DC    X'00',X'80',X'90',X'A0',X'B0',X'84',X'94',X'A4',X'B4'    16119000
         DC    X'82',X'92',X'A2',X'B2'  RECFM(F) THROUGH RECFM(FBTM)    16120000
         DC          X'40',X'50',X'60',X'70',X'44',X'54',X'64',X'74'    16121000
         DC    X'42',X'52',X'62',X'72'  RECFM(V) THROUGH RECFM(VBTM)    16122000
         DC          X'C0',X'E0',X'C4',X'C2',X'E4',X'E2'                16123000
         SPACE 2                                                        16124000
PCLHIST  IKJPARM DSECT=PDLHIST                                          16125000
PCLH1    IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16126000
               PROMPT='NAME OF MEMBER',VALIDCK=VRTMEMBR,HELP=('NAME OF $16127000
               THE LOAD MODULE WHOSE HISTORY IS TO BE LISTED')          16128000
PCLHTRNK IKJKEYWD                                                       16129000
         IKJNAME  'TRAN',SUBFLD=PCLHTRNS                                16130000
PCLHZAPK IKJKEYWD                                                       16131000
         IKJNAME  'ZAP',SUBFLD=PCLHZAPS                                 16132000
PCLHUSRK IKJKEYWD                                                       16133000
         IKJNAME  'USER',SUBFLD=PCLHUSRS                                16134000
         IKJNAME  'SYSMOD',SUBFLD=PCLHUSRS                              16135000
PCLHLKDK IKJKEYWD                                                       16136000
         IKJNAME  'LKED',SUBFLD=PCLHLKDS                                16137000
PCLHMODK IKJKEYWD                                                       16138000
         IKJNAME  'MODULE',SUBFLD=PCLHMODS                              16139000
PCLHMODS IKJSUBF                                                        16140000
PCLHMOD  IKJIDENT 'MODULE NAME',MAXLNTH=8,FIRST=ANY,OTHER=ANY,         $16141000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF A MODULE NAME')  16142000
PCLHUSRS IKJSUBF                                                        16143000
PCLHUSR  IKJIDENT 'IDR USER DATA',FIRST=ANY,OTHER=ANY,MAXLNTH=8,       $16144000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF IDR USER DATA')  16145000
PCLHLKDS IKJSUBF                                                        16146000
PCLHLKD  IKJIDENT 'LINKAGE EDITOR',FIRST=ANY,OTHER=ANY,                $16147000
               MAXLNTH=10,HELP=('FIRST ONE TO TEN CHARACTERS OF A LINKA$16148000
               GE EDITOR NAME')                                         16149000
PCLHZAPS IKJSUBF                                                        16150000
PCLHZAP  IKJIDENT 'ZAP IDRDATA NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=8,    $16151000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF ZAP IDRDATA')    16152000
PCLHTRNS IKJSUBF                                                        16153000
PCLHTRN  IKJIDENT 'TRANSLATOR NAME',FIRST=ANY,OTHER=ANY,               $16154000
               MAXLNTH=10,HELP=('FIRST ONE TO TEN CHARACTERS OF A TRANS$16155000
               LATOR (ASSEMBLER OR COMPILER) NAME')                     16156000
         IKJENDP                                                        16157000
         SPACE 2                                                        16158000
PCLIFTTR IKJPARM DSECT=PDLIFTTR                                         16159000
PCLIFT1  IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16160000
               PROMPT='NAME OF MEMBER',                                $16161000
               HELP=('NAME OF THE MEMBER WHOSE ATTRIBUTES ARE TO BE CHE$16162000
               CKED'),VALIDCK=VRTMEMBR                                  16163000
IFLKREUS IKJKEYWD                                                       16164000
         IKJNAME  'REUS'                                                16165000
         IKJNAME  'NOREUS'                                              16166000
IFLKREFR IKJKEYWD                                                       16167000
         IKJNAME  'REFR'                                                16168000
         IKJNAME  'NOREFR'                                              16169000
IFLKRENT IKJKEYWD                                                       16170000
         IKJNAME  'RENT'                                                16171000
         IKJNAME  'NORENT'                                              16172000
IFLKEXEC IKJKEYWD                                                       16173000
         IKJNAME  'EXEC'                                                16174000
         IKJNAME  'NOEXEC'                                              16175000
IFLKLOAD IKJKEYWD                                                       16176000
         IKJNAME  'LOADONLY'                                            16177000
         IKJNAME  'NOLOADONLY'                                          16178000
IFLKEDIT IKJKEYWD                                                       16179000
         IKJNAME  'EDIT'                                                16180000
         IKJNAME  'NOEDIT'                                              16181000
IFLKAUTH IKJKEYWD                                                       16182000
         IKJNAME  'AUTH'                                                16183000
         IKJNAME  'NOAUTH'                                              16184000
IFLKPAGE IKJKEYWD                                                       16185000
         IKJNAME  'PAGE'                                                16186000
         IKJNAME  'NOPAGE'                                              16187000
IFLKOVER IKJKEYWD                                                       16188000
         IKJNAME  'OVERLAY'                                             16189000
         IKJNAME  'NOOVERLAY'                                           16190000
IFLKTEST IKJKEYWD                                                       16191000
         IKJNAME  'TEST'                                                16192000
         IKJNAME  'NOTEST'                                              16193000
IFRLD0   IKJKEYWD                                                       16194000
         IKJNAME  'RLDZERO'                                             16195000
         IKJNAME  'NORLDZERO'                                           16196000
IFAPFERR IKJKEYWD                                                       16197000
         IKJNAME  'APFERR'                                              16198000
         IKJNAME  'NOAPFERR'                                            16199000
IFRLDERR IKJKEYWD                                                       16200000
         IKJNAME  'RLDERR'                                              16201000
         IKJNAME  'NORLDERR'                                            16202000
IFLKSCTR IKJKEYWD                                                       16203000
         IKJNAME  'SCTR'                                                16204000
         IKJNAME  'NOSCTR'                                              16205000
IFLKLKED IKJKEYWD                                                       16206000
         IKJNAME  'FLEVEL'                                              16207000
         IKJNAME  'NOFLEVEL'                                            16208000
IFLKVSLE IKJKEYWD                                                       16209000
         IKJNAME  'VSLKED'                                              16210000
         IKJNAME  'NOVSLKED'                                            16211000
IFLKDC   IKJKEYWD                                                       16212000
         IKJNAME  'DC'                                                  16213000
         IKJNAME  'NODC'                                                16214000
IFLKALIA IKJKEYWD                                                       16215000
         IKJNAME  'ALIAS'                                               16216000
         IKJNAME  'NOALIAS'                                             16217000
IFLOADER IKJKEYWD                                                       16218000
         IKJNAME  'LOADERR'                                             16219000
         IKJNAME  'NOLOADERR'                                           16220000
IFLKEDER IKJKEYWD                                                       16221000
         IKJNAME  'LKEDERR'                                             16222000
         IKJNAME  'NOLKEDERR'                                           16223000
IFIOERR  IKJKEYWD                                                       16224000
         IKJNAME  'IOERR'                                               16225000
         IKJNAME  'NOIOERR'                                             16226000
IFBLKERR IKJKEYWD                                                       16227000
         IKJNAME  'BLOCKERR'                                            16228000
         IKJNAME  'NOBLOCKERR'                                          16229000
IFLRECLE IKJKEYWD                                                       16230000
         IKJNAME  'LRECLERR'                                            16231000
         IKJNAME  'NOLRECLERR'                                          16232000
IFNULL   IKJKEYWD                                                       16233000
         IKJNAME  'NULL'                                                16234000
         IKJNAME  'NONULL'                                              16235000
IFAALIAS IKJKEYWD                                                       16236000
         IKJNAME  'APPARENTALIAS'                                       16237000
         IKJNAME  'NOAPPARENTALIAS'                                     16238000
IFORPHAN IKJKEYWD                                                       16239000
         IKJNAME  'ORPHAN'                                              16240000
         IKJNAME  'NOORPHAN'                                            16241000
IFSPFEDT IKJKEYWD                                                       16242000
         IKJNAME  'SPFEDIT'                                             16243000
         IKJNAME  'NOSPFEDIT'                                           16244000
IFNAMERR IKJKEYWD                                                       16245000
         IKJNAME  'NAMEERR'                                             16246000
         IKJNAME  'NONAMEERR'                                           16247000
IFRLDF   IKJKEYWD                                                       16248000
         IKJNAME  'RLDFIX'                                              16249000
         IKJNAME  'NORLDFIX'                                            16250000
IFRMODE  IKJKEYWD                                                       16251000
         IKJNAME  'RMODE24'                                             16252000
         IKJNAME  'RMODEANY'                                            16253000
         IKJNAME  'NORMODE24'                                           16254000
         IKJNAME  'NORMODEANY'                                          16255000
IFAMODE  IKJKEYWD                                                       16256000
         IKJNAME  'AMODE24'                                             16257000
         IKJNAME  'AMODE31'                                             16258000
         IKJNAME  'AMODEANY'                                            16259000
         IKJNAME  'NOAMODE24'                                           16260000
         IKJNAME  'NOAMODE31'                                           16261000
         IKJNAME  'NOAMODEANY'                                          16262000
IFLKSSI  IKJKEYWD                                                       16263000
         IKJNAME  'SSI',SUBFLD=IFTSSIS                                  16264000
         IKJNAME  'NOSSI'                                               16265000
IFTUSERK IKJKEYWD                                                       16266000
         IKJNAME  'USERID',SUBFLD=IFTUSERS                              16267000
         IKJNAME  'NOUSERID'                                            16268000
         IKJNAME  'NOTUSERID',SUBFLD=IFTUSERS                           16269000
IFTHENC  IKJKEYWD                                                       16270000
         IKJNAME  'THEN',SUBFLD=IFTHENCS                                16271000
IFELSEC  IKJKEYWD                                                       16272000
         IKJNAME  'ELSE',SUBFLD=IFELSECS                                16273000
IFTLTRNK IKJKEYWD                                                       16274000
         IKJNAME  'TRAN',SUBFLD=IFTLTRNS                                16275000
IFTLZAPK IKJKEYWD                                                       16276000
         IKJNAME  'ZAP',SUBFLD=IFTLZAPS                                 16277000
IFTLUSRK IKJKEYWD                                                       16278000
         IKJNAME  'USER',SUBFLD=IFTLUSRS                                16279000
         IKJNAME  'SYSMOD',SUBFLD=IFTLUSRS                              16280000
IFTLMODK IKJKEYWD                                                       16281000
         IKJNAME  'MODULE',SUBFLD=IFTLMODS                              16282000
IFTLKEDK IKJKEYWD                                                       16283000
         IKJNAME  'LKED',SUBFLD=IFTLKEDS                                16284000
IFTTTRK  IKJKEYWD                                                       16285000
         IKJNAME  'TTR',SUBFLD=IFTTTRS                                  16286000
IFABOKY  IKJKEYWD                                                       16287000
         IKJNAME  'ABOVE',SUBFLD=IFABOSB                                16288000
IFBELKY  IKJKEYWD                                                       16289000
         IKJNAME  'BELOW',SUBFLD=IFBELSB                                16290000
IFCREKY  IKJKEYWD                                                       16291000
         IKJNAME  'CREATED',SUBFLD=IFCRESB                              16292000
IFMODKY  IKJKEYWD                                                       16293000
         IKJNAME  'CHANGED',SUBFLD=IFMODSB                              16294000
IFMODSB  IKJSUBF                                                        16295000
IFMODSUB IKJIDENT 'MODIFICATION DATE RANGE',                           $16296000
               RANGE,FIRST=NUMERIC,OTHER=NUMERIC,                      $16297000
               PROMPT='DATE CHANGED',MAXLNTH=5,VALIDCK=VRTDATE,        $16298000
               HELP=('THE MODIFICATION DATE RANGE TO SEARCH')           16299000
IFCRESB  IKJSUBF                                                        16300000
IFCRESUB IKJIDENT 'CREATION DATE RANGE',                               $16301000
               RANGE,FIRST=NUMERIC,OTHER=NUMERIC,                      $16302000
               PROMPT='DATE CREATED',MAXLNTH=5,VALIDCK=VRTDATE,        $16303000
               HELP=('THE CREATION DATE RANGE TO SEARCH')               16304000
IFABOSB  IKJSUBF                                                        16305000
IFABOSUB IKJIDENT 'MINIMUM SIZE',FIRST=NUMERIC,OTHER=NUMERIC,          $16306000
               PROMPT='MINIMUM SIZE',MAXLNTH=9,                        $16307000
               HELP=('MINIMUM SIZE OF A DESIRED MEMBER')                16308000
IFBELSB  IKJSUBF                                                        16309000
IFBELSUB IKJIDENT 'MAXIMUM SIZE',FIRST=NUMERIC,OTHER=NUMERIC,          $16310000
               PROMPT='MAXIMUM SIZE',MAXLNTH=9,                        $16311000
               HELP=('MAXIMUM SIZE OF A DESIRED MEMBER')                16312000
IFTTTRS  IKJSUBF                                                        16313000
IFTTTR   IKJIDENT 'TTR RANGE',RANGE,FIRST=ALPHANUM,OTHER=ALPHANUM,     $16314000
               MAXLNTH=6,PROMPT='HEXADECIMAL TTR',HELP=('THE LOW:HIGH H$16315000
               ADECIMAL TTR ADDRESS RANGE OF THE MEMBER ENTRIES')       16316000
IFTLKEDS IKJSUBF                                                        16317000
IFTLKED  IKJIDENT 'LINKAGE EDITOR',FIRST=ANY,OTHER=ANY,                $16318000
               MAXLNTH=10,HELP=('FIRST ONE TO TEN CHARACTERS OF A LINKA$16319000
               GE EDITOR NAME')                                         16320000
IFTLMODS IKJSUBF                                                        16321000
IFTLMOD  IKJIDENT 'MODULE NAME',MAXLNTH=8,FIRST=ANY,OTHER=ANY,         $16322000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF A MODULE NAME')  16323000
IFTLUSRS IKJSUBF                                                        16324000
IFTLUSR  IKJIDENT 'IDR USER DATA',FIRST=ANY,OTHER=ANY,MAXLNTH=8,       $16325000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF IDR USER DATA')  16326000
IFTLZAPS IKJSUBF                                                        16327000
IFTLZAP  IKJIDENT 'ZAP IDRDATA NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=8,    $16328000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF ZAP IDRDATA')    16329000
IFTLTRNS IKJSUBF                                                        16330000
IFTLTRN  IKJIDENT 'TRANSLATOR NAME',FIRST=ANY,OTHER=ANY,               $16331000
               MAXLNTH=10,HELP=('FIRST ONE TO TEN CHARACTERS OF A TRANS$16332000
               LATOR (ASSEMBLER OR COMPILER) NAME')                     16333000
IFTUSERS IKJSUBF                                                        16334000
IFTUSER  IKJIDENT 'TSO USERID',FIRST=ALPHA,OTHER=ALPHANUM,MAXLNTH=7,   $16335000
               HELP=('FIRST ONE TO SEVEN CHARACTERS OF A TSO USERID')   16336000
IFTSSIS  IKJSUBF                                                        16337000
IFTSSI   IKJIDENT 'SSI DATA',FIRST=ALPHANUM,OTHER=ALPHANUM,MAXLNTH=8,  $16338000
               HELP=('ONE TO EIGHT BYTES OF HEXADECIMAL SSI DATA')      16339000
IFTHENCS IKJSUBF                                                        16340000
IFTHENCC IKJKEYWD                                                       16341000
&NATT    CONDIKJ '&NATT'                                                16342000
&NBRO    CONDIKJ '&NBRO'                                                16343000
&NDIR    CONDIKJ '&NDIR'                                                16344000
&NDEL    CONDIKJ '&NDEL'                                                16345000
&NDSP    CONDIKJ '&NDSP'                                                16346000
&NEDI    CONDIKJ '&NEDI'                                                16347000
&NEND    CONDIKJ '&NEND'                                                16348000
&NFIN    CONDIKJ '&NFIN'                                                16349000
&NFSE    CONDIKJ '&NFSE'                                                16350000
&NHIS    CONDIKJ '&NHIS'                                                16351000
&NLIS    CONDIKJ '&NLIS'                                                16352000
&NMAP    CONDIKJ '&NMAP'                                                16353000
&NMEM    CONDIKJ '&NMEM'                                                16354000
&NMML    CONDIKJ '&NMML'                                                16355000
&NOUT    CONDIKJ '&NOUT'                                                16356000
&NPRI    CONDIKJ '&NPRI'                                                16357000
&NREV    CONDIKJ '&NREV'                                                16358000
&NSPF    CONDIKJ '&NSPF'                                                16359000
&NSUB    CONDIKJ '&NSUB'                                                16360000
&NTSE    CONDIKJ '&NTSE'                                                16361000
&NTSL    CONDIKJ '&NTSL'                                                16362000
&NVER    CONDIKJ '&NVER'                                                16363000
         SPACE 1                                                        16364000
IFELSECS IKJSUBF                                                        16365000
IFELSECC IKJKEYWD                                                       16366000
&NATT    CONDIKJ '&NATT'                                                16367000
&NBRO    CONDIKJ '&NBRO'                                                16368000
&NDIR    CONDIKJ '&NDIR'                                                16369000
&NDEL    CONDIKJ '&NDEL'                                                16370000
&NDSP    CONDIKJ '&NDSP'                                                16371000
&NEDI    CONDIKJ '&NEDI'                                                16372000
&NEND    CONDIKJ '&NEND'                                                16373000
&NFIN    CONDIKJ '&NFIN'                                                16374000
&NFSE    CONDIKJ '&NFSE'                                                16375000
&NHIS    CONDIKJ '&NHIS'                                                16376000
&NLIS    CONDIKJ '&NLIS'                                                16377000
&NMAP    CONDIKJ '&NMAP'                                                16378000
&NMEM    CONDIKJ '&NMEM'                                                16379000
&NMML    CONDIKJ '&NMML'                                                16380000
&NOUT    CONDIKJ '&NOUT'                                                16381000
&NPRI    CONDIKJ '&NPRI'                                                16382000
&NREV    CONDIKJ '&NREV'                                                16383000
&NSPF    CONDIKJ '&NSPF'                                                16384000
&NSUB    CONDIKJ '&NSUB'                                                16385000
&NTSE    CONDIKJ '&NTSE'                                                16386000
&NTSL    CONDIKJ '&NTSL'                                                16387000
&NVER    CONDIKJ '&NVER'                                                16388000
         IKJENDP                                                        16389000
         SPACE 2                                                        16390000
PCLISPF  IKJPARM DSECT=PDLISPF                                          16391000
PCLISSTR IKJPOSIT STRING                                                16392000
         IKJENDP                                                        16393000
         SPACE 2                                                        16394000
PCLISPM  IKJPARM DSECT=PDLISPM                                          16395000
IKCHKMAX IKJKEYWD                                                       16396000
         IKJNAME  'CHKMAX',SUBFLD=ISCHKMA                               16397000
IKCMDMAX IKJKEYWD                                                       16398000
         IKJNAME  'CMDMAX',SUBFLD=ISCMDMA                               16399000
IKTBLMAX IKJKEYWD                                                       16400000
         IKJNAME  'TBLMAX',SUBFLD=ISTBLMA                               16401000
ISCHKMA  IKJSUBF                                                        16402000
ISCHKMAX IKJIDENT 'CHECKPOINT SIZE',FIRST=NUMERIC,OTHER=NUMERIC,       $16403000
               PROMPT='CHECKPOINT SIZE',MAXLNTH=5,                     $16404000
               HELP=('NUMBER OF OUTPUT LINES BETWEEN CHECKPOINTS')      16405000
ISCMDMA  IKJSUBF                                                        16406000
ISCMDMAX IKJIDENT 'LINES FOR A COMMAND',FIRST=NUMERIC,OTHER=NUMERIC,   $16407000
               PROMPT='MAXIMUM COMMAND OUTPUT LINES',MAXLNTH=5,        $16408000
               HELP=('MAXIMUM OUTPUT LINES FOR ONE COMMAND')            16409000
ISTBLMA  IKJSUBF                                                        16410000
ISTBLMAX IKJIDENT 'DIALOG TABLE SIZE',FIRST=NUMERIC,OTHER=NUMERIC,     $16411000
               PROMPT='DIALOG TABLE SIZE',MAXLNTH=5,                   $16412000
               HELP=('MAXIMUM NUMBER OF LINES IN THE DIALOG TABLE')     16413000
         IKJENDP                                                        16414000
         SPACE 2                                                        16415000
PCLLIST  IKJPARM DSECT=PDLLIST                                          16416000
PCLL1    IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16417000
               PROMPT='NAME OF MEMBER',                                $16418000
               HELP=('NAME OF THE MEMBER TO BE LISTED'),               $16419000
               VALIDCK=VRTMEMBR                                         16420000
LISTFMT  IKJKEYWD                                                       16421000
         IKJNAME  'NUM'                   FLAGSDD=X'00'                 16422000
         IKJNAME  'NONUM'                 FLAGSDD=X'01'                 16423000
         IKJNAME  'SNUM'                  FLAGSDD=X'02'                 16424000
         IKJNAME  'LBLOCK'                FLAGSDD=X'04'                 16425000
         IKJNAME  'LDUMP'                 FLAGSDD=X'08'                 16426000
         IKJNAME  'BLOCK'                 FLAGSDD=X'10'                 16427000
         IKJNAME  'DUMP'                  FLAGSDD=X'20'                 16428000
LISTSEC  IKJKEYWD                                                       16429000
         IKJNAME  'MODULE',SUBFLD=LDUMPC                                16430000
LISTOFFT IKJKEYWD                                                       16431000
         IKJNAME  'OFFSET',SUBFLD=LISTOFFS                              16432000
LMAXLEN  IKJKEYWD                                                       16433000
         IKJNAME  'MAXLEN',SUBFLD=LMAXLENS                              16434000
LMAXIN   IKJKEYWD                                                       16435000
         IKJNAME  'MAXIN',SUBFLD=LMAXINS                                16436000
LMAXOUT  IKJKEYWD                                                       16437000
         IKJNAME  'MAXOUT',SUBFLD=LMAXOUTS                              16438000
LSKIPR   IKJKEYWD                                                       16439000
         IKJNAME  'SKIPREC',SUBFLD=LSKIPRS                              16440000
LSKIPC   IKJKEYWD                                                       16441000
         IKJNAME  'SKIPCOL',SUBFLD=LSKIPCS                              16442000
LDUMPC   IKJSUBF                                                        16443000
LDUMPCS  IKJIDENT 'MODULE NAME',MAXLNTH=8,FIRST=ANY,OTHER=ANY,         $16444000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF A MODULE NAME')  16445000
LISTOFFS IKJSUBF                                                        16446000
LISTOFF  IKJIDENT 'MODULE OFFSET',FIRST=ALPHANUM,OTHER=ALPHANUM,       $16447000
               MAXLNTH=6,PROMPT='HEXADECIMAL OFFSET',HELP=('A ONE TO SI$16448000
               X DIGIT HEXADECIMAL OFFSET INTO THE LOAD MODULE')        16449000
LMAXLENS IKJSUBF                                                        16450000
LMAXLENC IKJIDENT 'MAXIMUM LENGTH',FIRST=NUMERIC,OTHER=NUMERIC,        $16451000
               PROMPT='MAXIMUM LENGTH',MAXLNTH=5,                      $16452000
               HELP=('MAXIMUM LENGTH OF EACH INPUT RECORD')             16453000
LMAXINS  IKJSUBF                                                        16454000
LMAXINC  IKJIDENT 'MAXIMUM INPUT',FIRST=NUMERIC,OTHER=NUMERIC,         $16455000
               PROMPT='MAXIMUM INPUT COUNT',MAXLNTH=7,                 $16456000
               HELP=('MAXIMUM NUMBER OF RECORDS TO INPUT')              16457000
LMAXOUTS IKJSUBF                                                        16458000
LMAXOUTC IKJIDENT 'MAXIMUM OUTPUT',FIRST=NUMERIC,OTHER=NUMERIC,        $16459000
               PROMPT='MAXIMUM OUTPUT RECORDS',MAXLNTH=7,              $16460000
               HELP=('MAXIMUM NUMBER OF RECORDS TO DISPLAY')            16461000
LSKIPRS  IKJSUBF                                                        16462000
LSKIPRC  IKJIDENT 'SKIP COUNT',FIRST=NUMERIC,OTHER=NUMERIC,            $16463000
               PROMPT='RECORDS TO SKIP',MAXLNTH=7,                     $16464000
               HELP=('NUMBER OF INPUT RECORDS TO IGNORE')               16465000
LSKIPCS  IKJSUBF                                                        16466000
LSKIPCC  IKJIDENT 'SKIP COLUMNS',FIRST=NUMERIC,OTHER=NUMERIC,          $16467000
               PROMPT='COLUMNS TO SKIP',MAXLNTH=5,                     $16468000
               HELP=('THE NUMBER OF BEGINNING COLUMNS TO IGNORE')       16469000
         IKJENDP                                                        16470000
         SPACE 2                                                        16471000
PCLMAP   IKJPARM DSECT=PDLMAP                                           16472000
PCLM1    IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16473000
               PROMPT='NAME OF MEMBER TO BE MAPPED',                   $16474000
               HELP=('NAME OF THE MEMBER WHOSE LOAD MODULE MAP IS TO BE$16475000
                PRODUCED'),VALIDCK=VRTMEMBR                             16476000
PCLMAPOP IKJKEYWD                                                       16477000
         IKJNAME  'FULL'                                                16478000
         IKJNAME  'SHORT'                                               16479000
         IKJNAME  'ENTRYPOINT'                                     @D01 16480000
         IKJNAME  'RELINK'                                         @D02
         IKJNAME  'JCL'                                            @D02
PCLMMODK IKJKEYWD                                                       16481000
         IKJNAME  'MODULE',SUBFLD=PCLMMODS                              16482000
PCLMMODS IKJSUBF                                                        16483000
PCLMMOD  IKJIDENT 'MODULE NAME',MAXLNTH=8,FIRST=ANY,OTHER=ANY,         $16484000
               HELP=('FIRST ONE TO EIGHT CHARACTERS OF A MODULE NAME')  16485000
         IKJENDP                                                        16486000
         SPACE 2                                                        16487000
PCLMEMB  IKJPARM DSECT=PDLMEMB                                          16488000
PCLMEM   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16489000
               PROMPT='MEMBER GROUP',VALIDCK=VRTMEMBR,HELP=('THE MEMBER$16490000
                GROUP TO BE DISPLAYED')                                 16491000
         IKJENDP                                                        16492000
         SPACE 2                                                        16493000
PCLMEML  IKJPARM DSECT=PDLMEML                                          16494000
PCLMEMZ  IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16495000
               PROMPT='MEMBER GROUP',VALIDCK=VRTMEMBR,HELP=('THE MEMBER$16496000
                GROUP TO BE DISPLAYED')                                 16497000
MEMLRES  IKJKEYWD                                                       16498000
         IKJNAME  'RESET'                                               16499000
         IKJNAME  'NORESET'                                             16500000
         IKJENDP                                                        16501000
         SPACE 2                                                        16502000
PCLOUT   IKJPARM DSECT=PDLOUT                                           16503000
PCLOUT1  IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16504000
               PROMPT='NAME OF MEMBER',VALIDCK=VRTMEMBR,HELP=('NAME OF $16505000
               THE MEMBER TO OUTPUT TO FILE(PDSOUT)')                   16506000
OUTCLOS  IKJKEYWD                                                       16507000
         IKJNAME  'CLOSE'                                               16508000
         IKJNAME  'NOCLOSE'                                             16509000
OUTECHO  IKJKEYWD                                                       16510000
         IKJNAME  'ECHO'                                                16511000
         IKJNAME  'NOECHO'                                              16512000
OUTASS   IKJKEYWD                                                       16513000
         IKJNAME  'ALIAS'                                               16514000
         IKJNAME  'NOALIAS'                                             16515000
OUTOPTN  IKJKEYWD                                                       16516000
         IKJNAME  'TEXT',SUBFLD=OUTTEX                                  16517000
         IKJNAME  'NOTEXT'                                              16518000
OUTTEX   IKJSUBF                                                        16519000
OUTTEXT  IKJPOSIT QSTRING,PROMPT='OUTPUT IDENTIFIER',                  $16520000
               HELP=('AN IDENTIFICATION STRING FOR OUTPUT SELECT STATEM$16521000
               ENTS')                                                   16522000
         IKJENDP                                                        16523000
         SPACE 2                                                        16524000
PCLPATTR IKJPARM DSECT=PDL2MEM                                          16525000
PCLPAT1  IKJIDENT 'PATTERN NAME',MAXLNTH=39,VALIDCK=VRTMEMBR,LIST,     $16526000
               HELP=('PATTERN CHARACTERS FOR A DIRECTORY SEARCH'),     $16527000
               FIRST=ANY,OTHER=ANY,PROMPT='PATTERN NAME'                16528000
PCLPAT2  IKJIDENT 'PATTERN NAME',MAXLNTH=19,VALIDCK=VRTMEMBR,          $16529000
               FIRST=ANY,OTHER=ANY                                      16530000
         IKJENDP                                                        16531000
         SPACE 2                                                        16532000
PCLPRINT IKJPARM DSECT=PDLPRINT                                         16533000
PCLPR1   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16534000
               PROMPT='NAME OF MEMBER',VALIDCK=VRTMEMBR,               $16535000
               HELP=('NAME OF THE MEMBER FOR THE COMMAND')              16536000
PCLPR2   IKJPOSIT SPACE                                                 16537000
PCLPRSTR IKJPOSIT STRING                                                16538000
         IKJENDP                                                        16539000
         SPACE 2                                                        16540000
PCLRENAM IKJPARM DSECT=PDLRENAM                                         16541000
PCLREN1  IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=19,        $16542000
               PROMPT='CURRENT MEMBER NAME',VALIDCK=VRTMEMBR,          $16543000
               HELP=('NAME OF THE MEMBER TO BE RENAMED')                16544000
PCLREN2  IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=19,        $16545000
               PROMPT='NEW MEMBER NAME',VALIDCK=VRTMEMBR,              $16546000
               HELP=('A NEW NAME FOR THE MEMBER')                       16547000
PCLRENSW IKJKEYWD                                                       16548000
         IKJNAME  'SWAP'                                                16549000
         IKJNAME  'NOSWAP'                                              16550000
PCLRENGP IKJKEYWD                                                       16551000
         IKJNAME  'GROUP'                                               16552000
         IKJNAME  'NOGROUP'                                             16553000
         IKJENDP                                                        16554000
         SPACE 2                                                        16555000
PCLRESTO IKJPARM DSECT=PDLRESTO                                         16556000
PCLRS1   IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=19,        $16557000
               PROMPT='NAME OF MEMBER TO RESTORE',VALIDCK=VRTMEMBR,    $16558000
               HELP=('NAME OF THE MEMBER TO BE RESURRECTED')            16559000
         AGO   .MA01740                                            @D01
PCLRS2   IKJIDENT 'TTR ADDRESS',FIRST=ALPHANUM,OTHER=ALPHANUM,         $16560000
               PROMPT='HEXADECIMAL TTR',MAXLNTH=6,VALIDCK=VRTMEMBR,    $16561000
               HELP=('THE START ADDRESS OF THE MEMBER TO BE RESTORED')  16562000
.MA01740 ANOP  ,                                                   @D01
PCLRSREP IKJKEYWD                                                       16563000
         IKJNAME  'REPEAT'                                              16564000
         IKJNAME  'NOREPEAT'                                            16565000
PCLRSDIS IKJKEYWD                                                       16566000
         IKJNAME  'DISPLAY'                                             16567000
         IKJNAME  'NODISPLAY'                                           16568000
PCLRSPRO IKJKEYWD                                                       16569000
         IKJNAME  'PROMPT'                                              16570000
         IKJNAME  'NOPROMPT'                                            16571000
PCLRESTK IKJKEYWD                                                       16572000
         IKJNAME  'LIKE',SUBFLD=PCLRESTS                                16573000
PCLRN    IKJKEYWD
*                                                                  @D01
         IKJNAME  'COUNT',SUBFLD=PCLRNU                            @D01
PCLTTR   IKJKEYWD
*                                                                  @D01
         IKJNAME  'TTR',SUBFLD=PCLTTRK                             @D01
PCLRESTS IKJSUBF                                                        16574000
PCLREST  IKJIDENT 'MEMBER NAME',FIRST=ALPHA,OTHER=ALPHANUM,MAXLNTH=8,  $16575000
               PROMPT='MEMBER NAME',HELP=('NAME OF A MODEL MEMBER')     16576000
PCLRNU   IKJSUBF
*                                                                  @D01
PCLRNUM  IKJIDENT 'NUMBER OF LINES',FIRST=NUMERIC,OTHER=NUMERIC,   @D01+
               PROMPT='NUMBER OF DISPLAY LINES',MAXLNTH=3,         @D01+
               HELP=('MAXIMUM NUMBER OF LINES TO DISPLAY')         @D01
PCLTTRK  IKJSUBF
*                                                                  @D01
PCLTTRKY IKJIDENT 'TTR ADDRESS',FIRST=ALPHANUM,OTHER=ALPHANUM,     @D01+
               PROMPT='HEXADECIMAL TTR',MAXLNTH=6,VALIDCK=VRTMEMBR,    +
               HELP=('THE START ADDRESS OF THE MEMBER TO BE RESTORED')
*                                                                  @D01
         IKJENDP                                                        16577000
         SPACE 2                                                        16578000
PCLTSOED IKJPARM DSECT=PDLTSOED                                         16579000
PCLTSOE1 IKJIDENT 'MEMBER NAME',MAXLNTH=39,FIRST=ANY,OTHER=ANY,LIST,   $16580000
               PROMPT='NAME OF MEMBER TO EDIT',VALIDCK=VRTMEMBR,       $16581000
               HELP=('NAME OF THE MEMBER FOR THE TSO EDIT COMMAND')     16582000
PCLNON   IKJKEYWD                                                       16583000
         IKJNAME  'NONUM'                                               16584000
PCLASIS  IKJKEYWD                                                       16585000
         IKJNAME  'ASIS'                                                16586000
PCLEDOP  IKJKEYWD                                                       16587000
         IKJNAME  'NEW'                                                 16588000
         IKJNAME  'OLD'                                                 16589000
         SPACE 2                                                        16590000
**    THE FOLLOWING ORDERED TABLE MUST CORRESPOND WITH EDITTYPE BELOW   16591000
**                                                                      16592000
**     DATA SET TYPE VS. EDIT DATA TYPE RULES ARE FROM "HELP EDIT S"    16593000
**                                                                      16594000
PCLTYPE  IKJKEYWD                                                       16595000
         IKJNAME  'DATA'                                                16596000
** INSERT INSTALLATION-ADDED DATA SET TYPES HERE AND IN EDITTYPE BELOW  16597000
         IKJNAME  'LIST'        ADDED LOCALLY AS A EDIT DATA SET TYPE   16598000
         IKJNAME  'VSBASIC'     NEW VS BASIC                            16599000
         IKJNAME  'BASIC'                                               16600000
         IKJNAME  'IPLI'                                                16601000
         IKJNAME  'TEXT'                                                16602000
         IKJNAME  'COBOL'                                               16603000
         IKJNAME  'ASM'                                                 16604000
         IKJNAME  'CLIST'                                               16605000
         IKJNAME  'CNTL'                                                16606000
         IKJNAME  'PLI'          $  -- DATA TYPE .PLI                   16607000
* END OF VALID DATA SET TYPES                                           16608000
         IKJNAME  'PLIF'         $        (DEFAULT EDIT TYPE IS PLI)    16609000
         IKJNAME  'FORTE'    *                                          16610000
         IKJNAME  'FORTG'    *                                          16611000
         IKJNAME  'FORTGI'   *  -- DATA TYPE .FORT                      16612000
         IKJNAME  'FORTH'    *        (DEFAULT EDIT TYPE IS GOFORT)     16613000
         IKJNAME  'GOFORT'   *                                          16614000
         IKJENDP                                                        16615000
         SPACE 2                                                        16616000
**  THE FOLLOWING ORDERED TABLE MUST CORRESPOND WITH PCLTYPE ABOVE      16617000
**                                                                      16618000
**     DATA SET TYPE VS. EDIT DATA TYPE RULES ARE FROM "HELP EDIT S"    16619000
**                                                                      16620000
EDITTYPE DC    CL7'DATA'                                                16621000
** INSERT INSTALLATION-ADDED EDIT DATA TYPES HERE AND IN PCLTYPE ABOVE  16622000
         DC    CL7'LIST'      ADDED LOCALLY AS A VALID DATA SET TYPE    16623000
         DC    CL7'VSBASIC'   NEW VS BASIC                              16624000
         DC    CL7'BASIC'                                               16625000
         DC    CL7'IPLI'                                                16626000
         DC    CL7'TEXT'                                                16627000
         DC    CL7'COBOL'                                               16628000
         DC    CL7'ASM'                                                 16629000
         DC    CL7'CLIST'                                               16630000
         DC    CL7'CNTL'                                                16631000
         DC    CL7'PLI'                                                 16632000
* END OF VALID DATA SET TYPES                                           16633000
PLIF     DC    CL7'PLIF'                                                16634000
         DC    CL7'FORTE'    *                                          16635000
         DC    CL7'FORTG'    *                                          16636000
         DC    CL7'FORTGI'   *  -- DATA TYPE .FORT                      16637000
         DC    CL7'FORTH'    *        (DEFAULT EDIT TYPE IS GOFORT)     16638000
GOFORT   DC    CL7'GOFORT'   *                                          16639000
         SPACE 2                                                        16640000
PCLVERIF IKJPARM DSECT=PDLVERIF                                         16641000
PCLVERMM IKJIDENT 'MEMBER NAME',FIRST=ANY,OTHER=ANY,MAXLNTH=39,LIST,   $16642000
               PROMPT='NAME OF MEMBER',VALIDCK=VRTMEMBR,HELP=('NAME OF $16643000
               THE MEMBER TO VERIFIED')                                 16644000
VERLOAD  IKJKEYWD                                                       16645000
         IKJNAME  'LOAD'                                                16646000
         IKJNAME  'NOLOAD'                                              16647000
VERINPUT IKJKEYWD                                                       16648000
         AIF   (&MVT).MA01760                                      @D01
         IKJNAME  'INPUT',ALIAS=('READ')                                16649000
         IKJNAME  'NOINPUT',ALIAS=('NOREAD')                            16650000
         AGO   .NA01760                                            @D01
.MA01760 ANOP  ,                                                   @D01
         IKJNAME  'INPUT'                                          @D01
         IKJNAME  'NOINPUT'                                        @D01
.NA01760 ANOP  ,                                                   @D01
VERNAME  IKJKEYWD                                                       16651000
         IKJNAME  'NAME'                                                16652000
         IKJNAME  'NONAME'                                              16653000
VERUPDT  IKJKEYWD                                                       16654000
         IKJNAME  'UPDATE'                                              16655000
         IKJNAME  'NOUPDATE'                                            16656000
VERSTATS IKJKEYWD                                                       16657000
         IKJNAME  'STATS'                                               16658000
         IKJNAME  'NOSTATS'                                             16659000
         IKJENDP                                                        16660000
         TITLE 'P D S  --  PDS CONSTANTS                       1/15/85' 16661000
WORKSIZE DC    0F'0',AL1(1),AL3(LENWORK)           DYNAMIC STORAGE SIZE 16662000
WORKBUFF DC    0F'0',AL1(1),AL3(32768*2+47968)     INPUT BUFFER SIZE    16663000
BLANKS   DC    0F'0',8X'40'                                             16664000
         SPACE 2                                                        16665000
FF       EQU   X'FF'        IMMEDIATE FLAG MASK (FOR NI INSTRUCTIONS)   16666000
DEBNMEXT EQU   16           OFFSET IN DEB FOR NUMBER OF EXTENTS         16667000
DEBUCBAD EQU   32           OFFSET IN DEB FOR UCB ADDRESS               16668000
UCBTYP   EQU   16           OFFSET IN UCB FOR UNIT TYPE WORD            16669000
UCBRR    EQU   X'20'        UCB IS ON A SHARED DASDI DEVICE             16670000
UCBVOLI  EQU   28           OFFSET IN UCB FOR DISK VOLUME NAME          16671000
         SPACE 3                                                        16672000
EXCPDCB  DCB   DEVD=DA,DDNAME=X,MACRF=E,EXLST=EXLST                     16673000
LEXCPDCB EQU   *-EXCPDCB                                                16674000
SAMDCB   DCB   DSORG=PO,DEVD=DA,DDNAME=X,MACRF=(R,W),EXLST=EXLST        16675000
LSAMDCB  EQU   *-SAMDCB                                                 16676000
DIRDCB   DCB   DSORG=PS,RECFM=FB,LRECL=256,BLKSIZE=256,DDNAME=X,       X16677000
               MACRF=(W),KEYLEN=8,DEVD=DA                               16678000
LDIRDCB  EQU   *-DIRDCB                                                 16679000
EXLST    DC    X'85',AL3(OPENEXIT)                                      16680000
         PRINT GEN                                                      16681000
         SPACE 2                                                        16682000
BLDLPARM DC    AL2(1,74)                                                16683000
RECFMTYP DC    C'*FV?U'                   RECFM=. TEXT                  16684000
DSORGTYP DC    C'**DAPS??IS'              DSORG=.. TEXT                 16685000
         SPACE 2                                                        16686000
DAYMONTH DC    AL1(31,28,31,30,31,30,31,31,30,31,30,31)                 16687000
TRTABLE  EQU   *-X'F0'                                                  16688000
HEXTBL   DC    C'0123456789ABCDEF'                                      16689000
         SPACE 2                                                        16690000
DATEMASK DC    X'402120612020612020'                                    16691000
         SPACE 2                                                        16692000
SYSHELP  DC    CL8'SYSHELP'               FOR DDNAME FREE IN HELP       16693000
SYSPROC  DC    CL8'SYSPROC'               FOR NO DDNAME FREE IN DEALLOC 16694000
SPFUSER  DC    CL8'SPFUSER'               FOR SPF OPTION 6 ENQ TEST     16695000
SPFEDIT  DC    CL8'SPFEDIT'               FOR SPF MEMBER ENQ TEST       16696000
SYSIEWLP DC    CL8'SYSIEWLP'              FOR LINKAGE-EDITOR RESERVE    16697000
         AIF ('&CISP' EQ 'NO SPF').MA01780                         @D01
         AIF ('&CISP' EQ 'ISPF' OR '&CISP' EQ 'ISPFV2').FORISPF         16698000
ISPF     DC    C'ISPF    PGM(12345678)    PARM(++12345678)             X16699000
                    '      COULD ZAP TO CHANGE "NEWAPPL(ISR)" OR "TEST" 16700000
ISPPANEL DC    CL33'PANEL(ISP@PRIM)              OPT('                  16701000
         AGO   .FORBOTH                                                 16702000
.FORISPF ANOP                                                           16703000
ISPF     DC    C'ISPF    PGM(12345678)    PARM(++12345678) NEWAPPL(ISR)X16704000
                    '      COULD ZAP TO CHANGE "NEWAPPL(ISR)" OR "TEST" 16705000
ISPPANEL DC    CL33'PANEL(ISR@PRIM) NEWAPPL(ISR) OPT('                  16706000
.FORBOTH ANOP                                                           16707000
ISPFPGM  EQU   12,8                       DISPLACEMENT TO PROGRAM NAME  16708000
ISPFPARM EQU   32,8                       DISPLACEMENT TO PARM PASSED   16709000
.MA01780 ANOP  ,                                                   @D01
         EJECT                                                          16710000
ISUBS    DC    33F'0'           INITIAL PDL AREA                        16711000
         ORG   *-16                                                     16712000
ZERO     DC    F'0'                                                     16713000
         DC    F'99999'         INITIALIZE #MAXLEN                      16714000
         DC    2F'9999999'      INITIALIZE #MAXIN, #MAXOUT              16715000
LISUBS   EQU   *-ISUBS          INITIALIZATION LENGTH                   16716000
         SPACE 2                                                        16717000
******           23051 23052  2314  3330  3340  3350  3375 33301  3380  16718000
******           ***** *****  ****  ****  ****  ****  **** *****  ****  16719000
RTABLE   DC  XL2'C0',AL2(0)      ...LOAD                                16720000
         DC  AL2(14136,14660,+7294,13030,+8368,19069,19069,13030,19069) 16721000
         DC  XL2'90',AL2(80)     ...OBJECT                              16722000
         DC  AL2(+3200,+2720,+2240,+3120,+2640,+2960,+3200,+3120,+3120) 16723000
         DC  XL2'50',AL2(255)    ...CLIST                               16724000
         DC  AL2(+4424,+4754,+2296,+4252,+1964,+6232,+6816,+4252,+6356) 16725000
         DC  XL2'90',AL2(80)     ...CNTL                                16726000
         DC  AL2(+6800,+7200,+3520,+6400,+4080,+6160,+6800,+6400,+6320) 16727000
         DC  XL2'90',AL2(80)     ...ASM                                 16728000
         DC  AL2(+6800,+7200,+3520,+6400,+4080,+6160,+6800,+6400,+6320) 16729000
         SPACE 2                                                        16730000
*  NOTE - THESE CCWS ARE USED FOR DATA READS                            16731000
CCWINIT  CCW   X'31',IOBSEEK-IOBSEEK+3,X'60',5  SEARCH ID EQUAL (CCHHR) 16732000
         CCW   X'08',*-8-(*-8),X'60',1          TIC                     16733000
         CCW   X'92',IOBSEEK-IOBSEEK+3,X'20',8  MT READ NEXT COUNT      16734000
*                                                                       16735000
         CCW   X'23',SNO-SNO,X'60',1            SET SECTOR              16736000
         CCW   X'31',IOBSEEK-IOBSEEK+3,X'60',5  SEARCH ID EQUAL (CCHHR) 16737000
         CCW   X'08',*-8-(*-8),X'60',1          TIC                     16738000
CCWREAD  CCW   X'0E',*-*,X'60',32768            READ KEY AND DATA       16739000
CCWTIC   CCW   X'08',*+8-(*+8),X'60',1          TIC (OR MT READ CKD)    16740000
         CCW   X'92',IOBSEEK-IOBSEEK+3,X'60',8  MT READ NEXT COUNT      16741000
         CCW   X'22',SNO-SNO,X'20',1            READ SECTOR NUMBER      16742000
         SPACE 1                                                        16743000
*  NOTE - THESE CCWS ARE USED FOR DIRECTORY COUNTS                      16744000
CCWDIRR  CCW   X'1A',0,X'70',5                  READ HOME ADDRESS       16745000
         CCW   X'92',IOBSEEK+3-IOBSEEK,X'60',5  MT READ NEXT COUNT      16746000
         CCW   X'A9',KEYDATA,X'60',8            SEARCH KEY EQUAL        16747000
         CCW   X'08',*-16-(*-16),X'60',1        TIC                     16748000
         CCW   X'92',WORKTBL+13-WORKTBL,X'60',5 MT READ NEXT COUNT      16749000
         CCW   X'86',0,X'70',1                  READ DATA               16750000
         CCW   X'08',*-16-(*-16),X'20',1        TIC                     16751000
         SPACE 2                                                        16752000
KEYDATA  DC    XL8'FFFFFFFFFFFFFFFF',XL2'000E',XL8'FFFFFFFFFFFFFFFF'    16753000
         EJECT                                                          16754000
UNITTBL  DC    CL9'D????    '                                           16755000
**       DC    CL9'D????    '                                      @D01
**       DC    CL9'D????    '                                      @D01
**       DC    CL9'D????    '                                      @D01
**       DC    CL9'D????    '                                      @D01
**       DC    CL9'D????    '                                      @D01
         DC    CL1'&DB2311 ',CL8'&UN2311  '                        @D01
         DC    CL1'&DB2301 ',CL8'&UN2301  '                        @D01
         DC    CL1'&DB2303 ',CL8'&UN2303  '                        @D01
         DC    CL1'&DB2302 ',CL8'&UN2302  '                        @D01
         DC    CL1'&DB2321 ',CL8'&UN2321  '                        @D01
         DC    CL1'&DB23051',CL8'&UN23051 '                             16761000
         DC    CL1'&DB23052',CL8'&UN23052 '                             16762000
         DC    CL1'&DB2314 ',CL8'&UN2314  '                             16763000
         DC    CL1'&DB3330 ',CL8'&UN3330  '                             16764000
         DC    CL1'&DB3340 ',CL8'&UN3340  '                             16765000
         DC    CL1'&DB3350 ',CL8'&UN3350  '                             16766000
         DC    CL1'&DB3375 ',CL8'&UN3375  '                             16767000
         DC    CL1'&DB33301',CL8'&UN33301 '                             16768000
         DC    CL1'&DB3380 ',CL8'&UN3380  '                             16769000
**       DC    CL9'M????    '                                      @D01
         DC    CL1'&DB3390 ',CL8'&UN3390  '                        @D01
         SPACE 3                                                        16771000
OBTAIN   CAMLST SEARCH,0,0,0                                            16772000
         ORG   OBTAIN+4                                                 16773000
         SPACE 3                                                        16774000
LOCATE   CAMLST NAME,0,,0                                               16775000
         ORG   LOCATE+4                                                 16776000
         SPACE 3                                                        16777000
ENQSTEP  ENQ   (*-*,*-*,E,7,STEP),RET=TEST,MF=L                         16778000
         ORG   ENQSTEP+4                                                16779000
         SPACE 3                                                        16780000
ENQTEST  ENQ   (*-*,*-*,E,*-*,SYSTEMS),RET=TEST,MF=L                    16781000
         ORG   ENQTEST+4                                                16782000
         SPACE 3                                                        16783000
ENQHAVE  ENQ   (*-*,*-*,E,*-*,SYSTEM),RET=HAVE,MF=L                     16784000
         ORG   ENQHAVE+4                                                16785000
         SPACE 7                                                        16786000
RESERVEL RESERVE (*-*,*-*,E,*-*,SYSTEMS),RET=HAVE,UCB=0,MF=L            16787000
         ORG   RESERVEL+4                                               16788000
         SPACE 3                                                        16789000
DEQSYSS  DEQ   (*-*,*-*,*-*,SYSTEMS),RET=HAVE,UCB=0,MF=L                16790000
         ORG   DEQSYSS+4                                                16791000
         SPACE 3                                                        16792000
DEQSYS   DEQ   (*-*,*-*,*-*,SYSTEM),RET=HAVE,MF=L                       16793000
         ORG   DEQSYS+4                                                 16794000
         SPACE 3                                                        16795000
STAELIST ESTAE *-*,PARAM=*-*,MF=L                                       16796000
         ORG   STAELIST+4                                               16797000
         EJECT                                                          16798000
***BITS FOR DIRATTR+0:                                                  16799000
ATTRRENT EQU   X'80'          REENTRANT                                 16800000
ATTRREUS EQU   X'40'          REUSABLE                                  16801000
ATTROVLY EQU   X'20'          OVERLAY STRUCTURE                         16802000
ATTRTEST EQU   X'10'          TEST SYMBOLS ARE AVAILABLE                16803000
ATTRLOAD EQU   X'08'          ONLY LOADABLE                             16804000
ATTRSCTR EQU   X'04'          SCATTER LOADED                            16805000
ATTREXEC EQU   X'02'          EXECUTABLE                                16806000
ATTR1TXT EQU   X'01'          ONE TEXT RECORD ONLY AND NO RLD ITEMS     16807000
         SPACE 1                                                        16808000
***BITS FOR DIRATTR+1:                                                  16809000
ATTRNODC EQU   X'80'          NOT DOWNWARD-COMPATABLE                   16810000
ATTRZORG EQU   X'40'          FIRST TEXT BLOCK HAS A ZERO ORIGIN        16811000
ATTREP0  EQU   X'20'          ENTRY POINT IS AT OFFSET ZERO             16812000
ATTRNRLD EQU   X'10'          NO RLD ITEMS                              16813000
ATTRNE   EQU   X'08'          CANNOT BE REPROCESSED BY LINKAGE-EDITOR   16814000
ATTRSYMS EQU   X'04'          CONTAINS TEST SYMBOLS                     16815000
ATTRFLEV EQU   X'02'          CREATED BY F LEVEL LINKAGE-EDITOR         16816000
ATTRREFR EQU   X'01'          REFRESHABLE                               16817000
         SPACE 3                                                        16818000
TBLATTR  DS    0H                                    PDS PROCESSING     16819000
*                                                    ==============     16820000
         DC    AL1(ATTROVLY,0,00006),CL9'OVERLAY'       LIST ONLY       16821000
         DC    AL1(ATTRTEST,0,00003),CL9'TEST'          LIST ONLY       16822000
         DC    AL1(0,ATTRFLEV,128+6),CL9'E-LEVEL'       LIST ONLY       16823000
SCTRTXT  DC    AL1(ATTRSCTR,0,00003),CL9'SCTR'          LIST ONLY       16824000
RENTTXT  DC    AL1(ATTRRENT,0,00003),CL9'RENT'       CHANGE AND LIST    16825000
REUSTXT  DC    AL1(ATTRREUS,0,00003),CL9'REUS'       CHANGE AND LIST    16826000
REFRTXT  DC    AL1(0,ATTRREFR,00003),CL9'REFR'       CHANGE AND LIST    16827000
         DC    AL1(ATTRLOAD,0,00008),CL9'LOAD ONLY'  CHANGE AND LIST    16828000
         DC    AL1(0,ATTRNE+0,00007),CL9'NOT EDIT'   CHANGE AND LIST    16829000
         DC    AL1(ATTREXEC,0,128+7),CL9'NOT EXEC'   CHANGE AND LIST    16830000
         DC    AL1(0,ATTRNODC,128+1),CL9'DC'         CHANGE AND LIST    16831000
         DC    X'FFFF'                                                  16832000
         SPACE 3                                                        16833000
MODULEN  DC    AL2(CVTPUTL-CVTMAP),CL8'IKJPUTL '                        16834000
         DC    AL2(CVTPARS-CVTMAP),CL8'IKJPARS '                        16835000
         DC    AL2(CVTPTGT-CVTMAP),CL8'IKJPTGT '                        16836000
         DC    AL2(CVTGETL-CVTMAP),CL8'IKJGETL '                        16837000
         DC    AL2(CVTSCAN-CVTMAP),CL8'IKJSCAN '                        16838000
         DC    AL2(CVTSTCK-CVTMAP),CL8'IKJSTCK '                        16839000
         DC    AL2(CVTEHDEF-CVTMAP),CL8'IKJEHDEF'                       16840000
         DC    AL2(CVTEFF02-CVTMAP),CL8'IKJEFF02'                       16841000
         DC    AL2(CVTPCNVT-CVTMAP),CL8'CVTPCNVT'                       16842000
         DC    AL2(CVTPRLTV-CVTMAP),CL8'CVTPRLTV'                       16843000
         AIF   (NOT &MVT).MA01800                                  @D01
         DC    AL2(CVTDAIR-CVTMAP),CL8'IKJDAIR'                    @D01
.MA01800 ANOP  ,                                                   @D01
         DC    X'FFFF'                                                  16844000
         PRINT NOGEN                                                    16845000
         TITLE 'P D S  --  PDS SUBCOMMAND TABLE                1/15/85' 16846000
         COPY  PDSTBL70                                        SS AUG84 16847000
         TITLE 'P D S  --  PDS PROGRAM MESSAGES                1/15/85' 16848000
         PRINT NOGEN                                                    16849000
MSGBLANK MSG   '  '                                                     16850000
         AIF   (&MVT).MA01820                                      @D01
MSGHELP  MSG   'H MS MS('                                               16851000
         AGO   .NA01820                                            @D01
.MA01820 ANOP  ,                                                   @D01
MSGHELP  MSG   'H MS OP('                                          @D01
.NA01820 ANOP  ,                                                   @D01
PDS480W  DC    C'PDS480W COMPRESS MAY NOT BE INTERRUPTED'               16852000
PDS480WL EQU   *-PDS480W                                                16853000
         SPACE 2                                                        16854000
SPFSTATH DC    CL72'SPF STATS:  VER.MOD  CREATED   LAST MODIFIED  SIZE X16855000
                INIT   MOD   ID'                                        16856000
MSGMEMQ  MSG   '**                                '                     16857000
MSGBL132 MSG   '                                                       X16858000
                                                                       X16859000
                                    '  -- 132 BYTES                     16860000
BLANK128 EQU   MSGBL132+4,128,C'C'                                 @D04
MSGABE   DC    C'S123 U1234 AT +123456 IN PROGRAM 12345678'             16861000
MSGABEUS EQU   6                 USER ERROR CODE                        16862000
MSGABEAT EQU   MSGABEUS+9        OFFSET TO ERROR                        16863000
MSGABEPG EQU   MSGABEAT+18       PROGRAM NAME                           16864000
MSGABEND EQU   *                 END OF MSGABE MESSAGE                  16865000
         SPACE 2                                                        16866000
MSGALIAS DC    C'ALIASES FOR THIS MEMBER ARE:'                          16867000
MSGRENAM DC    C'MEMBERS TO BE RENAMED ARE:'                            16868000
MSGDELET DC    C'MEMBERS TO BE DELETED ARE:'                            16869000
MSGDELAS DC    C'ASSOCIATED MEMBERS TO BE DELETED ARE:'                 16870000
MSGRESTO DC    C'CSECTS ARE:'                                           16871000
         SPACE 2                                                        16872000
** PROMPTING MESSAGES                                                   16873000
PDS300A  MSG   'PDS300A ENTER OPTION -- DSN=...                        X16874000
                                                                      ' 16875000
*BYTE COUNT:   ' 234567 10 234567 20 234567 30 234567 40 234567 50 2345 16876000
*DS300A  MSG   'PDS300A ENTER OPTION -- DSN=123456789012345678901234567 16877000
*              89012345678901234,VOL=SER=123456  GRP=12345678:12345678' 16878000
*BYTE COUNT:   67 60 234567 70 234567 80 234567 90 23456 100 23456 110' 16879000
*                                                                       16880000
*FOR DIALOG:   '- DSN=12345678901234567890123456789012345678901234,VOL= 16881000
*              SER=123456  GRP=12345678'                                16882000
*                                                                       16883000
PDS380A  MSG   'PDS380A REENTER THE FIND STRING WITH DELIMITERS:'       16884000
PDS381A  MSG   'PDS381A REENTER THE DATA SET NAME, VOLUME AND DISPOSITIX16885000
               ON'                                                      16886000
PDS382A  MSG   'PDS382A REENTER THE FIRST TTR:'                         16887000
PDS383A  MSG   'PDS383A REENTER THE SECOND TTR:'                        16888000
PDS384A  MSG   'PDS384A REENTER THE HEX OFFSET:'                        16889000
PDS385A  MSG   'PDS385A REENTER THE SSI DATA:'                          16890000
         SPACE 2                                                        16891000
** YES/NO PROMPTS                                                       16892000
PDS390A  MSG   'PDS390A SHOULD THIS MEMBER BE RESTORED (Y/N) ?'         16893000
PDS391A  MSG   'PDS391A SHOULD THESE MEMBERS BE RENAMED (Y/N) ?'        16894000
PDS392A  MSG   'PDS392A SHOULD THIS DATA SET BE MODIFIED (Y/N) ?'       16895000
PDS393A  MSG   'PDS393A SHOULD THIS MEMBER BE DELETED (Y/N) ?'          16896000
PDS394A  MSG   'PDS394A SHOULD ALL OF THESE MEMBERS BE DELETED (Y/N) ?' 16897000
         PRINT GEN                                                      16898000
         TITLE 'P D S  --  PDS MESSAGE LABEL POOL              1/15/85' 16899000
L000     DS    0H                                                       16900000
L001     DC    C'001'                                                   16901000
L002$1   DC    C'002'                                                   16902000
L005     DC    C'005'                                                   16903000
L006     DC    C'006'                                                   16904000
L010     DC    C'010'                                                   16905000
L020$2   DC    C'020'                                                   16906000
L021     DC    C'021'                                                   16907000
L022     DC    C'022'                                                   16908000
L023     DC    C'023'                                                   16909000
L024     DC    C'024'                                                   16910000
L025$1   DC    C'025'                                                   16911000
L030$1   DC    C'030'                                                   16912000
L031$1   DC    C'031'                                                   16913000
L032     DC    C'032'                                                   16914000
L033     DC    C'033'                                                   16915000
L034     DC    C'034'                                                   16916000
L035$2   DC    C'035'                                                   16917000
L040$1   DC    C'040'                                                   16918000
L050$1   DC    C'050'                                                   16919000
L051$1   DC    C'051'                                                   16920000
L060     DC    C'060'                                                   16921000
L061     DC    C'061'                                                   16922000
L062     DC    C'062'                                                   16923000
L064$2   DC    C'064'                                                   16924000
L065$1   DC    C'065'                                                   16925000
L066$1   DC    C'066'                                                   16926000
L071     DC    C'071'                                                   16927000
L080     DC    C'080'                                                   16928000
L081     DC    C'081'                                                   16929000
L090$2   DC    C'090'                                              @D01 16930000
L091$1   DC    C'091'                                                   16931000
L100$1   DC    C'100'                                                   16932000
L101$1   DC    C'101'                                                   16933000
L102$1   DC    C'102'                                                   16934000
L103$2   DC    C'103'                                                   16935000
L104$2   DC    C'104'                                                   16936000
         AGO   .MA01840                                            @D01
L106$1   DC    C'106'                                                   16937000
.MA01840 ANOP  ,                                                   @D01
L110$1   DC    C'110'                                                   16938000
L111$1   DC    C'111'                                                   16939000
L112$1   DC    C'112'                                                   16940000
L113$1   DC    C'113'                                                   16941000
L114$1   DC    C'114'                                                   16942000
L115$1   DC    C'115'                                                   16943000
L116     DC    C'116'                                                   16944000
L120$2   DC    C'120'                                                   16945000
L140$2   DC    C'140'                                                   16946000
L141$1   DC    C'141'                                                   16947000
L142$1   DC    C'142'                                                   16948000
L143$2   DC    C'143'                                                   16949000
L144$1   DC    C'144'                                                   16950000
L160$1   DC    C'160'                                                   16951000
L161$1   DC    C'161'                                                   16952000
L162$1   DC    C'162'                                                   16953000
L163$1   DC    C'163'                                                   16954000
L164$1   DC    C'164'                                                   16955000
L171$1   DC    C'171'                                                   16956000
L180$1   DC    C'180'                                                   16957000
L181$1   DC    C'181'                                                   16958000
L182$1   DC    C'182'                                                   16959000
L183$1   DC    C'183'                                                   16960000
L184$1   DC    C'184'                                                   16961000
L190$1   DC    C'190'                                                   16962000
L200$1   DC    C'200'                                                   16963000
L210$1   DC    C'210'                                                   16964000
L220$1   DC    C'220'                                                   16965000
L230$1   DC    C'230'                                                   16966000
L262$1   DC    C'262'                                              @D04
L400     DC    C'400'                                                   16967000
L401     DC    C'401'                                                   16968000
L402     DC    C'402'                                                   16969000
L441$1   DC    C'441'                                              @D01
L442$1   DC    C'442'                                              @D01
L450     DC    C'450'                                                   16970000
L451     DC    C'451'                                                   16971000
L460     DC    C'460'                                                   16972000
L470     DC    C'470'                                                   16973000
L480     DC    C'480'                                                   16974000
L481     DC    C'481'                                                   16975000
L482     DC    C'482'                                                   16976000
L510     DC    C'510'                                                   16977000
L520     DC    C'520'                                                   16978000
L530     DC    C'530'                                                   16979000
L700     DC    C'700'                                                   16980000
L701     DC    C'701'                                                   16981000
L702     DC    C'702'                                                   16982000
L703     DC    C'703'                                                   16983000
L704$1   DC    C'704'                                                   16984000
L710     DC    C'710'                                                   16985000
L720     DC    C'720'                                                   16986000
L721     DC    C'721'                                                   16987000
L722     DC    C'722'                                                   16988000
L723     DC    C'723'                                                   16989000
L724     DC    C'724'                                                   16990000
L726     DC    C'726'                                                   16991000
L730     DC    C'730'                                                   16992000
L731     DC    C'731'                                                   16993000
L732     DC    C'732'                                                   16994000
L740     DC    C'740'                                                   16995000
L750     DC    C'750'                                                   16996000
L751     DC    C'751'                                                   16997000
L752     DC    C'752'                                                   16998000
L770     DC    C'770'                                                   16999000
L771$1   DC    C'771'                                                   17000000
L780$1   DC    C'780'                                                   17001000
L781$1   DC    C'781'                                                   17002000
L800     DC    C'800'                                                   17003000
L801     DC    C'801'                                                   17004000
L802$1   DC    C'802'                                                   17005000
L804     DC    C'804'                                                   17006000
L805     DC    C'805'                                                   17007000
L811$1   DC    C'811'                                                   17008000
L812$1   DC    C'812'                                                   17009000
L813$1   DC    C'813'                                                   17010000
L814$1   DC    C'814'                                                   17011000
L820$2   DC    C'820'                                                   17012000
L821$1   DC    C'821'                                                   17013000
L822$1   DC    C'822'                                                   17014000
L823$1   DC    C'823'                                                   17015000
L824     DC    C'824'                                                   17016000
L825     DC    C'825'                                                   17017000
L826     DC    C'826'                                                   17018000
L827$2   DC    C'827'                                                   17019000
L830     DC    C'830'                                                   17020000
L831     DC    C'831'                                                   17021000
L832     DC    C'832'                                                   17022000
L833     DC    C'833'                                                   17023000
L834$1   DC    C'834'                                                   17024000
L835$1   DC    C'835'                                                   17025000
L836     DC    C'836'                                                   17026000
L840     DC    C'840'                                                   17027000
L841     DC    C'841'                                                   17028000
L842     DC    C'842'                                                   17029000
L843     DC    C'843'                                                   17030000
L844$1   DC    C'844'                                                   17031000
L850$2   DC    C'850'                                                   17032000
L851$1   DC    C'851'                                                   17033000
L852$1   DC    C'852'                                                   17034000
L853$1   DC    C'853'                                                   17035000
L854$1   DC    C'854'                                                   17036000
L855     DC    C'855'                                                   17037000
L860     DC    C'860'                                                   17038000
L861$1   DC    C'861'                                                   17039000
L862     DC    C'862'                                                   17040000
L864$1   DC    C'864'                                                   17041000
L865     DC    C'865'                                                   17042000
L870     DC    C'870'                                                   17043000
L871     DC    C'871'                                                   17044000
L872     DC    C'872'                                                   17045000
L873     DC    C'873'                                                   17046000
L874     DC    C'874'                                                   17047000
L875     DC    C'875'                                                   17048000
L876     DC    C'876'                                                   17049000
L877     DC    C'877'                                                   17050000
L880$1   DC    C'880'                                                   17051000
L881     DC    C'881'                                                   17052000
L882     DC    C'882'                                                   17053000
L883     DC    C'883'                                                   17054000
L884$1   DC    C'884'                                                   17055000
L892     DC    C'892'                                                   17056000
L910$1   DC    C'910'                                                   17057000
         AIF   (NOT &MVT).MA01860                                  @D01
L911$1   DC    C'911'                                                   17057000
.MA01860 ANOP  ,                                                   @D01
L920$1   DC    C'920'                                                   17058000
L930$1   DC    C'930'                                                   17059000
L990     DC    C'990'                                                   17060000
L991$1   DC    C'991'                                                   17061000
L998$1   DC    C'998'                                                   17062000
L999$1   DC    C'999'                                                   17063000
         DC    X'FF'             LIST TERMINATOR                        17064000
         SPACE 5                                                        17065000
PARTADDR DC    A(PROBE01)        PROBE POINTS FOR THE MESSAGE CSECT     17066000
         DC    A(PROBE02)          (FOR A PARTITIONED SEARCH)           17067000
         DC    A(PROBE03)                                               17068000
         DC    A(PROBE04)                                               17069000
         DC    A(PROBE05)                                               17070000
         DC    A(PROBE06)                                               17071000
         DC    A(PROBE07)                                               17072000
         DC    A(PROBE08)                                               17073000
         DC    A(PROBE09)                                               17074000
         DC    A(PROBE10)                                               17075000
         DC    A(PROBE11)                                               17076000
         DC    A(PROBE12)                                               17077000
         DC    A(PROBE99)                                               17078000
         TITLE 'P D S  --  PDS LITERALS                        1/15/85' 17079000
         LTORG                                                          17080000
         TITLE 'P D S  --  PDS TRANSLATE TABLES                1/15/85' 17081000
PATCH    B     PATCH                                                    17082000
         DC    18H'0'                                                   17083000
         SPACE 3                                                        17084000
***  TRANSLATE AND TEST TABLE TO FIND INVALID MEMBER NAMES              17085000
TRTMEM   DC    256X'FF'           ASSUME ALL INVALID FIRST              17086000
         ORG   TRTMEM+C'#'                                              17087000
         DC    1X'00'             # IS OK                               17088000
         ORG   TRTMEM+C'$'                                              17089000
         DC    1X'00'             $ IS OK                               17090000
         ORG   TRTMEM+C'@'                                              17091000
         DC    1X'00'             @ IS OK                               17092000
         ORG   TRTMEM+C'A'                                              17093000
         DC    9X'00'             ABCDEFGHI  ARE OK                     17094000
         ORG   TRTMEM+C'J'                                              17095000
         DC    9X'00'             JKLMNOPQR  ARE OK                     17096000
         ORG   TRTMEM+C'S'                                              17097000
         DC    8X'00'             STUVWXYZ  ARE OK                      17098000
         ORG   TRTMEM+C'0'                                              17099000
         DC    10X'00'            0123456789  ARE OK                    17100000
         ORG   ,                                                        17101000
         SPACE 3                                                        17102000
         AGO   .MA01880                                            @D01
***  TRANSLATE TABLE TO CONVERT UNPRINTABLES TO PERIODS                 17103000
TRLINE   DC    256C'.'            ASSUME ALL UNPRINTABLE FIRST          17104000
         ORG   TRLINE+C' '                                              17105000
         DC    1X'40'             BLANK IS OK                           17106000
         ORG   TRLINE+C' '                                              17107000
         DC    C' .<(+|&&'         .<(+|&  ARE OK                       17108000
         ORG   TRLINE+C'!'                                              17109000
         DC    C'!$*);^-/'        !$*);^-/  ARE OK                      17110000
         ORG   TRLINE+C','                                              17111000
         DC    C',%_>?'           ,%_>?  ARE OK                         17112000
         ORG   TRLINE+C':'                                              17113000
         DC    C':#@''="'         :#@'="  ARE OK                        17114000
         ORG   TRLINE+X'81'       LOWER-CASE ABCDEFGHI                  17115000
         DC    X'818283848586878889'                                    17116000
         ORG   TRLINE+X'91'       LOWER-CASE JKLMONPQR                  17117000
         DC    X'919293949596979899'                                    17118000
         ORG   TRLINE+X'A2'       LOWER-CASE STUVWXYZ                   17119000
         DC    X'A2A3A4A5A6A7A8A9'                                      17120000
         ORG   TRLINE+C'A'                                              17121000
         DC    C'ABCDEFGHI'       ABCDEFGHI  ARE OK                     17122000
         ORG   TRLINE+C'J'                                              17123000
         DC    C'JKLMNOPQR'       JKLMNOPQR  ARE OK                     17124000
         ORG   TRLINE+C'S'                                              17125000
         DC    C'STUVWXYZ'        STUVWXYZ  ARE OK                      17126000
         ORG   TRLINE+C'0'                                              17127000
         DC    C'0123456789'      0123456789  ARE OK                    17128000
         ORG   ,                                                        17129000
.MA01880 ANOP  ,                                                   @D01
***  TRANSLATE TABLE TO CONVERT UNPRINTABLES TO PERIODS            @D01
TRLINE   DC    256C'.'               Assume all unprintable first  @D01
         ORG   TRLINE+C' '                                         @D01
         DC    1X'40'                Blank is OK                   @D01
         ORG   TRLINE+X'4A'          .<(+|&  are OK               @D01
         DC    X'4A4B4C4D4E4F50'                                   @D01
         ORG   TRLINE+X'5A'                                        @D01
         DC    X'5A5B5C5D5E5F6061'   !$*);^-/  are OK              @D01
         ORG   TRLINE+X'6A'                                        @D01
         DC    X'6A6B6C6D6E6F'       ,%_>?  are OK                @D01
         ORG   TRLINE+X'79'                                        @D01
         DC    X'797A7B7C7D7E7F'     `:#@'="  are OK               @D01
         ORG   TRLINE+X'81'                                        @D01
         DC    X'818283848586878889' Lowercase ABCDEFGHI are OK    @D01
         ORG   TRLINE+X'91'                                        @D01
         DC    X'919293949596979899' Lowercase JKLMONPQR are OK    @D01
         ORG   TRLINE+X'A1'                                        @D01
         DC    X'A1A2A3A4A5A6A7A8A9' Lowercase ~STUVWXYZ are OK    @D01
         ORG   TRLINE+X'AD'                                        @D01
         DC    X'AD'                 Left bracket is OK            @D01
         ORG   TRLINE+X'BD'                                        @D01
         DC    X'BD'                 Right bracket is OK           @D01
         ORG   TRLINE+X'C0'                                        @D01
         DC    X'C0',C'ABCDEFGHI'    {ABCDEFGHI are OK             @D01
         ORG   TRLINE+X'D0'                                        @D01
         DC    X'D0',C'JKLMNOPQR'    }JKLMNOPQR are OK             @D01
         ORG   TRLINE+X'E0'                                        @D01
         DC    X'E0'                 \ is OK                       @D01
         ORG   TRLINE+C'S'                                         @D01
         DC    C'STUVWXYZ'           STUVWXYZ are OK               @D01
         ORG   TRLINE+C'0'                                         @D01
         DC    C'0123456789'         0123456789 are OK             @D01
         ORG   ,                                                   @D01
         TITLE 'P D S  --  PDS MESSAGE CSECT                   1/15/85' 17130000
MSGCSECT CSECT                                                          17131000
         PRINT NOGEN                                                    17132000
         SPACE 2                                                        17133000
** INFORMATIONAL MESSAGES                                               17134000
PROBE01  DS    0C          PLACE BEFORE THE FIRST MESSAGE OF THE CSECT  17135000
         IKJTSMSG ('PDS001I TESTMESSAGES -- ALL NUMBERED MESSAGES FOLLOX17136000
               W:'),L001                                                17137000
         IKJTSMSG ('PDS002I DEFAULT MEMBER IS ',),L002                  17138000
         IKJTSMSG ('PDS005I END OF FILE'),L005                          17139000
         IKJTSMSG ('PDS006I END OF DATA SET'),L006                      17140000
         IKJTSMSG ('PDS010I THE ALIAS HAS BEEN ASSIGNED'),L010          17141000
         IKJTSMSG ('PDS020I ',,' ATTRIBUTES ARE:',),L020                17142000
         IKJTSMSG ('PDS021I APF AUTHORIZED'),L021                       17143000
         IKJTSMSG ('PDS022I NOT APF AUTHORIZED, OBSOLETE LINKAGE EDITORX17144000
               '),L022                                                  17145000
         IKJTSMSG ('PDS023I APF AUTHORIZED, APF DATA VALUE GREATER THANX17146000
                1'),L023                                                17147000
         IKJTSMSG ('PDS024I PAGE ALIGNMENT IS REQUIRED'),L024           17148000
         IKJTSMSG ('PDS025I SSI INFORMATION: ',),L025                   17149000
         IKJTSMSG ('PDS030I GLOBAL OPERANDS: ',),L030                   17150000
         IKJTSMSG ('PDS031I INPUT BUFFERING: ',),L031                   17151000
PROBE02  DS    0C                                                       17152000
         IKJTSMSG ('PDS032I TESTCPULOOP -- CPU LOOP FOLLOWS:'),L032     17153000
         IKJTSMSG ('PDS033I TESTABEND -- SYSTEM 0C1 FOLLOWS:'),L033     17154000
         IKJTSMSG ('PDS034I TESTOUTLOOP -- THIS DATA REPEATS'),L034     17155000
         IKJTSMSG ('PDS035I TESTREAD -- EXCP RETURN CODE=',,'; NEXT TTRX17156000
                ADDRESS IS ',),L035                                     17157000
         IKJTSMSG ('PDS040I ',,' HAS BEEN DELETED'),L040                17158000
         IKJTSMSG ('PDS050I ',,' WILL BE MOVED'),L050                   17159000
         IKJTSMSG ('PDS051I ',,' IS BEING MOVED'),L051                  17160000
         IKJTSMSG ('PDS060I TRANSLATOR HISTORY BY CSECT -'),L060        17161000
         AIF   (&MVT).MA01890                                      @D01
         IKJTSMSG ('PDS061I AMASPZAP UPDATE HISTORY BY CSECT -'),L061   17162000
         AGO   .NA01890                                            @D01
.MA01890 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS061I IMASPZAP UPDATE HISTORY BY CSECT -'),  @D01+
               L061                                                @D01
.NA01890 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS062I USER-SUPPLIED UPDATE HISTORY BY CSECT -'), X17163000
               L062                                                     17164000
         IKJTSMSG ('PDS064I LAST LINK-EDITED ON ',,'  BY LKED ',),L064  17165000
         IKJTSMSG ('PDS065I ASSOCIATED INFORMATION UPDATED FOR MEMBER: X17166000
               ',),L065                                                 17167000
         IKJTSMSG ('PDS066I MEMBER IS AN ALIAS FOR: ',),L066            17168000
         IKJTSMSG ('PDS071I THE FOLLOWING OPTIONS ARE AVAILABLE:'),L071 17169000
PROBE03  DS    0C                                                       17170000
         IKJTSMSG ('PDS080I OUTCOPY DCB IS CLOSED'),L080                17171000
         IKJTSMSG ('PDS080I LOGCOPY DCB IS CLOSED'),L081                17172000
         IKJTSMSG ('PDS090I ',,' HAS BEEN RENAMED TO ',),L090      @D01 17173000
         IKJTSMSG ('PDS091I ',,' HAS BEEN RESTORED'),L091               17174000
         AIF   (&MVT).MA01900                                      @D01
         IKJTSMSG ('PDS100I ',,' -- VERSION 7.0   '),L100               17175000
         AGO   .NA01900                                            @D01
.MA01900 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS100I ',,' -- VERSION &VERS -- &FIXDATE'),   @D01+
               L100                                                @D01
.NA01900 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS101I DELETED MEMBER FOUND AT TTR: ',),L101       17176000
         IKJTSMSG ('PDS102I ENTRY POINT AT ',),L102                     17177000
         IKJTSMSG ('PDS103I ENTRY POINT AT ',,'  --  ',),L103           17178000
         IKJTSMSG ('PDS104I MODULE LENGTH  ',,'  -- ',),L104            17179000
         AGO   .MA01920                                            @D01
         IKJTSMSG ('PDS106I LAST LINK-EDITED ON ',),L106                17180000
.MA01920 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS110I',,' LOGICAL RECORDS WERE INPUT'),L110       17181000
         IKJTSMSG ('PDS111I',,' PHYSICAL BLOCKS WERE INPUT'),L111       17182000
         IKJTSMSG ('PDS112I',,' CHARACTERS IN THE LARGEST PHYSICAL BLOCX17183000
               K'),L112                                                 17184000
         IKJTSMSG ('PDS113I',,' CHARACTERS PER AVERAGE PHYSICAL BLOCK')X17185000
               ,L113                                                    17186000
         IKJTSMSG ('PDS114I',,' TRACKS COULD BE REGAINED BY COMPRESSINGX17187000
                THIS DATA SET'),L114                                    17188000
         IKJTSMSG ('PDS115I',,' MEMBERS WERE CHECKED'),L115             17189000
PROBE04  DS    0C                                                       17190000
         IKJTSMSG ('PDS116I DATA SET WAS CHECKED'),L116                 17191000
         IKJTSMSG ('PDS120I PROGRAM RESIDENCE MODE IS ',,' -- ADDRESSINX17192000
               G MODE IS ',),L120                                  @D01 17193000
         IKJTSMSG ('PDS140I ',,' RECORD',),L140                         17194000
         IKJTSMSG ('PDS141I AT ',),L141                                 17195000
         IKJTSMSG ('PDS142I ',),L142                                    17196000
         IKJTSMSG ('PDS143I ',,' DIRECTORY ENTRY, LENGTH=',),L143       17197000
         IKJTSMSG ('PDS144I DATA LINE ',,':'),L144                      17198000
         IKJTSMSG ('PDS160I ',),L160                                    17199000
         IKJTSMSG ('PDS161I ',),L161                                    17200000
         IKJTSMSG ('PDS162I ',),L162                                    17201000
         IKJTSMSG ('PDS163I ',),L163                                    17202000
         IKJTSMSG ('PDS164I ',),L164                                    17203000
         IKJTSMSG ('         ',),L169                                   17204000
         IKJTSMSG ('PDS171I COMPRESS HAS COMPLETED; RC',),L171          17205000
PROBE05  DS    0C                                                       17206000
         IKJTSMSG ('PDS180I ',),L180                                    17207000
         IKJTSMSG ('PDS181I EXTENTS IN TRACKS: ',),L181                 17208000
         IKJTSMSG ('PDS182I ',),L182                                    17209000
         IKJTSMSG ('PDS183I ',),L183                                    17210000
         IKJTSMSG ('PDS184I ',),L184                                    17211000
         IKJTSMSG ('PDS190I AN ALIAS NAMED ',,' IS ALREADY AT THIS TTR'X17212000
               ),L190                                                   17213000
         IKJTSMSG ('PDS200I ',),L200                                    17214000
         IKJTSMSG ('PDS210I ',),L210                                    17215000
         IKJTSMSG ('PDS220I ',),L220                                    17216000
         IKJTSMSG ('PDS230I ',),L230                                    17217000
         IKJTSMSG ('PDS262I ',),L262                               @D04
         SPACE 2                                                        17218000
** WARNING MESSAGES                                                     17219000
         IKJTSMSG ('PDS400W NO MEMBERS ARE IN THE DATA SET'),L400       17220000
         IKJTSMSG ('PDS401W NO MEMBER NAMES ARE IN THIS RANGE'),L401    17221000
         IKJTSMSG ('PDS402W NO MEMBER NAMES MATCH THIS PATTERN'),L402   17222000
         IKJTSMSG ('PDS441W ',,' (WEAK)'),L441                     @D01
         IKJTSMSG ('PDS442W ',,' (MISSING)'),L442                  @D01
         IKJTSMSG ('PDS450W ONE EXTRA PADDING DIRECTORY BLOCK WILL BE AX17223000
               DDED'),L450                                              17224000
PROBE06  DS    0C                                                       17225000
         IKJTSMSG ('PDS451W ALL MEMBERS IN THIS PDS WILL BE LOST'),    X17226000
               L451                                                     17227000
         IKJTSMSG ('PDS460W NO HISTORY DATA IS AVAILABLE'),L460         17228000
         IKJTSMSG ('PDS470W THE PROGRAM IS PROBABLY IN A LOOP'),L470    17229000
         IKJTSMSG ('PDS480W COMPRESS IS IN PROGRESS'),L480              17230000
         IKJTSMSG ('PDS480W COMPRESS MAY NOT BE INTERRUPTED'),L481      17231000
         IKJTSMSG ('PDS482W BLOCKSIZE SHOULD BE EVENLY DIVISIBLE BY THEX17232000
                DCB LRECL'),L482                                        17233000
         IKJTSMSG ('PDS510W THIS IS A NULL MEMBER'),L510                17234000
         IKJTSMSG ('PDS520W NO INFORMATION IS AVAILABLE'),L520          17235000
         IKJTSMSG ('PDS530W THIS DATA SET IS NOT PARTITIONED'),L530     17236000
         SPACE 2                                                        17237000
** ERROR MESSAGES                                                       17238000
         IKJTSMSG ('PDS700E THIS RANGE OF NAMES IS INVALID'),L700       17239000
         IKJTSMSG ('PDS701E THIS DATA SET IS NOT A LOAD LIBRARY'),L701  17240000
         IKJTSMSG ('PDS702E THIS DATA SET IS A LOAD LIBRARY'),L702      17241000
         IKJTSMSG ('PDS703E THIS MODULE HAS NO EXTERNAL SYMBOLS'),L703  17242000
         IKJTSMSG ('PDS704E MODULE ',,' HAS NO EXTERNAL SYMBOLS'),L704  17243000
PROBE07  DS    0C                                                       17244000
         IKJTSMSG ('PDS710E INVALID APF INFORMATION FORMAT; MEMBER IS AX17245000
               SSUMED NOT AUTHORIZED'),L710                             17246000
         IKJTSMSG ('PDS720E NOT APF AUTHORIZED; THE APF DATA IS MISSINGX17247000
               '),L720                                                  17248000
         IKJTSMSG ('PDS721E NOT APF AUTHORIZED; THE APF DATA IS THE WROX17249000
               NG LENGTH'),L721                                         17250000
         IKJTSMSG ('PDS722E THE APF DATA CAN NOT BE CHANGED'),L722      17251000
         IKJTSMSG ('PDS723E THE RLD/CONTROL COUNT CAN NOT BE CHANGED'),X17252000
               L723                                                     17253000
         IKJTSMSG ('PDS724E RMODE AND AMODE CAN NOT BE CHANGED -- OBSOLX17254000
               ETE LINKAGE-EDITOR'),L724                                17255000
         IKJTSMSG ('PDS726E PAGE ALIGNMENT CAN NOT BE CHANGED -- OBSOLEX17256000
               TE LINKAGE-EDITOR'),L726                                 17257000
         IKJTSMSG ('PDS730E THIS SUBCOMMAND IS NOT OPERATIONAL; YOU AREX17258000
                ALREADY UNDER SPF'),L730                                17259000
         IKJTSMSG ('PDS731E SPF IS NOT OPERATIONAL NOW'),L731           17260000
         IKJTSMSG ('PDS732E CLIST PROCESSING IS NOT SUPPORTED FROM ISPMX17261000
               ODE OR MEMLIST'),L732                                    17262000
         IKJTSMSG ('PDS740E THIS MODULE HAS NO MATCHING EXTERNAL SYMBOLX17263000
               S'),L740                                                 17264000
         IKJTSMSG ('PDS750E A REQUIRED NOTELIST POINTER WAS NOT FOUND IX17265000
               N THIS MEMBER'),L750                                     17266000
         IKJTSMSG ('PDS751E A NOTELIST RECORD COULD NOT BE FOUND FOR THX17267000
               IS MEMBER'),L751                                         17268000
         IKJTSMSG ('PDS752E THE NUMBER OF DESIRED DIRECTORY BLOCKS MUSTX17269000
                BE SPECIFIED'),L752                                     17270000
         IKJTSMSG ('PDS770E THE FIRST FIND SUBCOMMAND MUST CONTAIN A STX17271000
               RING'),L770                                              17272000
PROBE08  DS    0C                                                       17273000
         IKJTSMSG ('PDS771E ',,' IS AN INVALID SUBCOMMAND; ENTER "HELP"X17274000
                OR "OPTIONS" FOR HELP'),L771                            17275000
         IKJTSMSG ('PDS780E ',,' DCB OPEN ERROR -- REALLOCATE AND TRY AX17276000
               GAIN'),L780                                              17277000
         IKJTSMSG ('PDS781E ',,' DCB ATTRIBUTES CONFLICT -- USE SEQUENTX17278000
               IAL WITH RECFM=FB AND LRECL=80'),L781                    17279000
         IKJTSMSG ('PDS800E NO LOAD MODULE TEXT WAS FOUND FOR MEMBER'),X17280000
               L800                                                     17281000
         IKJTSMSG ('PDS801E END OF MEMBER SIMULATED -- REMAINDER OF TRAX17282000
               CK SKIPPED'),L801                                        17283000
         IKJTSMSG ('PDS802E A MAIN MEMBER NAMED ',,' IS ALREADY AT THISX17284000
                TTR'),L802                                              17285000
         IKJTSMSG ('PDS804E RESTORE ABANDONED'),L804                    17286000
         IKJTSMSG ('PDS805E INVALID LOAD MODULE DATA'),L805             17287000
         IKJTSMSG ('PDS811E RECORD LENGTH',,' IS INVALID'),L811         17288000
         IKJTSMSG ('PDS812E BLOCK LENGTH OF',,' EXCEEDS THE DATA SET DCX17289000
               B BLKSIZE'),L812                                         17290000
         IKJTSMSG ('PDS813E RECORD LENGTH OF',,' EXCEEDS THE MAXIMUM DCX17291000
               B LRECL'),L813                                           17292000
         IKJTSMSG ('PDS814E BLOCK LENGTH OF',,' IS NOT DIVISIBLE BY THEX17293000
                DCB LRECL'),L814                                        17294000
         IKJTSMSG ('PDS820E THIS MEMBER IS AN ALIAS FOR ',,' BUT IT POIX17295000
               NTS TO ',),L820                                          17296000
PROBE09  DS    0C                                                       17297000
         IKJTSMSG ('PDS821E RMODE ENTRY DOES NOT CORRESPOND WITH MEMBERX17298000
                ',),L821                                                17299000
         IKJTSMSG ('PDS822E MAIN AMODE ENTRY DOES NOT CORRESPOND WITH MX17300000
               EMBER ',),L822                                           17301000
         IKJTSMSG ('PDS823E RLD/CONTROL COUNT DOES NOT CORRESPOND WITH X17302000
               MEMBER ',),L823                                          17303000
         IKJTSMSG ('PDS824E DUPLICATE MEMBER NAME -- IGNORED'),L824     17304000
         IKJTSMSG ('PDS825E MEMBER NAME IS OUT OF SEQUENCE -- IGNORED')X17305000
               ,L825                                                    17306000
         IKJTSMSG ('PDS826E THE DIRECTORY RLD/CONTROL COUNT DOES NOT MAX17307000
               TCH THE FIRST RLD ENTRY'),L826                           17308000
         IKJTSMSG ('PDS827E ',,' IS AN ALIAS FOR THIS MEMBER BUT IT POIX17309000
               NTS TO ',),L827                                          17310000
         IKJTSMSG ('PDS830E OBTAIN ERROR -- PROGRAM TERMINATED'),L830   17311000
         IKJTSMSG ('PDS831E UNABLE TO OPEN DATA SET'),L831              17312000
         IKJTSMSG ('PDS832E DUMMY MEMBER ADD FAILED, RC=8'),L832        17313000
         IKJTSMSG ('PDS833E DUMMY MEMBER DELETE FAILED, RC=8'),L833     17314000
         AIF   (&MVT).MA01940                                      @D01
         IKJTSMSG ('PDS834E ERROR IN GENERAL FAIL SERVICE ROUTINE;  R15X17315000
               ',),L834                                                 17316000
         AGO   .NA01940                                            @D01
.MA01940 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS834E ERROR IN PARSE SERVICE ROUTINE;  R15',),   +
               L834                                                @D01
.NA01940 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS835E ERROR IN DAIRFAIL SERVICE ROUTINE;  R15',),X17317000
               L835                                                     17318000
         IKJTSMSG ('PDS836E I/O ERROR IN DIRECTORY'),L836               17319000
PROBE10  DS    0C                                                       17320000
         IKJTSMSG ('PDS840E INVALID HEXADECIMAL STRING LENGTH'),L840    17321000
         IKJTSMSG ('PDS841E INVALID HEXADECIMAL CHARACTERS'),L841       17322000
         IKJTSMSG ('PDS842E THIS SEARCH STRING IS TOO LONG'),L842       17323000
         IKJTSMSG ('PDS843E ONLY DISK DATA SETS ARE SUPPORTED'),L843    17324000
         IKJTSMSG ('PDS844E FILE(',,') HAS CONCATENATED DATA SETS -- ONX17325000
               LY INDIVIDUAL DATA SETS ARE SUPPORTED'),L844             17326000
         IKJTSMSG ('PDS850E ',,' IS BEING UPDATED BY ',),L850           17327000
         IKJTSMSG ('PDS851E THIS DATA SET IS BEING UPDATED BY ',),L851  17328000
         IKJTSMSG ('PDS852E ',,' ALREADY EXISTS'),L852                  17329000
         IKJTSMSG ('PDS853E ',,' NOT FOUND'),L853                       17330000
         IKJTSMSG ('PDS854E ',,' IS AN INVALID MEMBER NAME'),L854       17331000
         IKJTSMSG ('PDS855E THE DATA SET DIRECTORY IS FULL AND MEMBERS X17332000
               CANNOT BE ADDED'),L855                                   17333000
         IKJTSMSG ('PDS860E MEMBER IS AN ALIAS BUT NO MAIN MEMBER EXISTX17334000
               S'),L860                                                 17335000
PROBE11  DS    0C                                                       17336000
         IKJTSMSG ('PDS861E THE ALIAS DIRECTORY ENTRY NOTES THE MAIN ENX17337000
               TRY NAME AS ',),L861                                     17338000
         IKJTSMSG ('PDS862E ERROR IN GQSCAN DATA'),L862                 17339000
         IKJTSMSG ('PDS864E ',,' IS AN APPARENT ALIAS FOR THIS MEMBER')X17340000
               ,L864                                                    17341000
         IKJTSMSG ('PDS865E THE IEBCOPY OUTPUT CAN NOT BE OPENED'),L865 17342000
         IKJTSMSG ('PDS870E PDS DIRECTORIES MUST BE CONTAINED IN ONE EXX17343000
               TENT'),L870                                              17344000
         IKJTSMSG ('PDS871E A TTR FOR THIS MEMBER WAS NOT FOUND'),L871  17345000
         IKJTSMSG ('PDS872E THIS MEMBER IS AFTER THE DATA SET END-OF-FIX17346000
               LE'),L872                                                17347000
         IKJTSMSG ('PDS873E TTR IS BEYOND THE USED PORTION OF THE DATA X17348000
               SET'),L873                                               17349000
         IKJTSMSG ('PDS874E TSO COMMAND NAME IS INVALID'),L874          17350000
         IKJTSMSG ('PDS875E THIS DATA SET HAS NO DIRECTORY BLOCKS'),   X17351000
               L875                                                     17352000
         IKJTSMSG ('PDS876E A DIRECTORY RECORD HAS AN INCORRECT LENGTH X17353000
               (NOT 256 CHARACTERS)'),L876                              17354000
         IKJTSMSG ('PDS877E INVALID SUBCOMMAND NAME'),L877              17355000
PROBE12  DS    0C                                                       17356000
         IKJTSMSG ('PDS880E RESIDENCE MODE ANY AND ADDRESSING MODE ',, X17357000
               ' ARE INCOMPATIBLE'),L880                                17358000
         IKJTSMSG ('PDS881E REENTRANT ATTRIBUTE CONFLICTS WITH NOT REUSX17359000
               ABLE'),L881                                              17360000
         IKJTSMSG ('PDS882E TEST ATTRIBUTE CONFLICTS WITH NOT EDIT'),  X17361000
               L882                                                     17362000
         IKJTSMSG ('PDS883E REUSABLE ATTRIBUTE CONFLICTS WITH SCATTER')X17363000
               ,L883                                                    17364000
         IKJTSMSG ('PDS884E OVERLAY ATTRIBUTE CONFLICTS WITH ',),L884   17365000
         IKJTSMSG ('PDS892E READ MULTIPLE FAILED'),L892                 17366000
         IKJTSMSG ('PDS910E TSO COMMAND ',,' IS NOT ALLOWED'),L910      17367000
         AIF   (NOT &MVT).MA01960                                  @D01
         IKJTSMSG ('PDS911E TSO COMMAND ',,' NOT FOUND'),L911      @D01
.MA01960 ANOP  ,                                                   @D01
         IKJTSMSG ('PDS920E SUBCOMMAND ',,' IS NOT ALLOWED FOR THIS DATX17368000
               A SET'),L920                                             17369000
         IKJTSMSG ('PDS930E ',,' IS AN INVALID SUBCOMMAND ABBREVIATION'X17370000
               ),L930                                                   17371000
         IKJTSMSG ('PDS990E EXTENT INITIALIZATION READ FAILED'),L990    17372000
         IKJTSMSG ('PDS991E PERMANENT I/O ERROR AT TTR=',),L991         17373000
         IKJTSMSG ('PDS998E ABEND ',,' LOADING THIS MODULE'),L998       17374000
         IKJTSMSG ('PDS999E ABEND ',),L999                              17375000
         PRINT GEN                                                      17376000
***TEST  IKJTSMSG ('PDS123I ',,' HAS BEEN RENAMED+'),125                17377000
***TEST  IKJTSMSG (' THIS IS EXPLANATORY TEXT'),123,125                 17378000
          SPACE 2                                                       17379000
** END OF MESSAGES                                                      17380000
PROBE99  DS    0C               MUST BE THE LAST PROBE LABEL            17381000
         IKJTSMSG                                                       17382000
         PRINT NOGEN                                                    17383000
         TITLE 'P D S  --  PDS DYNAMIC AREA                    1/15/85' 17384000
WORKAREA DSECT                                                          17385000
MAINSAVE DS    18A                                                      17386000
         SPACE 1                                                        17387000
VALSAVE  DS    0A             SAVE AREA FOR VALIDITY CHECKING ROUTINES  17388000
ESDIDRSV DS    18A            SAVE AREA FOR READESD AND READIDR         17389000
ATTNSAVE DS    18A            SAVE AREA FOR ATTENTION EXIT              17390000
STAESAVE DS    18A            SAVE AREA FOR ESTAE EXIT                  17391000
         AIF ('&CISP' EQ 'NO SPF').MA01980                         @D01
SPFMAIN  DS    18A            SECONDARY SAVE AREA FOR SPF               17392000
.MA01980 ANOP  ,                                                   @D01
         SPACE 1                                                        17393000
R14SAVE  DS    A              FIRST LEVEL SAVE AREA                     17394000
R2PARSE  DS    A              BASE REGISTER SAVE AREA                   17395000
R8PARSE  DS    A              BASE REGISTER SAVE AREA                   17396000
R14PARSE DS    A              SECOND LEVEL SAVE AREA                    17397000
R14PUTT  DS    A              THIRD LEVEL SAVE AREA                     17398000
R14PUTM  DS    A              THIRD LEVEL SAVE AREA                     17399000
R14PUTL  DS    A              THIRD LEVEL SAVE AREA                     17400000
R14PUTL2 DS    4A             SECONDARY SAVE AREA FOR LOGDATA           17401000
R14PTGT  DS    A              THIRD LEVEL SAVE AREA                     17402000
R14EXCP  DS    A              THIRD LEVEL SAVE AREA                     17403000
R8EXCP   DS    A              SAVE AREA FOR THE BASE REGISTER           17404000
R14READD DS    A              THIRD LEVEL SAVE AREA                     17405000
BASES    DS    4A             PROGRAM BASE ADDRESSES                    17406000
         SPACE 1                                                        17407000
***      NOTE: KEEP THE FOLLOWING STATEMENTS TOGETHER AND IN THE        17408000
***            SAME PHYSICAL ORDER (FOR STM INSTRUCTIONS).              17409000
ADDRTEXT DS    A        * *    ADDRESS OF TEXT PASSED                   17410000
ADDRUPT  DS    A        * *    ADDRESS OF THE UPT                       17411000
ADDRPSCB DS    A        * *    ADDRESS OF THE PSCB                      17412000
ADDRECT  DS    A        * *    ADDRESS OF THE ECT                       17413000
ADDRCBUF DS    A        * *    ADDRESS OF THE COMMAND BUFFER            17414000
ADDRCPPL DS    A        * *    ADDRESS OF THE CPPL                      17415000
ADDRPUTL DS    A        * *    ADDRESS OF IKJPUTL                       17416000
ADDRPARS DS    A        * *    ADDRESS OF IKJPARS                       17417000
ADDRPTGT DS    A        * *    ADDRESS OF IKJPTGT                       17418000
ADDRGETL DS    A        * *    ADDRESS OF IKJGETL                       17419000
ADDRSCAN DS    A        * *    ADDRESS OF IKJSCAN                       17420000
ADDRSTCK DS    A        * *    ADDRESS OF IKJSTCK                       17421000
ADDRDEFT DS    A        * *    ADDRESS OF IKJEHDEF                      17422000
ADDRFF02 DS    A        * *    ADDRESS OF IKJEFF02                      17423000
ADDRCNVT DS    A        * *    TTR --> MBBCCHHR CONVERT ROUTINE         17424000
ADDRRLTV DS    A        * *    MBBCCHHR --> TTR CONVERT ROUTINE         17425000
         AIF   (NOT &MVT).MA02000                                  @D01
ADDRDAIR DS    A        * *    ADDRESS OF IKJDAIR                  @D01
.MA02000 ANOP  ,                                                   @D01
***                                                                     17426000
         SPACE 1                                                        17427000
ADDRANSR DS    A                                                        17428000
OPENLIST DS    2A                                                       17429000
PARMLIST DS    12A            GENERAL PARAMETER LIST                    17430000
PUTLPARM DS    4A             $PUTLINE PARAMETER AREA                   17431000
PTGTPARM DS    4A             $PUTGET PARAMETER AREA                    17432000
YESNOSV  DS    A              SAVED MESSAGE ADDRESS FOR YES/NO PROMPTS  17433000
SCANANSR DS    XL8                                                      17434000
PUTOLD1  DS    3F                                                       17435000
PAGESIZE DS    F              LINES/SCREEN                              17436000
LINESIZE DS    F              CHARACTERS/LINE                           17437000
DIRTRACK DS    F              NUMBER OF DIRECTORY BLOCKS PER TRACK      17438000
PDSENTRY DS    F              NUMBER OF ENTRIES TO PDS AFTER FIRST      17439000
         EJECT                                                          17440000
SUBCMNDP DS    A              SUBCOMMAND ENTERED ON PRIMARY LINE        17441000
ATTNECB  DS    F                                                        17442000
SUBSECB  DS    F                                                        17443000
SUBSTCB  DS    F                                                        17444000
RECOVER  DS    A                                                        17445000
         AIF ('&CISP' EQ 'NO SPF').MA02020                         @D01
SPFECB   DS    F                                                        17446000
SPFTCB   DS    A                                                        17447000
ISPLINK  DS    A              ADDRESS OF THE SPF INTERFACE ROUTINE      17448000
.MA02020 ANOP  ,                                                   @D01
DAIRRC   DS    F              DAIR RETURN CODE FROM REGISTER 15         17449000
RETURNCD DS    F              PROGRAM RETURN CODE                       17450000
OUTMEMBS DS    A              ROOT OF DUPLICATE MEMBER NAME LIST        17451000
SUBPDIAL DS    A              SUBPOOL AND ADDRESS OF SP 78 DATA         17452000
         SPACE 1                                                        17453000
UCBADDR  DS    A                                                        17454000
EXCPBUFF DS    A                  ADDRESS OF LAST RECORD READ           17455000
DSORG    DS    H                                                        17456000
LRECL    DS    H                                                        17457000
BLKSI    DS    H                                                        17458000
LABLRECL DS    H                                                        17459000
         SPACE 1                                                        17460000
TOTBLOCK DS    H        **  --   THIS AREA IS CLEARED                   17461000
TOTUSED  DS    H        **  --     VIA AN XC INSTRUCTION                17462000
TOTMEMR  DS    H        **  --     (LENGTH IS LTOT).                    17463000
TOTMEMA  DS    H        **  --                                          17464000
TOTMAXM  DS    H        **  --                                          17465000
TOTTHISM DS    H        **  --                                          17466000
TOTTRKS  DS    H        **  --                                          17467000
TOTCCHH  DS    XL4      **  --                                          17468000
LTOT     EQU   *-TOTBLOCK        LENGTH OF XC AREA                      17469000
DSNTOTAL DS    H                                                        17470000
DSNEMPTY DS    H                                                        17471000
TOTUSEDX DS    H                                                        17472000
TOTALLOX DS    H                                                        17473000
NUMEXT   DS    H              NUMBER OF EXTENTS                         17474000
BYTEUCB  DS    H              UCB TYPE IS THE SECOND BYTE               17475000
         SPACE 1                                                        17476000
LMEMBER1 DS    H              LENGTH OF MEMBER NAME ONE                 17477000
MEMBER1  DS    CL8            FIRST MEMBER NAME   *** TOGETHER (RENAME) 17478000
MEMBER2  DS    CL8            SECOND MEMBER NAME  *** TOGETHER (RENAME) 17479000
LMEMBER2 DS    H              LENGTH OF MEMBER NAME TWO                 17480000
         SPACE 1                                                        17481000
MEMBERD  DS    XL1,XL2,CL8,CL8,XL2                                      17482000
***      SAVE  FLAGSAA,LMEMBER1,MEMBER1,MEMBER2,LMEMBER2 FOR (GROUP)    17483000
MEMBERP  DS    XL1,XL2,CL8,CL8,XL2                                      17484000
***      SAVE  FLAGSAA,LMEMBER1,MEMBER1,MEMBER2,LMEMBER2 FOR PATTERN    17485000
         SPACE 1                                                        17486000
ERRORMSG DS    5CL3           HOLD AREA FOR ERROR MESSAGE IDENTIFIERS   17487000
DSPALLOC DS    X              CURRENT DISPOSITION (SHARE OR OLD)        17488000
DSPREQST DS    X              INITIAL DISPOSITION (SHARE OR OLD)        17489000
RECFM    DS    X              DCBRECFM FOR THIS DATA SET                17490000
SUBPOOLT DS    X              TEMPORARY SUBPOOL FOR A PDS SUBCOMMAND    17491000
RESERVET DS    X              "R" WHEN A SPDSN RESERVE IS OUTSTANDING   17492000
DOUBLE   DS    D                                                        17493000
         DS    XL1            BYTE OVERRUN BY UNPK INSTRUCTION          17494000
         TITLE 'P D S  --  PDS DYNAMIC AREA -- CONTROL FLAGS   1/15/85' 17495000
FLAGSAA  DS    XL1   FLAG BYTE 1 (CLEARED FOR EACH SUBCOMMAND)          17496000
FOPTIONS EQU   X'80'          OPTIONS PRESENT WITH COMMAND              17497000
FINDMSG  EQU   X'40'          FINDMEMQ MESSAGE IS AVAILABLE             17498000
FMEMSTAR EQU   X'20'          * NOTATION USED FOR THE MEMBER NAME       17499000
FHEAD    EQU   X'10'          HEADER HAS BEEN WRITTEN                   17500000
FMEMBER1 EQU   X'08'          FIRST MEMBER FLAG                         17501000
FMEMBER2 EQU   X'04'          SECOND MEMBER FLAG                        17502000
FMEMRANG EQU   X'02'          MEMBER RANGE DESIRED                      17503000
FMEM#MEM EQU   X'01'          MEMBER GROUP IS IN PROGRESS               17504000
         SPACE 2                                                        17505000
FLAGSBB  DS    XL1   FLAG BYTE 2                                        17506000
FNOTFILE EQU   X'80'          FILE(FILENAME) NOT ENTERED                17507000
FONESHOT EQU   X'40'          SUBCOMMAND ENTERED FROM PRIMARY LINE      17508000
FLINESET EQU   X'20'          OUTPUT LINE IN PROGRESS                   17509000
FEXIST   EQU   X'10'          MEMBERS EXIST IN DATA SET                 17510000
FRANPAT  EQU   X'08'          MEMBERS EXIST IN RANGE OR PATTERN         17511000
FCMD     EQU   X'04'          SUBCOMMAND BUFFER AVAILABLE               17512000
FQUOTE   EQU   X'02'          DATA SET NAME IS QUOTED                   17513000
FNULL    EQU   X'01'          NULL LINE ENTERED                         17514000
         SPACE 2                                                        17515000
FLAGSCC  DS    XL1   FLAG BYTE 3                                        17516000
FPERMDS  EQU   X'80'          "PERM" DATA SET                           17517000
*RECOVER EQU   X'40'          DSNAME PARSE FOR DATA SET RECOVERY        17518000
FIDR     EQU   X'20'          IDR RECORDS EXIST                         17519000
F1IDR    EQU   X'10'          IDR TITLE PROCESSED                       17520000
FBLDLOK  EQU   X'08'          PREVIOUS BLDL IS STILL VALID              17521000
RECFMU   EQU   X'04'          RECORD FORMAT U                           17522000
RECFMV   EQU   X'02'          RECORD FORMAT V                           17523000
RECFMF   EQU   X'01'          RECORD FORMAT F                           17524000
         SPACE 2                                                        17525000
FLAGSDD  DS    XL1   FLAG BYTE 4                                        17526000
OVERLAP  EQU   X'80'          OUTPUT THE NEXT LINE (OVERLAPPED STRING)  17527000
DONONUM  EQU   X'40'          NUM --> NONUM FOR THE REST OF THE MEMBER  17528000
DUMP     EQU   X'20'          ** DUMP OUTPUT FORMAT                     17529000
BLOCK    EQU   X'10'          ** BLOCK OUTPUT FORMAT                    17530000
LDUMP    EQU   X'08'          ** LDUMP OUTPUT FORMAT                    17531000
LBLOCK   EQU   X'04'          ** LBLOCK OUTPUT FORMAT                   17532000
SNUM     EQU   X'02'          ** SNUM OUTPUT FORMAT                     17533000
NONUM    EQU   X'01'          ** NONUM OUTPUT FORMAT                    17534000
*NUM     EQU   X'00'          ** NUM (DEFAULT) IF NOT SNUM, NONUM,      17535000
*                                    LBLOCK, LDUMP, BLOCK OR DUMP       17536000
         EJECT                                                          17537000
FLAGSEE  DS    XL1   FLAG BYTE 5                                        17538000
FDOUBCON EQU   X'80'          NODOUBLE                                  17539000
FFULLTRK EQU   X'40'          FULLTRACK                                 17540000
FDISKTRK EQU   X'20'          DISK CAPABLE OF FULL-TRACK  ***TEST AVAIL 17541000
FMEMLIST EQU   X'10'          A LIST OF MEMBER ENTRIES                  17542000
FBKGRND  EQU   X'08'          PDS IS EXECUTING IN BACKGROUND MODE       17543000
FNOTTERM EQU   X'04'          LAST RESPONSE WAS NOT FROM THE TERMINAL   17544000
FOUTASS  EQU   X'02'          SET ON TO GET ASSOCIATE MEMBERS TOO       17545000
FDIREND  EQU   X'01'          END OF MEMBERS IN DIRECTORY REACHED       17546000
***  X'C0' IS SINGLE                                                    17547000
***  X'40' IS DOUBLE                                                    17548000
***  X'00' IS MULTIPLE                                                  17549000
         SPACE 2                                                        17550000
FLAGSFF  DS    XL1   FLAG BYTE 6                                        17551000
FSPFDIAL EQU   X'80'          PDS WAS INVOKED BY SPF AS A DIALOG        17552000
FSPFERR  EQU   X'40'          SPF INITIALIZATION FAILED                 17553000
FSPFOPT6 EQU   X'20'          EXECUTING UNDER SPF OPTION 6              17554000
FSPFCALL EQU   X'10'          SET AFTER SPF HAS BEEN CALLED ONCE        17555000
FCHANGE  EQU   X'08'          SET OFF WHEN DATA SET IS CHANGED          17556000
FNOECHO  EQU   X'04'          SET ON TO TERMINATE ECHO MODE IN OUTCOPY  17557000
FLOGWRT  EQU   X'02'          SET ON TO LOG PDS MESSAGES                17558000
         SPACE 2                                                        17559000
FLAGSGG  DS    XL1   FLAG BYTE 7                                        17560000
FALINCON EQU   X'80'          NOALIASINFO (ATTRIB AND MAP)              17561000
FTRANCON EQU   X'40'          NOTRANSLATOR (HISTORY)               @D05
FLKEDCON EQU   X'20'          NOLKEDDATE (ATTRIB)                       17563000
FPROMCON EQU   X'10'          NOPROMPT                                  17564000
FRECVCON EQU   X'08'          NORECOVER                                 17565000
FSAVEOP  EQU   X'01'          NOSAVEOPER (FOR PRINTOFF, COMPARE, ) @D05
         SPACE 2                                                        17566000
FLAGSHH  DS    XL1   FLAG BYTE 8 (NOT USED YET)                         17567000
         SPACE 2                                                        17568000
FLAGSII  DS    XL1   FLAG BYTE 9 (CLEARED FOR EACH SUBCOMMAND)          17569000
FDIRGRP  EQU   X'80'          DIRECTORY READ FOR GROUP OPERATIONS       17570000
FSINGLE  EQU   X'40'          FORCE SINGLE BUFFERING FOR SUBCOMMAND     17571000
FNOTDOUB EQU   X'20'          FORCE SINGLE OR MULTIPLE FOR RESTORE SCAN 17572000
FATTNPRO EQU   X'08'          SET FOR ATTENTION PROCESSING              17573000
FMEMFRST EQU   X'01'          FIRST ELEMENT OF THE LIST IS INPUT        17574000
         SPACE 2                                                        17575000
FLAGSJJ  DS    XL1   FLAG BYTE 10 (MAINTAINED FOR DSNAME MESSAGE)       17576000
FTSOCMD  EQU   X'80'        VERIFY TSO COMMAND                          17577000
FSUBCMD  EQU   X'40'        VERIFY SUBCOMMAND                           17578000
FDSNMSG  EQU   X'03'        DSN SUBCOMMAND USES MSG (OR TABLE) FORMAT   17579000
FDSNTSO  EQU   X'02'        DSN SUBCOMMAND USES TSO FORMAT              17580000
FDSNJCL  EQU   X'01'        DSN SUBCOMMAND USES JCL FORMAT              17581000
         SPACE 2                                                        17582000
FLAGSSS  DS    XL1   FLAG BYTE 11 (MAINTAINED TO RE-INVOKE SPF SERVICE) 17583000
HFLAGSDD DS    XL1   FLAG BYTE 12 (HOLD AREA FOR FLAGSDD)               17584000
         TITLE 'P D S  --  PDS DYNAMIC AREA                    1/15/85' 17585000
DSNLEN   DS    H                                                        17586000
DSNAME   DS    CL44                                                     17587000
DSNMEMQ  DS    CL8                                                      17588000
PASSWORD DS    CL8                                                      17589000
VOLUME   DS    CL8                                                      17590000
SAVLEN   EQU   *-DSNLEN                                                 17591000
         SPACE 1                                                        17592000
SAVDSN   DS    XL1,XL2,XL44,XL8,XL8,XL8                                 17593000
*        DSN DISPOSITION, DSN LENGTH, DSN, ENQ MEMBER, PASSWORD, VOLUME 17594000
         SPACE 1                                                        17595000
PDSNAME  DS    CL8                      PDS ACTUAL COMMAND NAME         17596000
DDNAME   DS    CL8                                                      17597000
DDNAMEH  DS    CL8                      DDNAME HOLD                     17598000
DSNAMEH  DS    CL4                      FIRST FOUR DSNAME CHARACTERS    17599000
VOLALLOC DS    CL6                      ALLOCATED DISK VOLUME NAME      17600000
PDSNAML  DS    XL1                      PDS command name length    @D01
MODESAVE DS    CL1                      RMODE/AMODE WORK AREA           17601000
MSGENTDS DS    CL115                    ENTER OPTION MESSAGE            17602000
MSGENTPT DS    F                        WHERE GRP=... GOES              17603000
         SPACE 1                                                        17604000
         DS    0D                                                       17605000
MSGTEXT1 DS    XL124,XL136       4 BYTE COUNT AND 256 BYTE DISPLAY      17606000
MSGTEXT2 DS    XL124,XL12                                               17607000
         SPACE 1                                                        17608000
INSERT#1 EQU   MSGTEXT1+8,40     FIRST INSERT AREA                      17609000
INSERT#2 EQU   MSGTEXT1+64,40    SECOND INSERT AREA                     17610000
MSGLINE  EQU   MSGTEXT1+136,256  256 BYTES +4 BYTE LENGTH FIELD         17611000
MSGLAST  DS    XL80              PUTLINE AND PUTGET RECORD I/O BUFFER   17612000
         SPACE 2                                                        17613000
FULLWORD DS    0D,F                                                     17614000
         AIF ('&CISP' EQ 'NO SPF').MA02040                         @D01
ISPFTEXT DC    C'ISPF    PGM(12345678)    PARM(++12345678) NEWAPPL(ISR)X17615000
                    '      COULD ZAP TO CHANGE "NEWAPPL(ISR)" OR "TEST" 17616000
.MA02040 ANOP  ,                                                   @D01
         SPACE 1                                                        17617000
RLDCOUNT DS    X               RLD/CONTROL RECORDS AFTER FIRST TEXT     17618000
         SPACE 1                                                        17619000
WORKTBL  DS    XL256  ***      TRT TABLE (FIND FIRST BYTE) & WORK AREA  17620000
M99RBPTR DS    A      ***      REQUEST BLOCK POINTER                    17621000
M99RB    DS    5A     ***      DYNALLOC REQUEST BLOCK                   17622000
M99TUPL  DS    A      ***      TEXT UNIT POINTER                        17623000
M99TUNIT DS    3A     ***      TEXT UNIT (MAY OVERFLOW BY 50)           17624000
DAYTABLE DS    XL12                                                     17625000
FINDMEMQ DS    CL38                                                     17626000
         SPACE 2                                                        17627000
         ORG   WORKTBL                                                  17628000
TIMEWRKW DS    F                                                        17629000
TIMEDOUB DS    0D                                                       17630000
TIMEINYR DS    0ZL6,ZL4             WEEKDAY ARGUMENT                    17631000
TIMEINMT DS    ZL2                                                      17632000
TIMEINDY DS    ZL2                                                      17633000
TIMEDDAT DS    0D,XL4               BUCKET FOR PACKED DATE              17634000
TIMEDECC DS    0PL4                 MONTH AND YEAR 0YYYYMMS             17635000
TIMEDECY DS    PL3                  YEAR 0YYYYS                         17636000
         ORG   TIMEDECY+2                                               17637000
TIMEDECM DS    0PL2                 MONTH 0MMS                          17638000
TIMEYRSG DS    PL1,PL1                                                  17639000
         ORG   ,                                                        17640000
         SPACE 1                                                        17641000
FINDLTH  DS    H               ACTUAL STRING LENGTH                     17642000
FINDSTR  DS    CL16            ACTUAL FIND STRING                       17643000
PUTGETBF DS    XL256           $PUTGET INPUT LINE STORAGE               17644000
CONTFORM DS    XL6             FORM HOLD AREA FOR CONTROL               17645000
CONTDEST DS    XL10            DEST HOLD AREA FOR CONTROL               17646000
CONTSYS  DS    XL1             SYSOUT HOLD AREA FOR CONTROL             17647000
CONTOPTN DS    XL1             CONTROL OPTION IN EFFECT                 17648000
PARSPOST DS    3H              PARSE POST LINKAGE                       17649000
PARSNEXT DS    F               PARSE POST ADDRESS                       17650000
         SPACE 3                                                        17651000
         AIF ('&CISP' EQ 'NO SPF').MA02060                         @D01
         COPY  SPWRK70A        FIRST ISPMODE, MEMLIST WORK AREA         17652000
         SPACE 3                                                        17653000
.MA02060 ANOP  ,                                                   @D01
         DS    CL8             **IF BACK-LEVEL DCB MACRO                17654000
INDCB    DCB   DEVD=DA,DDNAME=X,MACRF=E,EXLST=EXLST                     17655000
STOWDCB  DCB   DSORG=PO,DEVD=DA,DDNAME=X,MACRF=(R,W),EXLST=EXLST        17656000
         DS    CL8            OVERFLOW FROM CMXDCB                      17657000
BAMDCB   DCB   DDNAME=RESET,DSORG=PS,RECFM=FB,LRECL=256,BLKSIZE=256,   X17658000
               MACRF=(W),KEYLEN=8,DEVD=DA                               17659000
QAMDCB   DCB   DSORG=PS,DDNAME=PDSOUT,MACRF=(PM),EXLST=OUT99            17660000
LOGDCB   DCB   DSORG=PS,DDNAME=PDSLOG,MACRF=(PM),EXLST=CONT990          17661000
EXLSTX   DS    A                                                        17662000
         TITLE 'P D S  --  PDS DYNAMIC AREA - POST-PROCESSING  1/15/85' 17663000
##SUBCOM DS    0F,CL8    ***  CURRENT FULL SUBCOMMAND NAME              17664000
         SPACE 1                                                        17665000
##ADRCM# EQU   *,1            OFFSET FOR SUB OPERANDS, FLAGS            17666000
CONTINUE EQU   X'80'          SUBCOMMAND CONTINUES AFTER DATA SET OPEN  17667000
FIXOPEN  EQU   X'40'          SUBCOMMAND IS FIXPDS (SPECIAL OPEN FLAG)  17668000
EDITOR   EQU   X'20'          SUBCOMMAND - EDIT, BROWSE, TSOEDIT OR FSE 17669000
EXTERNAL EQU   X'10'          SUBCOMMAND IS EXTERNAL TO PDS             17670000
FABEND   EQU   X'01'          CONTINUE IS NOT CLEARED IN STAE           17671000
FATTRHDR EQU   X'0F'          HEADER FLAG FOR ATTRIB SUBCOMMAND         17672000
##ADRCMD DS    A         ***  SUBCOMMAND PROCESSING ROUTINE             17673000
         SPACE 1                                                        17674000
##ADRPC# EQU   *,1            SUBCOMMAND FLAGS                          17675000
@Q       EQU   X'80'     QUIET MODE FOR SUBCOMMAND                      17676000
@I       EQU   X'40'+@Q  BROWSE, EDIT, AND VERIFY CHECK FOR :           17677000
@N       EQU   X'20'     OPERAND IS IGNORED IF PRESENT                  17678000
@R       EQU   X'10'     OPERAND REQUIRED, PARSE IS ALWAYS CALLED       17679000
@S       EQU   X'08'     SUBCOMMAND WORKS FOR NON-PARTITIONED DATA SETS 17680000
@G       EQU   X'04'     MEMBER GROUP AND MEMBER DEFAULT ALLOWED        17681000
@B       EQU   X'02'     BLDL REQUIRED TO VERIFY FIRST MEMBER EXISTS    17682000
@C       EQU   X'01'     SUBCOMMAND INVALIDATES BLDL                    17683000
         SPACE 1                                                        17684000
##ADRPCL DS    A         ***  PCL FOR THE SUBCOMMAND PARSE              17685000
         SPACE 1                                                        17686000
##ADRPA# EQU   *,1            ADDITIONAL SUBCOMMAND FLAGS               17687000
$F       EQU   X'80'          FINDLIST -- CONVERTS TO LIST AFTER FIND   17688000
$D       EQU   X'40'          DEFAULT MEMBER MESSAGE IS SUPPRESSED      17689000
$Q       EQU   X'20'          QUIET MODE PROCESSING FLAG                17690000
$M       EQU   X'10'          DISPLAY OR PATTERN SUBCOMMAND             17691000
$A       EQU   X'08'          DO NOT ACCEPT ATTENTIONS                  17692000
$P       EQU   X'02'          SPF PANEL NAME IN ##SUBCAL       SS NOV84 17693000
$J       EQU   X'01'+$P       SPF PANEL PARSE WITH NO MEMBERS  SS NOV84 17694000
##ADRPAR DS    A         ***  POST-PARSE PROCESSING ROUTINE             17695000
         SPACE 2                                                        17696000
##SUBCAL DS    CL8       ***  EXTERNAL TSO PROCESSOR TO ATTACH          17697000
         SPACE 2                                                        17698000
##HELOFF DS    AL2       ***  OFFSET TO HELP MESSAGE  (USED BY LIST)    17699000
         DS    AL2       ***  AVAILABLE               (USED BY LIST)    17700000
         SPACE 2                                                        17701000
##ANSWER DS    XL132          PARSE CSECT WORKAREA                      17702000
         EJECT                                                          17703000
** ALIAS, COMPRESS, CONTROL, DELETE, DIRENTRY, FIND, LIST, OUT,         17704000
**   PRINTOFF, RESTORE, REVIEW, SUBMIT AND TSOLIST SUBCOMMAND AREA:     17705000
#OUT     EQU   ##ANSWER+0,80    OUT: LOGICAL RECORD AREA                17706000
#CMXFLAG EQU   ##ANSWER+0,1     COMPRESS: SUMMARY/LIST/NOLIST           17707000
#DELFLAG EQU   ##ANSWER+0,1     DELETE: ALIAS/NOALIAS                   17708000
#RESFLAG EQU   ##ANSWER+0,1     RESTORE: REPEAT/DISPLAY/PROMPT          17709000
#CMXSHR  EQU   ##ANSWER+1,1     COMPRESS: SHR                           17710000
#CMXSYSI EQU   ##ANSWER+12,14   COMPRESS: REQUEST A DDNAME              17711000
#LISTN0  EQU   ##ANSWER+12,4    LIST: NEXT MEMBER DISPLACEMENT          17712000
#LISTN1  EQU   ##ANSWER+16,4    LIST: DISPLACEMENT IN LOAD MODULE       17713000
#RESTNUM EQU   ##ANSWER+16,4    RESTORE: COUNT OF DISPLAY RECORDS  @D01
#LISTN2  EQU   ##ANSWER+20,4    LIST: DISPLACEMENT IN CSECT             17714000
#CMXSYSP EQU   ##ANSWER+20,14   COMPRESS: REQUEST A DDNAME              17715000
*#ESDPTR  EQU  ##ANSWER+24,4    ADDRESS OF ESD DATA CHAIN               17716000
#CMXSYS3 EQU   ##ANSWER+28,14   COMPRESS: REQUEST A DDNAME              17717000
*#ACTIONT EQU  ##ANSWER+32,4    ACTION AFTER A SUCCESSFUL FIND          17718000
#RESTAPF EQU   ##ANSWER+34,1    RESTORE: APF DATA FROM LIKE             17719000
#RESTDIR EQU   ##ANSWER+35,33   RESTORE: DIRECTORY USER DATA            17720000
*#ACTIONE EQU  ##ANSWER+36,4    ACTION AFTER AN UNSUCCESSFUL FIND       17721000
#LFSAVE2 EQU   ##ANSWER+40,8    LIST/FIND SAVE AREA FOR R14 AND R15     17722000
#CMXLIST EQU   ##ANSWER+40,8    COMPRESS: IEBCOPY PARM LIST             17723000
#LFSAVE4 EQU   ##ANSWER+48,16   LIST/FIND SAVE AREA FOR R3, R4, R5 & R6 17724000
#CMXDDNA EQU   ##ANSWER+50,2    COMPRESS: LENGTH OF DDNAME LIST         17725000
#SKIPCOL EQU   ##ANSWER+64,4    COLUMNS TO SKIP FOR EACH RECORD         17726000
#SKIPREC EQU   ##ANSWER+68,4    RECORDS TO SKIP AT THE BEGINNING        17727000
#RESTSSI EQU   ##ANSWER+68,4    RESTORE: LOAD MODULE SSI DATA           17728000
#RESTLIK EQU   ##ANSWER+72,8    RESTORE: LIKE MODEL MEMBER NAME/MACRO   17729000
#SPFMACR EQU   ##ANSWER+72,8    SPFEDIT: MACRO NAME                     17730000
#BLKCNT  EQU   ##ANSWER+72,4    LIST RECORD/BLOCK COUNTER               17731000
#COMMDSZ EQU   ##ANSWER+76,2    EXTERNAL SUBCOMMAND OPERAND LENGTH      17732000
#LISTOFF EQU   ##ANSWER+76,4    LIST OFFSET                             17733000
#OUTREGS EQU   ##ANSWER+80,28   OUTCOPY REGISTER R2:R8 SAVE AREA        17734000
#RESTSEQ EQU   ##ANSWER+80,4    SEQUENTIAL MEMBER NAME COUNT            17735000
#RESTLEN EQU   ##ANSWER+84,4    MACHINE LENGTH OF ENTERED NAME          17736000
#LISTID  EQU   ##ANSWER+84,2    LIST ESDID                              17737000
#CMXDDIN EQU   ##ANSWER+84,8    COMPRESS: SYSIN DDNAME                  17738000
#LISTFLG EQU   ##ANSWER+88,1    LIST CSECT FLAG                         17739000
#ALIAESD EQU   ##ANSWER+89,1    ALIAS   MVS/XA RMODE/AMODE ESD FLAGS    17740000
#DIRSHOR EQU   ##ANSWER+89,1    DIRENTRY: SHORT/LONG               @D04
#RESTESD EQU   ##ANSWER+90,1    RESTORE MVS/XA RMODE/AMODE ESD FLAGS    17741000
#RESTMOD EQU   ##ANSWER+91,1    RESTORE MVS/XA RMODE ESD SUMMARY AREA   17742000
#LISTVIR EQU   ##ANSWER+92,4    VIRTUAL LOAD MODULE START ADDRESS       17743000
#CMXDDPR EQU   ##ANSWER+92,8    COMPRESS: SYSPRINT DDNAME               17744000
#LISTENT EQU   ##ANSWER+96,4    CURRENT ESD ENTRY                       17745000
#LISTWD  EQU   ##ANSWER+100,4   WIDTH (16 OR 64)                        17746000
#LISTE1  EQU   ##ANSWER+104,4   END OF CSECT OR EXTERNAL SYMBOL         17747000
#OUTOPTN EQU   ##ANSWER+108,1   OUTCOPY TEXT/NOTEXT                     17748000
#CMXDDT1 EQU   ##ANSWER+108,8   COMPRESS: SYSUT1 DDNAME                 17749000
#CMXDDT2 EQU   ##ANSWER+116,8   COMPRESS: SYSUT2 DDNAME                 17750000
#MAXLEN  EQU   ##ANSWER+120,4   MAXIMUM RECORD LENGTH                   17751000
#CMXDDT3 EQU   ##ANSWER+124,8   COMPRESS: SYSUT3 DDNAME                 17752000
#MAXIN   EQU   ##ANSWER+124,4   MAXIMUM RECORDS TO READ                 17753000
#MAXOUT  EQU   ##ANSWER+128,4   MAXIMUM DATA LINES TO OUTPUT            17754000
         EJECT                                                          17755000
** ATTRIB, IF, HISTORY AND MAP SUBCOMMAND AREA:                         17756000
#ZAPOPT  EQU   ##ANSWER+0,1  ** ZAP(PARTNAME)             (LOAD ONLY)   17757000
#USEROPT EQU   ##ANSWER+1,1  ** USER(PARTNAME)            (LOAD ONLY)   17758000
#TRANOPT EQU   ##ANSWER+2,1  ** TRAN(PARTNAME)            (LOAD ONLY)   17759000
#LKEDOPT EQU   ##ANSWER+3,1  ** LKED(PARTNAME)            (LOAD ONLY)   17760000
#MODOPT  EQU   ##ANSWER+4,1  ** MODULE(PARTNAME)          (LOAD ONLY)   17761000
#RLDERR  EQU   ##ANSWER+5,1  ** RLDERR/NORLDERR           (LOAD ONLY)   17762000
#ATTRYES EQU   ##ANSWER+6,2  ** BITS ON FOR ATTR/IF       (LOAD ONLY)   17763000
#ATTRNO  EQU   ##ANSWER+8,2  ** BITS OFF FOR ATTR/IF      (LOAD ONLY)   17764000
#AUTHOPT EQU   ##ANSWER+10,1 ** AUTH/NOAUTH               (LOAD ONLY)   17765000
#PAGEOPT EQU   ##ANSWER+11,1 ** PAGE/NOPAGE               (LOAD ONLY)   17766000
#RMODE   EQU   ##ANSWER+12,1 ** RMODE24/RMODEANY          (LOAD ONLY)   17767000
#AMODE   EQU   ##ANSWER+13,1 ** AMODE24/AMODE31/AMODEANY  (LOAD ONLY)   17768000
#VSLKED  EQU   ##ANSWER+14,1 ** VSLKED/NOVSLKED           (LOAD ONLY)   17769000
#LOADERR EQU   ##ANSWER+15,1 ** LOADERR/NOLOADERR         (LOAD ONLY)   17770000
#LKEDERR EQU   ##ANSWER+16,1 ** CONFLICT/NOCONFLICT       (LOAD ONLY)   17771000
#RLD0    EQU   ##ANSWER+17,1 ** RLDZERO/NORLDZERO         (LOAD ONLY)   17772000
#APFERR  EQU   ##ANSWER+18,1 ** APFERR/NOAPFERR           (LOAD ONLY)   17773000
#MODLEN  EQU   ##ANSWER+19,1    PARTNAME LENGTH FOR MODULE(..           17774000
#MAPOPT  EQU   ##ANSWER+20,1    SHORT/FULL/ENTRY                        17775000
#ALIAOPT EQU   ##ANSWER+21,1    ALIAS/NOALIAS                           17776000
#USERIDO EQU   ##ANSWER+22,1    USERID(PUSER)/NOTUSERID(PUSER)/NOUSERID 17777000
#OPTOPT  EQU   ##ANSWER+23,1    PROCESSING OPTIONS SUMMARY              17778000
#ESDPTR  EQU   ##ANSWER+24,4    ADDRESS OF ESD DATA CHAIN               17779000
#IDRPTR  EQU   ##ANSWER+28,4    ADDRESS OF IDR DATA CHAIN               17780000
#ACTIONT EQU   ##ANSWER+32,4    ACTION AFTER A SUCCESSFUL FIND          17781000
#ACTIONE EQU   ##ANSWER+36,4    ACTION AFTER AN UNSUCCESSFUL FIND       17782000
#ATTRLO  EQU   ##ANSWER+40,3    LOWER TTR LIMIT FROM TTR(LOW:HIGH)      17783000
#ATTRHI  EQU   ##ANSWER+43,3    UPPER TTR LIMIT FROM TTR(LOW:HIGH)      17784000
#ZAPLEN  EQU   ##ANSWER+46,1 ** PARTNAME LENGTH FOR ZAP(..              17785000
#USERLEN EQU   ##ANSWER+47,1 ** PARTNAME LENGTH FOR USER(..             17786000
#TRANLEN EQU   ##ANSWER+48,1 ** PARTNAME LENGTH FOR TRAN(..             17787000
#LKEDLEN EQU   ##ANSWER+49,1    PARTNAME LENGTH FOR LKED(..             17788000
#USERIDL EQU   ##ANSWER+50,1    USERID(NAME) LENGTH                     17789000
#SSIOPT  EQU   ##ANSWER+51,1    SSI/NOSSI                               17790000
#IFABOVE EQU   ##ANSWER+52,4 ** ABOVE(COUNT)           (MAYBE READ)     17791000
#IFBELOW EQU   ##ANSWER+56,4 ** BELOW(COUNT)           (MAYBE READ)     17792000
#IOERROR EQU   ##ANSWER+60,1 ** IOERROR/NOIOERROR      (IMPLIES READ)   17793000
#BLOCKER EQU   ##ANSWER+61,1 ** BLOCKERR/NOBLOCKERR    (IMPLIES READ)   17794000
#LRECLER EQU   ##ANSWER+62,1 ** LRECLERR/NOLRECLERR    (IMPLIES READ)   17795000
#NULL    EQU   ##ANSWER+63,1 ** NULL/NONULL            (IMPLIES READ)   17796000
#AALIAS  EQU   ##ANSWER+64,1    APPARENTALIAS/NOAPPARENTALIAS           17797000
#ORPHAN  EQU   ##ANSWER+65,1    ORPHAN/NOORPHAN                         17798000
#SPFEDIT EQU   ##ANSWER+66,1    SPFEDIT/NOSPFEDIT                       17799000
#NAMEERR EQU   ##ANSWER+67,1    NAMEERR/NONAMEERR                       17800000
#LKEDTXT EQU   ##ANSWER+68,10   LKED(NAME) TEXT                         17801000
#IFLEN   EQU   ##ANSWER+68,4    LENGTH OF MODULE OR NUMBER OF LINES     17802000
#TRANTXT EQU   ##ANSWER+78,10   TRAN(NAME) TEXT                         17803000
*** AVAILABLE  ##ANSWER+88,4 *** ***                                    17804000
#SSITEXT EQU   ##ANSWER+92,4    SSI(ABCDABCD) CONVERTED TEXT            17805000
#MODTXT  EQU   ##ANSWER+96,8    MODULE(NAME) TEXT                       17806000
#IFMODIF EQU   ##ANSWER+104,6   IF CHANGED(84047:84050)                 17807000
#IFCREIF EQU   ##ANSWER+110,6   IF CREATED(84047:84050)                 17808000
#ZAPTXT  EQU   ##ANSWER+116,8   ZAP(NAME) TEXT                          17809000
#USERTXT EQU   ##ANSWER+124,8   USER(NAME)/USERID(USERID7) TEXT         17810000
         EJECT                                                          17811000
** EDIT, FIXPDS, FSE, RENAME, SPFEDIT AND VERIFY SUBCOMMAND AREA:       17812000
#FIXOPT  EQU   ##ANSWER+0,1     FIXPDS  EXPANDDIR/RESETDIR/DCB          17813000
#EDITOLD EQU   ##ANSWER+0,1     TSOEDIT OLD/NEW                         17814000
#SPFOLD  EQU   ##ANSWER+0,1     EDIT    OLD/NEW                         17815000
#VERLOAD EQU   ##ANSWER+0,1     VERIFY  LOAD/NOLOAD                     17816000
#FIXOPT2 EQU   ##ANSWER+1,1     FIXPDS  RELEASE/RESERVE                 17817000
#VERUPDT EQU   ##ANSWER+1,1     VERIFY  UPDATE/NOUPDATE                 17818000
#EDITNON EQU   ##ANSWER+1,1     EDIT    NONUM                           17819000
#EDITASI EQU   ##ANSWER+2,1     EDIT    ASIS                            17820000
#RESTERR EQU   ##ANSWER+2,2     RESTORE CONSECUTIVE I/O ERRORS          17821000
#VERREAD EQU   ##ANSWER+2,1     VERIFY  READ/NOREAD                     17822000
#VERSTND EQU   ##ANSWER+3,1     VERIFY  STANDARD/NOSTANDARD             17823000
#FIXRES  EQU   ##ANSWER+4,4     FIXPDS  RESERVE QUANTITY                17824000
#VERSTAT EQU   ##ANSWER+4,1     VERIFY  STATS/NOSTATS                   17825000
#EDITTYP EQU   ##ANSWER+4,4     EDIT    TYPE (CNTL, ASM, OR ...)        17826000
#VERMBR  EQU   ##ANSWER+8,8     VERIFY  MEMBER NAME                     17827000
#RECFM   EQU   ##ANSWER+8,4     RECORD FORMAT DESIRED FOR FIXPDS        17828000
#LRECL   EQU   ##ANSWER+12,4    LRECL DESIRED FOR FIXPDS                17829000
#BLKSI   EQU   ##ANSWER+16,4    BLKSIZE DESIRED FOR FIXPDS              17830000
#NEWDIR  EQU   ##ANSWER+20,4    DIRECTORY BLOCKS DESIRED FOR FIXPDS     17831000
#MEMPTR  EQU   ##ANSWER+24,4    BASE FOR THE MEMBER NAME LIST           17832000
#MEMBLKE EQU     X'08'            BLKSIZE TOO LARGE                     17833000
#MEMDIVE EQU     X'04'            BLKSIZE/LRECL NOT INTEGRAL            17834000
#MEMLRLE EQU     X'02'            LRECL TOO LARGE                       17835000
#MEMLRL0 EQU     X'01'            LRECL NEGATIVE OR ZERO                17836000
#MEMLAST EQU   ##ANSWER+28,4    END OF MEMBER LIST POINTER              17837000
#NOTEPTR EQU   ##ANSWER+28,4    BASE FOR THE NOTELIST                   17838000
#RENSWAP EQU   ##ANSWER+28,1    SWAP/NOSWAP FOR RENAME                  17839000
#RENRANG EQU   ##ANSWER+29,1    RANGE/NORANGE FOR RENAME                17840000
#RENDEFT EQU   ##ANSWER+30,21   FLAGS, L1, M1, M2, L2 FOR RENAME        17841000
#MEMCNT  EQU   ##ANSWER+32,4    COUNT OF RECORDS IN THIS MEMBER         17842000
#FINDTTR EQU   ##ANSWER+32,4    LAST MEMBER TTR                         17843000
#SAVEREG EQU   ##ANSWER+36,4*7  REGISTER SAVE AREA                      17844000
#FIXTTRI EQU   ##ANSWER+36,4    LAST INPUT TTR                          17845000
#FIXTTRO EQU   ##ANSWER+40,4    LAST OUTPUT TTR                         17846000
#EOF1TTR EQU   ##ANSWER+44,4    TTR OF ORIGINAL DIRECTORY EOF           17847000
#EOF2TT  EQU   ##ANSWER+48,4    TT OF NEW DIRECTORY EOF                 17848000
#DIRFIX  EQU   ##ANSWER+52,12   TEMPORARY STOW AND DELETE MEMBER        17849000
#DIRBTRK EQU   ##ANSWER+64,4    NUMBER OF DIRECTORY BLOCKS PER TRACK    17850000
#VERCREC EQU   ##ANSWER+64,4    VERIFY COMPRESS TRACK RECORD NUMBER     17851000
#VERCTRK EQU   ##ANSWER+68,4    VERIFY COMPRESS TRACK NUMBER            17852000
#VERCBAL EQU   ##ANSWER+72,4    VERIFY COMPRESS TRACK BALANCE           17853000
#VERCREG EQU   ##ANSWER+76,4    VERIFY COMPRESS REGISTER SAVE           17854000
#VERCLOG EQU   ##ANSWER+80,4    VERIFY COUNT LOGICAL RECORDS            17855000
#VERCBLK EQU   ##ANSWER+84,4    VERIFY COUNT PHYSICAL BLOCKS            17856000
#VERCBLC EQU   ##ANSWER+88,4    VERIFY COUNT PHYSICAL CHARACTERS        17857000
#VERMEM  EQU   ##ANSWER+92,8    VERIFY LAST MEMBER NAME CHANGED         17858000
#VERMAX  EQU   ##ANSWER+100,4   VERIFY MAXIMUM BLOCKSIZE READ           17859000
#VERR4   EQU   ##ANSWER+104,16  VERIFY MAXIMUM BLOCKSIZE READ           17860000
         SPACE 1                                                        17861000
#LSUB    EQU   *-##SUBCOM     RESET LENGTH FOR SUBCOMMANDS              17862000
         SPACE 3                                                        17863000
#SUBHOLD DS    CL8,3AL4,CL8,2AL2,CL132  RESET SAVE AREA FOR SUBCOMMANDS 17864000
         TITLE 'P D S  --  PDS DYNAMIC AREA                    1/15/85' 17865000
CCWS     DS    0D                                                       17866000
CCW1A    CCW   X'31',IOBSEEK-IOBSEEK+3,X'60',5  SEARCH ID EQUAL (CCHHR) 17867000
CCW2A    CCW   X'08',*-8-(*-8),X'60',1          TIC                     17868000
CCW3A    CCW   X'92',IOBSEEK-IOBSEEK+3,X'20',8  MT READ NEXT COUNT      17869000
*                                                                       17870000
CCW0     CCW   X'23',SNO-SNO,X'60',1            SET SECTOR              17871000
CCW1     CCW   X'31',IOBSEEK-IOBSEEK+3,X'60',5  SEARCH ID EQUAL (CCHHR) 17872000
CCW2     CCW   X'08',*-8-(*-8),X'60',1          TIC                     17873000
CCW3     CCW   X'0E',*-*,X'60',32768            READ KEY AND DATA       17874000
CCW4     CCW   X'08',*+8-(*+8),X'60',1          TIC (OR MT READ CKD)    17875000
CCW5     CCW   X'92',IOBSEEK-IOBSEEK+3,X'60',8  MT READ NEXT COUNT      17876000
CCW6     CCW   X'22',SNO-SNO,X'20',1            READ SECTOR NUMBER      17877000
LCCWINIT EQU   *-CCWS                                                   17878000
         SPACE 2                                                        17879000
IOB      DC    X'C2000000'                                              17880000
IOBECB   DC    A(IOECB)                                                 17881000
IOBCSW   DC    2A(0)                                                    17882000
IOBCCW   DC    A(CCW0)                                                  17883000
IOBDCB   DC    A(INDCB)                                                 17884000
         DC    2A(0)                                                    17885000
IOBSEEK  DC    2A(0)       *** NEXT MBBCCHHR ADDRESS                    17886000
KEYLN    DS    X           *** NEXT KEYLENGTH                           17887000
DATALN   DS    2X          *** NEXT RECORD LENGTH                       17888000
SNO      DS    X           *** NEXT SECTOR NUMBER                       17889000
IOECB    DS    F           *** ECB FOR EXCP                             17890000
CUREXT   DS    F           *** CURRENT DATA SET EXTENT                  17891000
LIOBDIR  EQU   *-IOBSEEK                                                17892000
         SPACE 2                                                        17893000
IODIR1   DS    A,12C,12C,2A    PRIMARY DIRECTORY GROUP INPUT CONTROL    17894000
IODIR2   DS    A 12C,12C,2A****SECONDARY DIRECTORY GROUP INPUT CONTROL  17895000
IOBUFF1  DS    A 12C,12C,2A****PRIMARY INPUT BUFFER CONTROL             17896000
IOBUFF2  DS    A 12C,12C,2A****SECONDARY INPUT BUFFER CONTROL CONTROL   17897000
         SPACE 1                                                        17898000
DIRPTRS  DS    3A              READDIR DIRECTORY POINTERS               17899000
DIRPTRS2 DS    3A              READDIR DIRECTORY POINTERS FOR GROUPS    17900000
CURMBB   DS    XL8             CURRENT MBBCCHHR ADDRESS                 17901000
CURDIR   DS    XL8             LAST DIRECTORY ADDRESS FOR A GROUP       17902000
LSTARMBB DS    XL8             DS1LSTAR IN MBBCCHHR FORMAT              17903000
EXCPCCWI DS    A               INITIAL CCW (CCW0 OR CCW1)               17904000
STARTTR  DS    F               INITIAL TTR TO READ                      17905000
LS       DS    F               CURRENT RECORD LENGTH                    17906000
         EJECT                                                          17907000
ICONTROL DS    F               POINTER TO IODIRCUR OR IOBUFCUR          17908000
IODIRCUR DS    F               CURRENT LOGICAL INPUT RECORD             17909000
IODIRADD DS    F               CURRENT CCHH ADDRESS                     17910000
IOBUFCUR DS    F               CURRENT LOGICAL INPUT RECORD             17911000
IOBUFADD DS    F               CURRENT CCHH ADDRESS                     17912000
         SPACE 2                                                        17913000
MEMNAME  DS    CL8            DIRECTORY NAME FOR READDIR                17914000
MEMTTR   DS    XL3            TTR ADDRESS FOR READDIR                   17915000
MEMFLAG  DS    X              FLAG BYTE FOR READDIR                     17916000
         SPACE 2                                                        17917000
PMEMMIN  DS    F              FIRST MEMBER LIST POINTER                 17918000
PMEMCURR DS    F              CURRENT MEMBER LIST POINTER               17919000
PMEMMAX  DS    F              LAST MEMBER LIST POINTER                  17920000
PMEMHOLD DS    F              MEMBER PROCESSING HOLD FOR ATTENTION      17921000
         SPACE 2                                                        17922000
ENTRYPT  DS    CL8            MODULE ENTRY POINT NAME                   17923000
LKEDDATE DS    XL3                                                      17924000
LKEDNAME DS    XL10                                                     17925000
LKEDVVMM DS    XL4                                                      17926000
         SPACE 3                                                        17927000
IODONE   DS    H             **  INPUT ROUTINE ENTRIES                  17928000
IODONEW  DS    H             **  NUMBER OF TTR CHANGES                  17929000
IOLOGUSE DS    H             **  INITIATED SECOND BUFFER USES           17930000
IOPHYTRK DS    H             **  NUMBER OF READ MULTIPLES               17931000
         SPACE 3                                                        17932000
DEVTYPE  DS    F             **  UCBTYPE INFORMATION                    17933000
DEVTBLK  DS    F             **  MAXIMUM BLOCKSIZE                      17934000
         DS    H             **  PHYSICAL CYLINDERS                     17935000
DEVTTRKS DS    H             **  TRACKS/CYLINDER                        17936000
DEVTMAXT DS    H             **  MAXIMUM TRACK LENGTH                   17937000
         DS    H             **  BLOCK OVERHEAD                         17938000
         DS    F             **  BLOCK OVERHEAD                         17939000
         DS    F             **  RPS DATA                               17940000
         TITLE 'P D S  --  PDS DYNAMIC AREA -- MF=L MACROS     1/15/85' 17941000
         PRINT GEN                                                      17942000
STAEPARM ESTAE *-*,CT,PARAM=*-*,MF=L                                    17943000
         SPACE 1                                                        17944000
STAXPARM STAX  *-*,REPLACE=YES,IBUF=0,OBUF=0,MF=L                       17945000
         SPACE 1                                                        17946000
         WRITE FIXPDSD,SF,*-*,*-*,'S',MF=L                              17947000
         SPACE 1                                                        17948000
*INKSFL  LINK   EPLOC=*-*,SF=L                                          17949000
         SPACE 1                                                        17950000
ATTACHS1 ATTACH EPLOC=*-*,ECB=*-*,SZERO=NO,SHSPV=78,SF=L                17951000
         SPACE 1                                                        17952000
         AIF   (&MVT).MA02080                                      @D01
ATTACHS2 ATTACH EPLOC=*-*,ECB=*-*,SZERO=NO,SHSPV=78,                  XX17953000
               TERM=YES,ESTAI=(*-*,*-*),SF=L                            17954000
         AGO   .NA02080                                            @D01
.MA02080 ANOP  ,                                                   @D01
ATTACHS2 ATTACH EPLOC=*-*,ECB=*-*,SZERO=NO,SHSPV=78,               @D01X
               STAI=(*-*,*-*),SF=L                                 @D01
.NA02080 ANOP  ,
         TITLE 'P D S  --  PDS DYNAMIC AREA                    1/15/85' 17955000
DIRLINK  DS    0F             ***   DIRECTORY AREA MAPPING  ***         17956000
BLDLLIST DS    XL4                                                      17957000
DIRNAME  DS    CL8                                                      17958000
DIRTTR   DS    XL3                                                      17959000
DIRFLAG  DS    X                                                        17960000
DIRALIAS EQU   X'80'          MEMBER IS AN ALIAS                        17961000
DIR2TTR  EQU   X'40'          TWO TTR'S TO UPDATE                       17962000
DIR1TTR  EQU   X'20'          ONE TTR TO UPDATE                         17963000
DIRUSER  DS    XL62                                                     17964000
         ORG   DIRUSER  FOLLOWING FOR LOAD MODULES                      17965000
DIRSTART DS    XL4            TTR OF FIRST TEXT BLOCK                   17966000
DIRNOTE  DS    XL3            TTR OF NOTELIST                           17967000
DIRNOTE# DS    X              NUMBER OF NOTELIST ENTRIES                17968000
DIRATTR  DS    XL2            MEMBER ATTRIBUTES                         17969000
DIRSTORE DS    XL3            SIZE OF LOAD MODULE                       17970000
DIRTEXTL DS    XL2            LENGTH OF 1ST TEXT RECORD                 17971000
DIREPA   DS    XL3            ENTRY POINT ADDRESS                       17972000
DIRATTR2 DS    X          ADDITIONAL ATTRIBUTE BYTES:                   17973000
DIRAOSLE EQU   X'80'          VS LINKAGE EDITOR CREATED THIS MODULE     17974000
DIR2BIG  EQU   X'40'          REQUIRES 16M OR MORE VIRTUAL STORAGE @D04
DIR2PAGA EQU   X'20'          PAGE ALIGNMENT REQUIRED FOR THIS MODULE   17975000
DIR2SSI  EQU   X'10'          SSI INFORMATION IS PRESENT FOR MODULE     17976000
DIRAPFLG EQU   X'08'          APF INFORMATION FOR THIS MODULE IS VALID  17977000
DIR2LFMT EQU   X'04'          MODULE IS IN PROGRAM OBJECT FORMAT   @D04
DIRATTR3 DS    X          ADDITIONAL ATTRIBUTE BYTES:                   17978000
DIRRMANY EQU   X'10'          RMODE=ANY                                 17979000
DIRAA31  EQU   X'08'          AMODE=31 (ALIAS ENTRY)               @D02
DIRAA64  EQU   X'04'          AMODE=64 (ALIAS ENTRY)               @D02
DIRAA24  EQU   X'00'          AMODE=24 (ALIAS ENTRY)               @D02
DIRAM31  EQU   X'02'          AMODE=31 (MAIN ENTRY)                @D02
DIRAM64  EQU   X'01'          AMODE=64 (MAIN ENTRY)                @D02
DIRAM24  EQU   X'00'          AMODE=24 (MAIN ENTRY)                @D02
DIRATTR4 DS    X              COUNT OF RLD ENTRIES AFTER FIRST TEXT     17984000
         SPACE 1                                                        17985000
DIRAPF   DS    0XL2           APF (IF NOT SCAT, SSI OR ALIAS)           17986000
DIREP    DS    XL3            ENTRY POINT (MAIN MEMBER)                 17987000
DIRREAL  DS    CL8            REAL NAME OF MEMBER                       17988000
DIRAPF2  DS    XL2            APF INFORMATION (ALIAS, NO SCAT OR SSI)   17989000
DIREND2  EQU   *              END OF ALIAS SECTION                      17990000
         ORG   DIRAPF    FOLLOWING FOR SCATTER LOADED MEMBERS           17991000
DIRSCLL  DS    XL2            LENGTH OF SCATTER LIST                    17992000
DIRSCTL  DS    XL2            LENGTH OF TRANSLATE TABLE                 17993000
DIRSCET  DS    XL2            ESDID OF FIRST TEXT RECORD                17994000
DIRSCEP  DS    XL2            ESDID OF ENTRY POINT                      17995000
DIRAPF3  DS    0XL2           APF (IF SCAT, NO SSI AND NO ALIAS)        17996000
DIREPSC  DS    XL3            ENTRY POINT (MAIN MEMBER)                 17997000
DIRREALS DS    CL8            REAL NAME OF MEMBER                       17998000
DIRAPF4  DS    XL2            APF INFORMATION (SCAT, NO SSI AND ALIAS)  17999000
DIREND3  EQU   *              END OF SCATTER, ALIAS SECTION             18000000
*                                                                       18001000
         ORG   DIRUSER   FOLLOWING FOR MODULES SAVED BY SPF EDIT        18002000
DIRSPFV  DS    XL1            VERSION NUMBER IN BINARY                  18003000
DIRSPFR  DS    XL1            REVISION NUMBER IN BINARY                 18004000
DIRSPFZ  DS    0XL2           Was NOT CURRENTLY USED               @D04
DIRSPFFL DS    XL1            FLAGS                                @D04
DIRSPFSC EQU   X'80'          SCLM                                 @D04
DIRSPFXS EQU   X'20'          EXTENDED STATS                       @D04
DIRSPFCS DS    XL1            LAST CHANGE TIME IN FORMAT SS        @D04
DIRSPFCR DS    XL4            CREATION DATE IN FORMAT 00YYDDDF          18006000
DIRSPFCD DS    XL4            LAST CHANGE DATE IN FORMAT 00YYDDDF       18007000
DIRSPFCT DS    XL2            LAST CHANGE TIME IN FORMAT HHMM           18008000
DIRSPFSI DS    XL2            CURRENT SIZE IN BINARY                    18009000
DIRSPFIN DS    XL2            INITIAL SIZE IN BINARY                    18010000
DIRSPFMD DS    XL2            MODIFIED LINES IN BINARY                  18011000
DIRSPFID DS    CL8            USERID OF LAST PERSON TO UPDATE           18012000
*                             END OF SPF SECTION                        18013000
         ORG   ,                                                        18014000
DIREND   EQU   *              END OF DIRECTORY INFORMATION              18015000
         DS    XL2 (74 BYTES)  PADDING FOR:    MVC    DIRFLAG,DIRFLAG+2 18016000
         SPACE 1                                                   @D02
*----------------------------------------------------------------* @D02
*        Note:  Older PDS releases including 7.0 did not         * @D02
*        correctly identify the AMODE bits in DIRATTR3.          * @D02
*        The correct values are:                                 * @D02
*                                                                * @D02
*        ...1 .... Load module residence mode                    * @D02
*                      1 RMODE=ANY, 0 RMODE=24                   * @D02
*                                                                * @D02
*        .... 11.. Alias entry point addressing mode             * @D02
*                     00 AMODE=24, 10 AMODE=31,                  * @D02
*                     01 AMODE=64, 11 AMODE=ANY                  * @D02
*                                                                * @D02
*        .... ..11 Main entry point addressing mode              * @D02
*                     00 AMODE=24, 10 AMODE=31,                  * @D02
*                     01 AMODE=64, 11 AMODE=ANY                  * @D02
*                                                                * @D02
*----------------------------------------------------------------* @D02
         SPACE 3                                                        18017000
         IKJEFFMT                                                       18018000
         SPACE 3                                                        18019000
         AIF   (NOT &MVT).MA02100                                  @D01
         EJECT ,                                                   @D01
*----------------------------------------------------------------* @D01
*        Area for DAIR parameter blocks.  To conserve            * @D01
*        storage, all blocks use the same storage, so            * @D01
*        only one DAIR request can be built at a time.           * @D01
*----------------------------------------------------------------* @D01
DAIRBLK  DS    0F                                                  @D01
DAIR08   DS    XL88,XL12           DAIR allocation block           @D01
         ORG   DAIRBLK                                             @D01
DAIR18   DS    XL40                DAIR free block                 @D01
         ORG   DAIRBLK                                             @D01
DAIR2C   DS    XL16                DAIR not-in-use block           @D01
         ORG   ,                                                   @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        Remap WORKTBL+30 (used as the data set name area        * @D01
*        of the "specify DSN" text unit) as input data           * @D01
*        set name area for DAIR.                                 * @D01
*----------------------------------------------------------------* @D01
         ORG   WORKTBL+14+8+4+4    Position location counter       @D01
DAIRDSN  EQU   *                   Data set name for DAIR          @D01
DAIRDSNL DS    AL2(*-*)            Length of data set name         @D01
DAIRDSNT DS    CL44                Data set name                   @D01
         ORG   ,                   Reset location counter          @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        DD name of the active log data set, required in         * @D01
*        MVT so it can be expliciitly unallocated.               * @D01
*----------------------------------------------------------------* @D01
LOGDDN   DS    CL8                 DD name of log data set         @D01
         SPACE 1                                                   @D01
*----------------------------------------------------------------* @D01
*        Registers for retry after abend, saved by the           * @D01
*        recovery return and loaded by the retry routine.        * @D01
*        With ESTAE, this field would be contained in the        * @D01
*        SDWA.  MVT STAE doesn't provide an area in the SDWA     * @D01
*        for retry registers, so we must provide space in        * @D01
*        our work area for them.                                 * @D01
*----------------------------------------------------------------* @D01
         DS    0F                                                  @D01
SDWASRSV DS    0CL64               Registers R0-R15 for retry      @D01
SDWASR00 DS    F       GPR 0.                                      @D01
SDWASR01 DS    F       GPR 1.                                      @D01
SDWASR02 DS    F       GPR 2.                                      @D01
SDWASR03 DS    F       GPR 3.                                      @D01
SDWASR04 DS    F       GPR 4.                                      @D01
SDWASR05 DS    F       GPR 5.                                      @D01
SDWASR06 DS    F       GPR 6.                                      @D01
SDWASR07 DS    F       GPR 7.                                      @D01
SDWASR08 DS    F       GPR 8.                                      @D01
SDWASR09 DS    F       GPR 9.                                      @D01
SDWASR10 DS    F       GPR 10.                                     @D01
SDWASR11 DS    F       GPR 11.                                     @D01
SDWASR12 DS    F       GPR 12.                                     @D01
SDWASR13 DS    F       GPR 13.                                     @D01
SDWASR14 DS    F       GPR 14.                                     @D01
SDWASR15 DS    F       GPR 15.                                     @D01
         EJECT ,                                                   @D01
.MA02100 ANOP  ,                                                   @D01
         DS    0F             ***   FORMAT 1 DSCB  ***                  18020000
         ORG   *-44                                                     18021000
         IECSDSL1 (1)         FORMAT 1 DSCB                             18022000
         ORG   ,                                                        18023000
         SPACE 2                                                        18024000
**    AGO .NMVS12B  **** MVS testing ****                          @D01
         AIF   (NOT &MVT).NMVS12B                                  @D01
         AGO   .MA02120                                            @D01
         AIF ('&MVSLEV' GT 'MVS12X').NMVS12B                            18025000
.MA02120 ANOP  ,                                                   @D01
*----------------------------------------------------------------* @D01
*        MVS OBTAIN requires a 140 byte work area, but MVT       * @D01
*        requires 148 bytes.                                     * @D01
*----------------------------------------------------------------* @D01
         DS    XL8            8 more work area bytes for MVT       @D01
*----------------------------------------------------------------* @D01
*        Equates for bits in DS1DSORG.  APAR OZ44701 added       * @D01
*        these fields to the IECSDSL1 macro in MVS, but          * @D01
*        they need to be defined for MVT.                        * @D01
*----------------------------------------------------------------* @D01
DS1DSGIS EQU   X'80'          ISAM                                 @D01
DS1DSGPS EQU   X'40'          SEQUENTIAL                           @D01
DS1DSGDA EQU   X'20'          DIRECT                               @D01
DS1DSGPO EQU   X'02'          PARTITIONED                          @D01
DS1DSGU  EQU   X'01'          UNMOVEABLE                           @D01
DS1ACBM  EQU   X'08'          VSAM                                 @D01
*----------------------------------------------------------------* @D01
*        Equates for bits in DS1DSIND.                           * @D01
*----------------------------------------------------------------* @D01
DS1DSCHA EQU   X'02'          DATASET OPENED FOR OTHER             @D01
*                             THAN INPUT SINCE LAST                @D01
*                             BACKUP COPY MADE                     @D01
*----------------------------------------------------------------* @D01
*        Last referenced date field.                             * @D01
*----------------------------------------------------------------* @D01
         ORG   DS1SYSCD+L'DS1SYSCD                                 @D01
DS1REFD  DS    XL3                 DATE LAST REFERENCED            @D01
         ORG   ,                                                   @D01
.NMVS12B ANOP                                                           18032000
         AIF   (&MVT).MA02140                                      @D01
         TITLE 'P D S  --  PDS DYNAMIC AREA -- GENERAL FAIL    1/15/85' 18033000
GFPARMP  DS    F              POINTER TO START OF GENERAL FAIL PARMS    18034000
         IKJEFFGF                                                       18035000
.MA02140 ANOP  ,                                                   @D01
         TITLE 'P D S  --  PDS DYNAMIC AREA -- DEFAULT RTN.    1/15/85' 18036000
PARMPARS DS    F              START PARSE PARAMETERS (OVERLAY DFPARMS)  18037000
         IKJEFFDF                                                       18038000
         ORG   DFBUFS         NO CALLER-SUPPLIED BUFFERS NEEDED         18039000
DFPARM   EQU   DFPARMS,DFLEN       Alias with length               @D01
         SPACE 3                                                        18040000
PARMSTAK DS    F              START CURRENT GETLINE STACK ADDRESS  @D01
         SPACE 3                                                   @D01
FIRST4K  DS    CL(WORKAREA+4096-DFBUFS)   *** RESERVED TO 4K BOUNDARY   18041000
**NOTE: IF YOU HAVE ADDED STORAGE IN THE DYNAMIC AREA AND YOU RECEIVE   18042000
**      AN ERROR ON THE ABOVE STATEMENT, IT INDICATES THAT YOU HAVE     18043000
**      ADDED MORE STORAGE THAN CAN BE ACCOMODATED IN THE FIRST 4K OF   18044000
**      STORAGE.  CONSIDER RELOCATING SOME PROGRAM VARIABLES INTO THE   18045000
**      FOLLOWING AREA AFTER LABEL TSMSGWRK.                            18046000
         SPACE 3                                                        18047000
DMEMAREA DS    50CL20         SPACE FOR 50 MEMBER LIST ENTRIES          18048000
         SPACE 3                                                        18049000
TSMSGWRK DS    CL124          MESSAGE WORK AREA                         18050000
         SPACE 3                                                        18051000
         AIF ('&CISP' EQ 'NO SPF').MA02160                         @D01
         COPY  SPWRK70B        SECOND ISPMODE, MEMLIST WORK AREA        18052000
         SPACE 3                                                        18053000
.MA02160 ANOP  ,                                                   @D01
RECALLST DS    XL256           RECALL TEXT AREA                         18054000
CONTDSN  DS    XL60            DSNAME FORMATTED AREA FOR CONTROL        18055000
LOGREGS  DS    XL44            REGISTERS R14:R8 SAVED FOR LOGDATA       18056000
SAVECOMP DS    XL40            SAVE TEXT FOR COMPARE                    18057000
SAVEOUT  DS    XL40            SAVE TEXT FOR OUTCOPY                    18058000
SAVETEXT DS    8XL40           SAVE TEXT FOR OTHER SUBCOMMANDS          18059000
         SPACE 3                                                        18060000
LENWORK  EQU   *-WORKAREA                                               18061000
         TITLE 'P D S  --  PDS ESD, IDR DSECTS                 1/15/85' 18062000
*                                                                       18063000
*        ESD TABLE FORMAT                                               18064000
*                                                                       18065000
ESDENTRY DSECT                                                          18066000
ESDLINK  DS    F                                                        18067000
ESDNAME  DS    CL8            NAME OF EXTERNAL SYMBOL                   18068000
ESDTYPE  DS    X              ESD TYPE                                  18069000
CODESD   EQU   X'00'          ENTERNAL DEFINITION                       18070000
CODEER   EQU   X'02'          ENTERNAL REFERENCE                        18071000
CODELR   EQU   X'03'          LABEL REFERENCE                           18072000
CODEPC   EQU   X'04'          PRIVATE CODE DEFINITION                   18073000
CODECM   EQU   X'05'          COMMON BLOCK                              18074000
CODEPR   EQU   X'06'          PSEUDO REGISTER                           18075000
CODENL   EQU   X'07'          NULL                                      18076000
CODEWK   EQU   X'0A'          WEAK EXTERNAL                             18077000
CODESEG  EQU   X'14'          OVERLAY SEGMENT TABLE                     18078000
CODEENTB EQU   CODESEG        OVERLAY ENTRY TABLE                       18079000
ESDADDR  DS    XL3            RELATIVE OFFSET                           18080000
ESDSEG#  DS    X              SEGMENT NUMBER                            18081000
ESDXAFLG EQU   ESDSEG#        FLAGS FOR MVS/XA                          18082000
RMODEANY EQU   X'04'          RMODE=ANY                                 18083000
AMODE31  EQU   X'02'          AMODE=31                             @D02
AMODE64  EQU   X'10'          AMODE=64                             @D02
AMODE24  EQU   X'01'          AMODE=24                             @D02
ESDLEN   DS    XL3            LENGTH OF SD ENTRY                        18086000
LENESD1  EQU   *-ESDNAME      LENGTH OF ESD DATA                        18087000
ESDID    DS    XL2            RELATIVE ESD ID #                         18088000
ESDIDIN  DS    XL2            ESD IS IN THIS PHYSICAL RECORD            18089000
ESDCSECT DS    XL4            LIST ONLY -- POINTER TO CSECT ENTRY       18090000
ESDMAIN  DS    XL4            LIST ONLY -- ENTRY POINT OF CSECT ENTRY   18091000
LENESD2  EQU   *-ESDNAME      LENGTH OF ESD DATA                        18092000
LENESD   EQU   *-ESDENTRY     LENGTH OF ENTRY                           18093000
         SPACE 3                                                        18094000
*                                                                       18095000
*        IDR TABLE FORMAT                                               18096000
*                                                                       18097000
IDRENTRY DSECT                                                          18098000
IDRLINK  DS    A                                                        18099000
IDRSTART EQU   *                                                        18100000
IDRESDID DS    XL2                                                      18101000
IDRTYPE  DS    X                                                        18102000
IDRZAP   EQU   X'01'                                                    18103000
IDRLKED  EQU   X'02'                                                    18104000
IDRTRAN  EQU   X'04'                                                    18105000
IDRUSER  EQU   X'08'                                                    18106000
IDRDATE  DS    XL3                                                      18107000
IDRLDATA DS    X                                                        18108000
IDRUPREF DS    XL6            USER RECORD PREFIX                        18109000
IDRZDATA DS    0CL8                                                     18110000
IDRTDATA DS    0CL30                                                    18111000
IDRDATA  DS    CL40                                                     18112000
LENIDR1  EQU   *-IDRSTART                                               18113000
LENIDR   EQU   *-IDRENTRY                                               18114000
         TITLE 'P D S  --  PDS SDWA DSECT                      1/15/85' 18115000
         AIF ('&MVSLEV' EQ 'MVS038').MVS038                             18116000
         IHASDWA  VRAMAP=NO                                             18117000
         AGO   .SDWADEF                                                 18118000
.MVS038  ANOP                                                           18119000
         IHASDWA                                                        18120000
.SDWADEF ANOP                                                           18121000
         AIF   (&MVT).MA02180                                      @D01
         TITLE 'P D S  --  PDS SVC 99 PARAMETER LIST           1/15/85' 18122000
         IEFZB4D0                                                       18123000
.MA02180 ANOP  ,                                                   @D01
         AIF ('&MVSLEV' LT 'MVS13X').NMVS13C                            18124000
         TITLE 'P D S  --  RIB, RIBE DEFINITION                1/15/85' 18125000
         ISGRIB                                                         18126000
.NMVS13C ANOP                                                           18127000
         TITLE 'P D S  --  PDS PPL, CSPL, CSOA DSECTS          1/15/85' 18128000
         IKJPPL                                                         18129000
         SPACE 3                                                        18130000
         IKJCSPL                                                        18131000
         SPACE 2                                                        18132000
         IKJCSOA                                                        18133000
         TITLE 'P D S  --  PDS IOPL, PGPB DSECTS               1/15/85' 18134000
         IKJIOPL                                                        18135000
         SPACE 5                                                        18136000
         IKJPGPB                                                        18137000
**       TITLE 'P D S  --  PDS GTPB DSECT                      1/15/85' 18138000
**       IKJGTPB                                                        18139000
         TITLE 'P D S  --  PDS UPT DSECT                       1/15/85' 18140000
         IKJUPT                                                         18141000
         TITLE 'P D S  --  PDS PSCB DSECT                      1/15/85' 18142000
         IKJPSCB                                                        18143000
         TITLE 'P D S  --  PDS ECT DSECT                       1/15/85' 18144000
         IKJECT                                                         18145000
         TITLE 'P D S  --  PDS CPPL DSECT                      1/15/85' 18146000
         IKJCPPL                                                        18147000
         TITLE 'P D S  --  PDS DAPL DSECT                      1/15/85' 18148000
         IKJDAPL                                                        18149000
**       TITLE 'P D S  --  PDS DAIR00 DSECT                    1/15/85' 18150000
**       IKJDAP00                                                       18151000
**       TITLE 'P D S  --  PDS DAIR04 DSECT                    1/15/85' 18152000
**       IKJDAP04                                                       18153000
         TITLE 'P D S  --  PDS DAIR08 DSECT'                       @D01
         IKJDAP08                                                  @D01
         TITLE 'P D S  --  PDS DAIR18 DSECT'                       @D01
         IKJDAP18                                                  @D01
**       SPACE 2                                                        18158000
**       IKJDAP0C                                                       18159000
**0CDDN  DS    XL8 START OF DDNAME LIST                                 18160000
**       TITLE 'P D S  --  PDS DAIR10 DSECT                    1/15/85' 18161000
**       IKJDAP10                                                       18162000
**       TITLE 'P D S  --  PDS DAIR14 DSECT                    1/15/85' 18163000
**       IKJDAP14                                                       18164000
**       TITLE 'P D S  --  PDS DAIR1C DSECT                    1/15/85' 18165000
**       IKJDAP1C                                                       18166000
**       TITLE 'P D S  --  PDS DAIR24 DSECT                    1/15/85' 18167000
**       IKJDAP24                                                       18168000
**       TITLE 'P D S  --  PDS DAIR28 DSECT                    1/15/85' 18169000
**       IKJDAP28                                                       18170000
         TITLE 'P D S  --  PDS DAIR2C DSECT'                       @D01
         IKJDAP2C                                                  @D01 18172000
**       TITLE 'P D S  --  PDS DAIR30 DSECT                    1/15/85' 18173000
**       IKJDAP30                                                       18174000
         TITLE 'P D S  --  PDS DFPL AND DFPB DSECTS            1/15/85' 18175000
         IKJDFPL                                                        18176000
         SPACE 3                                                        18177000
         IKJDFPB                                                        18178000
         TITLE 'P D S  --  PDS DCBD AND CVT DSECTS             1/15/85' 18179000
         PRINT NOGEN                                                    18180000
         DCBD  DSORG=PO                                                 18181000
         SPACE 5                                                        18182000
         AIF   (&MVT).MA02200                                      @D01
         CVT   DSECT=YES                                                18183000
         AGO   .NA02200                                            @D01
.MA02200 ANOP  ,                                                   @D01
CVT      DSECT ,                                                   @D01
         CVT   SYS=MVT                                             @D01
*                                                                  @D01
*  Following equates for MVS CVT fields that don't exist in MVT    @D01
*  are defined as dummy values to prevent errors assembling        @D01
*  the service routine load table MODULEN.                         @D01
*                                                                  @D01
CVTPUTL  EQU   CVTMAP                                              @D01
CVTPARS  EQU   CVTMAP                                              @D01
CVTPTGT  EQU   CVTMAP                                              @D01
CVTGETL  EQU   CVTMAP                                              @D01
CVTSCAN  EQU   CVTMAP                                              @D01
CVTSTCK  EQU   CVTMAP                                              @D01
CVTEHDEF EQU   CVTMAP                                              @D01
CVTEFF02 EQU   CVTMAP                                              @D01
CVTDAIR  EQU   CVTMAP                                              @D01
         TITLE 'P D S  --  PDS TSCVT DSECT'                        @D01
         IKJTSCVT ,                                                @D01
.NA02200 ANOP  ,                                                   @D01
         SPACE 5                                                        18184000
.NOGEN   END  PDSMAIN                                                   18185000
./ ADD NAME=SETRP
         MACRO ,                                                        00011037
&NAME    SETRP &RETADDR=,&RETREGS=,&DUMP=,&RECORD=,&WKAREA=,&REGS=,    J00013038
               &DUMPOPT=,&RECPARM=,&RC=0,&FRELOCK=,&CPU=,              J00014037
               &COMPCOD=,&FRESDWA=,&RUB=                                00015037
.*---------------------------------------------------------------*      00012037
.*       Define SETRP macro to generate return from STAE         *      00012138
.*       exit routine.  The only significant parameters are      *      00012238
.*       RC=, REGS= and RETADDR=.                                *      00012338
.*---------------------------------------------------------------*      00012437
         LCLC  &A                                                       00015137
         LCLA  &B                                                       00015237
&B       SETA  &RC                                                      00015337
.*                                                                      00015537
.*---------------------------------------------------------------*      00015637
.*       Process RC= parameter.                                  *      00015738
.*---------------------------------------------------------------*      00015937
.RC      ANOP                                                           00016037
         AIF   ('&RC'(1,1) EQ '(').ERR17                                00016137
         AIF   (&B EQ 16 OR &B EQ 0).STRC                               00016237
         AIF   (&B EQ 4).RETA                                           00016337
         IHBERMAC 54,,&RC                                               00016437
         MEXIT                                                          00016537
.STRC    ANOP                                                           00016637
&A       SETC  '&RC(1)'                                                 00016837
         LA    15,&A -             Set return code                      00016937
         AGO   .REGS                                                    00017037
.*                                                                      00017137
.*---------------------------------------------------------------*      00017237
.*       Process RETADDR= parameter.                             *      00017338
.*---------------------------------------------------------------*      00017537
.RETA    ANOP                                                           00017637
         AIF   ('&RETADDR' EQ '').ERR2                                  00017737
&A       SETC  '&RC(1)'                                                 00018137
         LA    15,&A -             Set return code                      00018237
         AIF   ('&RETADDR'(1,1) EQ '(').RETAR                           00018337
&A       SETC  '&RETADDR(1)'                                            00018637
         LA    0,&A -              Get retry address                    00018837
         ST    0,20(,13) -         Set in save area                     00018937
         AGO   .FSDWA                                                   00019037
.RETAR   ANOP                                                           00019137
&A       SETC  '&RETADDR(1)'                                            00019337
         ST    &A,20(,13) -        Set retry address in save area       00019437
.FSDWA   ANOP                                                           00019637
.*                                                                      00019737
.*---------------------------------------------------------------*      00019837
.*       Process REGS= parameter.                                *      00019938
.*---------------------------------------------------------------*      00020037
.REGS    ANOP                                                           00020237
         AIF   ('&REGS(1)' EQ '').RETUSER                               00020337
&A       SETC   'REGS'                                                  00020437
         AIF   ('&REGS'(1,1) NE '(').ERR1                               00020537
         AIF   ('&REGS(2)' EQ '').RET2                                  00020637
         RETURN  (&REGS(1),&REGS(2)),RC=(15)                            00020737
         MEXIT                                                          00020837
.RET2    RETURN  (&REGS(1)),RC=(15)                                     00020937
.RETUSER ANOP                                                           00021037
         MEXIT                                                          00021137
.*                                                                      00021237
.*---------------------------------------------------------------*      00021337
.*       Errors.                                                 *      00021438
.*---------------------------------------------------------------*      00021537
.ERR1    ANOP                                                           00021737
         MNOTE 12,'***  REGISTER SPECIFICATION REQUIRED FOR &A KEYWORD' 00021837
         MEXIT                                                          00021937
.ERR2    ANOP                                                           00022037
         MNOTE 12,'***   RETADDR MUST BE SPECIFIED WITH RC/&RC'         00022137
         MEXIT                                                          00022237
.ERR17   ANOP                                                           00022337
         MNOTE 12,'*** REGISTER SPECIFICATION ILLEGAL FOR RC KEYWORD'   00022437
         MEXIT                                                          00022537
         MEND  ,                                                        00022637
./ ADD NAME=SGSTAR
IEC0SCR1 CSECT -                        Resume CSECT
         TITLE 'IGC018 - SYSTEM TRACK ALGORITHM ROUTINE (STAR)'
******************************************************************
*                                                                *
* Name         STAR                                              *
*                                                                *
* Description  System Track Algorithm Routine                    *
*                                                                *
* Function     This routine performs two major functions, track  *
*              balance and track capacity.  The track balance    *
*              function calculates the number of remaining       *
*              writeable bytes (called track balance) on a       *
*              track.  The calculation is made using a record    *
*              number, a key length, a data length, and          *
*              optionally an input track balance value,          *
*              provided by the caller (see the description of    *
*              input below).                                     *
*                                                                *
*              The track capacity function calculates the number *
*              of whole records that will fit in a given track   *
*              balance.  These functions are accomplished in     *
*              three phases.                                     *
*                                                                *
*     Phase 1: First the actual size of the record (record       *
*              cost) is calculated.  This is accomplished by     *
*              summing the caller provided key and data lengths, *
*              and the unique record overheads for the target    *
*              device.                                           *
*                                                                *
*              Note - overhead values are obtained from the      *
*              system Device Characteristics Table (DVCT) entry  *
*              provided by the caller or located by STAR via     *
*              the device type passed or obtained from the       *
*              target UCB.  The DVCT entry data is used in the   *
*              remaining phases as well.                         *
*                                                                *
*     Phase 2: Next the input track balance is either            *
*              calculated or determined to have been provided    *
*              by the caller.  The value of the calculated       *
*              input balance is dependent upon whether the       *
*              "remove" option was selected by the caller.       *
*                                                                *
*              For REMOVE=YES, the input balance calculated is   *
*              for the remaining bytes after the record number   *
*              passed by the caller.  For REMOVE=NO (default),   *
*              the input balance calculated is for the remaining *
*              bytes after the specified record number.          *
*                                                                *
*              Note - when the input balance is passed by the    *
*              caller, the value provided is assumed to match    *
*              the above conditions.                             *
*                                                                *
*              Note - a unique condition occurs when the caller  *
*              specifies a record number of one.  In this case,  *
*              STAR forces the input balance to the maximum      *
*              track size then tests for REMOVE=YES.  If it      *
*              is a remove request, return is immediately made   *
*              to the caller without passing through phase 3.    *
*                                                                *
*     Phase 3: Here the caller's request is carried out using    *
*              the provided key and data length, and the         *
*              calculated or provided input balance.             *
*                                                                *
*       TRKCAP - Track capacity request - The input balance is   *
*              used to determine how many whole records will fit *
*              on the remaining writeable bytes of a track.      *
*                                                                *
*       TRKBAL - Track balance request - Here the input balance  *
*              is either decremented (REMOVE=NO - default) or    *
*              incremented (REMOVE=YES) and passed back to the   *
*              caller.  In producing the output balance, a non-  *
*              last record cost is used to either decrement or   *
*              increment the input balance.  An exception to     *
*              this is provided via the "last" option described  *
*              below.                                            *
*                                                                *
*              Two additional options, "maxsize" and "last",     *
*              are provided.  If MAXSIZE=YES is specified        *
*              (available only with REMOVE=NO) and the input     *
*              balance is insufficient to accommodate an         *
*              additional record, a calculation is made to       *
*              determine if at least one byte of data will fit.  *
*              If so, then the number of writeable data bytes    *
*              is calculated and returned to the caller with a   *
*              special return code.                              *
*                                                                *
*              The LAST=YES option is provided to meet the       *
*              special requirements of ISAM.  Here the caller    *
*              can request that a last-record-cost be used as    *
*              the decrement/increment to obtain the output      *
*              balance.                                          *
*                                                                *
* Input        Register 1 - Address of STAR parameter list       *
*                           (described below)                    *
*              Register 14 - Caller return address               *
*              Register 15 - Base address for IEC0SCR1           *
*                                                                *
*              STAR parameter list - (addressed by register 1)   *
*              Offset Length  Description                        *
*              0      4 bytes Address of DVCT entry, or          *
*              0      4 bytes Address of UCB, or                 *
*              3      1 byte  Device type                        *
*              4      1 byte  Function and option flags          *
*                 B'10000000' Function: 0=TRKBAL, 1=TRKCAP       *
*                 B'01000000' 1=MAXSIZE requested                *
*                 B'00100000' 1=REMOVE requested                 *
*                 B'00010000' 1=Caller provided input balance    *
*                 B'00001000' 1=Last-record option requested     *
*                 B'00000110' DVCT entry source flags            *
*                             00=DVCT entry address provided     *
*                             01=Reserved                        *
*                             10=UCB address provided            *
*                             11=Device type provided            *
*                 B'00000001' Reserved - must be zero            *
*              5      1 Byte  Reserved                           *
*              6      2 Bytes Track balance                      *
*              8      1 Byte  Record number                      *
*              9      1 Byte  Key length                         *
*              A      2 Bytes Data length                        *
*                                                                *
* Output       Register 0 - Varies depending on the function     *
*                requested (TRKCAP or TRKBAL) and the results.   *
*                TRKCAP - Set to the number of whole records     *
*                         that will fit on the remainder of a    *
*                         track (input track balance).           *
*                TRKBAL - If a new record fits or an old record  *
*                         is removed, register 0 is set to the   *
*                         output track balance.                  *
*                       - If a whole record will not fit and     *
*                         MAXSIZE=YES was specified, register    *
*                         0 is set to the maximum writable       *
*                         data bytes.                            *
*                       - If a whole record will not fit and     *
*                         MAXSIZE was not requested, register    *
*                         0 is set to zero.                      *
*              Register 1  - Unchanged                           *
*              Register 14 - Unchanged                           *
*              Register 15 - Return code register.  Meaning de-  *
*                pends on the nature of the caller's request     *
*                (TRKCAP or TRKBAL).                             *
*                TRKCAP - 0=One or more records of the spec-     *
*                           ified length will fit within the     *
*                           input track balance.                 *
*                         4=No records of the specified length   *
*                           will fit within the input balance.   *
*                         C=The user provided a device type,     *
*                           but but the Device Characteristics   *
*                           Table indicates that no device of    *
*                           the specified type was generated.    *
*                           Register 0 is set to zero.           *
*                TRKBAL - 0=REMOVE=NO was specified or           *
*                           defaulted, and the specified record  *
*                           size will fit within the input       *
*                           balance (a new is balance            *
*                           returned).  Or, REMOVE=YES was       *
*                           specified.  In which case, a new     *
*                           balance is always returned.          *
*                         4=The input balance is not sufficient  *
*                           to accommodate a record of the       *
*                           specified key and data length.       *
*                           (Possible on REMOVE=NO only)         *
*                         8=The same as return code 4 except     *
*                           MAXSIZE=YES was specified and at     *
*                           least one byte of data could be      *
*                           written.  Register 0 is set to the   *
*                           maximum data bytes that will fit.    *
*                         C=The user provided a device type,     *
*                           but the Device Characteristics       *
*                           Table indicates that no device of    *
*                           the specified type was generated.    *
*                           Register 0 is set to zero.           *
*                                                                *
*              STARBAL (of the STAR parameter list) - First set  *
*                to the calculated input balance if not pro-     *
*                vided by the caller.  This is true for both     *
*                TRKBAL and TRKCAP functions.                    *
*                Finally, if the request is for a TRKBAL func-   *
*                tion, STARBAL is set to the new (output)        *
*                balance except when a new record will not       *
*                fit.  In this case, STARBAL is left with the    *
*                input balance.                                  *
*                                                                *
*              Note - Registers 2, 3, 9, 10 and 11 are used as   *
*              work registers during STAR processing and are not *
*              restored.                                         *
*                                                                *
* Exit         Control is returned to the address passed in      *
*              register 14.                                      *
*                                                                *
* Attributes   Reentrant, refreshable                            *
*                                                                *
******************************************************************
         EJECT ,
         SPACE 1
         USING IEC0SCR1,R15 -           BASE ADDRESSABILITY
         USING STARMAP,R1 -             ADDRESS PARM LIST
***************************************************************
*   FIND ENTRY IN DEVICE CHARACTERISTICS TABLE
***************************************************************
STAR     SR    R10,R10 -                CLEAR WORK REG
         SR    R11,R11 -                CLEAR WORK REG
         L     R9,STARDCTA -            PRELOAD DCT OR UCB ADDR
         TM    STARFLGS,STARDTU -       TST PARM FORMAT FLGS
         BZ    DCTE@ -                  BR IF DCT ADDR PROVIDED
         BM    UCB@ -                   BR IF UCB ADDR PROVIDED
*
*   DEVICE TYPE PROVIDED BY CALLER
*
         IC    R11,STARTYPE -           DEVTYPE TO R11
         B     TBLLOOK -                ON TO FINDING DCT ENTRY
*
*   UCB ADDRESS PROVIDED BY CALLER
*
UCB@     EQU   *
         IC    R11,UCBUNTYP(,R9) -      GET DEVTYPE FROM UCB
*
*   LOCATE THE DEVICE TABLE ENTRY
*
TBLLOOK  EQU   *
         L     R9,CVTPT -               ADDR OF CVT
         L     R9,CVTZDTAB(,R9) -        GET DVCT ADDRESS
         USING DVCTI,R9 -               ADDRESS THE DVCT INDEX
         IC    R10,DVCTIOFF(R11) -      GET INDEX VALUE
         LTR   R10,R10 -                WAS DEVICE TYPE GENNED?
         BNZ   GENNED -                 YES: CONTINUE
         XR    R0,R0 -                  NO: CLEAR R0
         LA    R15,12 -                 SET RETURN CODE = 12
         BR    R14 -                    RETURN TO CALLER
GENNED   EQU   *
         AR    R9,R10 -                 ADDRESS DVCT ENTRY
         USING DVCT,R9 -                DVCT ENTRY ADDRESSABILITY
DCTE@    EQU   *
         EJECT ,
***************************************************************
* PHASE 1  -
***************************************************************
*   CALCULATE RECORD COST AS KL + DL + OVERHEAD
*             (IF DL=0, DL WILL BE SET TO 1 UNLESS DEVICE
*              IS 2305-2; IN THAT CASE DL WITH BE SET TO 2)
***************************************************************
         IC    R10,STARKL -             GET KEY LENGTH
         LTR   R10,R10 -                TEST KEY LENGTH
         BNZ   GOTKEY -                 BR IF THERE IS A KEY
         IC    R10,DVCOVNK -            GET KEY OVERHEAD
         LCR   R10,R10 -                MAKE IT NEGATIVE SO IT
*                                       IS SUBTRACTED IN SUB-
*                                       SEQUENT ARITHMETIC
GOTKEY   CH    R11,=H'07' -             IS IT A 2305-2?
         BE    GOTKEY2 -                YES IT IS, BRANCH
         LH    R11,STARDL -             GET DATA LENGTH
         N     R11,MASK16 -             ENSURE DL NOT NEGATIVE
         BNZ   GOTDATA -                BRANCH IF DL POSITIVE
         LA    R11,1 -                  ELSE FORCE DL=1
         B     GOTDATA -                CONTINUE
GOTKEY2  LH    R11,STARDL -             GET DATA LENGTH
         N     R11,MASK16 -             ENSURE DL NOT NEGATIVE
         BNZ   GOTDATA -                BRANCH IF DL POSITIVE
         LA    R11,2 -                  FORCE DL=2
GOTDATA  AR    R10,R11 -                R10=DL+KL(-KEYOVH IF
*                                       KL=0)
         LH    R11,DVCOVHD -            GET 2-BYTE OVERHEAD
         TM    DVCFLAGS,DVC2BOV -       2-BYTE OVERHEAD?
         BO    ADDOVH -                 BR IF 2-BYTES
         SR    R11,R11 -                CLEAR WORK REG
         IC    R11,DVCOVLB -            GET 1-BYTE LAST RCD OH
ADDOVH   EQU   *
         AR    R10,R11 -                SUM KL,DL,& OVERHEADS
         EJECT ,
***************************************************************
* PHASE 2 -
***************************************************************
*   DETERMINE THE TRACK BALANCE: THE TRACK BALANCE IS GOTTEN BY
*   ONE OF THREE METHODS: 1) IF THE RECORD NUMBER IS ONE, THEN
*   THE TOTAL TRACK SIZE IS GOTTEN FROM THE DCT (ANY BALANCE
*   GIVEN BY THE CALLER IS IGNORED); 2) IF THE RECORD IS NOT
*   ONE AND THE CALLER PASSES A BALANCE, THE CALLERS VALUE WILL
*   BE USED; 3) IF THE RECORD IS GREATER THAN ONE AND THE USER
*   DOES NOT PASS A BALANCE, IT WILL BE CALCULATED AS FOLLOWS:
*         A) IF REMOVE=YES, TRKSIZE-(RECORD_COST X RECORD#)
*         B) ALL OTHERS, TRKSIZE-(RECORD_COST X (RECORD#-1))
***************************************************************
BALANCE  CLI   STARR,X'01' -            DID CALLER SAY RCD 1
         BNE   BALTST -                 IF NOT, GO SEE IF
*                                       CALLER PROVIDED A
*                                       TRACK BALANCE
*
*   RECORD NUMBER IS 1.  INITIALIZE TRACK BALANCE TO TRACKSIZE.
*
         LH    R11,DVCTRKLN -           GET TRK SIZE
         STH   R11,STARBAL -            DROP INTO STAR PARM LST
         TM    STARFLGS,STARREMV -      REMOVE=YES?
         BNO   FUNCTNS -                IF NOT, GO PROCESS FUNC
         LR    R0,R11 -                 IF YES, PASS BACK BAL
         SR    R15,R15 -                SUCCESSFUL RTCODE (0)
         BR    R14 -                    BACK TO CALLER
*
*   IF CALLER PASSED A BALANCE, USE IT. OTHERWISE, CALCULATE IT
*
BALTST   EQU   *
         TM    STARFLGS,STARUBAL -      DID CALLER PASS A BAL
         BO    FUNCTNS -                IF SO , CONT. WITH FUNC
         LR    R0,R10 -                 SAVE LAST RECORD COST
         TM    DVCFLAGS,DVCFTOL -       DOES TOLERANCE APPLY?
         BNO   BALNTOL1 -               BRANCH IF NOT
         BAL   R11,APPLYTOL -           ELSE APPLY TOLERANCE
BALNTOL1 EQU   *
         SR    R11,R11 -                CLEAR WORK REG
         IC    R11,STARR -              GET CALLER'S RECORD NR
         TM    STARFLGS,STARREMV -      REMOVE=YES?
         BO    BALCONT -                YES, SKIP R DECREMENT
         BCTR  R11,0 -                  SUBTRACT 1 IF NOT REMV
BALCONT  EQU   *
         MR    R10,R10 -                RCD_COST(NONLAST)*RCD
         LCR   R11,R11 -                MAKE RECORD_COSTS NEG
         AH    R11,DVCTRKLN -           R11=TRKSIZE-RCD_COSTS
         STH   R11,STARBAL -            STORE CALCULATED BAL
         LR    R10,R0 -                 RESTORE LAST RCD COST
         EJECT ,
***************************************************************
* PHASE 3
***************************************************************
*   FUNCTIONAL OPERATIONS FOLLOW:
*     1. TRKCAP: NUMBER OF RECORDS WHICH WILL FIT INTO BALANCE
*     2. TRKBAL: A) WILL GIVEN SIZE BLOCK FIT INTO BALANCE
*                B) IF REMOVE, DETERMINE NEW BALANCE
***************************************************************
FUNCTNS  EQU   *
         LH    R0,STARBAL -             PRELOAD WORKING BALANCE
         TM    STARFLGS,STARFUNC -      TEST REQUESTED FUNCTION
         BNO   TRKBAL -                 BR IF TRACK BAL REQ'ED
*
*   PROCESS TRACK CAPACITY REQUEST
*     THIS FUNCTION WILL ACCOUNT FOR A LAST RECORD SITUATION
*     BEFORE CALCULATING THE NUMBER OF ADDITIONAL NONLAST RE-
*     CORDS THAT WILL FIT IN THE DETERMINED (OR SUPPLIED) TRACK
*     BALANCE.
*
         SR    R0,R10 -                 SUBTRACT 1ST RCD COST
         BM    LUKE -                   IF RESULT IS NEGATIVE,
*                                       RETURN TO CALLER WITH
*                                       A RETURN CODE OF 4.
         TM    DVCFLAGS,DVCFTOL -       NEED TO APPLY TOLERANCE?
         BNO   CAPNOTOL -               BRANCH IF NOT
         BAL   R11,APPLYTOL -           ELSE APPLY TOLERANCE
CAPNOTOL EQU   *
         LR    R11,R0 -                 NEW BAL TO DIVIDEND REG
         LR    R0,R10 -                 RCD COST TO DIVISOR REG
         SR    R10,R10 -                0 HI-ORDER DIVIDEND REG
         DR    R10,R0 -                 GET WHOLE RCDS IN REG11
         LA    R0,1(,R11) -             BUMP BY 1 FOR EARLIER
*                                       SUBTRACTION
         SR    R15,R15 -                SUCCESSFUL RTCODE (0)
         BR    R14 -                    BACK TO CALLER
         EJECT
*
*   PROCESS TRACK BALANCE REQUEST
*
TRKBAL   EQU   *
         TM    STARFLGS,STARREMV -      REMOVE=YES?
         BNO   NOTREMOV -               BR IF NO
         TM    DVCFLAGS,DVCFTOL -       DEVICE NEED TOLERANCE?
         BNO   BALNTOL2 -               BRANCH IF NOT
         TM    STARFLGS,STARLAST -      SPECIAL LAST RECORD?
         BO    BALNTOL2 -               BRANCH IF SO
         BAL   R11,APPLYTOL -           ELSE APPLY TOLERANCE
BALNTOL2 EQU   *
         AR    R0,R10 -                 ADD RCD COST TO OLD BAL
         STH   R0,STARBAL -             UPDATE STAR PARM LIST
         SR    R15,R15 -                SUCCESSFUL RTCODE (0)
         BR    R14 -                    BACK TO CALLER
*
*   SEE IF CURRENT BALANCE WILL ACCOMMODATE A LAST RECORD
*
NOTREMOV EQU   *
         CR    R0,R10 -                 BALANCE VS RCD COST
         BL    NOFIT -                  BR IF BAL < RCD COST
         TM    DVCFLAGS,DVCFTOL -       DEVICE NEED TOLERANCE?
         BNO   FIXNOTOL -               BRANCH IF NOT
         TM    STARFLGS,STARLAST -      SPECIAL LAST RECORD?
         BO    FIXNOTOL -               BRANCH IF SO
         BAL   R11,APPLYTOL -           ELSE APPLY TOLERANCE
FIXNOTOL EQU   *
         SR    R0,R10 -                 R0=OLD_BAL - RCD_COST
         STH   R0,STARBAL -             UPDATE STAR PARM BAL
         SR    R15,R15 -                SUCCESSFUL RTCODE (0)
         BR    R14 -                    BACK TO CALLER
*
*   RECORD WILL NOT FIT.
*
NOFIT    EQU   *
         TM    STARFLGS,STARMAXS -      MAXSIZE=YES?
         BNO   LUKE -                   IF NOT MAXSIZE=YES,
*                                       RETURN TO CALLER WITH
*                                       A RETURN CODE OF 4.
*
         SR    R11,R11 -                CLEAR WORK REG
         IC    R11,DVCOVLB -            GET 1-BYTE LAST RCD OVH
         TM    DVCFLAGS,DVC2BOV -       IS IT REALLY 1-BYTE
         BNO   DARTH -                  YES, SKIP 2-BYTE GET
         LH    R11,DVCOVHD -            GET 2-BYTE RCD OVERHEAD
DARTH    EQU   *
         SR    R10,R10 -                CLEAR WORK REG
         CLI   STARKL,X'00' -           KL=0?
         BNE   VADER -                  IF NOT, BR
         IC    R10,DVCOVNK -            GET KEY DECREMENT
         SR    R11,R10 -                SUBTRACT KEY OVERHEAD
VADER    EQU   *
         SR    R0,R11 -                 GET KL+DL_MAXSIZE
         IC    R10,STARKL -             GET KEY LENGTH
         SR    R0,R10 -                 GET DL_MAXSIZE
         BNP   LUKE -                   IF DL_MAXSIZE NOT > 0,
*                                       RETURN TO CALLER WITH
*                                       A RETURN CODE OF 4.
         LA    R15,8 -                  SEMI-SUCCESSFUL RETURN
*                                       CODE (8); MAXSIZE AVAIL
         BR    R14 -                    BACK TO CALLER
*
*   COMMON EXIT FOR:
*
*     1. FUNCTN=TRKCAP AND NO RECORDS FIT
*     2. FUNCTN=TRKBAL, NEW RECORD DOESN'T FIT, AND MAXSIZE=NO
*     3. FUNCTN=TRKBAL, NEW RECORD DOESN'T FIT, MAXSIZE=YES,
*        BUT NO DATA BYTES ARE WRITEABLE
*
LUKE     EQU   *
         SR    R0,R0 -                  ZERO OUTPUT REGISTER
         LA    R15,4 -                  UNSUCCESSFUL RTCODE (4)
         BR    R14 -                    BACK TO CALLER
         EJECT ,
***************************************************************
* APPLYTOL -
***************************************************************
*   SUBROUTINE TO APPLY TOLERANCE FACTOR TO DEVICES
*   REQUIRING IT USING INFORMATON FROM THE APPROPRIATE
*   DEVICE CHARACTERISTICS TABLE
***************************************************************
APPLYTOL EQU   *
         XR    R2,R2 -                  CLEAR A REGISTER
         LR    R3,R2 -                  CLEAR ANOTHER REGISTER
         IC    R2,DVCOVLB -             GET LAST BLOCK OVERHEAD
*                                       IN R2
         CLI   STARKL,X'00' -           IS KEY LENGTH ZERO?
         BE    APTOL01 -                YES: BRANCH
         SR    R10,R2 -                 NO: ADJUST FOR LAST RECORD
APTOL01  DS    0H
         MH    R10,DVCTOL -             TIMES TOLERANCE FACTOR
         SRL   R10,DVCTSHFT -           DIVIDED BY 512
         IC    R3,DVCOVNLB -            GET NON-LAST-BLOCK
*                                       OVERHEAD IN R3
         AR    R10,R3 -                 ADD OVERHEAD LAST RECORD
         IC    R3,DVCOVNK -             GET NONKEYED OVERHEAD
*                                       DECREMENT IN R3
         SR    R10,R3 -                 SUBTRACT DECREMENT
         CLI   STARKL,X'00' -           IS KEY LENGTH ZERO?
         BCR   8,R11 -                  RETURN NOW IF SO
         AR    R10,R2 -                 NO, ADJUST FOR KEY
         BR    R11 -                     RETURN
**** END TOLERANCE ADJUSTMENT SUBROUTINE USING ZDTAB ENTRY ****
         SPACE 1
MASK16   DC    0F'0',X'0000FFFF' -      MASK TO FORCE UNSIGNED
*                                       HALFWORD
         LTORG -                        LITERAL POOL
         SPACE 1
UCBUNTYP EQU   19 -                     UCBTYP4 - DEVICE TYPE
         SPACE 1
         TITLE 'IGC018'
         IHADVCT , -                    MAP ZDTAB ENTRY
         EJECT ,
STARMAP  TRKCALC MF=D -                 MAP STAR PARAMETER LIST
./ ADD NAME=STARRTN
***********************************************************************
*                                                                     *
*                                                                     *
* Module name  =  STARRTN (IEC0SCR1 CSECT)                            *
*                                                                     *
*                                                                     *
* Descriptive name  =  System Track Algorithm Routine                 *
*                                                                     *
*                                                                     *
* Function  =  To provide standard MVS TRKCALC track balance          *
*              and track capacity services in the MVT environment.    *
*              See the extended comments in the SGSTAR macro for      *
*              more details.                                          *
*                                                                     *
*                                                                     *
* Module type  =  CSECT                                               *
*                                                                     *
*   Processor =  OS/VS XF assembler IFOX00                            *
*                                                                     *
*   Module size  =  See assembly listing.                             *
*                                                                     *
*   Attributes  =  Reentrant, caller state, caller key.               *
*                                                                     *
*                                                                     *
* Change activity      =                                              *
*                                                                     *
*   Flag  Date        By    Description                               *
*   ----  ----------  ----  ----------------------------------------  *
*   none  2010/05/04  KL    Refit MVS 3.8 STAR code for MVT.          *
*                                                                     *
*                                                                     *
***********************************************************************
         EJECT ,
*----------------------------------------------------------------*
*        Equates.                                                *
*----------------------------------------------------------------*
IEC0SCR1 CSECT
         PRINT ON
R0       EQU   0
R1       EQU   1
R2       EQU   2
R3       EQU   3
R4       EQU   4
R5       EQU   5
R6       EQU   6
R7       EQU   7
R8       EQU   8
R9       EQU   9
R10      EQU   10
R11      EQU   11
R12      EQU   12
R13      EQU   13
R14      EQU   14
R15      EQU   15
* Following two equates are defined in MVT SGIEC0DT
CVTPT    EQU   X'10' ABSOLUTE ADDRESS OF CVT POINTER             A27543
CVTZDTAB EQU   64                       DEVICE TABLE ADDR IN CVT
         EJECT ,
*----------------------------------------------------------------*
*        Following vector table is normally pointed to           *
*        by CVT field CVT0SCR1 and is simulated here.            *
*        Unmodified MVT has the first two entries, +0            *
*        and +4.  In MVS, the value at +4 is all binary          *
*        zeroes, +8 points to the extended RPS sector            *
*        convert routine and +12 to STAR.  For MVT,              *
*        +8 has been set to zeroes.                              *
*----------------------------------------------------------------*
IEC0SCR1 CSECT ,
         USING *,R15
         B     NOTQCNVT            +0   BRANCH AROUND ADCON             37567020
         DC    A(IEFQCNVT)         +4   ADDR OF ALT CONVERT RTN         37767020
         DC    X'00000000'         +8   Not used in OS/360         @D1x 37824021
         B     STAR                +12  STAR entry                 @D1x 37844021
NOTQCNVT EQU   *                        Dummy address                   37967020
IEFQCNVT EQU   *                        Dummy address
*MRPS    DC    F'0'                     RPS INDICATOR                   81967020
         COPY  SGSTAR                   Copy STAR code             @D1x 82070021
*FIN     MEND                                                           82167020
         END   IEC0SCR1
./ ADD NAME=STFSMODE
         MACRO                                                          00050000
&NAME    STFSMODE &A,&INITIAL=NO,&RSHWKEY=64 PROTOTYPE                  00100000
.********************************************************************** 00150000
.*                                                                    * 00200000
.* STATUS - OS/VS2 TSO/VTAM DYNAMIC RESHOW LEVEL 2.0                  * 00250000
.*                                                                    * 00300000
.* NAME - STFSMODE  (SET FULL SCREEN MODE)                            * 00350000
.*                                                                    * 00400000
.* FUNCTION - THE STFSMODE MACRO IS USED TO SPECIFY WHETHER OR NOT    * 00450000
.*            AN APPLICATION IS PRESENTING DISPLAYS TO A TSO/VTAM     * 00500000
.*            DISPLAY TERMINAL IN FULL SCREEN MODE.                   * 00550000
.*            WHEN INITIALLY SETTING THE MODE ON, INITIAL=YES WILL    * 00560000
.*            PREVENT PAGING FOR THE FIRST FULL SCREEN TPUT ISSUED BY * 00570000
.*            THE APPLICATION.                                        * 00580000
.*            RSHWKEY IS USED TO SPECIFY WHICH PFKEY IS TO BE USED    * 00582000
.*            AS THE RESHOW KEY.  E.G., RSHWKEY=3 MEANS THAT PFKEY 3  * 00584000
.*            IS TO BE THE RESHOW KEY.  WHEN STFSMODE IS OFF,         * 00586000
.*            RSHWKEY IS NOT TO BE SPECIFIED.  WHEN STFSMODE IS ON    * 00588000
.*            AND NO RSHWKEY HAS BEEN SPECIFIED, RSHWKEY WILL DEFAULT * 00590000
.*            TO ZERO.                                                * 00592000
.*                                                                    * 00600000
.*       THE MACRO PROTOTYPE IS ABOVE                                 * 00650000
.*                                                                    * 00700000
.*       THE STANDARD FORM OF THE EXPANSION IS BELOW                  * 00750000
.*&NAME  LA    1,128+64                 FLAGS FOR MODE/INITIAL CALL   * 00800000
.*       SLL   1,24                     SHIFT TO HIGH ORDER BYTE      * 00850000
.*       SR    0,0                      CLEAR REGISTER                * 00860000
.*       LA    0,10                     LOAD RSHWKEY                  * 00870000
.*       OR    1,0                      RSHWKEY IN RIGHTMOST BYTE     * 00880000
.*       LA    0,18                     LOAD ENTRY CODE               * 00900000
.*       SLL   0,24                     SHIFT TO HIGH ORDER BYTE      * 00950000
.*       SVC   94                       TERMINAL CONTROL MACRO SVC    * 01000000
.*                                                                    * 01050000
.* Note - In MVT, STFSMODE returns a return code of zero, but      @D01 01050200
.*        otherwise doesn't do anything.                           @D01 01050400
.*                                                                 @D01 01050600
.********************************************************************** 01100000
         LCLA  &SYSFS                                                   01105000
         LCLA  &SYSINIT                                                 01110000
&SYSFS   SETA  128                                                      01115000
&SYSINIT SETA  0                                                        01120000
         AIF   ('&INITIAL' NE 'YES' AND '&INITIAL' NE 'NO').ERROR1      01125000
         AIF   (&RSHWKEY GT 0 AND &RSHWKEY LT 13).TESTFS                01125700
         AIF   (&RSHWKEY NE 64).ERROR2                                  01126100
         AGO   .NEXT                                                    01127100
.TESTFS  ANOP                                                           01127800
         AIF   ('&A' EQ 'OFF').ERROR3                                   01128500
.NEXT    ANOP                                                           01129200
         AIF   ('&INITIAL' EQ 'NO').TESTA                               01130000
&SYSINIT SETA  64                                                       01135000
.TESTA   ANOP                                                           01140000
         AIF   ('&A' EQ 'ON' OR '&A' EQ '').FSON                        01150000
         AIF   ('&A' EQ 'OFF').FSOFF                                    01200000
.ERROR   IHBERMAC 36,,&A                                                01250000
         MEXIT                                                          01300000
.ERROR1  IHBERMAC 54,,,                                                 01310000
         MEXIT                                                          01320000
.ERROR2  IHBERMAC 54,,RSHWKEY                                           01326000
         MEXIT                                                          01332000
.ERROR3  IHBERMAC 1020,RSHWKEY,&A                                       01338000
         MEXIT                                                          01344000
.FSON    ANOP                                                           01350000
&NAME    LA    1,&SYSFS+&SYSINIT -      FLAGS FOR MODE/INITIAL CALL     01400000
         SLL   1,24 -                   SHIFT TO HIGH ORDER BYTE        01450000
         AGO   .PFCD                                                    01500000
.FSOFF   ANOP                                                           01550000
&NAME    SR    1,1 -                    CLEAR PARAMETER REGISTER        01600000
.PFCD    ANOP                                                           01608000
         AIF   ('&A' EQ 'OFF').ENTRYCD                                  01616000
         AIF   (&RSHWKEY EQ 64).ENTRYCD                                 01620000
         SR    0,0 -                    CLEAR REGISTER                  01624000
         LA    0,&RSHWKEY -             LOAD RSHWKEY                    01632000
         OR    1,0 -                    RSHWKEY IN RIGHTMOST BYTE       01638000
.ENTRYCD ANOP                                                           01650000
         LA    0,18 -                   LOAD ENTRY CODE                 01700000
         SLL   0,24 -                   SHIFT TO HIGH ORDER BYTE        01750000
         SVC   94 -                     TERMINAL CONTROL MACRO SVC      01800000
         MEND                                                           01850000
./ ADD NAME=STLINENO
         MACRO                                                          00050000
&NAME    STLINENO &LINE=,&LINELOC=,&MODE=OFF      PROTOTYPE             00100000
.********************************************************************** 00150000
.*                                                                    * 00200000
.* STATUS - CHANGE LEVEL 000                                          * 00250000
.*                                                                    * 00300000
.* NAME - STLINENO   (SET LINE NUMBER FOR NEXT TPUT EDIT TO 3270)     * 00350000
.*                                                                    * 00400000
.* FUNCTION - THE STLINENO MACRO IS USED TO SPECIFY ON WHICH LINE OF  * 00450000
.*            A TSO/VTAM DISPLAY SCREEN THE NEXT NON-FULL SCREEN TPUT * 00500000
.*            IS TO APPEAR.                                           * 00550000
.*                                                                    * 00600000
.*       THE MACRO PROTOTYPE IS ABOVE                                 * 00650000
.*                                                                    * 00700000
.*       THE STANDARD FORM OF THE EXPANSION IS BELOW                  * 00750000
.*                                                                    * 00800000
.*&NAME  LA    1,3                      PUT LINE NUM IN PARM REG      * 00850000
.*       LA    0,19                     LOAD ENTRY CODE               * 00900000
.*       SLL   0,24                     SHIFT TO HIGH ORDER BYTE      * 00950000
.*       SVC   94                       TERMINAL CONTROL MACRO SVC    * 01000000
.*                                                                    * 01050000
.* Note - In MVT, STLINENO operates as in MVS 3.8.  It sets the    @D01 01050200
.*        line for the next non-full screen TPUT.  STLINENO with   @D01 01050400
.*        LINE=1 does not automatically clear the screen as it     @D01 01050600
.*        does in more modern versions of MVS.                     @D01 01050800
.*                                                                 @D01 01051000
.********************************************************************** 01100000
         AIF   ('&LINE' NE '' AND '&LINELOC' NE '').ERROR1              01150000
         AIF   ('&LINE' EQ '' AND '&LINELOC' EQ '').ERROR2              01200000
         AIF   ('&MODE' NE 'OFF' AND '&MODE' NE 'ON').ERROR1            01250000
         AIF   ('&LINELOC' NE '').LNADDR                                01300000
         AIF   ('&LINE'(1,1) EQ '(').LNREG                              01350000
&NAME    LA    1,&LINE -                PUT LINE NUM IN PARM REG        01400000
         AGO   .STMODE                                                  01450000
.LNREG   ANOP                                                           01470000
&NAME    LR    1,&LINE(1) -             PUT LINE NUM IN PARM REG        01500000
         AGO   .STMODE                                                  01550000
.LNADDR  ANOP                                                           01600000
         AIF   ('&LINELOC'(1,1) EQ '(').LNADREG                         01650000
&NAME    L     1,&LINELOC -             PUT LINE NUM IN PARM REG        01700000
         AGO   .STMODE                                                  01750000
.LNADREG ANOP                                                           01800000
&NAME    L     1,0(,&LINELOC(1)) -      PUT LINE NUM IN PARM REG        01850000
.STMODE  ANOP                                                           01900000
         AIF   ('&MODE' EQ 'OFF').STMDOFF                               01950000
         LA    0,128 -                  PREPARE FLAY BYTE               02000000
         SLL   0,24 -                   SHIFT TO HIGH ORDER BYTE        02050000
         OR    1,0 -                    SET MODE=ON FLAG IN REG 1       02100000
         AGO   .ENTRYCD                                                 02110000
.STMDOFF ANOP                                                           02120000
         SR    0,0 -                    PREPARE FLAG BYTE               02130000
         OR    1,0 -                    SET MODE=OFF FLAG IN REG 1      02140000
.ENTRYCD ANOP                                                           02150000
         LA    0,19 -                   LOAD ENTRY CODE                 02200000
         SLL   0,24 -                   SHIFT TO HIGH ORDER BYTE        02250000
         SVC   94 -                     TERMINAL CONTROL MACRO SVC      02300000
         MEXIT                                                          02350000
.ERROR1  IHBERMAC 54,,,                                                 02400000
         MEXIT                                                          02450000
.ERROR2  IHBERMAC 24,,,                                                 02500000
         MEND                                                           02550000
./ ADD NAME=TRKCALC
         MACRO                                                          00050037
&NAME    TRKCALC &FUNCTN=,&DEVTAB=,&TYPE=,&UCB=,&BALANCE=,&REMOVE=,    C00100037
               &MAXSIZE=,&REGSAVE=,&RKDD=,&R=,&K=,&DD=,&LAST=,&MF=I     00150037
.***** START OF SPECIFICATIONS **************************************** 00200037
.*                                                                      00250037
.* MODULE NAME - TRKCALC                                                00300037
.*                                                                      00350037
.* DESCRIPTIVE NAME -                                                   00400037
.*      SYSTEM TRACK ALGORITHM ROUTINE (STAR) SERVICE MACRO             00450037
.*                                                                      00500037
.* COPYRIGHT - NONE                                                     00550037
.*                                                                      00600037
.* STATUS - NEW                                                         00650037
.*                                                                      00700037
.* FUNCTION -                                                           00750037
.*    THIS MACRO, DEPENDING ON THE VALUE OF THE "MF" PARAMETER,         00800037
.*    PERFORMS ONE OF FOUR BASIC FUNCTIONS RELATED TO ESTABLISHING      00850037
.*    OR MAPPING THE INPUT PARAMETER LIST FOR THE SYSTEM TRACK          00900037
.*    ALGORITHM ROUTINE (STAR). THE FOUR FUNCTIONS ARE DESCRIBED        00950037
.*    BELOW:                                                            01000037
.*                                                                      01050037
.*    MF=I - DEFAULT - WITH A SPECIFICATION OF MF=I, THIS MACRO         01100037
.*       WILL ALLOCATE STORAGE FOR THE STAR PARAMETER LIST AND          01150037
.*       INITIALIZE IT ACCORDING TO THE OPTIONS SELECTED VIA THE        01200037
.*       ALLOWABLE KEYWORDS (SEE BELOW FOR KEYWORD DESCRIPTIONS).       01250037
.*       THIS IS CALLED THE STANDARD-FORM (INSTRUCTION FORMAT) OF       01300037
.*       THE MACRO.                                                     01350037
.*    MF=E - THIS SPECIFICATION WILL RESULT IN THE INITIALIZATION       01400037
.*       OF AN ALREADY EXISTING STAR PARAMETER LIST. THE ADDRESS        01450037
.*       OF THE EXISTING PARAMETER LISTS IS PROVIDED VIA A SECOND       01500037
.*       SUBPARAMETER OF THE "MF" KEYWORD. (SEE THE SECTION BELOW       01550037
.*       ON KEYWORDS FOR THE SOURCE OF THE INITIALIZATION DATA).        01600037
.*       THIS IS CALLED THE EXECUTE-FORM OF THE MACRO.                  01650037
.*                                                                      01700037
.*    NOTE - NO KEYWORDS ARE PROCESSED FOR THE FOLLOWING MACRO FORMS.   01750037
.*                                                                      01800037
.*    MF=L - THIS SPECIFICATION WILL RESULT IN THE ALLOCATION           01850037
.*       OF THE STAR PARAMETER LIST WITHOUT INITIALIZATION. THIS IS     01900037
.*       CALLED THE LIST-FORM OF THE MACRO.                             01950037
.*    MF=D - THIS SPECIFICATION WILL RESULT IN THE GENERATION OF A      02000037
.*       MAPPING OF THE SYMBOLS USED TO ADDRESS THE FIELDS AND          02050037
.*       FLAGS OF THE STAR PARAMETER LIST. THE CALLER MUST PROVIDE      02100037
.*       A "DSECT" STATEMENT IN ORDER TO OBTAIN SYMBOLIC ADDRESSING     02150037
.*       WITHOUT STORAGE ALLOCATION. THIS IS CALLED THE DSECT-FORM      02200037
.*       OF THE MACRO.                                                  02250037
.*                                                                      02300037
.*    KEYWORDS- (APPLICABLE ONLY FOR MF=I AND MF=E FORMS)               02350037
.*       FUNCTN - USED TO REQUEST TRACK BALANCE (TRKBAL) OR TRACK       02400037
.*          CAPACITY (TRKCAP) FUNCTIONS.                                02450037
.*       NOTE 1 - A SPECIAL OPTION IS PROVIDED TO ALLOW A TRKCALC CALL  02500037
.*                WITH THE 'FUNCTN' KEYWORD OMITTED. THIS OPTION IS     02550037
.*                ALLOWED ONLY IF THE KEYWORD MF=E IS CODED. IF THE     02600037
.*                'FUNCTN' KEYWORD IS OMITTED, NO INSTRUCTION WILL BE   02650037
.*                GENERATED TO SET THE PARAMETER LIST FLAGS. THUS,      02700037
.*                THE MUTUALLY EXCLUSIVE TEST FOR FUNCTN=TRKCAP AND     02750037
.*                REMOVE=YES, MAXSIZE=YES, AND LAST=YES IS BYPASSED.    02800037
.*                ALSO, THE FOLLOWING NOTE (2) DOES NOT APPLY.          02850037
.*       NOTE 2 - ONE OF THE FOLLOWING THREE KEYWORDS (DEVTAB,          02900037
.*                TYPE, OR UCB) MUST BE PROVIDED WHEN THE 'FUNCTN'      02950037
.*                KEYWORD IS CODED. THIS IS TO ENSURE A SOURCE FOR THE  03000037
.*                DEVICE CHARACTERISTICS TABLE. IF THE PARAMETER LIST   03050037
.*                HAS BEEN PREVIOUSLY SET WITH A SOURCE, THEN AN '*'    03100037
.*                SHOULD BE CODED AS THE INPUT VALUE FOR THE PROPER     03150037
.*                SOURCE KEYWORD. THIS WILL RESULT IN THE PROPER SOURCE 03200037
.*                FLAG SETTING WITHOUT ACTUALLY GENERATING THE CODE TO  03250037
.*                STORE THE DVCT.                                       03300037
.*       DEVTAB - USED TO SUPPLY THE ADDRESS OF THE DEVICE CHARACTER-   03350037
.*          ISTICS TABLE ENTRY.                                         03400037
.*       TYPE - USED TO SUPPLY THE UCB DEVICE TYPE VIA THE LOW ORDER    03450037
.*          BYTE OF A REGISTER OR AN ADDRESS. UCB TYPE IS USED BY STAR  03500037
.*          TO FIND THE DEVICE CHARACTERISTICS TABLE ENTRY.             03550037
.*       UCB - USED TO PROVIDE THE ADDRESS OF THE UCB. STAR WILL        03600037
.*          EXTRACT THE DEVICE TYPE TO FIND THE PROPER DEVICE CHAR-     03650037
.*          ACTERISTICS TABLE ENTRY.                                    03700037
.*       BALANCE - USED TO PROVIDE THE ADDRESS OF A TRACK BALANCE TO BE 03750037
.*          USED BY STAR IN THE CAPACITY AND BALANCE ALGORITHMS.        03800037
.*       RKDD - USED TO SUPPLY THE ADDRESS OF A FULL WORD CONTAINING    03850037
.*          A RECORD NUMBER, KEY LENGTH, AND DATA LENGTH OR TO DESIG-   03900037
.*          NATE A REGISTER CONTAINING SAME. THE FOLLOWING THREE KEY-   03950037
.*          WORDS SUPPLY THE SAME DATA, BUT FROM SEPARATE SOURCES.      04000037
.*                                                                      04050037
.*       NOTE - THE FOLLOWING THREE KEYWORDS PROVIDE THE CAPABILITY     04100037
.*              FOR THE CALLER TO CODE THE RECORD NUMBER, KEY LENGTH,   04150037
.*              AND DATA LENGTH AS SELF-DEFINING DECIMAL VALUES         04200037
.*              (REFERRED TO HERE AS IMMEDITATE DATA).                  04250037
.*                                                                      04300037
.*       R - USED TO PROVIDE THE SUBJECT RECORD NUMBER VIA THE LOW-     04350037
.*           ORDER BYTE OF A REGISTER, A STORAGE ADDRESS, OR IMMEDIATE  04400037
.*           DATA.                                                      04450037
.*       K - USED TO PROVIDE THE SUBJECT KEY LENGTH VIA THE LOW-ORDER   04500037
.*           BYTE OF A REGISTER, A STORAGE ADDRESS, OR IMMEDIATE        04550037
.*           DATA.                                                      04600037
.*       DD - USED TO PROVIDE THE SUBJECT DATA LENGTH VIA THE LOW-ORDER 04650037
.*           BYTE OF A REGISTER, A STORAGE ADDRESS, OR IMMEDIATE        04700037
.*           DATA.                                                      04750037
.*                                                                      04800037
.*       NOTE - THE FOLLOWING THREE KEYWORDS (REMOVE, MAXSIZE, AND      04850037
.*              LAST) ARE VALID ONLY WHEN 'FUNCTN=TRKBAL' IS CODED.     04900037
.*              THEY ARE IGNORED IF 'FUNCTN' IS OMITTED.                04950037
.*                                                                      05000037
.*       REMOVE - USED TO OPTIONALLY REQUEST THE DELETION OF A RECORD   05050037
.*          DURING A TRACK BALANCE REQUEST.                             05100037
.*       MAXSIZE - USED TO OPTIONALLY REQUEST A COUNT OF THE RESIDUAL   05150037
.*          DATA BYTES ON A TRACK AFTER IT IS FOUND THAT ANOTHER WHOLE  05200037
.*          RECORD WILL NOT FIT DURING A TRACK BALANCE REQUEST.         05250037
.*       LAST - A SPECIAL OPTION MADE AVAILABLE FOR ISAM. IF SPECIFIED, 05300037
.*          THE OVERHEAD FOR THE LAST RECORD IS USED IN CALCULATING     05350037
.*          A NEW TRACK BALANCE.                                        05400037
.*       REGSAVE - USED TO OPTIONALLY REQUEST SAVING AND RESTORING      05450037
.*          REGISTERS 1 - 14 ACROSS THE INVOCATION OF STAR.             05500037
.*       MF - USED TO SPECIFY WHICH FORM OF THE TRKCALC MACRO IS        05550037
.*          DESIRED. SEE OPENING PARAGRAPH ABOVE.                       05600037
.*                                                                      05650037
.*    INTERNAL PROCESSING FOR THE I AND E FORMS OF THE MACRO IS         05700037
.*    CONTROLLED BY A NUMBER OF LOCAL BINARY AND CHARACTER              05750037
.*    VARIABLES. THE L AND D FORMS OF THE MACRO ARE HANDLED BY          05800037
.*    DIRECT PATHS THROUGH THE MACRO AND AS SUCH DO NOT INVOLVE THE     05850037
.*    USE OF LOCAL VARIABLES. FOLLOWING ARE THE DESCRIPTIONS OF THE     05900037
.*    THE LOCAL VARIABLES USED FOR THE I AND E FORMS:                   05950037
.*                                                                      06000037
.*    LCLC'S -                                                          06050037
.*       &FUNFLG - 'B' = TRKBAL FUNCTION REQUESTED                      06100037
.*               - 'C' = TRKCAP FUNCTION REQUESTED                      06150037
.*               - (OMITTED) = USE FUNCTION FLAGS FROM LAST CALL        06200037
.*       &SAVAREA - 'NO' = DON'T SAVE AND RESTORE REGISTERS             06250037
.*                  'YES' = SAVE AND RESTORE REGISTERS                  06300037
.*       &SET(1) - DVCT SOURCE WITH POSSIBLE PARENTHESES REMOVED: DVCT  06350037
.*                 ADDRESS, UCB ADDRESS, OR DEVICE TYPE (ADDRESS        06400037
.*                 OR IMMEDIATE DATA)                                   06450037
.*       &SET(2) - RKDD PARAMETER VALUE WITH POSSIBLE PARENTHESES       06500037
.*                 REMOVED                                              06550037
.*       &SET(3) - R PARAMETER VALUE WITH POSSIBLE PARENTHESES REMOVED  06600037
.*       &SET(4) - K PARAMETER VALUE WITH POSSIBLE PARENTHESES REMOVED  06650037
.*       &SET(5) - DD PARAMETER VALUE WITH POSSIBLE PARENTHESES REMOVED 06700037
.*       &SET(6) - BALANCE PARAMETER VALUE WITH POSSIBLE PARENTHESES    06750037
.*                 REMOVED                                              06800037
.*       &SKIP - 'P3' = RKDD PARAMETER NOT SPECIFIED                    06850037
.*       &FLGA(1) - 'R' = &SET(1) (DVCT SOURCE PARAMETER) IS IN         06900037
.*                        REGISTER FORMAT                               06950037
.*                - 'A' = &SET(1) (DVCT SOURCE PARAMETER) IS IN ADDRESS 07000037
.*                        FORMAT                                        07050037
.*       &FLGA(2) - 'R' = RKDD PARAMETER IS IN REGISTER FORMAT          07100037
.*                - 'A' = RKDD PARAMETER IS IN ADDRESS FORMAT           07150037
.*       &FLGA(3) - 'R' = BALANCE PARAMETER IS IN REGISTER OR IMMED-    07200037
.*                        IATE DATA FORMAT                              07250037
.*                - 'A' = BALANCE PARAMETER IS IN ADDRESS FORMAT        07300037
.*       &FLGA(4) - 'R' = R PARAMETER IS IN REGISTER FORMAT             07350037
.*       &FLGA(5) - 'R' = K PARAMETER IS IN REGISTER FORMAT             07400037
.*       &FLGA(6) - 'R' = DD PARAMETER IS IN REGISTER FORMAT            07450037
.*       &LABEL - AID TO VARIABLE LABEL ASSIGNMENT                      07500037
.*       &BITS - USED TO COLLECT BIT SWITCHES FOR STAR PARM FLAGS       07550037
.*                                                                      07600037
.*    LCLB'S                                                            07650037
.*       &BIT(1) - 0 = TRKBAL REQUESTED OR FUNCTN WAS OMITTED           07700037
.*               - 1 = TRKCAP REQUESTED                                 07750037
.*       &BIT(2) - 0 = REMOVE OPTION NOT REQUESTED                      07800037
.*               - 1 = REMOVE OPTION REQUESTED                          07850037
.*       &BIT(3) - 0 = MAXSIZE OPTION NOT REQUESTED                     07900037
.*               - 1 = MAXSIZE OPTION REQUESTED                         07950037
.*       &BIT(4) - 0 = BALANCE NOT PROVIDED CALLER                      08000037
.*               - 1 = BALANCE PROVIDED BY CALLER                       08050037
.*       &BIT(5) - 0 = LAST OPTION NOT REQUESTED                        08100037
.*               - 1 = LAST OPTION REQUESTED                            08150037
.*       &BIT(6&7) - 00 = DVCT ENTRY ADDRESS PROVIDED                   08200037
.*                   01 = NOT USED                                      08250037
.*                   10 = UCB ADDRESS PROVIDED                          08300037
.*                   11 = DEVICE TYPE (ADDRESS OR IMMEDIATE) PROVIDED   08350037
.*       &QUIT - 0 = SUCCESSFUL PARAMETER LIST CONSTRUCTION             08400037
.*             - 1 = ERRORS DETECTED. DO NOT GENERATE ANY CODE          08450037
.*       &MSG - 0 = NO INFORMATION/WARNING MESSAGES ISSUED              08500037
.*              1 = INFORMATION/WARNING MESSAGES ISSUED                 08550037
.*                                                                      08600037
.* NOTES - N/A                                                          08650037
.*                                                                      08700037
.* MODULE TYPE - MACRO                                                  08750037
.*                                                                      08800037
.* ENTRY POINT - N/A                                                    08850037
.*                                                                      08900037
.* INPUT - SEE DESCRIPTION OF KEYWORDS UNDER "FUNCTION".                08950037
.*                                                                      09000037
.* OUTPUT - SEE OPENING PARAGRAPH UNDER "FUNCTION".                     09050037
.*                                                                      09100037
.* EXIT, NORMAL - RETURN TO CALLER WITH A SEVERITY CODE OF 0            09150037
.*                                                                      09200037
.* EXIT, ERROR - RETURN TO CALLER WITH A SEVERITY CODE OF:              09250037
.*                  4 - IF ASSUMPTIONS HAD TO BE MADE REGARDING         09300037
.*                      KEYWORD VALUES.                                 09350037
.*                  8 - IF UNRECOVERABLE ERRORS ARE DETECTED.           09400037
.*                 12 - If the user provided a device type,        @D01 09420000
.*                      but the Device Characteristics Table       @D01 09420200
.*                      indicates that no device of the specified  @D01 09420400
.*                      type was generated.                        @D01 09420600
.*                                                                      09450037
.* EXTERNAL REFERENCES - N/A                                            09500037
.*                                                                      09550037
.* TABLES - N/A                                                         09600037
.*                                                                      09650037
.* MACROS - IHBINNRA                                                    09700037
.*                                                                      09750037
.* Change activity -                                               @D01 09800037
.*  Flag  Date        By    Description                            @D01 09800300
.*  ----  ----------  ----  ------------------------------------   @D01 09800500
.*  $D01  2010/04/16  KL    Support for TRKCALC on OS/360:         @D01 09830750
.*                          Require REGSAVE=YES; document STAR     @D01 09830780
.*                          use of R2 and R3 in addition to R0,    @D01 09830810
.*                          R1, R9, R10, R11, R14 and R15; add     @D01 09830840
.*                          test in macro calling sequence to      @D01 09830870
.*                          verify that STAR is present on OS;     @D01 09830900
.*                          load base vector address from VCON     @D01 09831200
.*                          instead of CVT.                        @D01 09831400
.*                                                                      09850037
.***** END OF SPECIFICATIONS ****************************************** 09900037
         LCLC  &FUNFLG,&SAVAREA,&SET(6),&SKIP,&FLGA(6),&LABEL,&BITS     09950037
         LCLB  &BIT(7),&QUIT,&MSG                                       10000037
&LABEL   SETC  '&NAME'                                                  10050037
         AIF   ('&MF' EQ 'L').LIST      BR IF LIST OPTION               10100037
         AIF   ('&MF' EQ 'D').DSECT     BR IF DSECT OPTION              10150037
*                                                                       10200037
*   STAR USES REGISTERS; 0(OUTPUT),1,9,10,11,14, AND               @D01 10250037
*                        15(RETURN CODE)                           @D01 10250437
*                                                                       10300037
.********************************************************************** 10350037
.*    KEYWORD SYNTAX CHECKING FOLLOWS                                   10400037
.********************************************************************** 10450037
.*                                                                      10500037
.********************************************************************** 10550037
.*    CHECK SYNTAX OF REGSAVE KEYWORD                                   10600037
.********************************************************************** 10650037
         AIF   (T'&REGSAVE EQ 'O').NOSAVE                               10700037
         AIF   ('&REGSAVE' EQ 'NO').NOSAVE                              10750037
         AIF   ('&REGSAVE' EQ 'YES').SAVE                               10800037
         AGO   .NOSAVE                                             @D01 10800400
         SPACE 1                                                        10850037
         MNOTE 4,'REGSAVE= OPERAND NOT RECOGNIZED; ''NO'' IS ASSUMED'   10900037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         10950037
.NOSAVE  ANOP                                                           11000037
         MNOTE 8,'REGSAVE=YES IS REQUIRED IN OS/360 ENVIRONMENT'   @D01 11002000
         MEXIT ,                                                   @D01 11004000
&SAVAREA SETC  'NO'                     INDICATE REG SAVING NOT REQ'D   11050037
         AGO   .SYNTAX                                                  11100037
.SAVE    ANOP                                                           11150037
*   REGSAVE OPTION SPECIFIED; ALL REGISTERS BUT 0 AND 15 WILL BE        11200037
*   SAVED AND RESTORED.                                                 11250037
*                                                                       11300037
&SAVAREA SETC  'YES'                    INDICATE REG SAVING REQ'D       11350037
.********************************************************************** 11400037
.*    SYNTAX CHECK OF FUNCTN KEYWORD                                    11450037
.********************************************************************** 11500037
.SYNTAX  ANOP                                                           11550037
         AIF   (T'&FUNCTN EQ 'O').NOFUNC                                11600037
         AIF   ('&FUNCTN' EQ 'TRKBAL').BALFUN                           11650037
         AIF   ('&FUNCTN' EQ 'TRKCAP').CAPFUN                           11700037
         SPACE 1                                                        11750037
         MNOTE 8,'FUNCTN= OPERAND INVALID; PROCESSING TERMINATED'       11800037
         SPACE 1                                                        11850037
         MEXIT                          ABORT - CAN'T VALIDATE          11900037
.*                                      REMAINING KEYWORD CONFLICTS     11950037
.NOFUNC  ANOP                                                           12000037
         AIF   ('&MF' NE 'I').NOPROBM   FUNCTN OMITTED AND MF=E IS OK   12050037
         SPACE 1                                                        12100037
         MNOTE 8,'FUNCTN= CAN NOT BE OMITTED WITH MF=I; PROCESSING TERMI12150037
               INATED'                                                  12200037
         SPACE 1                                                        12250037
         MEXIT                                                          12300037
.BALFUN  ANOP                                                           12350037
&FUNFLG  SETC  'B'                      INDICATE TRKBAL REQ'D           12400037
.NOPROBM ANOP                                                           12450037
&BIT(1)  SETB  0                        SET TRKBAL/OMITTED FLG FOR      12500037
.*                                      STAR PARMS                      12550037
         AGO   .TRKC010                                                 12600037
.CAPFUN  ANOP                                                           12650037
&FUNFLG  SETC  'C'                      INDICATE TRKCAP REQ'D           12700037
&BIT(1)  SETB  1                        SET TRKCAP FLG FOR STAR PARMS   12750037
.********************************************************************** 12800037
.*   CHECK SYNTAX OF DEVTAB KEYWORD                                     12850037
.********************************************************************** 12900037
.TRKC010 ANOP                                                           12950037
&BIT(6)  SETB  0                        INIT SOURCE FLAGS               13000037
&BIT(7)  SETB  0                        FOR DVCT ADDR                   13050037
         AIF   (T'&DEVTAB EQ 'O').TRKC020                               13100037
         AIF   ('&DEVTAB'(1,1) NE '(').DEVADDR                          13150037
         AIF   (N'&DEVTAB GT 1).DEVBAD                                  13200037
&SET(1)  SETC  '&DEVTAB(1)'             SAVE KEYW VALUE W/O PARENS      13250037
&FLGA(1) SETC  'R'                      INDICATE REG-FORM               13300037
         AGO   .TRKC020                 ON TO NEXT KEYW                 13350037
.DEVADDR ANOP                                                           13400037
&SET(1)  SETC  '&DEVTAB'                SAVE KEYW VALUE                 13450037
&FLGA(1) SETC  'A'                      INDICATE ADDR-FORM              13500037
         AGO   .TRKC020                 ON TO NEXT KEYW                 13550037
.DEVBAD  ANOP                                                           13600037
         SPACE 1                                                        13650037
         MNOTE 8,'DEVTAB= OPERAND INVALID; NO CODE PRODUCED'            13700037
&QUIT    SETB  1                        DEFER TERMINATION               13750037
.********************************************************************** 13800037
.*  CHECK SYNTAX OF TYPE KEYWORD                                        13850037
.********************************************************************** 13900037
.TRKC020 ANOP                                                           13950037
         AIF   (T'&TYPE EQ 'O').TRKC030                                 14000037
         AIF   ('&FLGA(1)' NE '').DEVBAD2  HAVE DVCT SOURCE ALREADY?    14050037
         AIF   ('&TYPE'(1,1) NE '(').TYPADDR                            14100037
         AIF   (N'&TYPE GT 1).TYPEBAD                                   14150037
&SET(1)  SETC  '&TYPE(1)'               SAVE KEYW VALUE W/O PARENS      14200037
&FLGA(1) SETC  'R'                      INDICATE REG-FORM               14250037
         AGO   .SETTYPE                 ON TO SETTING OF TYPE FLG       14300037
.TYPADDR ANOP                                                           14350037
&SET(1)  SETC  '&TYPE'                  SAVE KEYW VALUE                 14400037
&FLGA(1) SETC  'A'                      INDICATE ADDR-FORM              14450037
.SETTYPE ANOP                                                           14500037
&BIT(6)  SETB  1                        SET TYPE FLGS FOR               14550037
&BIT(7)  SETB  1                        STAR PARMS                      14600037
         AGO   .TRKC030                 ON TO NEXT KEYW                 14650037
.TYPEBAD ANOP                                                           14700037
         SPACE 1                                                        14750037
         MNOTE 8,'TYPE= OPERAND INVALID; NO CODE PRODUCED'              14800037
&QUIT    SETB  1                        DEFER TERMINATION               14850037
.********************************************************************** 14900037
.*  CHECK SYNTAX OF UCB KEYWORD                                         14950037
.********************************************************************** 15000037
.TRKC030 ANOP                                                           15050037
         AIF   (T'&UCB EQ 'O').TRKC040                                  15100037
         AIF   ('&FLGA(1)' NE '').DEVBAD2  HAVE DVCT SOURCE ALREADY?    15150037
         AIF   ('&UCB'(1,1) NE '(').UCBADDR                             15200037
         AIF   (N'&UCB GT 1).UCBBAD                                     15250037
&SET(1)  SETC  '&UCB(1)'                SAVE KEYW VALUE W/O PARENS      15300037
&FLGA(1) SETC  'R'                      INDICATE REG-FORM               15350037
         AGO   .SETUCB                  ON TO SETTING UCB FLG           15400037
.UCBADDR ANOP                                                           15450037
&SET(1)  SETC  '&UCB'                   SAVE KEYW VALUE                 15500037
&FLGA(1) SETC  'A'                      INDICATE ADDR-FORM              15550037
.SETUCB  ANOP                                                           15600037
&BIT(6)  SETB  1                        SET UCB FLG FOR STAR PARMS      15650037
         AGO   .TRKC040                 ON TO NEXT KEYW                 15700037
.DEVBAD2 ANOP                                                           15750037
         SPACE 1                                                        15800037
         MNOTE 8,'DEVTAB=, TYPE=, AND UCB= OPERANDS ARE MUTUALLY EXCLUSI15850037
               IVE;              NO CODE PRODUCED'                      15900037
&QUIT    SETB  1                        DEFER TERMINATION               15950037
         AGO   .TRKC040                 ON TO NEXT KEYW                 16000037
.UCBBAD  ANOP                                                           16050037
         SPACE 1                                                        16100037
         MNOTE 8,'UCB= OPERAND INVALID; NO CODE PRODUCED'               16150037
&QUIT    SETB  1                        DEFER TERMINATION               16200037
.********************************************************************** 16250037
.*  ENSURE THAT A SOURCE (DEVTAB, UCB, OR TYPE) FOR THE DEVICE CHAR-    16300037
.*  ACTERISTICS TABLE WAS PROVIDED. IF NOT, DEFAULT TO A RESIDUAL       16350037
.*  DEVTAB ADDRESS AS THE DVCT SOURCE.                                  16400037
.********************************************************************** 16450037
.TRKC040 ANOP                                                           16500037
         AIF   (T'&FUNCTN EQ 'O').TRKC045  BR, IF FUNCTN NOT PROVIDED - 16550037
.*                                      SOURCE ASSUMED, FLGS NOT SET    16600037
         AIF   ('&FLGA(1)' NE '').TRKC045  BR, IF DVCT SOURCE GIVEN     16650037
.*  AT THIS POINT IF &QUIT=1, THE CALLER PROVIDED A SOURCE FOR THE      16700037
.*  DVCT BUT IT WAS IN ERROR.                                           16750037
         AIF   (&QUIT).TRKC045          BR, IF &QUIT=1                  16800037
         SPACE 1                                                        16850037
         MNOTE 4,'DVCT SOURCE (DEVTAB=, UCB=, OR TYPE=) IS MISSING;    X16900037
                                 DEVTAB=* IS ASSUMED'                   16950037
&SET(1)  SETC  '*'                      INDICATE A RESIDUAL DEVTAB      17000037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         17050037
.********************************************************************** 17100037
.*  CHECK SYNTAX OF RKDD KEYWORD                                        17150037
.********************************************************************** 17200037
.TRKC045 ANOP                                                           17250037
         AIF   (T'&RKDD EQ 'O').TRKC050                                 17300037
         AIF   ('&RKDD'(1,1) NE '(').DORKDD                             17350037
         AIF   (N'&RKDD GT 1).RKDDBAD                                   17400037
&SET(2)  SETC  '&RKDD(1)'               SAVE KEYW VALUE W/O PARENS      17450037
&FLGA(2) SETC  'R'                      INDICATE REG-FORM               17500037
         AGO   .TSTDUP                                                  17550037
.DORKDD  ANOP                                                           17600037
         AIF   (T'&RKDD EQ 'N').RKDDBAD  BR IF IMMEDIATE-FORM; ERROR    17650037
&SET(2)  SETC  '&RKDD'                  SAVE KEYW VALUE                 17700037
&FLGA(2) SETC  'A'                      INDICATE ADDR-FORM              17750037
         AGO   .TSTDUP                                                  17800037
.RKDDBAD ANOP                                                           17850037
         SPACE 1                                                        17900037
         MNOTE 8,'RKDD= OPERAND INVALID; NO CODE PRODUCED'              17950037
&QUIT    SETB  1                        DEFER TERMINATION               18000037
.********************************************************************** 18050037
.*  SYNTAX CHECK FOR R, K, AND DD KEYWORDS                              18100037
.********************************************************************** 18150037
.TSTDUP  AIF   (T'&R NE 'O' OR T'&K NE 'O').MLTXERR  RKDD AND R, K, OR  18200037
         AIF   (T'&DD EQ 'O').TRKC060   DD ARE MUTUALLY EXCLUSIVE       18250037
.MLTXERR ANOP                                                           18300037
         SPACE 1                                                        18350037
         MNOTE 4,'R=, K=, OR DD= CAN NOT BE CODED WITH RKDD=; R=, K=, AN18400037
               ND DD=            ARE IGNORED'                           18450037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         18500037
         AGO   .TRKC060                 ON TO NEXT KEYW                 18550037
.TRKC050 ANOP                                                           18600037
&SKIP    SETC  'P3'                     INDICATE R/K/DD PROVIDED        18650037
         AIF   (T'&R EQ 'O').NORXX                                      18700037
         AIF   ('&R'(1,1) NE '(').NORXX                                 18750037
         AIF   (N'&R GT 1).BADPARM                                      18800037
&FLGA(4) SETC  'R'                      INDICATE REG-FORM               18850037
.NORXX   AIF   (T'&K EQ 'O').NOKXX                                      18900037
         AIF   ('&K'(1,1) NE '(').NOKXX                                 18950037
         AIF   (N'&K GT 1).BADPARM                                      19000037
&FLGA(5) SETC  'R'                      INDICATE REG-FORM               19050037
.NOKXX   AIF   (T'&DD EQ 'O').NODDXX                                    19100037
         AIF   ('&DD'(1,1) NE '(').NODDXX                               19150037
         AIF   (N'&DD GT 1).BADPARM                                     19200037
&FLGA(6) SETC  'R'                      INDICATE REG-FORM               19250037
.NODDXX  ANOP                                                           19300037
&SET(3)  SETC  '&R(1)'                  SAVE KEYW VALUES AND            19350037
&SET(4)  SETC  '&K(1)'                  STRIP AWAY                      19400037
&SET(5)  SETC  '&DD(1)'                 POSSIBLE PARENS                 19450037
         AGO   .TRKC060                 ON TO NEXT KEYW                 19500037
.BADPARM ANOP                                                           19550037
         SPACE 1                                                        19600037
         MNOTE 8,'R=, K=, OR DD= OPERAND INVALID; NO CODE PRODUCED'     19650037
&QUIT    SETB  1                        DEFER TERMINATION               19700037
.********************************************************************** 19750037
.*  SYNTAX CHECKING OF REMOVE KEYWORD                                   19800037
.********************************************************************** 19850037
.TRKC060 ANOP                                                           19900037
         AIF   (T'&REMOVE EQ 'O').NOREMV                                19950037
         AIF   ('&REMOVE' EQ 'NO').NOREMV                               20000037
         AIF   ('&REMOVE' NE 'YES').GARMSG1                             20050037
         AIF   ('&FUNFLG' EQ 'C').WARN1                                 20100037
&BIT(2)  SETB  1                        SET REMOVE FLG FOR STAR PARMS   20150037
         AGO   .TRKC070                 ON TO NEXT KEYW                 20200037
.GARMSG1 ANOP                                                           20250037
         SPACE 1                                                        20300037
         MNOTE 4,'REMOVE= OPERAND NOT RECOGNIZED; ''NO'' IS ASSUMED'    20350037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         20400037
         AGO   .NOREMV                                                  20450037
.WARN1   ANOP                                                           20500037
         SPACE 1                                                        20550037
         MNOTE 4,'REMOVE=YES AND FUNCTN=TRKCAP ARE MUTUALLY EXCLUSIVE; X20600037
                                 REMOVE=YES IS IGNORED'                 20650037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         20700037
.NOREMV  ANOP                                                           20750037
&BIT(2)  SETB  0                        RESET REMOVE FLG FOR STAR PARMS 20800037
.********************************************************************** 20850037
.*  SYNTAX CHECKING OF MAXSIZE KEYWORD                                  20900037
.********************************************************************** 20950037
.TRKC070 ANOP                                                           21000037
         AIF   ('&MAXSIZE' EQ 'NO').NOMAX                               21050037
         AIF   (T'&MAXSIZE EQ 'O').NOMAX                                21100037
         AIF   ('&MAXSIZE' NE 'YES').GARMSG2                            21150037
         AIF   ('&FUNFLG' EQ 'C').WARN2                                 21200037
&BIT(3)  SETB  1                        SET MAXSIZE FLG FOR STAR PARMS  21250037
         AGO   .TRKC080                 ON TO NEXT KEYW                 21300037
.GARMSG2 ANOP                                                           21350037
         SPACE 1                                                        21400037
         MNOTE 4,'MAXSIZE= OPERAND NOT RECOGNIZED; ''NO'' IS ASSUMED'   21450037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         21500037
         AGO   .NOMAX                                                   21550037
.WARN2   ANOP                                                           21600037
         SPACE 1                                                        21650037
         MNOTE 4,'MAXSIZE=YES AND FUNCTN=TRKCAP ARE MUTUALLY EXCLUSIVE;X21700037
                                 MAXSIZE=YES IS IGNORED'                21750037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         21800037
.NOMAX   ANOP                                                           21850037
&BIT(3)  SETB  0                        RESET MAXSIZE FLG FOR           21900037
.*                                      STAR PARMS                      21950037
.********************************************************************** 22000037
.*  SYNTAX CHECKING OF LAST KEYWORD                                     22050037
.********************************************************************** 22100037
.TRKC080 ANOP                                                           22150037
         AIF   ('&LAST' EQ 'NO').NOLAST                                 22200037
         AIF   (T'&LAST EQ 'O').NOLAST                                  22250037
         AIF   ('&LAST' NE 'YES').GARMSG3                               22300037
         AIF   ('&FUNFLG' EQ 'C').WARN3                                 22350037
&BIT(5)  SETB  1                        SET LAST FLG FOR STAR PARMS     22400037
         AGO   .TRKC090                 ON TO NEXT KEYW                 22450037
.GARMSG3 ANOP                                                           22500037
         SPACE 1                                                        22550037
         MNOTE 4,'LAST= OPERAND NOT RECOGNIZED; ''NO'' IS ASSUME'       22600037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         22650037
         AGO   .NOLAST                                                  22700037
.WARN3   ANOP                                                           22750037
         SPACE 1                                                        22800037
         MNOTE 4,'LAST=YES AND FUNCTN=TRKCAP ARE MUTUALLY EXCLUSIVE;   X22850037
                                 LAST=YES IS IGNORED'                   22900037
&MSG     SETB  1                        INDICATE MESSAGE ISSUED         22950037
.NOLAST  ANOP                                                           23000037
&BIT(5)  SETB  0                        RESET LAST FLG FOR STAR PARMS   23050037
.********************************************************************** 23100037
.*  SYNTAX CHECKING OF BALANCE KEYWORD                                  23150037
.********************************************************************** 23200037
.TRKC090 ANOP                                                           23250037
         AIF   (T'&BALANCE EQ 'O').BALOFF                               23300037
         AIF   ('&BALANCE'(1,1) EQ '(').BALREG                          23350037
&SET(6)  SETC  '&BALANCE'               SAVE KEYW VALUE                 23400037
&FLGA(3) SETC  'A'                      INDICATE ADDR-FORM              23450037
         AGO   .BALON                   ON TO SETTING BALANCE FLG       23500037
.BALREG  ANOP                                                           23550037
         AIF   (N'&BALANCE GT 1).BADBAL                                 23600037
&SET(6)  SETC  '&BALANCE(1)'            SAVE KEYW VALUE W/O PARENS      23650037
&FLGA(3) SETC  'R'                      INDICATE REG-FORM               23700037
         AGO   .BALON                   ON TO SETTING BALANCE FLG       23750037
.BADBAL  ANOP                                                           23800037
         SPACE 1                                                        23850037
         MNOTE 8,'BALANCE= OPERAND INVALID; NO CODE PRODUCED'           23900037
&QUIT    SETB  1                        DEFER TERMINATION               23950037
.BALOFF  ANOP                                                           24000037
&BIT(4)  SETB  0                        RESET BALANCE FLG FOR           24050037
.*                                      STAR PARMS                      24100037
         AGO   .TSTERR                                                  24150037
.BALON   ANOP                                                           24200037
&BIT(4)  SETB  1                        SET BALANCE FLG FOR STAR PARMS  24250037
.********************************************************************** 24300037
.*  TEST TO SEE IF ANY SERIOUS (TERMINATING) ERRORS WERE FOUND          24350037
.********************************************************************** 24400037
.TSTERR  AIF   (&MSG EQ 0 AND &QUIT EQ 0).SETBITS  DON'T SPACE IF CLEAN 24450037
         SPACE 1                                                        24500037
         AIF   (&QUIT EQ 0).SETBITS     CONTINUE IF NO TERMINAL ERRORS  24550037
         MEXIT                          OTHERWISE, GIVE IT UP           24600037
.********************************************************************** 24650037
.*  SET STAR PARM FLAGS FOR CODE GENERATION                             24700037
.********************************************************************** 24750037
.SETBITS ANOP                                                           24800037
&BITS    SETC  '&BIT(1).&BIT(3).&BIT(2).&BIT(4).&BIT(5).&BIT(6).&BIT(7)-24850037
               .0'                                                      24900037
.********************************************************************** 24950037
.*  CHECK SYNTAX OF MF KEYWORD                                          25000037
.********************************************************************** 25050037
.MFCHECK AIF   ('&MF' EQ 'I').DOCNOP                                    25100037
         AIF   (N'&MF NE 2).MFBAD                                       25150037
         AIF   ('&MF(1)' NE 'E').MFBAD                                  25200037
         AGO   .TSTSA                   GO TEST FOR REG SAVE REQ        25250037
.DOCNOP  ANOP                                                           25300037
         CNOP  0,4 -                    BOUNDARY ALIGNMENT              25350037
.TSTSA   AIF   ('&SAVAREA' NE 'YES').NOSA                               25400037
&LABEL   STM   14,12,12(13) -           SAVE REGISTERS                  25450037
&LABEL   SETC  ''                       CAN USE A LABEL ONLY ONCE       25500037
.NOSA    AIF   ('&MF' EQ 'I').STNDARD                                   25550037
&LABEL   IHBINNRA &MF(2)                GO LOAD PARM REG                25600037
         AGO   .XECUTE                  GO GEN CODE TO INIT PARM LIST   25650037
.MFBAD   ANOP                                                           25700037
         MNOTE 8,'MF= OPERAND INVALID; PROCESSING TERMINATED'           25750037
         SPACE 1                                                        25800037
         MEXIT                          A BAD MF KEYW IS FATAL          25850037
.STNDARD ANOP                                                           25900037
&LABEL   BAL   1,*+16 -                 BRANCH AROUND LIST              25950037
&LABEL   SETC  ''                       CAN USE A LABEL ONLY ONCE       26000037
.LIST    ANOP                                                           26050037
&LABEL   DC    A(0)                     DVCT OR UCB ADDR, OR DEVTYPE    26100037
         AIF   ('&MF' EQ 'L').SKIPFLG   IF LIST, GEN ONLY ZERO'S        26150037
         DC    B'&BITS' -               FLAG BYTE                       26200037
         AGO   .TRKC100                 GO AROUND LIST CODE             26250037
.SKIPFLG ANOP                                                           26300037
         DC    X'00' -                  FLAG BYTE                       26350037
.TRKC100 ANOP                                                           26400037
         DC    X'00' -                  RESERVED                        26450037
         DC    AL2(0) -                 TRACK BALANCE                   26500037
         AIF   ('&MF' EQ 'L').SKIPR     GEN ZERO FOR                    26550037
         AIF   ('&FLGA(4)' EQ 'R').SKIPR  RECORD NUMBER UNLESS          26600037
         AIF   (T'&R NE 'N').SKIPR      IT'S THE IMMEDIATE-FORM         26650037
         DC    AL1(&R) -                RECORD NUMBER                   26700037
         AGO   .TRKC110                                                 26750037
.SKIPR   ANOP                                                           26800037
         DC    AL1(0) -                 RECORD NUMBER                   26850037
.TRKC110 ANOP                                                           26900037
         AIF   ('&MF' EQ 'L').SKIPK     GEN ZERO FOR                    26950037
         AIF   ('&FLGA(5)' EQ 'R').SKIPK  KEY LENGTH UNLESS             27000037
         AIF   (T'&K NE 'N').SKIPK      IT'S THE IMMEDIATE-FORM         27050037
         DC    AL1(&K) -                KEY LENGTH                      27100037
         AGO   .TRKC120                                                 27150037
.SKIPK   ANOP                                                           27200037
         DC    AL1(0) -                 KEY LENGTH                      27250037
.TRKC120 ANOP                                                           27300037
         AIF   ('&MF' EQ 'L').SKIPDD    GEN ZERO FOR                    27350037
         AIF   ('&FLGA(6)' EQ 'R').SKIPDD  DATA LENGTH UNLESS           27400037
         AIF   (T'&DD NE 'N').SKIPDD    IT'S THE IMMEDIATE-FORM         27450037
         DC    AL2(&DD)                 DATA LENGTH                     27500037
         AGO   .TRKC130                                                 27550037
.SKIPDD  ANOP                                                           27600037
         DC    AL2(0) -                 DATA LENGTH                     27650037
.TRKC130 ANOP                                                           27700037
         AIF   ('&MF' EQ 'L').FINISH    GEN NO INSTRUCTION IF LIST REQ  27750037
.XECUTE  ANOP                                                           27800037
         AIF   ('&SET(1)' EQ '*').TRKC140  IF *, THEN DVCT SOURCE IS    27850037
.*                                      ALREADY IN THE STAR LIST        27900037
         AIF   (&BIT(7)).GOTTYPE        BR IF TYPE PROVIDED             27950037
         AIF   ('&FLGA(1)' EQ 'R').BR1  BR IF REG-FORM                  28000037
         AIF   ('&FLGA(1)' NE 'A').TRKC140  BR IF NOT ADDR-FORM         28050037
         L     15,&SET(1) -             MOVE ADDR OF DEVTAB OR          28100037
         ST    15,0(0,1) -              UCB TO LIST                     28150037
         AGO   .TRKC140                                                 28200037
.BR1     ANOP                                                           28250037
         ST    &SET(1),0(0,1) -         ST @ OF DEVTAB OR UCB IN LIST   28300037
         AGO   .TRKC140                                                 28350037
.GOTTYPE AIF   ('&FLGA(1)' EQ 'R').TYPER  BR IF REG-FORM                28400037
.*                                      OTHERWISE, IT'S ADDR-FORM       28450037
         IC    15,&SET(1) -             MOVE DEVICE TYPE                28500037
         STC   15,3(0,1) -              TO LIST                         28550037
         AGO   .TRKC140                                                 28600037
.TYPER   ANOP                                                           28650037
         STC   &SET(1),3(0,1) -         ST DEVICE TYPE IN LIST          28700037
.TRKC140 ANOP                                                           28750037
         AIF   ('&MF' EQ 'I').NOFLAG    FLGS ARE DC'D FOR I-FORM        28800037
         AIF   (T'&FUNCTN EQ 'O').NOFLAG  USE RESIDUAL FLGS IF NO FUNCT 28850037
         MVI   4(1),B'&BITS' -          FLAGS TO LIST                   28900037
.NOFLAG  ANOP                                                           28950037
         AIF   (&BIT(4) NE 1).TRKC150   BR IF NO BALANCE PROVIDED       29000037
         AIF   ('&SET(6)' EQ '*').TRKC150  IF '*', BAL IS IN STAR       29050037
.*                                      PARM LIST ALREADY               29100037
         AIF   ('&FLGA(3)' EQ 'R').BR2  BR IF REG-FORM                  29150037
         LH    15,&SET(6) -             TRK BALANCE                     29200037
         STH   15,6(0,1) -              TO LIST                         29250037
         AGO   .TRKC150                                                 29300037
.BR2     ANOP                                                           29350037
         STH   &SET(6),6(0,1) -         ST TRK BALANCE IN LIST          29400037
.TRKC150 ANOP                                                           29450037
         AIF   ('&SKIP' EQ 'P3').RKDD3  BR IF RKDD WAS NOT PROVIDED     29500037
         AIF   ('&FLGA(2)' EQ 'R').BR3  BR IF REG-FORM                  29550037
         L     15,&SET(2) -             MOVE RKDD                       29600037
         ST    15,8(0,1) -              TO LIST                         29650037
         AGO   .EXITBR                                                  29700037
.BR3     ANOP                                                           29750037
         ST    &SET(2),8(0,1) -         ST RKDD IN LIST                 29800037
         AGO   .EXITBR                                                  29850037
.RKDD3   ANOP                                                           29900037
         AIF   (T'&R EQ 'O').AKY        BR IF R NOT PROVIDED            29950037
         AIF   ('&FLGA(4)' NE 'R').RADDR  BR IF NOT REG-FORM            30000037
         STC   &SET(3),8(0,1) -         ST REC NO. IN LIST              30050037
         AGO   .AKY                                                     30100037
.RADDR   ANOP                                                           30150037
         AIF   (T'&R EQ 'N').NRX        BR IF IMMEDIATE-FORM            30200037
         IC    15,&SET(3) -             MOVE REC NO.                    30250037
         STC   15,8(0,1) -              TO LIST                         30300037
         AGO   .AKY                                                     30350037
.NRX     ANOP                                                           30400037
         AIF   ('&MF' EQ 'I').AKY       IF I-FORM, R IS DC'D            30450037
         MVI   8(1),&R -                ST REC NO. IN LIST              30500037
.AKY     ANOP                                                           30550037
         AIF   (T'&K EQ 'O').ADDY       BR IF K NOT PROVIDED            30600037
         AIF   ('&FLGA(5)' NE 'R').KADDR  BR IF NOT REG-FORM            30650037
         STC   &SET(4),9(0,1) -         ST KEY LENGTH IN LIST           30700037
         AGO   .ADDY                                                    30750037
.KADDR   ANOP                                                           30800037
         AIF   (T'&K EQ 'N').NKX        BR IF IMMEDIATE-FORM            30850037
         IC    15,&SET(4) -             MOVE KEY LENGTH                 30900037
         STC   15,9(0,1) -              TO LIST                         30950037
         AGO   .ADDY                                                    31000037
.NKX     ANOP                                                           31050037
         AIF   ('&MF' EQ 'I').ADDY      IF I-FORM, K IS DC'D            31100037
         MVI   9(1),&K -                ST KEY LENGTH IN LIST           31150037
.ADDY    ANOP                                                           31200037
         AIF   (T'&DD EQ 'O').EXITBR    BR IF DD NOT PROVIDED           31250037
         AIF   ('&FLGA(6)' NE 'R').DDADDR  BR IF NOT REG-FORM           31300037
         STH   &SET(5),10(0,1) -        ST DATA LENGTH IN LIST          31350037
         AGO   .EXITBR                                                  31400037
.DDADDR  ANOP                                                           31450037
         AIF   (T'&DD EQ 'N').NDDX      BR IF IMMEDIATE-FORM            31500037
         LH    15,&SET(5) -             MOVE DATA LENGTH                31550037
         STH   15,10(0,1) -             TO LIST                         31600037
         AGO   .EXITBR                                                  31650037
.NDDX    ANOP                                                           31700037
         AIF   ('&MF' EQ 'I').EXITBR    IF I-FORM, DD IS DC'D           31750037
         MVI   10(1),&DD/256 -          ST DATA LENGTH(1) IN LIST       31800037
         MVI   11(1),&DD-((&DD/256)*256) ST DATA LENGTH(2) IN LIST      31850037
.EXITBR  ANOP                                                           31900037
.*       L     15,16 -                  ADDRESS OF CVT             @D01 31950037
.*       L     15,232(0,15) -           ADDRESS OF SECTOR CONV. RT @D01 32000037
         L     15,=V(IEC0SCR1) -        Get routine address        @D01 32020300
         L     14,4(,15) -              Get +4 word for MVS test   @D01 32020600
         LTR   14,14 -                  Is this MVS?               @D01 32020900
         BZ    *+20 -                   Yes, go call STAR          @D01 32021200
         CLI   8(15),X'00' -            Is STAR available in OS?   @D01 32021500
         BE    *+12 -                   Yes, go call STAR          @D01 32021800
         LA    15,16 -                  Else set error return      @D01 32022100
         B     *+8 -                    Skip STAR call             @D01 32022400
         BAL   14,12(0,15) -            USE STAR ENTRY ON CALL          32050037
         AIF   ('&SAVAREA' EQ 'NO').FINISH  BR IF REGSAVE NOT REQ'D     32100037
         LM    1,12,24(13) -            RESTORE REGS 1-12               32150037
         L     14,12(0,13) -            RESTORE REG 14                  32200037
.FINISH  MEXIT                                                          32250037
.DSECT   ANOP                                                           32300037
         DS    0F -                     ALIGN TO FULL WORD BOUNDARY     32350037
&NAME    DS    0CL12 -                  STAR PARM LIST MAP              32400037
STARUCBA DS    0F -                     UCB ADDRESS                     32450037
STARDCTA DS    0F -                     DEVICE TABLE ADDRESS            32500037
         DS    XL3 -                                                    32550037
STARTYPE DS    XL1 -                    DEVICE TYPE                     32600037
STARFLGS DS    XL1 -                    FUNCTION AND OPTIONS            32650037
STARFUNC EQU   B'10000000' -            FUNCTION: 0=TRKBAL, 1=TRKCAP    32700037
STARMAXS EQU   B'01000000' -            1=MAXSIZE REQUESTED             32750037
STARREMV EQU   B'00100000' -            1=REMOVE REQUESTED              32800037
STARUBAL EQU   B'00010000' -            1=CALLER PROVIDED BALANCE       32850037
STARLAST EQU   B'00001000' -            1=SPECIAL LAST RCD REQUEST      32900037
STARDTU  EQU   B'00000110' -            DVCT ENTRY SOURCE FLAGS:        32950037
*                                       00=DVCT ENTRY ADDRESS PROVIDED  33000037
*                                       01=RESERVED                     33050037
*                                       10=UCB ADDRESS PROVIDED         33100037
*                                       11=DEVICE TYPE PROVIDED         33150037
*        EQU   B'00000001' -            RESERVED - MUST BE ZERO         33200037
         DS    XL1 -                    RESERVED                        33250037
STARBAL  DS    H -                      TRACK BALANCE                   33300037
STARRKDD DS    0F -                     RECORD INFO AS DEFINED BELOW    33350037
STARR    DS    XL1 -                    RECORD NUMBER                   33400037
STARKL   DS    XL1 -                    KEY LENGTH                      33450037
STARDL   DS    H -                      DATA LENGTH                     33500037
         MEND                                                           33550037
./ ENDUP
??
//UPDHELP.SYSIN  DD  DATA,DLM='??'
./ ADD   NAME=PDS7003
./ ALIAS NAME=PDS
)F FUNCTION -                                                           00120000
 The PDS 7.0.03 command allows a TSO user to access and manipulate the  00130000
 directory and selected members of a partitioned data set (PDS).        00140000
                                                                        00150000
 PDS subcommands are available to display statistics on the data set    00160000
 directory and data set usage, modify the data set directory, modify    00170000
 the DCB attributes of the data set and validity check the data set.    00180000
                                                                        00190000
 Additional subcommands can display portions of the member name         00200000
 directory, list occurances of a search string in a member, restore a   00210000
 previously deleted member, create an alias for a member, display all   00220000
 aliases for a member, locate a member with desired attributes, and     00230000
 browse, list, delete or rename a member.                               00240000
                                                                        00250000
 For load data sets, subcommands are available to display and modify    00260000
 the linkage attributes of a module, list the HISTORY data for a        00270000
 module and MAP the CSECT structure of a module.                        00280000
                                                                        00290000
 For other partitioned data sets, subcommands are available to submit   00300000
 a JCL member, edit a member, print a member and display SPF statistics 00310000
 for a member.                                                          00320000
                                                                        00330000
                                                                        00340000
 PDS command features:                                                  00350000
    Hexadecimal member names -- member names may be entered in hex for  00360000
    any of the subcommands which accept member names (or partial member 00370000
    names) as input.  Thus, for these subcommands, x'd7c4e2f9' and PDS9 00380000
    are equivalent.  Also, note that x'333' and x'0333' are equivalent. 00390000
                                                                        00400000
    Default member names -- if no member name is entered for an ATTRIB, 00410000
    DELETE, DIRENTRY, EDIT, FIND, FSE, HISTORY, IF, LIST, MAP, MEMBERS, 00420000
    OUTCOPY, or SUBMIT subcommand, the PDS command will use the last    00430000
    member name or member group entered for any of these subcommands.   00440000
    In addition, note that the ALIAS, RENAME and RESTORE subcommands    00450000
    also modify the default member name.                                00460000
                                                                        00470000
    Member groups -- the above subcommands which allow default member   00480000
    names also accept ranges and patterns of member names.  A member    00490000
    name range is specified as name1:name2, which selects the same      00500000
    members as DISPLAY name1 name2; a pattern member name is            00510000
    specified as name1/name2, which selects the same members as         00520000
    PATTERN name1 name2.                                                00530000
                                                                        00540000
    Sequential data sets -- the following PDS subcommands are also      00550000
    defined for non-partitioned data sets: EDIT, FIND, FSE, LIST,       00560000
    SUBMIT and VERIFY.  The documented syntax is unchanged except that  00570000
    no data may be entered corresponding to the member name position.   00580000
                                                                        00590000
    Subcommand name abbreviations -- all subcommand names can be        00600000
    abbreviated to the first few characters of the subcommand name.     00610000
    Subcommand names are scanned in the order of output from the        00620000
    OPTIONS subcommand; the first match between the entered name        00630000
    and the subcommand name table is used.                              00640000
)X SYNTAX -                                                             00650000
     PDS     dsname VOLUME(name) SHR/OLD  subcommand operands           00660000
                                                                        00670000
 ALIASES  - none.                                                       00680000
 DEFAULTS - SHR                                                         00690000
 REQUIRED - dsname                                                      00700000
)O OPERANDS -                                                           00710000
  dsname       - specifies the data set name.                           00720000
                                                                        00730000
))VOLUME(name) - optional, specifies the volume name on which the       00740000
                 data set resides.  If a volume name is entered,        00750000
                 SYSDA is assumed as the unit name; otherwise,          00760000
                 the unit name from the catalog is used.  Note:         00770000
                 this parameter should be used if the data set is       00780000
                 not cataloged.                                         00790000
))SHR          - optional, specifies that the data set is to be         00800000
                 allocated with a disposition of SHR.                   00810000
))OLD          - optional, specifies that the data set is to be         00820000
                 allocated with a disposition of OLD to prevent the     00830000
                 use of this data set by other users.                   00840000
))SUBCOMMAND   - optional, specifies that PDS is not to process         00850000
                 subcommands -- only the single subcommand entered      00860000
                 and any of its operands will be processed.             00870000
))OPERANDS     - optional, specifies any required operands for a        00880000
                 subcommand entered on the primary command line.        00890000
)S  The PDS command has the following subcommands:                      00900000
   ATTRIB xx       - list attributes of member or module XX             00910000
   ATTRIB xx reus  - assign the reusable linkage attribute to module XX 00920000
   ALIAS xx yy     - add an alias of YY to member XX                    00930000
   CHANGE zzz      - switch to the data set ZZZ                         00940000
   COMPARE xxx yyy - compare members XXX and YYY with TSO COMPARE       00950000
   COMPRESS        - compress the data set                              00960000
   DISPLAY rr tt   - display member names in the range RR thru TT999999 00970000
   DIRENTRY xx     - dump the directory entry for member XX             00980000
   DELETE xx       - delete member XX                                   00990000
   EDIT xx         - edit member XX with the EDIT command processor     01000000
   END             - terminate the PDS command                          01010000
   EXEC ccc        - execute PDS subcommands from the CLIST CCC         01020000
   FIND xx =fff=   - list occurances of the string FFF in member XX     01030000
   FIXPDS exp(30)  - add 30 directory blocks to the data set            01040000
   FSE xx          - edit member XX with the FSE command processor      01050000
   HELP sss        - list the HELP entry for subcommand SSS             01060000
   HISTORY xx      - list HISTORY data for module XX                    01070000
   IF mvs/ rent    - locate the ..MVS.. modules marked as reentrant     01080000
   LIST xx         - display member XX                                  01090000
   MAP xx short    - map the CSECT structure of module XX in short form 01100000
   MEMBERS         - display the current member group                   01110000
   OPTIONS         - display the menu of PDS subcommands                01120000
   OUTCOPY xx      - output an IEBCOPY select statement for member XX   01130000
   PATTERN pp dd   - display all member names containing PP and DD      01140000
   RECALL          - display or reenter the previous PDS subcommand     01150000
   RENAME xx yy    - rename member XX to YY                             01160000
   RESTORE xx      - resurrect member XX                                01170000
   SUBMIT xx       - submit JCL member XX                               01180000
   TSO yy z1 z2    - invoke the TSO routine YY with operands Z1 and Z2  01190000
   USAGE           - list directory and data set statistics             01200000
   VERIFY          - validity check the data set                        01210000
                                                                        01220000
   Additional HELP only entries for PDS:                                01230000
   ABEND           - explains ABEND processing                          01240000
   ATTN            - explains attention handling                        01250000
   DEFINE          - explains member and data set terminology           01260000
   GROUP           - explains member groups and name forms allowed      01270000
   UPDATE          - explains data set protection and SHR updates       01280000
=ATTRIB=A=AT=ATT=ATTR=ATTRI                                             01290000
)F  The ATTRIB subcommand lists the attributes of a member.             01300000
                                                                        01310000
 If the data set is not a load library, SPF statistics are displayed    01320000
 for members last saved by SPF edit, any SSI information is formatted   01330000
 and displayed and alias information is displayed as follows:           01340000
   A.  If the member is an alias, an -A is displayed after the member   01350000
       name and unless NOALIASINFO is specified, the name of any        01360000
       corresponding real members will be displayed.                    01370000
   B.  If the member is not an alias and if ALIASINFO is specified,     01380000
       the name of any corresponding alias members and any apparent     01390000
       aliases will be displayed.                                       01400000
                                                                        01410000
 If the data set is a load library, the following linkage-editor        01420000
 attributes are identified:                                             01430000
   AMODE     - addressing mode (if AMODE is not 24 or RMODE is not 24)  01440000
   AUTH      - APF authorized                                           01450000
   DC        - downward compatible (the module can be reprocessed by    01460000
               a level E linkage-editor).                               01470000
   LOAD ONLY - only loadable (OL -- the module can be brought into main 01480000
               storage only with a LOAD MACRO)                          01490000
   NOT EDIT  - not editable (the module cannot be linkage-edited)       01500000
   NOT EXEC  - not executable (the linkage-editor noted an error and    01510000
               LET processing was not requested)                        01520000
   OVERLAY   - overlay load module structure                            01530000
   PAGE      - page alignment required                                  01540000
   REFR      - refreshable (replaceable by a new copy during execution) 01550000
   RENT      - reentrant (executable by several tasks simultaneously)   01560000
   REUS      - reusable (executable by several tasks in serial order)   01570000
   RLD error - if there is a mismatch between the directory RLD/CONTROL 01580000
               field and the first RLD entry of OS/VS linked modules    01590000
   RMODE     - residence mode (if RMODE is not 24 or AMODE is not 24)   01600000
   SCTR      - scatter load module structure                            01610000
   SSI       - SSI information in hexadecimal                           01620000
   TEST      - linked with the TEST option                              01630000
                                                                        01640000
 In addition, the ATTRIB subcommand can add or delete several linkage   01650000
 attributes for a load module.  When the ATTRIB subcommand is changing  01660000
 a module's attributes and the module is reentrant, the reusable        01670000
 attribute is also added as is done by the linkage-editor.              01680000
                                                                        01690000
 If a non-alias module is assigned a RMODE or AMODE value, any          01700000
 associated alias directory entries are updated to reflect the same     01710000
 RMODE value and the main module's AMODE value.                         01720000
                                                                        01730000
 If the module is an alias and unless NOALIASINFO is specified, the     01740000
 name of any corresponding real member will be displayed if it          01750000
 exists; otherwise, the module name from the alias directory entry      01760000
 (the real module name at the time the alias was created) will be       01770000
 displayed.                                                             01780000
                                                                        01790000
 If the module is not an alias and unless NOALIASINFO is specified,     01800000
 the name of any corresponding alias members and any apparent aliases   01810000
 will be displayed.                                                     01820000
                                                                        01830000
 Caution: this subcommand modifies the data set if linkage-edit         01840000
 attributes are specified.  To ensure data set integrity, you should    01850000
 allocate the data set as OLD or be aware of the data set update        01860000
 protection provided by the PDS command for SHR allocations (for        01870000
 details, see HELP UPDATE).                                             01880000
)X SYNTAX -                                                             01890000
     ATTRIB  member  AMODE24/AMODE31/AMODE64/AMODEANY                   01900000
                     AUTH/NOAUTH                                        01910000
                     DC/NODC                                            01920000
                     EDIT/NOEDIT                                        01930000
                     EXEC/NOEXEC                                        01940000
                     LOADONLY/NOLOADONLY                                01950000
                     PAGE/NOPAGE                                        01960000
                     REFR/NOREFR                                        01970000
                     RENT/NORENT                                        01980000
                     REUS/NOREUS                                        01990000
                     RLDFIX/NORLDFIX                                    02000000
                     RMODE24/RMODEANY                                   02010000
                     NONE                                               02020000
                     LKEDDATE/NOLKEDDATE                                02030000
                     ALIASINFO/NOALIASINFO                              02040000
                                                                        02050000
 ALIASES  - A, AT, ATT, ATTR, ATTRI, ATTRIB                             02060000
 DEFAULTS - for load or alias members:  member,   LKEDDATE,   ALIASINFO 02070000
            for other members:          member, NOLKEDDATE, NOALIASINFO 02080000
 REQUIRED - none.                                                       02090000
)O OPERANDS -                                                           02100000
  member  -  optional, specifies the name of the member(s) whose        02110000
             attributes are to be displayed or the name of the load     02120000
             module(s) whose attributes are to be updated.  Default     02130000
             member names, member name ranges and member name patterns  02140000
             are allowed; for more information, enter HELP GROUP.       02150000
                                                                        02160000
 The following linkage attribute modifications can be requested for     02170000
 load modules:                                                          02180000
))AMODE24     -  change addressing mode to 24                           02190000
))AMODE31     -  change addressing mode to 31                           02200000
))AMODE64     -  change addressing mode to 64                           02202000
))AMODEANY    -  change addressing mode to ANY                          02210000
))AUTH        -  authorize the module with APF                          02220000
))NOAUTH      -  remove APF authorization from the module               02230000
))DC          -  indicate that the module is downward compatible        02240000
))NODC        -  indicate that the module is not downward compatible    02250000
))EDIT        -  allow the module to be linkage-edited                  02260000
))NOEDIT      -  disallow linkage-editing of the module                 02270000
))EXEC        -  allow execution of the module                          02280000
))NOEXEC      -  disallow execution of the module                       02290000
))LOADONLY    -  allow module use only by a LOAD MACRO                  02300000
))NOLOADONLY  -  allow module use by any means                          02310000
))PAGE        -  require page alignment for the module                  02320000
))NOPAGE      -  allow any alignment for the module                     02330000
))REFR        -  add the refreshable attribute                          02340000
))NOREFR      -  remove the refreshable attribute                       02350000
))RENT        -  add the reentrant (and reusable) attribute             02360000
))NORENT      -  remove the reentrant attribute                         02370000
))REUS        -  add the reusable attribute                             02380000
))NOREUS      -  remove the reusable attribute                          02390000
))RLDFIX      -  change the directory's RLD/CONTROL count to match      02400000
                 the value in the first RLD entry for modules linked    02410000
                 since OS/VS                                            02420000
))NORLDFIX    -  do not modify the directory's RLD/CONTROL count        02430000
))RMODE24     -  change residence mode to 24                            02440000
))RMODEANY    -  change residence mode to ANY                           02450000
))NONE        -  equivalent to entering: AMODE24, NOAUTH, NODC,         02460000
                 EDIT, EXEC, NOLOADONLY, NOPAGE, NOREFR, NORENT,        02470000
                 NOREUS, and RMODE24.                                   02480000
                                                                        02490000
                 Note:  NONE takes effect first; any additional         02500000
                 parameters override corresponding NONE parameters.     02510000
))LKEDDATE    -  provide the date of the last linkage-edit if possible  02520000
))NOLKEDDATE  -  do not provide the date of the last linkage-edit       02530000
                 nor check the directory's RLD/CONTROL count against    02540000
                 the value in the first RLD entry                       02550000
))ALIASINFO   -  provide the names of any alias or real members         02560000
))NOALIASINFO -  do not provide the names of any alias or real members  02570000
=ALIAS=AL=ALI=ALIA                                                      02580000
)F   The ALIAS subcommand assigns an alias name to a named member.      02590000
                                                                        02600000
  If the data set is not a load library, the alias name may be used     02610000
  as an alternate name for the identified member.                       02620000
                                                                        02630000
  If the data set is a load library, then if the alias name is an       02640000
  imbedded external name within the load module, that external name     02650000
  will be used as the alias entry point; otherwise, the entry point     02660000
  of the named member will also be used as the alias entry point.       02670000
                                                                        02680000
  An alias name may be assigned to a member which is already an alias.  02690000
                                                                        02700000
  Caution: this subcommand modifies the data set. To ensure data set    02710000
  integrity, you should allocate the data set as OLD or be aware of     02720000
  the data set update protection provided by the PDS command for SHR    02730000
  allocations (for details, see HELP UPDATE).                           02740000
)X SYNTAX -                                                             02750000
     ALIAS  membername aliasname                                        02760000
                                                                        02770000
 ALIASES  - AL, ALI, ALIA, ALIAS                                        02780000
 DEFAULTS - none.                                                       02790000
 REQUIRED - membername, aliasname                                       02800000
)O OPERANDS -                                                           02810000
 membername - specifies the member to which an alias is to be assigned. 02820000
                                                                        02830000
 aliasname  - Specifies the alias name to be assigned.  Note that       02840000
              this alias name becomes the PDS default member name.      02850000
=CHANGE=C=CH=CHA=CHAN=CHANG=PDS=PD                                      02860000
)F The CHANGE or PDS subcommand switches PDS to a different             02870000
 data set.                                                              02880000
)X SYNTAX -                                                             02890000
     CHANGE  dsname VOLUME(name) SHR/OLD                                02900000
                                                                        02910000
 ALIASES  - PD, PDS, C, CH, CHA, CHAN, CHANG, CHANGE                    02920000
 DEFAULTS - SHR or previously used data set if no operands are entered  02930000
 REQUIRED - none.                                                       02940000
)O OPERANDS -                                                           02950000
  dsname       - optional, specifies the name of a different data set.  02960000
                 If no data set name is entered, the previously used    02970000
                 data set will be assumed.                              02980000
                                                                        02990000
))VOLUME(name) - optional, specifies the volume name on which the       03000000
                 data set resides.  If a volume name is entered,        03010000
                 SYSDA is assumed as the unit name; otherwise,          03020000
                 the unit name from the catalog is used.  Note:         03030000
                 this parameter should be used if the data set is       03040000
                 not cataloged.                                         03050000
))SHR          - optional, specifies that the data set is to be         03060000
                 allocated with a disposition of SHR.                   03070000
))OLD          - optional, specifies that the data set is to be         03080000
                 allocated with a disposition of OLD to prevent the     03090000
                 use of this data set by other users.                   03100000
=COMPARE=CO=COM=COMP=COMPA=COMPAR                                       03110000
)F  Example -     COMPARE oldmem newmem                                 03120000
                                                                        03130000
 The COMPARE subcommand displays differences between two members.       03140000
 The TSO COMPARE command is used; any desired COMPARE operands may      03150000
 be added after the member names.                                       03160000
)X SYNTAX -                                                             03170000
     COMPARE  membero membern  FULL           / ASM                     03180000
                               IEBCOMPR       / ZEBCOMPR                03190000
                               SYSOUT / PRINT / NOPRINT / OUTFILE(name) 03200000
                               OVOL(volname)  / NVOL(volume)            03210000
                                                                        03220000
 ALIASES  - CO, COM, COMP, COMPA, COMPAR, COMPARE                       03230000
 DEFAULTS - none.                                                       03240000
 REQUIRED - membero, membern                                            03250000
)O OPERANDS -                                                           03260000
  membero       - the base member which is to be compared with membern. 03270000
                                                                        03280000
  membern       - the new member which is to be compared with membero.  03290000
                                                                        03300000
  operands      - optional, may include any desired COMPARE operands.   03310000
=COMPRESS=COMPR=COMPRE=COMPRES                                          03320000
)F  Example -     COMPRESS summary                                      03330000
                                                                        03340000
 The COMPRESS subcommand invokes IEBCOPY (or a compatible program)      03350000
 to compress a partitioned data set.                                    03360000
                                                                        03370000
 Note: a COMPRESS operation should not be interrupted with an attention 03380000
 since data sets are updated in-place.                                  03390000
)X SYNTAX -                                                             03400000
     COMPRESS  SUMMARY / LIST / NOLIST                                  03410000
                                                                        03420000
 ALIASES  - COMPR, COMPRE, COMPRES, COMPRESS                            03430000
 DEFAULTS - SUMMARY                                                     03440000
 REQUIRED - none.                                                       03450000
)O OPERANDS -                                                           03460000
))SUMMARY  - specifies that only compress summary and error messages    03470000
             are to be displayed.                                       03480000
))LIST     - specifies that all compress messages are to be displayed.  03490000
))NOLIST   - specifies that no compress messages are to be displayed.   03500000
=CONTROL=CON=CONT=CONTR=CONTRO                                          03500100
)F  Example -     CONTROL dsname(lib.cntl(pdsdata)) old                 03500200
                                                                        03500300
 The CONTROL subcommand specifies global and immediate processing       03500400
 options.                                                               03500500
                                                                        03500600
 Most CONTROL subcommand operands (such as ALIASINFO and SINGLE) are    03500700
 global in that they remain in effect until reset by another CONTROL    03500800
 subcommand.                                                            03500900
                                                                        03501000
 The other operands (such as TESTABEND and IOSTATS) are immediate and   03501100
 take effect for only a single CONTROL subcommand.                      03501200
                                                                        03501300
 Note that the input buffering type (SINGLE, DOUBLE or MULTIPLE) is     03501400
 reset for each data set allocated according to the device type on      03501500
 which the data set resides.  MULTIPLE buffering is used for device     03501600
 types which support the READ MULTIPLE CCW and DOUBLE is used           03501700
 otherwise.                                                             03501800
)X SYNTAX -                                                             03501900
     CONTROL  ALIASINFO  / NOALIASINFO                                  03502000
              LKEDDATE   / NOLKEDDATE                                   03502100
              PROMPT     / NOPROMPT                                     03502200
              RECOVER    / NORECOVER                                    03502300
              TRANSLATOR / NOTRANSLATOR                                 03502350
              SINGLE     / DOUBLE      /  MULTIPLE                      03502400
              DSN(dsn)   / NODSN    / OLD/MOD/NEW/SHR                   03502500
                                                                        03502600
 ALIASES  - CON, CONT, CONTR, CONTRO, CONTROL                           03502700
 DEFAULTS - Initially in TSO:                                           03502800
            ALIASINFO, LKEDDATE, PROMPT, RECOVER, TRANSLATOR, DOUBLE    03502900
 REQUIRED - none.                                                       03503000
)O OPERANDS -                                                           03503100
))ALIASINFO     - specifies that a MAP subcommand with no limiting      03503200
                  operands is to provide alias information for alias    03503300
                  members and that an ATTRIB subcommand is to provide   03503400
                  alias information.                                    03503500
))NOALIASINFO   - specifies that ATTRIB and MAP subcommands need not    03503600
                  provide alias or main member identification.          03503700
))LKEDDATE      - specifies that an ATTRIB subcommand should provide    03503800
                  the date of the linkage edit.                         03503900
))NOLKEDDATE    - specifies that an ATTRIB subcommand should not        03504000
                  provide the date of the linkage edit.                 03504100
))PROMPT        - specifies that YES/NO decision prompting should be    03504200
                  solicited from the terminal operator unless -PDS86-   03504300
                  is executing in the background, from CLIST input or   03504400
                  from a storage stack.                                 03504500
                                                                        03504600
                  YES/NO prompting is normally performed at the         03504700
                  following decision points:                            03504800
                     1.  before renaming a group of members             03504900
                     2.  before deleting a default member               03505000
                     3.  before deleting a list or a group of members   03505100
                     4.  before restoring a member found in scan mode   03505200
                     5.  before modifying a data set with FIXPDS        03505300
                     6.  before submitting a group of members           03505400
                     7.  before reproducing a group of members          03505500
))NOPROMPT      - specifies that YES/NO decision prompting should be    03505600
                  circumvented and that a YES response should be        03505700
                  assumed in each case.                                 03505800
                                                                        03505900
                  YES/NO prompting is normally performed at the         03506000
                  following decision points:                            03506100
                     1.  before renaming a group of members             03506200
                     2.  before deleting a default member               03506300
                     3.  before deleting a list or a group of members   03506400
                     4.  before restoring a member found in scan mode   03506500
                     5.  before modifying a data set with FIXPDS        03506600
                     6.  before submitting a group of members           03506700
                     7.  before reproducing a group of members          03506800
))RECOVER       - specifies that STAE recovery is to be attempted       03506900
                  after a program ABEND.                                03507000
))NORECOVER     - specifies that STAE recovery is not to be attempted   03507100
                  after a program ABEND.  Note that subcommands which   03507200
                  specifically test for ABEND conditions (such as IF    03507300
                  with LOADERR or VERIFY with LOAD) should recover from 03507400
))TRANSLATOR    - specifies that HISTORY subcommands should output      03507420
                  TRANSLATOR information.                               03507440
))NOTRANSLATOR  - specifies that HISTORY subcommands should not output  03507460
                  TRANSLATOR information.                               03507480
                  ABEND situations regardless of RECOVER/NORECOVER.     03507500
))DSNAME(dsn)   - specifies that a session log output is to be started  03507600
                  to the named data set.  The DSNAME output will        03507700
                  continue until the end of the program or until        03507800
                  CONTROL DSNAME/NODSNAME is entered.                   03507900
                                                                        03508000
                  Notes:                                                03508100
                    1.  A member name must be entered for session log   03508200
                        output to a partitioned data set.               03508300
                    2.  A data set password may be entered.             03508400
                    3.  A data set disposition (OLD/MOD/SHR/NEW)        03508500
                        may also be entered.                            03508600
))NODSNAME      - specifies that any DSNAME session log output is to    03508700
                  be terminated.                                        03508800
))OLD           - specifies that the session log data set should not    03508900
                  be shared with other users.                           03509000
))MOD           - specifies that the session log output is to be added  03509100
                  to the end of an existing data set.  If the data set  03509200
                  does not exist, it will be created with               03509300
                  DCB=(RECFM=FB,LRECL=80,BLKSIZE=3120)                  03509400
))SHR           - specifies that the session log data set should be     03509500
                  shared with other users.  Note: since the data set    03509600
                  is modified, the use of this parameter should be      03509700
                  minimized.                                            03509800
))NEW           - specifies that the session log data set should be     03509900
                  created with DCB=(RECFM=FB,LRECL=80,BLKSIZE=3120)     03510000
))SINGLE        - specifies that a single input buffer is to be used.   03510100
))DOUBLE        - specifies that two buffers are to be used wherever    03510200
                  possible for input operations.                        03510300
))MULTIPLE      - specifies that an entire disk track is to be read     03510400
                  wherever possible for input operations.               03510500
))TESTABEND     - specifies that a S0C1 ABEND is to be provided for     03510600
                  program testing.                                      03510700
))TESTCPULOOP   - specifies that a program branch loop is to be         03510800
                  entered for program testing.                          03510900
))TESTMSGS      - specifies that the program should issue all numbered  03511000
                  messages for program testing.                         03511100
))TESTOUTLOOP   - specifies that a program output message loop is to be 03511200
                  entered for program testing.                          03511300
))TESTREAD      - specifies that the program should test its input EXCP 03511400
                  routine using an initial TTR of 000001 for each of    03511500
                  the following cases:                                  03511600
                                                                        03511700
          SINGLE: Read single (each read obtains one physical block).   03511800
                  The return code should be 00 and NEXT TTR ADDRESS     03511900
                  should be 000002 if sufficient data is available.     03512000
                                                                        03512100
          DOUBLE: Read double (each read obtains two physical blocks).  03512200
                  The return code should be 00 and NEXT TTR ADDRESS     03512300
                  should be 000003 if sufficient data is available.     03512400
                                                                        03512500
        MULTIPLE: Read multiple (each read obtains an entire track).    03512600
                  If the disk unit supports the READ MULTIPLE CCW, the  03512700
                  return code should be 00 and NEXT TTR ADDRESS         03512800
                  should be 000101 if sufficient data is available.     03512900
                                                                        03513000
                  If the disk unit does not support the READ MULTIPLE   03513100
                  CCW, a PDS892E message should be received, the return 03513200
                  code should be 00 and NEXT TTR ADDRESS should be      03513300
                  000003 (double buffering is used).                    03513400
=DISPLAY=D=DI=DIS=DISP=DISPL=DISPLA                                     03510000
)F    The DISPLAY subcommand lists member names from the data set       03520000
   directory.                                                           03530000
                                                                        03540000
   Note that -A is added following a displayed member name if the       03550000
   member name is an alias.  The member name is listed in a combined    03560000
   hexadecimal/character format if it does not contain upper-case       03570000
   alphanumeric characters (including @, $ and #) or if the first       03580000
   character is numeric.  Unprintable characters (for 3270-type         03590000
   devices) in a member name are displayed as periods.                  03600000
)X SYNTAX -                                                             03610000
     DISPLAY  name1 name2                                               03620000
                                                                        03630000
 ALIASES  - D, DI, DIS, DISP, DISPL, DISPLA, DISPLAY                    03640000
 DEFAULTS - entire directory                                            03650000
 REQUIRED - none.                                                       03660000
)O OPERANDS -                                                           03670000
 name1    - optional, specifies the starting member name (or portion    03680000
            of the member name) at which the display is to start. if    03690000
            omitted, the entire directory is displayed.                 03700000
                                                                        03710000
 name2    - optional, specifies the ending member name (or portion of   03720000
            the member name) after which the display is to stop.  If    03730000
            omitted, the display continues to the end of the directory. 03740000
=DIRENTRY=DIR=DIRE=DIREN=DIRENT=DIRENTR                                 03750000
)F The DIRENTRY subcommand dumps the directory entry of a member.       03760000
                                                                        03770000
 OFFSET  NAME      DESCRIPTION  (from GC28-1049, debugging handbook #3) 03780000
 ------  --------  ---------------------------------------------------- 03790000
  00     PDS2NAME  CL8   -- member name                                 03800000
  08     PDS2TTRP  XL3   -- TTR of first block of data                  03810000
  0B     PDS2INDC  X'80' -- member is an alias                          03820000
                   X'60' -- number of TTR's following (0 - 3)           03830000
                   X'1F' -- number of halfwords following (0 - 31)      03840000
                                                                        03850000
 *** Load module section only:                                          03860000
  0C     PDS2TTRT  XL4   -- first text TTR, x'00'                       03870000
  10     PDS2TTRN  XL4   -- overlay: note list TTR, number of entries   03880000
                            scatter: translation table TTR, x'00'       03890000
  14     PDS2ATR1  X'F0' -- reentrant, reusable, overlay, test          03900000
                   X'0F' -- only loadable, scatter, executable, 1 text  03910000
  15     PDS2ATR2  X'F0' -- not DC, text origin=0, EP=0, no rld items   03920000
                   X'0F' -- not EDIT, test symbols, LKED F, refreshable 03930000
  16     PDS2STOR  XL3   -- total contiguous storage required           03940000
  19     PDS2FTBL  XL2   -- length of first text block                  03950000
  1B     PDS2EPA   XL3   -- entry point address of this member          03960000
  1E     PDS2FTB1  XL1   -- x'80' processed by OS/VS linkage-editor     03970000
                            x'20' page alignment required               03980000
                            x'10' SSI information is present            03990000
                            x'08' APF information is valid              04000000
  1F     PDS2FTB2  XL1   -- x'10' RMODE ANY                             04010000
                            x'00' RMODE 24                              04010400
                            x'0C' Alias entry point is AMODE ANY        04020000
                            x'08' Alias entry point is AMODE 31         04020400
                            x'04' Alias entry point is AMODE 64         04020600
                            x'00' Alias entry point is AMODE 24         04020800
                            x'03' Main entry point is AMODE ANY         04030000
                            x'02' Main entry point is AMODE 31          04030400
                            x'01' Main entry point is AMODE 64          04030600
                            x'00' Main entry point is AMODE 24          04030800
  20     PDS2FTB3  XL1   -- # of RLD/CONTROL records after first text   04040000
                                                                        04050000
 *** Scatter load module section only:                                  04060000
  +0     PDS2SLSZ  XL2   -- number of bytes in scatter list             04070000
  +2     PDS2TTSZ  XL2   -- number of bytes in translation table        04080000
  +4     PDS2ESDT  XL2   -- ESD CSECT identifier of first text block    04090000
  +6     PDS2ESDC  XL2   -- ESD CSECT identifier of entry point         04100000
                                                                        04110000
 *** Alias load module section only:                                    04120000
  +0     PDS2EPM   XL3   -- entry point address of real member          04130000
  +3     PDS2MNM   CL8   -- member name of real member                  04140000
                                                                        04150000
 *** SSI section (note this section is on a halfword boundary):         04160000
  +0     PDSSSIW   XL4   -- SSI information                             04170000
                                                                        04180000
 *** APF section for OS/VS load modules:                                04190000
  +0     PDSAPFCT  X'01' -- length of following APF information         04200000
  +1     PDSAPFAC  XL1   -- 0 is not authorized; otherwise, authorized  04210000
                                                                        04210200
 *** LPO section for OS/VS load modules:                                04210400
  +0     PDS2LPOL  X'0D' -- length of the large program object section  04210600
  +1     PDS2VSTR  XL4   -- virtual storage requirement for this module 04210600
  +5     PDS2MEPA  XL4   -- main entry point offset                     04211000
  +9     PDA2AEPA  XL4   -- alias entry point offset                    04211200
)X SYNTAX -                                                             04220000
     DIRENTRY  member SHORT/LONG                                        04230000
                                                                        04240000
 ALIASES  - DIR, DIRE, DIREN, DIRENT, DIRENTR, DIRENTRY                 04250000
 DEFAULTS - member, SHORT for THEN(DIR) or ELSE(DIR); otherwise, LONG   04260000
 REQUIRED - none.                                                       04270000
)O OPERANDS -                                                           04280000
 member -   optional, specifies the name of the member(s) whose         04290000
            directory entry is to be dumped.  Default member names,     04300000
            member name ranges and member name patterns are allowed;    04310000
            for more information, enter HELP GROUP.                     04320000
                                                                        04320400
))SHORT   - specifies that only a directory entry dump is desired.      04320600
))LONG    - specifies that a directory entry dump and a listing of      04320800
            elements in the directory entry are desired.                04321000
=DELETE=DE=DEL=DELE=DELET=SC=SCR=SCRA=SCRAT=SCRATC=SCRATCH              04330000
)F   The DELETE or SCRATCH subcommand deletes a member from the         04340000
  data set.                                                             04350000
                                                                        04360000
  Caution: this subcommand modifies the data set. To ensure data set    04370000
  integrity, you should allocate the data set as OLD or be aware of     04380000
  the data set update protection provided by the PDS command for SHR    04390000
  allocations (for details, see HELP UPDATE).                           04400000
)X SYNTAX -                                                             04410000
     DELETE  member   ALIAS/NOALIAS                                     04420000
                                                                        04430000
 ALIASES  - DE, DEL, DELE, DELET, DELETE,                               04440000
            SC, SCR, SCRA, SCRAT, SCRATC, SCRATCH                       04450000
 DEFAULTS - member, NOALIAS                                             04460000
 REQUIRED - none.                                                       04470000
)O OPERANDS -                                                           04480000
 member -   optional, specifies the name of the member(s) to be         04490000
            deleted.  Default member names, member name ranges and      04500000
            member name patterns are allowed; for more information,     04510000
            enter HELP GROUP.                                           04520000
                                                                        04530000
            If asterisk notation is used to represent a member or a     04540000
            member group or if only a simple member name is entered,    04550000
            the represented members will be deleted without prompting.  04560000
                                                                        04570000
            If a member name is not entered or if a member group name   04580000
            is entered, a yes/no prompt will be provided by member name 04590000
            to allow selective member deletion.                         04600000
                                                                        04610000
))ALIAS   - specifies that any associated members (aliases, apparent    04620000
            aliases and associated real members) are also to be         04630000
            deleted.  Note: the ALIAS operand is given control after    04640000
            an identified member is deleted; no selective prompting     04650000
            is performed for these associated members.                  04660000
))NOALIAS - specifies that only the member(s) specifically identified   04670000
            are candidates for deletion.                                04680000
=DSNAME=DSNAMES=DSNAM=DSNA=DSN=DS                                       04680200
)F  Example -     DSN                                                   04680400
                                                                        04680600
   The DSNAME subcommand displays statistics on the current data        04680800
   set allocation using message format PDS200I, PDS210I or PDS220I      04681000
   depending on the last DSNAME operand (MSG, TSO, or JCL) entered.     04681200
                                                                        04681400
   Note: the DSNAME subcommand is automatically invoked for several     04681600
   situations (such as in the CHANGE or FIXPDS subcommands).            04681800
)X SYNTAX -                                                             04682000
     DSNAME  MSG / TSO / JCL                                            04682200
                                                                        04682400
 ALIASES  - DS, DSN, DSNA, DSNAM, DSNAME, DSNAMES                       04682600
 DEFAULTS - initially MSG; thereafter, previous MSG/TSO/JCL             04682800
 REQUIRED - none.                                                       04683000
)O OPERANDS -                                                           04683200
))MSG       - specifies that allocation messages are to be in table     04683400
              format using the PDS200I message.                         04683600
))TSO       - specifies that allocation messages are to be in TSO       04683800
              format using the PDS210I message.                         04684000
))JCL       - specifies that allocation messages are to be in JCL       04684200
              format using the PDS220I message.                         04684400
=EDIT=E=ED=EDI                                                          04690000
)F  The EDIT subcommand edits a member using the TSO EDIT command.      04700000
                                                                        04710000
 If an EDIT type keyword is entered, that keyword is passed to EDIT     04720000
 as the descriptive qualifier; otherwise, a descriptive qualifier is    04730000
 computed as follows:                                                   04740000
   A. If the low-level qualifier of the partitioned data set name is    04750000
      one of the valid descriptive qualifiers for EDIT (ASM, BASIC,     04760000
      CLIST, CNTL, COBOL, DATA, IPLI, LIST, PLI, TEXT or VSBASIC),      04770000
      that qualifier is passed to EDIT.                                 04780000
   B. If the low-level qualifier is FORT, GOFORT is passed to EDIT.     04790000
   C. Otherwise, the data type qualifier is not a valid descriptive     04800000
      qualifier and the general descriptive qualifier, DATA, is         04810000
      passed to EDIT.                                                   04820000
)X SYNTAX -                                                             04830000
     EDIT  member NONUM ASIS  OLD/NEW  ASM/BASIC/CLIST/CNTL/COBOL/DATA/ 04840000
                                       FORTE/FORTG/FORTGI/FORTH/GOFORT/ 04850000
                                       IPLI/LIST/PLI/PLIF/TEXT/VSBASIC  04860000
                                                                        04870000
 ALIASES  - E, ED, EDI, EDIT                                            04880000
 DEFAULTS - member, EDIT type based on the data set name                04890000
 REQUIRED - none.                                                       04900000
)O OPERANDS -                                                           04910000
 member   - optional, specifies the member name(s) to be passed (along  04920000
            with the data set name) to the TSO EDIT command.  Default   04930000
            member names, member name ranges and member name patterns   04940000
            are allowed; for more information, enter HELP GROUP.        04950000
                                                                        04960000
))NONUM   - optional, specifies that the member is to be edited without 04970000
            line numbers.                                               04980000
))ASIS    - optional, specifies that the member is to be edited with    04990000
            upper and lower-case data.                                  05000000
))OLD     - optional, specifies that PDS is to verify that the member   05010000
            exists before calling EDIT.                                 05020000
))NEW     - optional, specifies that PDS is to verify that the member   05030000
            does not exist before calling EDIT.                         05040000
 EDIT type keywords are as follows:                                     05050000
))ASM     -  EDIT type is assembly                                      05060000
))BASIC   -  EDIT type is BASIC                                         05070000
))CLIST   -  EDIT type is CLIST                                         05080000
))CNTL    -  EDIT type is CNTL                                          05090000
))COBOL   -  EDIT type is COBOL                                         05100000
))DATA    -  EDIT type is DATA                                          05110000
))FORTE   -  EDIT type is FORTRAN level "E"                             05120000
))FORTG   -  EDIT type is FORTRAN level "G"                             05130000
))FORTGI  -  EDIT type is FORTRAN level "GI"                            05140000
))FORTH   -  EDIT type is FORTRAN level "H"                             05150000
))GOFORT  -  EDIT type is GOFORT                                        05160000
))IPLI    -  EDIT type is IPLI                                          05170000
))LIST    -  EDIT type is LIST                                          05180000
))PLI     -  EDIT type is PLI                                           05190000
))PLIF    -  EDIT type is PLI (F-level)                                 05200000
))TEXT    -  EDIT type is TEXT                                          05210000
))VSBASIC -  EDIT type is VSBASIC                                       05220000
=END=EN                                                                 05230000
)F   The END subcommand terminates the PDS command.                     05240000
)X SYNTAX -                                                             05250000
     END                                                                05260000
                                                                        05270000
 ALIASES  - EN, END                                                     05280000
)O OPERANDS -                                                           05290000
 no operands are supported.                                             05300000
=EXEC=EX=EXE                                                            05310000
)F   The EXEC subcommand executes a CLIST containing PDS                05320000
  subcommands.  The TSO CLIST processor is used.   Note that            05330000
  MVT TSO does not support the implicit ("%") form of the EXEC          05340000
  command.                                                              05350000
)X SYNTAX -                                                             05360000
     EXEC  clistname 'operands'                                         05370000
                                                                        05380000
 ALIASES  - EX, EXE, EXEC                                               05390000
 DEFAULTS - none.                                                       05400000
 REQUIRED - clistname or clistmem                                       05410000
)O OPERANDS -                                                           05420000
 clistname - specifies the CLIST data set name.                         05430000
                                                                        05440000
 clistmem  - specifies the name of a member in the CLIST partitioned    05450000
             data set allocated to FILE(SYSPROC).                       05460000
                                                                        05470000
 operands  - optional, may include any parameters for the CLIST.        05480000
=FIND=F=FI=FIN                                                          05490000
)F  The FIND subcommand displays portions of a member which contain a   05500000
  search string.  Optionally, the THEN or ELSE keywords may be entered  05510000
  to allow conditional execution of other subcommands.                  05520000
                                                                        05530000
 Unprintable characters for 3270-type devices are translated to periods 05540000
 before they are displayed.                                             05550000
                                                                        05560000
 The FIND formats are NUM, SNUM, NONUM, MULTILINE, LINEDUMP, BLOCK      05570000
 and DUMP.  The default format is initially NUM; however, each time     05580000
 a format operand is entered on a LIST or FIND subcommand, the value    05590000
 entered is used as the output format for subsequent LIST and FIND      05600000
 subcommands.  Also, note the following:                                05610000
   A. Formats NUM, SNUM and NONUM limit the search and display length   05620000
      for logical records to 256 characters.                            05630000
   B. Formats BLOCK and DUMP apply to physical records; the other       05640000
      formats apply to logical records.                                 05650000
   C. If any output is displayed, a summary line is displayed stating   05660000
      the number of lines (records for BLOCK or DUMP formats) in the    05670000
      member.                                                           05680000
   D. Formats MULTILINE, LINEDUMP, BLOCK and DUMP display only those    05690000
      segments of a record which contain the search string; however,    05700000
      a following segment will also be displayed if the string spans    05710000
      a segment boundary.                                               05720000
)X SYNTAX -                                                             05730000
     FIND  member 'string' NUM/SNUM/NONUM/MULTILINE/LINEDUMP/BLOCK/DUMP 05740000
                           SKIPREC(n) MAXIN(n) MAXOUT(n)                05750000
                           SKIPCOL(n) MAXLEN(n) FIRST/NOFIRST           05760000
                        THEN(ATTRIB/DIRENTRY/DELETE/EDIT/END/           05770000
                             FIND/FSE/HISTORY/LIST/MAP/MEMBERS/         05780000
                             OUTCOPY/SUBMIT)                            05790000
                        ELSE(ATTRIB/DIRENTRY/DELETE/EDIT/END/           05800000
                             FIND/FSE/HISTORY/LIST/MAP/MEMBERS/         05810000
                             OUTCOPY/SUBMIT)                            05820000
                                                                        05830000
 ALIASES  - F, FI, FIN, FIND                                            05840000
 DEFAULTS - member, previous string,  NUM or previous LIST/FIND format, 05850000
                    SKIPREC(0), MAXIN(9999999), MAXOUT(9999999),        05860000
                    SKIPCOL(0), MAXLEN(99999), NOFIRST                  05870000
 REQUIRED - none.                                                       05880000
)O OPERANDS -                                                           05890000
 member      -  optional, specifies the name of the member(s) to be     05900000
                scanned.  Default member names, member name ranges      05910000
                and member name patterns are allowed; for more          05920000
                information, enter HELP GROUP.                          05930000
                                                                        05940000
 string      -  optional, the string to be searched for.  It is coded   05950000
                as a delimited string like +searched for+.  If the      05960000
                string is not entered or is null, the last string       05970000
                entered will be used. The string may contain one to     05980000
                16 characters.                                          05990000
                                                                        06000000
                As an alternative, hexadecimal data may be entered as   06010000
                a string delimited with x's like x0123456789abcdefx.    06020000
                Note that the string may contain one to 32 characters   06030000
                and that x333x and x0333x are equivalent.               06040000
                                                                        06050000
 FIND format control keywords are as follows:                           06060000
))NUM        -  The line number field (the last 8 bytes of a fixed-     06070000
                format record or the first 8 bytes otherwise) of        06080000
                each logical record is examined; if the field is not    06090000
                numeric, formatting is switched to NONUM mode for the   06100000
                remainder of the member.                                06110000
                                                                        06120000
                For SPF-saved members, the high-order six digits of     06130000
                the line number field is formatted; otherwise, the      06140000
                low-order six digits of the line number field is        06150000
                formatted by suppressing leading zeroes.  The line      06160000
                number segment is followed by a blank and up to 249     06170000
                characters of data from the logical record.  Note that  06180000
                the formatted line including the line number segment    06190000
                and the following blank is scanned for the search       06200000
                string.                                                 06210000
))SNUM       -  The line number field (the last 8 bytes of a fixed-     06220000
                format record or the first 8 bytes otherwise) is        06230000
                discarded.  Up to 256 bytes from a logical record are   06240000
                searched or displayed.                                  06250000
))NONUM      -  Up to 256 bytes from a logical record are searched or   06260000
                displayed.                                              06270000
))MULTILINE  -  Logical records are formatted with a decimal character  06280000
                displacement count and segments of (line width - 10)    06290000
                characters.  A blank line is output to separate         06300000
                segments displayed by record.  Only formatted segments  06310000
                which contain the search string are displayed;          06320000
                however, a following segment will also be displayed if  06330000
                the string spans a segment boundary.                    06340000
))LINEDUMP   -  Logical records are formatted with a hexadecimal byte   06350000
                displacement field, segments of up to 32 characters of  06360000
                hexadecimal data and up to 16 bytes of equivalent       06370000
                characters surrounded by asterisks.  A blank line is    06380000
                output to separate segments displayed by record.  Only  06390000
                formatted segments which contain the search string are  06400000
                displayed; however, a following segment will also be    06410000
                displayed if the string spans a segment boundary.       06420000
))BLOCK      -  Physical records are formatted with a decimal           06430000
                character displacement count and segments of (line      06440000
                width - 10) characters.  A blank line and a header are  06450000
                output to separate segments displayed by record.  Only  06460000
                formatted segments which contain the search string are  06470000
                displayed; however, a following segment will also be    06480000
                displayed if the string spans a segment boundary.       06490000
))DUMP       -  Physical records are formatted with a hexadecimal byte  06500000
                displacement field, segments of up to 32 characters of  06510000
                hexadecimal data and up to 16 bytes of equivalent       06520000
                characters surrounded by asterisks.  A blank line and   06530000
                a header are output to separate segments displayed by   06540000
                record.  Only formatted segments which contain the      06550000
                search string are displayed; however, a following       06560000
                segment will also be displayed if the string spans a    06570000
                segment boundary.                                       06580000
 FIND control keywords are as follows:                                  06590000
))SKIPREC(n)  - n is coded as 0 through 9999999 to specify the number   06600000
                of logical records (physical records for BLOCK or       06610000
                DUMP formats) to ignore at the beginning of a member.   06620000
))MAXIN(n)    - n is coded as 0 through 9999999 to specify the maximum  06630000
                number of logical records (physical records for BLOCK   06640000
                or DUMP formats) to input for a member after            06650000
                satisfying any SKIPREC operand.                         06660000
))MAXOUT(n)   - n is coded as 0 through 9999999 to specify the maximum  06670000
                number of logical records (partial logical records for  06680000
                MULTILINE or LINEDUMP formats; partial physical records 06690000
                for BLOCK or DUMP formats) to output for a member.      06700000
))SKIPCOL(n)  - n is coded as 0 through 99999 to specify the number     06710000
                of columns to ignore at the beginning of each logical   06720000
                record (physical record for BLOCK or DUMP formats).     06730000
                                                                        06740000
                Note: for NUM or SNUM output format with OS/VS record   06750000
                format V or U, SKIPCOL(0) positions the data formatter  06760000
                to the first data position after the line number field. 06770000
))MAXLEN(n)   - n is coded as 0 through 99999 to specify the maximum    06780000
                length of a logical record (physical record for BLOCK   06790000
                or DUMP formats) to search or display.                  06800000
))FIRST       - Specifies that all remaining data in the member is      06810000
                to be listed after the first occurance of the string.   06820000
))NOFIRST     - Specifies that normal FIND processing is to be in       06830000
                effect.                                                 06840000
 FIND conditional keywords are as follows:                              06850000
))THEN(action) - The THEN subcommand is executed if the string is       06860000
                 found in a member.  The subcommand may be ATTRIB,      06870000
                 DIRENTRY, DELETE, EDIT, END, FIND, FSE, HISTORY,       06880000
                 LIST, MAP, MEMBERS, OUTCOPY or SUBMIT.                 06890000
))ELSE(action) - The ELSE subcommand is executed if the string is not   06900000
                 found in a member.  The subcommand may be ATTRIB,      06910000
                 DIRENTRY, DELETE, EDIT, END, FIND, FSE, HISTORY,       06920000
                 LIST, MAP, MEMBERS, OUTCOPY or SUBMIT.                 06930000
=FIXPDS=FIXPD=FIXP=FIX                                                  06940000
)F   The FIXPDS subcommand can perform several utility functions for    06950000
  partitioned data sets; it can modify the data set DCB and optionally, 06960000
  either expand the PDS directory or reinitialize the PDS directory.    06970000
                                                                        06980000
  After the FIXPDS subcommand gains control, it comments on the data    06990000
  set action to be taken and any potential error conditions; it then    07000000
  waits for a user response to a prompt before changing the data set.   07010000
                                                                        07020000
  Following are more detailed implementation notes on each of the       07030000
  different functions available through the FIXPDS subcommand:          07040000
    A.  EXPANDDIR (expand the directory)                                07050000
        1.  If no members exist in the data set, RESETDIR is used       07060000
        2.  The names of any members that will be moved out of the      07070000
            way of the expanded directory are listed                    07080000
        3.  If any of these members are in use by an SPF edit session,  07090000
            a warning message is issued                                 07100000
        4.  As each member is moved, an informational message is issued 07110000
        5.  The additional directory blocks are written                 07120000
        6.  DCB is invoked to make any DCB changes                      07130000
    B.  RESETDIR (reset the directory)                                  07140000
        1.  If any members exist in the data set, a warning message     07150000
            is issued                                                   07160000
        2.  If any members are in use by an SPF edit session, a         07170000
            warning message is issued                                   07180000
        3.  The data set's directory blocks are rewritten with null     07190000
            data, destroying any existing member information            07200000
        4.  The end of data marker (DS1LSTAR) is reset to indicate      07210000
            an empty partitioned data set                               07220000
        5.  DCB is invoked to make any DCB changes                      07230000
    C.  DCB (modify the DCB attributes)                                 07240000
        1.  The data set is opened for output with any new DCB          07250000
            parameters                                                  07260000
        2.  The data set is closed                                      07270000
                                                                        07280000
                                                                        07290000
  Note: if the total number of directory blocks to be written will      07300000
  fill the last directory disk track for the RESETDIR or EXPANDDIR      07310000
  options, PDS will add an extra padding directory block to ensure      07320000
  that the end of file marker is written on the following track.        07330000
  This is done for compatibility with partitioned data set allocation.  07340000
                                                                        07350000
  Caution: this subcommand modifies the data set. To ensure data set    07360000
  integrity, you should allocate the data set as OLD or be aware of     07370000
  the data set update protection provided by the PDS command for SHR    07380000
  allocations (for details, see HELP UPDATE).                           07390000
)X SYNTAX -                                                             07400000
     FIXPDS  EXPANDDIR(Addblks) / RESETDIR(Totblks) / DCB               07410000
               CLIST / CNTL / LOAD / OBJECT                             07420000
               RECFM(F/FB/FT/FBT/FA/FBA/FTA/FBTA/FM/FBM/FTM/FBTM/       07430000
                     V/VB/VT/VBT/VA/VBA/VTA/VBTA/VM/VBM/VTM/VBTM/       07440000
                     U/UT/UA/UM/UTA/UTM)                                07450000
               LRECL(L1)                                                07460000
               BLKSIZE(L2)                                              07470000
                                                                        07480000
 ALIASES  - FIX, FIXP, FIXPD, FIXPDS                                    07490000
 DEFAULTS - RECFM(previous value),                                      07500000
            LRECL(previous value),                                      07510000
            BLKSIZE(previous value)                                     07520000
 REQUIRED - EXPANDDIR, RESETDIR or DCB                                  07530000
)O OPERANDS -                                                           07540000
                                                                        07550000
))EXPANDDIR(Addblks) - specifies that the directory is to be expanded   07560000
                       by the number of specified directory blocks.     07570000
                       Addblks may be entered as a number from 1        07580000
                       through 99999 and it defaults to 50.             07590000
))RESETDIR(Totblks)  - specifies that the directory is to be over-      07600000
                       written with the specified number of directory   07610000
                       blocks.  Totblks may be entered as a number      07620000
                       from 1 through 99999 and it defaults to the      07630000
                       number of directory blocks already allocated.    07640000
))DCB                - specifies that only the DCB for the data set     07650000
                       is to be modified.                               07660000
))CLIST       - specifies the equivalent of RECFM(VB) LRECL(255)        07670000
                BLKSIZE(6232).  Note that RECFM, LRECL and BLKSIZE      07680000
                may also be explicitly specified.                       07690000
))CNTL        - specifies the equivalent of RECFM(FB) LRECL(80)         07700000
                BLKSIZE(9440).  Note that RECFM, LRECL and BLKSIZE      07710000
                may also be explicitly specified.                       07720000
))LOAD        - specifies the equivalent of RECFM(U) BLKSIZE(19069).    07730000
                Note that RECFM and BLKSIZE may also be explicitly      07740000
                specified.                                              07750000
))OBJECT      - specifies the equivalent of RECFM(FB) LRECL(80)         07760000
                BLKSIZE(3120).  Note that RECFM, LRECL and BLKSIZE      07770000
                may also be explicitly specified.                       07780000
))RECFM(Newr) - specifies a new DCB RECFM value for the data set.  Newr 07790000
                defaults to its previous value for the data set or may  07800000
                be entered as any one of the following:                 07810000
                F, FB, FT, FBT, FA, FBA, FTA, FBTA, FM, FBM, FTM, FBTM, 07820000
                V, VB, VT, VBT, VA, VBA, VTA, VBTA, VM, VBM, VTM, VBTM, 07830000
                U, UT, UA, UM, UTA or UTM.                              07840000
))LRECL(L1)   - specifies a new DCB LRECL value for the data set.       07850000
                L1 defaults to its previous value for the data set      07860000
                or may be entered as a number from 1 through 32767.     07870000
))BLKSIZE(L2) - specifies a new DCB BLKSIZE value for the data set.     07880000
                L2 defaults to its previous value for the data set      07890000
                or may be entered as a number from 1 through 32767.     07900000
=FSE=FS                                                                 07910000
)F  The FSE subcommand edits a member.  The TSO FSE command is used;    07920000
 both the FSE+ product from Applied Software, Inc. and the command      07930000
 called FSE from the CBT MVS SHARE tape (file 207) are compatable       07940000
 with the interface provided by this subcommand.                        07950000
                                                                        07960000
 If an EDIT type keyword is entered, that keyword is passed to FSE      07970000
 as the descriptive qualifier; otherwise, a descriptive qualifier is    07980000
 computed as follows:                                                   07990000
   A. If the low-level qualifier of the partitioned data set name is    08000000
      one of the valid descriptive qualifiers for FSE (ASM, BASIC,      08010000
      CLIST, CNTL, COBOL, DATA, IPLI, LIST, PLI, TEXT or VSBASIC),      08020000
      that qualifier is passed to FSE.                                  08030000
   B. If the low-level qualifier is FORT, GOFORT is passed to FSE.      08040000
   C. Otherwise, the data type qualifier is not a valid descriptive     08050000
      qualifier and the general descriptive qualifier, DATA, is         08060000
      passed to FSE.                                                    08070000
)X SYNTAX -                                                             08080000
      FSE  member NONUM ASIS  OLD/NEW  ASM/BASIC/CLIST/CNTL/COBOL/DATA/ 08090000
                                       FORTE/FORTG/FORTGI/FORTH/GOFORT/ 08100000
                                       IPLI/LIST/PLI/PLIF/TEXT/VSBASIC  08110000
                                                                        08120000
 ALIASES  - FS, FSE                                                     08130000
 DEFAULTS - member, EDIT type based on the data set name                08140000
 REQUIRED - none.                                                       08150000
)O OPERANDS -                                                           08160000
 member   - optional, specifies the member name(s) to be passed (along  08170000
            with the data set name) to the TSO FSE command.  Default    08180000
            member names, member name ranges and member name patterns   08190000
            are allowed; for more information, enter HELP GROUP.        08200000
                                                                        08210000
))NONUM   - optional, specifies that the member is to be edited without 08220000
            line numbers.                                               08230000
))ASIS    - optional, specifies that the member is to be edited with    08240000
            upper and lower-case data.                                  08250000
))OLD     - optional, specifies that PDS is to verify that the member   08260000
            exists before calling FSE.                                  08270000
))NEW     - optional, specifies that PDS is to verify that the member   08280000
            does not exist before calling FSE.                          08290000
 EDIT type keywords are as follows:                                     08300000
))ASM     -  EDIT type is assembly                                      08310000
))BASIC   -  EDIT type is BASIC                                         08320000
))CLIST   -  EDIT type is CLIST                                         08330000
))CNTL    -  EDIT type is CNTL                                          08340000
))COBOL   -  EDIT type is COBOL                                         08350000
))DATA    -  EDIT type is DATA                                          08360000
))FORTE   -  EDIT type is FORTRAN level "E"                             08370000
))FORTG   -  EDIT type is FORTRAN level "G"                             08380000
))FORTGI  -  EDIT type is FORTRAN level "GI"                            08390000
))FORTH   -  EDIT type is FORTRAN level "H"                             08400000
))GOFORT  -  EDIT type is GOFORT                                        08410000
))IPLI    -  EDIT type is IPLI                                          08420000
))LIST    -  EDIT type is LIST                                          08430000
))PLI     -  EDIT type is PLI                                           08440000
))PLIF    -  EDIT type is PLI (F-level)                                 08450000
))TEXT    -  EDIT type is TEXT                                          08460000
))VSBASIC -  EDIT type is VSBASIC                                       08470000
=HELP=H=HE=HEL                                                          08480000
)F   The HELP subcommand lists data from the HELP data set.  The TSO    08490000
  HELP command is used; if the HELP subcommand is entered without       08500000
  operands, a list of valid subcommands is displayed.                   08510000
)X SYNTAX -                                                             08520000
     HELP  subcommand FUNCTION SYNTAX OPERAND/OPERAND(k)                08530000
                                                                        08540000
 ALIASES  - H, HE, HEL, HELP                                            08550000
 DEFAULTS - none.                                                       08560000
 REQUIRED - none.                                                       08570000
)O OPERANDS -                                                           08580000
 subcommand  - optional, specifies the name of a subcommand (or the     08590000
               alias name of a subcommand) for which HELP is to be      08600000
               displayed.  if the subcommand name is omitted, a list    08610000
               of valid subcommands is displayed.                       08620000
                                                                        08630000
))FUNCTION   - specifies that function information for the subcommand   08640000
               is to be displayed.                                      08650000
))SYNTAX     - specifies that syntax information for the subcommand     08660000
               is to be displayed.                                      08670000
))OPERAND(k) - specifies that information for the keyword identified    08680000
               in the (k) operand is to be displayed.  if the (k)       08690000
               operand is omitted, information on all operands of the   08700000
               subcommand will be displayed.                            08710000
=HISTORY=HI=HIS=HIST=HISTO=HISTOR                                       08720000
)F  The HISTORY subcommand displays the last linkage-edit date for a    08730000
 module and lists any CSECT IDR data assigned to a load module.         08740000
)X SYNTAX -                                                             08750000
     HISTORY  member  MODULE(Partm)                                     08760000
                      LKED(Partl)                                       08770000
                      TRANS(Partt)                                      08780000
                      USER(Partu)                                       08790000
                      ZAP(Partz)                                        08800000
                                                                        08810000
 ALIASES  - HI, HIS, HIST, HISTO, HISTOR, HISTORY                       08820000
 DEFAULTS - member, LKED, MODULE, TRANS, USER and ZAP; however,         08830000
            if LKED, TRANS, USER or ZAP are specified, only the         08840000
            corresponding types of data will be provided.               08850000
 REQUIRED - none.                                                       08860000
)O OPERANDS -                                                           08870000
 member          - optional, specifies the name of the load module(s)   08880000
                   for which a HISTORY summary is to be produced.       08890000
                   Default member names, member name ranges and member  08900000
                   name patterns are allowed; for more information,     08910000
                   enter HELP GROUP.                                    08920000
                                                                        08930000
))MODULE(Partm)  - specifies that CSECTS defined by the partial name,   08940000
                   Partm, are to be listed. Partm may be entered as a   08950000
                   partial CSECT name with one to eight characters.     08960000
                                                                        08970000
                   Note that if MODULE(Partm) is entered, any TRAN,     08980000
                   USER or ZAP keywords apply only to CSECT's whose     08990000
                   names match the partial CSECT name, Partm.           09000000
))LKED(Partl)    - specifies that if the linkage-editor name matches    09010000
                   the partial name, Partl, a line identifying the      09020000
                   editor is to be listed. Partl may be entered as a    09030000
                   partial linkage-editor name with one to ten          09040000
                   characters.                                          09050000
))TRAN(Partt)    - specifies that CSECTS identified as having been      09060000
                   assembled or compiled by the translator defined by   09070000
                   the partial name, Partt, are to be listed. Partt     09080000
                   may be entered as a partial translator name with     09090000
                   one to ten characters.                               09100000
                   Note that if MODULE(Partm) is also entered, any      09110000
                   TRAN operand applies only to CSECT's whose names     09120000
                   match the partial CSECT name, Partm.                 09130000
))USER(Partu)    - specifies that user IDR data which matches the       09140000
                   partial name, Partu, is to be listed. Partu may      09150000
                   be entered as partial IDR data with one to eight     09160000
                   characters.                                          09170000
                   Note that if MODULE(Partm) is also entered, any      09180000
                   USER operand applies only to CSECT's whose names     09190000
                   match the partial CSECT name, Partm.                 09200000
))ZAP(Partz)     - specifies that zap IDR data which matches the        09210000
                   partial name, Partz, is to be listed. Partz may be   09220000
                   entered as partial zap IDR data with one to eight    09230000
                   characters.                                          09240000
                   Note that if MODULE(Partm) is also entered, any      09250000
                   ZAP operand applies only to CSECT's whose names      09260000
                   match the partial CSECT name, Partm.                 09270000
=IF=I                                                                   09280000
)F   The IF subcommand searches for members meeting defined conditions. 09290000
  The action to be taken is specified by the THEN and ELSE keywords.    09300000
  Either the THEN or ELSE keyword may be omitted; if both THEN and ELSE 09310000
  are omitted, a default of THEN(ATTRIB) is provided.                   09320000
                                                                        09330000
  If all conditions are true for a given member, any THEN action is     09340000
  taken for that member; otherwise, one or more conditions were not     09350000
  true and any ELSE action is taken for the member.                     09360000
)X SYNTAX -                                                             09370000
     IF member   ABOVE(Count1)                                          09380000
                 ALIAS/NOALIAS                                          09390000
                 AMODE24/AMODE31/AMODEANY/NOAMODE24/                    09400000
                         NOAMODE31/NOAMODEANY  (load modules only)      09410000
                 APPARENTALIAS/NOAPPARENTALIAS                          09420000
                 AUTH/NOAUTH                   (load modules only)      09430000
                 BELOW(Count2)                                          09440000
                 BLOCKERR/NOBLOCKERR                                    09450000
                 DC/NODC                       (load modules only)      09460000
                 EDIT/NOEDIT                   (load modules only)      09470000
                 EXEC/NOEXEC                   (load modules only)      09480000
                 FLEVEL/NOFLEVEL               (load modules only)      09490000
                 IOERR/NOIOERR                                          09500000
                 LKED(Partl)                   (load modules only)      09510000
                 LKEDERR/NOLKEDERR             (load modules only)      09520000
                 LOADERR/NOLOADERR             (load modules only)      09530000
                 LOADONLY/NOLOADONLY           (load modules only)      09540000
                 LRECLERR/NOLRECLERR                                    09550000
                 MODULE(Partm)                 (load modules only)      09560000
                 NAMEERR/NONAMEERR                                      09570000
                 NULL/NONULL                                            09580000
                 ORPHAN/NOORPHAN                                        09590000
                 OVERLAY/NOOVERLAY             (load modules only)      09600000
                 PAGE/NOPAGE                   (load modules only)      09610000
                 REFR/NOREFR                   (load modules only)      09620000
                 RENT/NORENT                   (load modules only)      09630000
                 REUS/NOREUS                   (load modules only)      09640000
                 RLDERR/NORLDERR               (load modules only)      09650000
                 RLDZERO/NORLDZERO             (load modules only)      09660000
                 RMODE24/RMODEANY/                                      09670000
                         NORMODE24/NORMODEANY  (load modules only)      09680000
                 SCTR/NOSCTR                   (load modules only)      09690000
                 SPFEDIT/NOSPFEDIT                                      09700000
                 SSI/NOSSI                                              09710000
                 TEST/NOTEST                   (load modules only)      09720000
                 TRAN(Partt)                   (load modules only)      09730000
                 TTR(Lttr:Httr)                                         09740000
                 USER(Partu)                   (load modules only)      09750000
                 USERID(Puid)/NOUSERID/NOTUSERID(Puid)                  09760000
                 VSLKED/NOVSLKED               (load modules only)      09770000
                 ZAP(Partz)                    (load modules only)      09780000
               THEN(ATTRIB/DIRENTRY/DELETE/EDIT/END/                    09790000
                    FIND/FSE/HISTORY/LIST/MAP/MEMBERS/                  09800000
                    OUTCOPY/SUBMIT)                                     09810000
               ELSE(ATTRIB/DIRENTRY/DELETE/EDIT/END/                    09820000
                    FIND/FSE/HISTORY/LIST/MAP/MEMBERS/                  09830000
                    OUTCOPY/SUBMIT)                                     09840000
                                                                        09850000
 ALIASES  - I, IF                                                       09860000
 DEFAULTS - member, THEN(ATTRIB) if neither THEN nor ELSE is entered    09870000
 REQUIRED - none                                                        09880000
)O OPERANDS -                                                           09890000
 member          - optional, specifies the name of the member(s) whose  09900000
                   attributes are to be examined.  Default member       09910000
                   names, member name ranges and member name patterns   09920000
                   are allowed; for more information, enter HELP GROUP. 09930000
                                                                        09940000
))ABOVE(Count1)  - specifies that members with more than the number of  09950000
                   lines (amount of storage for load modules) defined   09960000
                   by the number, Count1, are desired.                  09970000
))ALIAS          - specifies that alias members are desired.            09980000
))NOALIAS        - specifies that non-alias members are desired.        09990000
))AMODE24        - specifies that modules with addressing mode 24 are   10000000
                   desired.                                             10010000
))NOAMODE24      - specifies that modules with addressing mode 31 or    10020000
                   ANY are desired.                                     10030000
))AMODE31        - specifies that modules with addressing mode 31 are   10040000
                   desired.                                             10050000
))NOAMODE31      - specifies that modules with addressing mode 24 or    10060000
                   ANY are desired.                                     10070000
))AMODEANY       - specifies that modules with addressing mode ANY      10080000
                   are desired.                                         10090000
))NOAMODEANY     - specifies that modules with addressing mode 24 or    10100000
                   31 are desired.                                      10110000
))APPARENTALIAS  - specifies that real members whose start addresses    10120000
                   match the start address of another real member       10130000
                   are desired.                                         10140000
))NOAPPARENTALIAS - specifies that alias members or real members whose  10150000
                   start addresses do not match the start address of    10160000
                   another real member are desired.                     10170000
))AUTH           - specifies that APF authorized modules are desired.   10180000
))NOAUTH         - specifies that non-authorized modules are desired.   10190000
))BELOW(Count2)  - specifies that members with less than the number of  10200000
                   lines (amount of storage for load modules) defined   10210000
                   by the number, Count2, are desired.                  10220000
))BLOCKERR       - specifies that members with input blocksizes         10230000
                   exceeding the DCB BLKSIZE are desired.               10240000
))NOBLOCKERR     - specifies that members without blocksize errors      10250000
                   are desired.                                         10260000
))DC             - specifies that downward-compatible modules are       10270000
                   desired.                                             10280000
))NODC           - specifies that no downward-compatible modules are    10290000
                   desired.                                             10300000
))EDIT           - specifies that modules which can be reprocessed      10310000
                   by the linkage-editor are desired.                   10320000
))NOEDIT         - specifies that modules which can not be reprocessed  10330000
                   by the linkage-editor are desired.                   10340000
))EXEC           - specifies that modules which are marked as           10350000
                   "executable" are desired.                            10360000
))NOEXEC         - specifies that modules which are marked as           10370000
                   "not executable" are desired.                        10380000
))FLEVEL         - specifies that modules processed by the              10390000
                   F-level linkage-editor are desired.                  10400000
))NOFLEVEL       - specifies that modules not processed by the          10410000
                   F-level linkage-editor are desired.                  10420000
))IOERR          - specifies that members with I/O errors are           10430000
                   desired.                                             10440000
))NOIOERR        - specifies that members without I/O errors are        10450000
                   desired.                                             10460000
))LKED(Partl)    - specifies that modules identified as linked by the   10470000
                   linkage-editor defined by the partial name, Partl,   10480000
                   are desired.  Partl may be entered as a partial      10490000
                   linkage-editor name with one to ten characters.      10500000
))LKEDERR        - specifies that modules with any of the following     10510000
                   illegal linkage-edit attribute combinations are      10520000
                   desired:                                             10530000
                     1.  Modules with RENT and NOREUS attributes        10540000
                     2.  Modules with RMODEANY and AMODE24 or           10550000
                         AMODEANY attributes                            10560000
                     3.  Modules with OVLY and RENT, REUS, REFR, SCTR,  10570000
                         RMODEANY, AMODE31, or AMODEANY attributes      10580000
                     4.  Modules with TEST and NOEDIT attributes        10590000
                     5.  Modules with REUS and SCTR attributes          10600000
))NOLKEDERR      - specifies that modules with none of the following    10610000
                   illegal linkage-edit attribute combinations are      10620000
                   desired:                                             10630000
                     1.  Modules with RENT and NOREUS attributes        10640000
                     2.  Modules with RMODEANY and AMODE24 or           10650000
                         AMODEANY attributes                            10660000
                     3.  Modules with OVLY and RENT, REUS, REFR, SCTR,  10670000
                         RMODEANY, AMODE31, or AMODEANY attributes      10680000
                     4.  Modules with TEST and NOEDIT attributes        10690000
                     5.  Modules with REUS and SCTR attributes          10700000
))LOADERR        - specifies that modules which cause ABENDS when       10710000
                   they are LOADED and DELETED are desired.             10720000
))NOLOADERR      - specifies that modules which can be LOADED and       10730000
                   DELETED without errors are desired.                  10740000
))LOADONLY       - specifies that modules marked as "LOAD ONLY"         10750000
                   are desired.                                         10760000
))NOLOADONLY     - specifies that modules not marked as "LOAD ONLY"     10770000
                   are desired.                                         10780000
))LRECLERR       - specifies that members with any of the following     10790000
                   errors are desired:                                  10800000
                     a.  Input blocksize/LRECL not integral (RECFM=F)   10810000
                     b.  Input LRECL exceeding maximum LRECL (RECFM=V)  10820000
                     c.  Input LRECL less than 4 bytes (RECFM=V)        10830000
))NOLRECLERR     - specifies that members with no LRECL errors are      10840000
                   desired.                                             10850000
))MODULE(Partm)  - specifies that modules with CSECTS defined by the    10860000
                   partial name, Partm, are desired.  Partm may be      10870000
                   entered as a partial CSECT name with one to eight    10880000
                   characters.                                          10890000
                   Note that if MODULE(Partm) is entered, any TRAN,     10900000
                   USER or ZAP keywords apply only to CSECT's whose     10910000
                   names match the partial CSECT name, Partm.           10920000
))NAMEERR        - specifies that members whose member names are not    10930000
                   upper-case alphanumeric or whose first character     10940000
                   is numeric are desired.                              10950000
))NONAMEERR      - specifies that members whose member names are        10960000
                   upper-case alphanumeric and whose first character    10970000
                   is not numeric are desired.                          10980000
))NULL           - specifies that members with no data are desired.     10990000
))NONULL         - specifies that members with data are desired.        11000000
))ORPHAN         - specifies that alias members which have no           11010000
                   associated real member are desired.                  11020000
))NOORPHAN       - specifies that real members or alias members which   11030000
                   have an associated real member are desired.          11040000
))OVERLAY        - specifies that modules marked as being               11050000
                   "in overlay" are desired.                            11060000
))NOOVERLAY      - specifies that modules not marked as being           11070000
                   "in overlay" are desired.                            11080000
))PAGE           - specifies that modules marked for loading on         11090000
                   a page boundary are desired.                         11100000
))NOPAGE         - specifies that modules not marked for loading on     11110000
                   a page boundary are desired.                         11120000
))REFR           - specifies that refreshable modules are desired.      11130000
))NOREFR         - specifies that non-refreshable modules are desired.  11140000
))RENT           - specifies that reentrant modules are desired.        11150000
))NORENT         - specifies that non-reentrant modules are desired.    11160000
))REUS           - specifies that reusable modules are desired.         11170000
))NOREUS         - specifies that non-reusable modules are desired.     11180000
))RLDERR         - specifies that modules linked since OS/VS whose      11190000
                   RLD/CONTROL count from the directory does not match  11200000
                   the first RLD entry are desired.                     11210000
))NORLDERR       - specifies that modules whose RLD/CONTROL count       11220000
                   from the directory match the first RLD entry or      11230000
                   modules linked before OS/VS are desired.             11240000
))RLDZERO        - specifies that modules whose RLD/CONTROL count is    11250000
                   zero are desired.                                    11260000
))NORLDZERO      - specifies that modules whose RLD/CONTROL count is    11270000
                   not zero are desired.                                11280000
))RMODE24        - specifies that modules with residence mode 24 are    11290000
                   desired.                                             11300000
))NORMODE24      - specifies that modules with residence mode ANY       11310000
                   are desired.                                         11320000
))RMODEANY       - specifies that modules with residence mode ANY       11330000
                   are desired.                                         11340000
))NORMODEANY     - specifies that modules with residence mode 24 are    11350000
                   desired.                                             11360000
))SCTR           - specifies that scatter-loaded modules are desired.   11370000
))NOSCTR         - specifies that no scatter-loaded modules are desired.11380000
))SPFEDIT        - specifies that members which are currently in-use    11390000
                   by an SPF EDIT session are desired.                  11400000
))NOSPFEDIT      - specifies that members which are not currently       11410000
                   in-use by an SPF EDIT session are desired.           11420000
))SSI            - specifies that members with SSI data are desired.    11430000
))NOSSI          - specifies that members without SSI data are desired. 11440000
))TEST           - specifies that modules with the "TEST" attribute     11450000
                   are desired.                                         11460000
))NOTEST         - specifies that modules without the "TEST" attribute  11470000
                   are desired.                                         11480000
))TRAN(Partt)    - specifies that modules with CSECTS identified as     11490000
                   having been assembled or compiled by the translator  11500000
                   defined by the partial name, Partt, are desired.     11510000
                   Partt may be entered as a partial translator name    11520000
                   with one to ten characters.                          11530000
                   Note that if MODULE(Partm) is also entered, the      11540000
                   TRAN operand applies only to CSECT's whose names     11550000
                   match the partial CSECT name, Partm.                 11560000
))TTR(Lttr:Httr) - specifies that members whose start address is in     11570000
                   the specified TTR range are desired.                 11580000
                   Lttr defaults to 0 and may be entered as a           11590000
                   hexadecimal TTR value from 0 through FFFFFF.         11600000
                   Httr defaults to FFFFFF and may be entered as        11610000
                   a hexadecimal TTR value from 0 through FFFFFF.       11620000
))USER(Partu)    - specifies that modules with user IDR data which      11630000
                   matches the partial name, Partu, are desired.        11640000
                   Partu may be entered as partial IDR data with        11650000
                   one to eight characters.                             11660000
                   Note that if MODULE(Partm) is also entered, the      11670000
                   USER operand applies only to CSECT's whose names     11680000
                   match the partial CSECT name, Partm.                 11690000
))USERID(Puid)   - specifies that members with SPF statistics and       11700000
                   userids matching the partial name, Puid, are         11710000
                   desired.  Puid may be entered as a partial TSO       11720000
                   userid with one to seven characters.                 11730000
))NOUSERID       - specifies that members without SPF statistics are    11740000
                   desired.                                             11750000
))NOTUSERID(Puid) - specifies that members without SPF statistics or    11760000
                   members with SPF statistics and userids which do     11770000
                   not match the partial name, Puid, are desired.       11780000
                   Puid may be entered as a partial TSO userid with     11790000
                   one to seven characters.                             11800000
))VSLKED         - specifies that modules linked by the MVS OS/VS       11810000
                   linkage-editor are desired.                          11820000
))NOVSLKED       - specifies that modules not linked by the MVS OS/VS   11830000
                   linkage-editor are desired.                          11840000
))ZAP(Partz)     - specifies that modules with zap IDR data which       11850000
                   matches the partial name, Partz, are desired.        11860000
                   Partz may be entered as partial zap IDR data with    11870000
                   one to eight characters.                             11880000
                   Note that if MODULE(Partm) is also entered, the      11890000
                   ZAP operand applies only to CSECT's whose names      11900000
                   match the partial CSECT name, Partm.                 11910000
))THEN(action)   - The THEN subcommand is executed if all conditions    11920000
                   are true for a member.  The subcommand may be        11930000
                   ATTRIB, DIRENTRY, DELETE, EDIT, END, FIND, FSE,      11940000
                   HISTORY, LIST, MAP, MEMBERS, OUTCOPY or SUBMIT.      11950000
                                                                        11960000
                   Note that if neither a THEN nor an ELSE operand is   11970000
                   entered, THEN(ATTRIB) is the default condition.      11980000
))ELSE(action)   - The ELSE subcommand is executed if any condition     11990000
                   is not true for a member.  The subcommand may be     12000000
                   ATTRIB, DIRENTRY, DELETE, EDIT, END, FIND, FSE,      12010000
                   HISTORY, LIST, MAP, MEMBERS, OUTCOPY or SUBMIT.      12020000
                                                                        12030000
                   Note that if neither a THEN nor an ELSE operand is   12040000
                   entered, THEN(ATTRIB) is the default condition.      12050000
=LIST=L=LI=LIS                                                          12060000
)F  The LIST subcommand displays data from a member.                    12070000
                                                                        12080000
 Unprintable characters for 3270-type devices are translated to periods 12090000
 before they are displayed.                                             12100000
                                                                        12110000
 The LIST formats are NUM, SNUM, NONUM, MULTILINE, LINEDUMP, BLOCK      12120000
 and DUMP.  The default format is initially NUM; however, each time     12130000
 a format operand is entered on a LIST or FIND subcommand, the value    12140000
 entered is used as the output format for subsequent LIST and FIND      12150000
 subcommands.  Also, note the following:                                12160000
   A. Formats NUM, SNUM and NONUM limit the display length for logical  12170000
      records to 256 characters.                                        12180000
   B. Formats BLOCK and DUMP apply to physical records; the other       12190000
      formats apply to logical records.                                 12200000
   C. If the entire member is input, a summary line is displayed        12210000
      stating the number of lines (records for BLOCK or DUMP formats)   12220000
      in the member.                                                    12230000
)X SYNTAX -                                                             12240000
     LIST  member NUM/SNUM/NONUM/MULTILINE/LINEDUMP/BLOCK/DUMP          12250000
                  SKIPREC(n) MAXIN(n) MAXOUT(n)                         12260000
                  SKIPCOL(n) MAXLEN(n)                                  12270000
                                                                        12280000
 ALIASES  - L, LI, LIS, LIST                                            12290000
 DEFAULTS - member, NUM or previous LIST/FIND format,                   12300000
                    SKIPREC(0), MAXIN(9999999), MAXOUT(9999999),        12310000
                    SKIPCOL(0), MAXLEN(99999)                           12320000
 REQUIRED - none.                                                       12330000
)O OPERANDS -                                                           12340000
 member      -  optional, specifies the name of the member(s) to be     12350000
                listed.  Default member names, member name ranges and   12360000
                member name patterns are allowed; for more information, 12370000
                enter HELP GROUP.                                       12380000
                                                                        12390000
 LIST format keywords are as follows:                                   12400000
))NUM        -  The line number field (the last 8 bytes of a fixed-     12410000
                format record or the first 8 bytes otherwise) of        12420000
                each logical record is examined; if the field is not    12430000
                numeric, formatting is switched to NONUM mode for the   12440000
                remainder of the member.                                12450000
                                                                        12460000
                For SPF-saved members, the high-order six digits of     12470000
                the line number field is formatted; otherwise, the      12480000
                low-order six digits of the line number field is        12490000
                formatted by suppressing leading zeroes.  The line      12500000
                number segment is followed by a blank and up to 249     12510000
                characters of data from a logical record.               12520000
))SNUM       -  The line number field (the last 8 bytes for a fixed-    12530000
                format record or the first 8 otherwise) is discarded.   12540000
                Up to 256 bytes from a logical record are displayed.    12550000
))NONUM      -  Up to 256 bytes from a logical record are displayed.    12560000
))MULTILINE  -  Logical records are formatted with a decimal character  12570000
                displacement count and segments of (line width - 10)    12580000
                characters.  A blank line is output to separate         12590000
                displayed records.                                      12600000
))LINEDUMP   -  Logical records are formatted with a hexadecimal byte   12610000
                displacement field, segments of up to 32 characters of  12620000
                hexadecimal data and up to 16 bytes of equivalent       12630000
                characters surrounded by asterisks.  A blank line is    12640000
                output to separate displayed records.                   12650000
))BLOCK      -  Physical records are formatted with a decimal character 12660000
                displacement count and segments of (line width - 10)    12670000
                characters.  A blank line and a header line are output  12680000
                to separate displayed records.                          12690000
))DUMP       -  Physical records are formatted with a hexadecimal byte  12700000
                displacement field, segments of up to 32 characters of  12710000
                hexadecimal data and up to 16 bytes of equivalent       12720000
                characters surrounded by asterisks.  A blank line and a 12730000
                header line are output to separate displayed records.   12740000
 LIST control keywords are as follows:                                  12750000
))SKIPREC(n)  - n is coded as 0 through 9999999 to specify the number   12760000
                of logical records (physical records for BLOCK or       12770000
                DUMP formats) to ignore at the beginning of a member.   12780000
))MAXIN(n)    - n is coded as 0 through 9999999 to specify the maximum  12790000
                number of logical records (physical records for BLOCK   12800000
                or DUMP formats) to input for a member after            12810000
                satisfying any SKIPREC operand.                         12820000
))MAXOUT(n)   - n is coded as 0 through 9999999 to specify the maximum  12830000
                number of logical records (physical records for BLOCK   12840000
                or DUMP formats) to output for a member.                12850000
))SKIPCOL(n)  - n is coded as 0 through 99999 to specify the number     12860000
                of columns to ignore at the beginning of each logical   12870000
                record (physical record for BLOCK or DUMP formats).     12880000
                                                                        12890000
                Note:  for NUM or SNUM output format with OS/VS record  12900000
                format V or U, SKIPCOL(0) positions the data formatter  12910000
                to the first data position after the line number field. 12920000
))MAXLEN(n)   - n is coded as 0 through 99999 to specify the maximum    12930000
                length of a logical record (physical record for BLOCK   12940000
                or DUMP formats) to display.                            12950000
=MAP=M=MA                                                               12960000
)F  The MAP subcommand lists the CSECT structure of a load module.      12970000
 This MAP is similar in nature to the output produced by the MAP        12980000
 option of the linkage-editor.                                          12990000
                                                                        13000000
 The name of the module entry point is displayed in the MAP summary     13010000
 information.  Note that if a mapped module is an alias, the MAP        13020000
 subcommand will display the name of the corresponding real module      13030000
 if the FULL operand is entered or defaulted to.                        13040000
)X SYNTAX -                                                             13050000
     MAP  member  FULL/SHORT/ENTRY/RELINK/JCL  MODULE(Partm)            13060000
                                                                        13070000
 ALIASES  - M, MA, MAP                                                  13080000
 DEFAULTS - member, FULL                                                13090000
 REQUIRED - none.                                                       13100000
)O OPERANDS -                                                           13110000
 member          - optional, specifies the name of the load module(s)   13120000
                   for which a module MAP is to be produced.  Default   13130000
                   member names, member name ranges and member name     13140000
                   patterns are allowed; for more information, enter    13150000
                   HELP GROUP.                                          13160000
                                                                        13170000
))FULL           - a full CSECT map is to be provided                   13180000
))SHORT          - a CSECT map with all CSECTS but no entries within    13190000
                   CSECTS is to be provided; also, no alias information 13200000
                   is to be provided.                                   13210000
))ENTRY          - only the ENTRY point symbol is to be mapped;         13220000
                   also, no alias information is to be provided.        13230000
))RELINK         - JCL and linkage editor control statements are to     13231200
                   be generated for use in relinking this module.       13231400
                   Note:  The generated linkage editor control          13231600
                   statements are appropriate for OS/VS and later       13231600
                   linkage editors, and may require manual adjustment   13231800
                   when used with older linkage editors.                13231000
))JCL            - JCL and linkage editor control statements are to     13232200
                   be generated for use in relinking this module.       13232400
                   Note:  The generated linkage editor control          13232600
                   statements are appropriate for OS/VS and later       13232800
                   linkage editors, and may require manual adjustment   13233000
                   when used with older linkage editors.                13233200
))MODULE(Partm)  - specifies that CSECTS defined by the partial name,   13240000
                   Partm, are to be listed. Partm may be entered as a   13250000
                   partial CSECT name with one to eight characters.     13260000
=MEMBERS=ME=MEM=MEMB=MEMBE=MEMBER                                       13270000
)F    The MEMBERS subcommand lists member names from the data set       13280000
   directory.  Only those member names in the specified member group    13290000
   are displayed.                                                       13300000
                                                                        13310000
   Note that the MEMBERS subcommand may be used to check member names   13320000
   in a given group before invoking another subcommand which processes  13330000
   member groups.                                                       13340000
                                                                        13350000
   Note that -A is added following a displayed member name if the       13360000
   member name is an alias.  The member name is listed in a combined    13370000
   hexadecimal/character format if it does not contain upper-case       13380000
   alphanumeric characters (including @, $ and #) or if the first       13390000
   character is numeric.  Unprintable characters (for 3270-type         13400000
   devices) in a member name are displayed as periods.                  13410000
)X SYNTAX -                                                             13420000
     MEMBERS  memgroup                                                  13430000
                                                                        13440000
 ALIASES  - ME, MEM, MEMB, MEMBE, MEMBER, MEMBERS                       13450000
 DEFAULTS - memgroup                                                    13460000
 REQUIRED - none.                                                       13470000
)O OPERANDS -                                                           13480000
 memgroup - optional, specifies the group of members whose names        13490000
            are to be displayed.  Default member names, member name     13500000
            ranges and member name patterns are allowed; for more       13510000
            information, enter HELP GROUP.                              13520000
=OPTIONS=O=OP=OPT=OPTI=OPTIO=OPTION                                     13530000
)F  The OPTIONS subcommand displays the subcommands (or options)        13540000
 supported by the PDS command. Note that this display varies            13550000
 when a non-partitioned data set is being processed.                    13560000
)X SYNTAX -                                                             13570000
     OPTIONS                                                            13580000
                                                                        13590000
 ALIASES  - O, OP, OPT, OPTI, OPTIO, OPTION, OPTIONS                    13600000
)O OPERANDS -                                                           13610000
 no operands are supported.                                             13620000
=OUTCOPY=OU=OUT=OUTC=OUTCO=OUTCOP                                       13630000
)F   The OUTCOPY subcommand formats utility control statements          13640000
  which can be used by IEBCOPY to select members from a data set.       13650000
                                                                        13660000
  OUTCOPY usage notes:                                                  13670000
   A.  Output is directed to DDNAME PDSOUT.                             13680000
   B.  PDSOUT must be allocated to a sequential data set or to a        13690000
       member of a partitioned data set with fixed, 80 character        13700000
       records prior to entering the first OUTCOPY subcommand.          13710000
   C.  For new data sets, the default DCB attributes of                 13720000
       DCB=(RECFM=FB,LRECL=80,BLKSIZE=3120)  will be used.              13730000
   D.  An IEBCOPY COPY statement is written after opening PDSOUT        13740000
       initially and after each CHANGE or PDS subcommand; the           13750000
       statement is of the form:                                        13760000
       COPY  OUTDD=OUTPUT,INDD=xxx                                      13770000
       where xxx is the low-level qualifier of the input data set name. 13780000
   E.  Each IEBCOPY select statement is of the form:                    13790000
       S M=memname ,memname))                                           13800000
       Note -- memname is the member name; this format output statement 13810000
       can be modified by an editor if member rename or member replace  13820000
       functions are to be performed.                                   13830000
   F.  OUTCOPY maintains a list of member names written after each      13840000
       copy statement and does not output a member name more than once. 13850000
   G.  A CLIST such as the following could be established for IEBCOPY   13860000
       use:                                                             13870000
        PROC 3 FROMDSN FROMQUAL TODSN CONTROLS(PDSOUT.CNTL)             13880000
        ALLOC F(SYSIN) DA(&CONTROLS.) SHR                               13890000
        ALLOC F(SYSPRINT) DA(*)                                         13900000
        ALLOC F(&FROMQUAL.) DA(&FROMDSN.) SHR                           13910000
        ALLOC F(OUTPUT) DA(&TODSN.) OLD                                 13920000
        CALL 'SYS1.LINKLIB(IEBCOPY)'                                    13930000
                                                                        13940000
   H.  Then to copy selected members from your LIB.LOAD data set to     13950000
       'SYS1.LINKLIB2', you could enter the following line from         13960000
       READY mode:                                                      13970000
       exec copyout lib.load load 'sys1.linklib2'                       13980000
                                                                        13990000
)X SYNTAX -                                                             14000000
     OUTCOPY  member   ECHO/NOECHO  CLOSE/NOCLOSE                       14010000
                                                                        14020000
 ALIASES  - OU, OUT, OUTC, OUTCO, OUTCOP, OUTCOPY                       14030000
 DEFAULTS - member, previous ECHO/NOECHO, NOCLOSE                       14040000
 REQUIRED - none.                                                       14050000
)O OPERANDS -                                                           14060000
 member     - optional, specifies the member name(s) to be output on    14070000
              an IEBCOPY format SELECT statement.  Default member       14080000
              names, member name ranges and member name patterns are    14090000
              allowed; for more information, enter HELP GROUP.          14100000
                                                                        14110000
))ECHO      - Each IEBCOPY statement is to be written to the terminal   14120000
              as well as to the PDSOUT data set.                        14130000
))NOECHO    - IEBCOPY statements are to be written to the PDSOUT        14140000
              data set only.                                            14150000
))CLOSE     - The PDSOUT file is to be closed.  Note: the member or     14160000
              member group specified with the close operand is not      14170000
              output to the PDSOUT file.                                14180000
))NOCLOSE   - The PDSOUT data set is to be opened or to stay open.      14190000
=PATTERN=P=PA=PAT=PATT=PATTE=PATTER                                     14200000
)F    The PATTERN subcommand lists member names from the data set       14210000
   directory.  Only those member names which contain the PATTERN        14220000
   name segments specified are displayed.                               14230000
                                                                        14240000
   One or two member name segments may be entered as patterns.  If two  14250000
   segments are entered, both segments must occur in a member name for  14260000
   it to be displayed.  For example, with the pattern segments xx and   14270000
   1x, members named M1X4XX, M1XX and XX1X would be displayed by this   14280000
   subcommand while members named X1X or MXX13X would not be displayed. 14290000
                                                                        14300000
   Note that -A is added following a displayed member name if the       14310000
   member name is an alias.  The member name is listed in a combined    14320000
   hexadecimal/character format if it does not contain upper-case       14330000
   alphanumeric characters (including @, $ and #) or if the first       14340000
   character is numeric.  Unprintable characters (for 3270-type         14350000
   devices) in a member name are displayed as periods.                  14360000
)X SYNTAX -                                                             14370000
     PATTERN  segment1 segment2                                         14380000
                                                                        14390000
 ALIASES  - P, PA, PAT, PATT, PATTE, PATTER, PATTERN                    14400000
 DEFAULTS - previously entered segment1 and segment2 operands           14410000
 REQUIRED - none.                                                       14420000
)O OPERANDS -                                                           14430000
 segment1 -  optional, specifies a name segment which must be found     14440000
             in a member name for the member name to be displayed.      14450000
                                                                        14460000
 segment2 -  optional, specifies a second name segment which must       14470000
             also be found in a member name for the member name to      14480000
             be displayed.                                              14490000
=RECALL=R=RE=REC=RECA=RECAL                                             14500000
)F   The RECALL subcommand displays the previous subcommand or          14510000
  reenters and displays the previous subcommand for execution.          14520000
)X SYNTAX -                                                             14530000
     RECALL  ENTER/NOENTER                                              14540000
                                                                        14550000
 ALIASES  - R, RE, REC, RECA, RECAL, RECALL                             14560000
 DEFAULTS - NOENTER                                                     14570000
 REQUIRED - none.                                                       14580000
)O OPERANDS -                                                           14590000
                                                                        14600000
))ENTER     - the previous subcommand is to be displayed and            14610000
              reentered for execution.                                  14620000
))NOENTER   - the previous subcommand is to be displayed.               14630000
=RENAME=REN=RENA=RENAM                                                  14640000
)F   The RENAME subcommand assigns a new name to a named member.        14650000
                                                                        14660000
  If a non-alias load module is renamed, all associated alias directory 14670000
  entries are updated to reflect the new base module name.  Note: if a  14680000
  non-alias load module is renamed to itself, any associated alias      14690000
  entries will be checked and updated as needed.                        14700000
                                                                        14710000
  Caution: this subcommand modifies the data set. To ensure data set    14720000
  integrity, you should allocate the data set as OLD or be aware of     14730000
  the data set update protection provided by the PDS command for SHR    14740000
  allocations (for details, see HELP UPDATE).                           14750000
)X SYNTAX -                                                             14760000
     RENAME  curname newname   SWAP/NOSWAP  GROUP/NOGROUP               14770000
                                                                        14780000
 ALIASES  - REN, RENA, RENAM, RENAME                                    14790000
 DEFAULTS - NOSWAP, NOGROUP                                             14800000
 REQUIRED - curname, newname                                            14810000
)O OPERANDS -                                                           14820000
 curname  - specifies the current name of the member.                   14830000
                                                                        14840000
 newname  - specifies the new name for the member.  Note that this      14850000
            new name becomes the PDS default member name.               14860000
                                                                        14870000
))SWAP    - the members named are to exchange directory entries.        14880000
))NOSWAP  - no member name exchange is to be performed.                 14890000
))GROUP   - specifies that a group rename is to be performed.  The      14900000
            range of names affected is defined by the first operand     14910000
            and the first portion of the resulting name is defined      14920000
            by the second operand.                                      14930000
                                                                        14940000
            For example, if  RENAME IEB ABCD GROUP  were entered,       14950000
            all members beginning IEB... would be renamed to ABCD..     14960000
            With the above rename statement, a member named IEB12       14970000
            would be assigned the member name ABCD2; note that          14980000
            member IEB12 would be assigned the member name OXB12 if     14990000
            RENAME IEB OX GROUP  were entered.                          15000000
))NOGROUP - only the member specifically identified is to be renamed.   15010000
=RESTORE=RES=REST=RESTO=RESTOR                                          15020000
)F   The RESTORE subcommand resurrects a deleted member at the given    15030000
  TTR address.  Deleted members remain in a partitioned data set until  15040000
  the data set is compressed.                                           15050000
                                                                        15060000
  Restrictions: the attributes authorized, load only, not editable, not 15070000
  executable, page boundary, reentrant, refreshable and reusable can    15080000
  not be determined from load module records; however, these attributes 15090000
  can be assigned to a restored load module with the ATTRIB subcommand. 15100000
  Also, note that SPF statistics and SSI information cannot be restored 15110000
  for a member.                                                         15120000
                                                                        15130000
  If the data set is a load library, then if the member name is an      15140000
  imbedded external name within the load module, that external name     15150000
  will be used as the entry point; otherwise, the first CSECT in the    15160000
  load module will be used as the entry point.                          15170000
                                                                        15180000
  Caution: this subcommand modifies the data set. To ensure data set    15190000
  integrity, you should allocate the data set as OLD or be aware of     15200000
  the data set update protection provided by the PDS command for SHR    15210000
  allocations (for details, see HELP UPDATE).                           15220000
)X SYNTAX -                                                             15230000
     RESTORE  member   TTR(strt)                                        15240000
                       REPEAT/NOREPEAT                                  15250000
                       DISPLAY/NODISPLAY                                15260000
                       PROMPT/NOPROMPT                                  15270000
                       COUNT(nm)                                        15280000
                                                                        15290000
 ALIASES  - RES, REST, RESTO, RESTOR, RESTORE                           15300000
 DEFAULTS - TTR(0), NOREPEAT, DISPLAY, PROMPT, COUNT(5)                 15310000
 REQUIRED - member                                                      15320000
)O OPERANDS -                                                           15330000
 member     - specifies the name of the member to be resurrected.       15340000
              This member name becomes the PDS default member name.     15350000
))TTR(strt) - strt is one to six hexadecimal digits which provide the   15360000
              relative track address for the deleted member; or if      15370000
              REPEAT, DISPLAY or PROMPT are in effect, it specifies     15380000
              the start relative address for a deleted member search.   15390000
))REPEAT    - multiple deleted members following the provided TTR       15400000
              address may be restored.                                  15410000
              The member name to be used is taken from the partial      15420000
              member name entered filled to eight characters by a       15430000
              sequential count field.  For example, if the partial      15440000
              member name is GASM the successive restored member        15450000
              names will be GASM0001, GASM0002, GASM0003, ...           15460000
))NOREPEAT  - at most one member is to be restored.                     15470000
))DISPLAY   - data from deleted members is to be displayed.             15480000
))NODISPLAY - no data from deleted members is to be displayed.          15490000
))PROMPT    - a YES response to a program prompt is to be required      15500000
              before restoring a deleted member.                        15510000
))NOPROMPT  - no program prompting is to be performed before            15520000
              restoring a deleted member.                               15530000
))COUNT(nm) - Maximum number of informational lines to display from     15540000
              deleted members before prompting.                         15550000
=REVIEW=REVIE=REVI=REV                                                  15550010
)F  Example -     REVIEW mema:memb                                      15550020
                                                                        15550040
   The REVIEW subcommand browses data.  The TSO REVIEW command          15550060
   is used; any desired REVIEW operands may be added after the          15550080
   member name.                                                         15550100
)X SYNTAX -                                                             15550120
     REVIEW  member operands                                            15550140
                                                                        15550160
 ALIASES  - REV, REVI, REVIE, REVIEW                                    15550180
 DEFAULTS - member                                                      15550200
 REQUIRED - none.                                                       15550220
)O OPERANDS -                                                           15550240
  member   - optional, specifies the member name(s) to be passed        15550260
             (along with the data set name) to the TSO REVIEW           15550280
             command.                                                   15550300
                                                                        15550320
             Default member names, member lists, member name            15550340
             ranges and member name patterns are allowed; for           15550360
             more information, enter HELP GROUP.                        15550380
                                                                        15550400
 operands -  optional, may include any desired TSO REVIEW operands.     15550420
=SUBMIT=SU=SUB=SUBM=SUBMI                                               15560000
)F  The SUBMIT subcommand submits a JCL member.  The TSO SUBMIT         15570000
 command is used; any desired SUBMIT operands may be specified          15580000
 after the member name.                                                 15590000
)X SYNTAX -                                                             15600000
     SUBMIT  member operands                                            15610000
                                                                        15620000
 ALIASES  - SU, SUB, SUBM, SUBMI, SUBMIT                                15630000
 DEFAULTS - member, no operands                                         15640000
 REQUIRED - none.                                                       15650000
)O OPERANDS -                                                           15660000
  member  -  optional, specifies the member name(s) to be passed        15670000
             (along with the data set name) to the TSO SUBMIT command.  15680000
             Default member names, member name ranges and member        15690000
             name patterns are allowed; for more information, enter     15700000
             HELP GROUP.                                                15710000
                                                                        15720000
  operands - optional, may include any desired TSO SUBMIT operands.     15730000
=TSO=TS=T                                                               15740000
)F    The TSO subcommand may be used to invoke a TSO command            15750000
   processor.  Any desired operands may be specified after the TSO      15760000
   command processor name.                                              15770000
)X SYNTAX -                                                             15780000
     TSO  command operands                                              15790000
                                                                        15800000
 ALIASES  - T, TS, TSO                                                  15810000
 DEFAULTS - none.                                                       15820000
 REQUIRED - command                                                     15830000
)O OPERANDS -                                                           15840000
 command  -    specifies the command processor to be given control.     15850000
                                                                        15860000
 operands -    optional, may include any desired operands.              15870000
=USAGE=U=US=USA=USAG                                                    15880000
)F  The USAGE subcommand displays statistics on the current data set.   15890000
                                                                        15900000
 In addition, the USAGE subcommand displays the allocated DDNAME, data  15910000
 set name, data set disposition, DCB subparameters (RECFM, LRECL and    15920000
 BLKSIZE), and the disk volume name and unit in a pseudo-JCL format.    15930000
                                                                        15940000
 The statistics displayed include:                                      15950000
   the number of directory blocks allocated                             15960000
   the number of directory blocks currently in use                      15970000
   the number of disk storage tracks used by the directory              15980000
   the maximum number of member entries in a directory block            15990000
   the number of members in the directory                               16000000
   the number of member names which are alias names                     16010000
   the number of disk storage tracks allocated                          16020000
   the number of disk storage tracks currently not in use               16030000
   the number of disk storage extents required for the data set         16040000
)X SYNTAX -                                                             16050000
     USAGE                                                              16060000
                                                                        16070000
 ALIASES  - U, US, USA, USAG, USAGE                                     16080000
)O OPERANDS -                                                           16090000
   no operands are supported                                            16100000
=VERIFY=V=VE=VER=VERI=VERIF                                             16110000
)F  The VERIFY subcommand validity checks partitioned data sets in the  16120000
 following manner:                                                      16130000
  A.  A dummy member is added and deleted to determine if the           16140000
      data set directory is full.                                       16150000
  B.  The data set directory is read, member names are placed into      16160000
      a program table in TTR sort order and the following checks        16170000
      are performed:                                                    16180000
      1.  If NAME is in effect, member names are checked for            16190000
          non upper-case alphanumeric characters or a numeric           16200000
          first character.                                              16210000
      2.  If the data set is a load library, the following illegal      16220000
          linkage-editor attribute combinations are checked for:        16230000
          a.  Modules with RENT and NOREUS attributes                   16240000
          b.  Modules with RMODEANY and AMODE24 or AMODEANY attributes  16250000
          c.  Modules with OVLY and RENT, REUS, REFR, SCTR, RMODEANY,   16260000
              AMODE31, or AMODEANY attributes                           16270000
          d.  Modules with TEST and NOEDIT attributes                   16280000
          e.  Modules with REUS and SCTR attributes                     16290000
      3.  If LOAD is in effect and the data set is a load library,      16300000
          each member is checked for ABENDS as it is LOADED and         16310000
          DELETED.                                                      16320000
      4.  Each member is checked for current usage by an SPF EDIT       16330000
          session.                                                      16340000
      5.  Member directory entries are sequence checked by name.        16350000
      6.  Each member's TTR address is checked against the end of       16360000
          the data set.                                                 16370000
  C.  The program TTR table is checked for the following:               16380000
      1.  Orphan members (aliases with no associated real member).      16390000
      2.  Apparent alias members (real members whose start address      16400000
          matches another real member's start address).                 16410000
      3.  Alias load modules whose directory pointers to associated     16420000
          real members are incorrect.                                   16430000
      4.  Alias load modules whose RMODE entries or main AMODE entries  16440000
          do not match their base module's entries.                     16450000
  D.  If READ or INPUT is in effect, the following applies.             16460000
      1.  The directory and each member is read checking for:           16470000
          a.  Permanent I/O errors                                      16480000
          b.  Input blocksizes exceeding the DCB BLKSIZE                16490000
          c.  Input blocksizes/LRECL not an integral if RECFM=F         16500000
          d.  Input LRECLs exceeding DCB LRECL if RECFM=V               16510000
          e.  Input LRECLs less than four bytes if RECFM=V              16520000
          f.  Null members                                              16530000
          g.  Directory RLD/CONTROL counts for modules linked since     16540000
              OS/VS which do not match the first RLD entry              16550000
  E.  Informational messages regarding the data set are provided.       16560000
                                                                        16570000
 The VERIFY subcommand validity checks sequential data sets in the      16580000
 following manner:                                                      16590000
  A.  The data set is checked for current usage by an SPF EDIT session. 16600000
  B.  If READ or INPUT is in effect, the data set is read and checks    16610000
      are made for:                                                     16620000
      1.  Permanent I/O errors                                          16630000
      2.  Input blocksizes exceeding the DCB BLKSIZE                    16640000
      3.  Input blocksizes/LRECL not an integral if RECFM=F             16650000
      4.  Input LRECLs exceeding DCB LRECL if RECFM=V                   16660000
      5.  Input LRECLs less than four bytes if RECFM=V                  16670000
  C.  Informational messages regarding the data set are provided.       16680000
)X SYNTAX -                                                             16690000
     VERIFY  LOAD  /  NOLOAD                                            16700000
             NAME  /  NONAME                                            16710000
             INPUT /  NOINPUT    or    READ / NOREAD                    16720000
                                                                        16730000
 ALIASES  - V, VE, VER, VERI, VERIF, VERIFY                             16740000
 DEFAULTS - LOAD, INPUT, NAME                                           16750000
 REQUIRED - none.                                                       16760000
)O OPERANDS -                                                           16770000
                                                                        16780000
))LOAD      -  For load libraries, each member is to be LOADED and      16790000
               DELETED.                                                 16800000
))NOLOAD    -  No members are to be LOADED and DELETED.                 16810000
))NAME      -  Each member is to be checked for valid member names.     16820000
               Valid member names are from one to eight characters      16830000
               long containing upper case alphanumeric characters       16840000
               and the first character is not numeric.                  16850000
))NONAME    -  No members are to be checked for valid member names.     16860000
))INPUT     -  Each member (or the data set) is to be input.            16870000
))NOINPUT   -  No members (nor the data set) are to be input.           16880000
))READ      -  Each member (or the data set) is to be input.            16890000
))NOREAD    -  No members (nor the data set) are to be input.           16900000
=ABEND=ABEN=ABE=AB=ESTAE=ESTAI=STAE=STAI                                16910000
)F  The ABEND HELP entry is provided to explain ABEND processing        16920000
 performed by PDS. In general, PDS will recover from ABENDS with        16930000
 its ESTAE and ESTAI recovery routines.                                 16940000
                                                                        16950000
                                                                        16960000
 In the following, the ABEND processing provided by PDS is described    16970000
 in more detail:                                                        16980000
                                                                        16990000
  A.  The PDS program uses different recovery routines depending on     17000000
      the subcommand being executed.  The routine used will perform any 17010000
      cleanup and initialization functions required to restart PDS.     17020000
                                                                        17030000
  B.  For internal PDS subcommands, recovery is performed by writing    17040000
      an error message and ignoring the subcommand.                     17050000
                                                                        17060000
                                                                        17070000
  C.  For the other external PDS subcommands (EDIT, EXEC, FSE, HELP,    17080000
      SUBMIT and TSO xxx), the subcommand processor is forcibly         17090000
      detached.                                                         17100000
                                                                        17110000
  D.  Certain external programs reached via the TSO subcommand (such    17120000
      as CALL) will terminate PDS with a "READY" message if the         17130000
      program it invokes ABENDS.  Note, however, that if a null line    17140000
      is entered at this point, PDS will regain control.                17150000
)X SYNTAX - none.                                                       17160000
)O OPERANDS - none.                                                     17170000
=ATTN=PA1=ATTE=ATTEN=ATTENT=ATTENTI=ATTENTIO                            17180000
)F  The ATTN HELP entry is provided to explain the attention processing 17190000
 performed by PDS. In general, an attention (the PA1 key) may be used   17200000
 to terminate the current PDS subcommand and two attentions in a row    17210000
 may be used to terminate the PDS command.                              17220000
                                                                        17230000
                                                                        17240000
 In the following, the attention processing provided by PDS is          17250000
 described in more detail:                                              17260000
                                                                        17270000
  A.  An single (double for EDIT) attention should terminate any        17280000
      member group in progress (except for the FSE subcommand).         17290000
                                                                        17300000
  B.  An attention at a prompt for a data set should terminate PDS.     17310000
                                                                        17320000
  C.  An attention at the normal subcommand prompt of "ENTER OPTION"    17330000
      should provide another "ENTER OPTION" prompt; another attention   17340000
      at this point should terminate PDS.                               17350000
                                                                        17360000
  D.  For PDS subcommands, an single (double for EDIT) attention        17370000
      should result in an "ENTER OPTION" prompt; the processing         17380000
      action taken at this point depends on the data entered next:      17390000
       1.  Another attention should terminate the PDS command.          17400000
       2.  A null line should cause the interrupted subcommand to       17410000
           continue at the point of interruption.  Note: any messages   17420000
           awaiting output at the time of the interrupt will be lost.   17430000
       3.  If a subcommand is entered and the currently executing       17440000
           subcommand is external to PDS (EDIT, EXEC, FSE, HELP,        17450000
           SUBMIT or TSO xxx), the subcommand processor should be       17460000
           forcibly detached and the ABEND message should be suppressed.17470000
       4.  An entered subcommand should be given control without delay. 17480000
                                                                        17490000
  E.  If a internal PDS subcommand is in a loop that does not involve   17500000
      input or output to the terminal or input from the current data    17510000
      set, a single attention will not terminate the loop:              17520000
       1.  The first attention will provide the normal enter            17530000
           option prompt.                                               17540000
       2.  If a subcommand is entered at this time, PDS will            17550000
           continue looping.                                            17560000
       3.  Another attention will produce the message                   17570000
           "WARNING: POSSIBLE PROGRAM LOOP" and PDS will perform        17580000
           the subcommand entered at the enter option prompt.           17590000
)X SYNTAX - none.                                                       17600000
)O OPERANDS - none.                                                     17610000
=DEFINE=DEF=DEFI=DEFIN                                                  17620000
)F  The DEFINE HELP entry is provided to explain terminology used       17630000
 in the PDS program and in its documentation:                           17640000
                                                                        17650000
 PDS or Partitioned data set - a data set with fixed, variable or       17660000
 undefined format which is commonly used as a "library" for related     17670000
 types of information.  Partitioned data sets contain two segments:     17680000
 a directory of information and the member data.                        17690000
                                                                        17700000
 PDS Directory -  a segment of a PDS which is a sequential data set     17710000
 with eight byte keys and 256 byte data records containing pointers     17720000
 to data in the PDS member portion of the data set.                     17730000
                                                                        17740000
 PDS member data - a segment of a PDS which contains current members    17750000
 (which are pointed to by one or more directory entries) and inactive   17760000
 or deleted members (which have no associated directory entries).       17770000
                                                                        17780000
 Load library -  a partitioned data set which has record format U, UA   17790000
 or UM and is commonly used to contain executable modules.              17800000
                                                                        17810000
 Member -  data in a partitioned data set (or PDS) which is pointed     17820000
 to by one or more PDS directory entries.                               17830000
                                                                        17840000
 Load module -  a member contained in a load library.                   17850000
                                                                        17860000
 Alias member -  a directory entry with a indicator value which         17870000
 indicates that the member entry is an alternate name for another       17880000
 member; a real member and its aliases are associated with the          17890000
 same recorded data in the PDS.                                         17900000
                                                                        17910000
 Real member -  a non-alias directory entry and its associated          17920000
 recorded data.                                                         17930000
                                                                        17940000
 Orphan member - an member marked as an alias which does not have       17950000
 an associated real member.                                             17960000
                                                                        17970000
 Deleted member -  member data which is not pointed to by any           17980000
 directory entry; deleted members remain in the PDS until the           17990000
 data set is compressed.                                                18000000
                                                                        18010000
 Apparent alias member -  data in a partitioned data set which is       18020000
 pointed to by more than one real PDS directory entry.                  18030000
)X SYNTAX - none.                                                       18040000
)O OPERANDS - none.                                                     18050000
=GROUPS=G=GR=GRO=GROU=GROUP=GROUP.                                      18060000
)F  The GROUP HELP entry is provided to explain the various member      18070000
 name forms allowed.  Member names may be entered in either character   18080000
 or hexadecimal mode for any subcommand which processes member names.   18090000
                                                                        18100000
 Character member names may be from one to eight bytes long with no     18110000
 imbedded blanks, commas or parentheses.                                18120000
                                                                        18130000
 Hexadecimal member names may contain from one to sixteen hexadecimal   18140000
 digits delimited by x' and '.  X'd7c4e2f9' and PDS9 are entirely       18150000
 equivalent; also, x'333' and x'0333' are equivalent.                   18160000
                                                                        18170000
                                                                        18180000
 Subcommands ATTRIB, DELETE, DIRENTRY, EDIT, FIND, FSE, IF, HISTORY,    18190000
 LIST, MAP, MEMBERS, OUTCOPY and SUBMIT allow additional member name    18200000
 specifications.  A member name range or member name pattern specifies  18210000
 what is called a member group.                                         18220000
                                                                        18230000
 When a member group is being processed, the subcommand processing      18240000
 routine is re-executed for each member in the group.  Specifically,    18250000
 note the following:                                                    18260000
                                                                        18270000
  A.  Default member name -- if no member name is specified, the        18280000
      last member name or member group entered for any of the above     18290000
      subcommands will be assumed.                                      18300000
                                                                        18310000
  B.  Asterisk member name -- if * is entered in the member name        18320000
      position, the last member name or member group entered for        18330000
      any of the above subcommands will be assumed.                     18340000
                                                                        18350000
  C.  Member name range -- any of these subcommands may process all     18360000
      members in a range by specifying a beginning partial member       18370000
      name, a colon, and a ending partial member name (either or        18380000
      both of the partial names may be null).                           18390000
                                                                        18400000
      Logic from the DISPLAY subcommand is used to select members;      18410000
      the subcommand processes these selected members in alphabetic     18420000
      order.  the following specifications would process the same       18430000
      member names:                                                     18440000
            subcommand  :              and    DISPLAY                   18450000
            subcommand  part1:         and    DISPLAY  part1            18460000
            subcommand  :part2         and    DISPLAY  x'00' part2      18470000
            subcommand  part1:part2    and    DISPLAY  part1 part2      18480000
                                                                        18490000
  D.  Member name pattern -- any of these subcommands may process all   18500000
      members whose names contain pattern characters by specifying a    18510000
      member name segment, a slash, and another member name segment     18520000
      (either, not both, of the member name segments may be null).      18530000
                                                                        18540000
      Logic from the PATTERN subcommand is used to select members;      18550000
      the subcommand processes these selected members in alphabetic     18560000
      order.  the following specifications would process the same       18570000
      member names:                                                     18580000
            subcommand  seg1/          and    PATTERN  seg1             18590000
            subcommand  /seg2          and    PATTERN  seg2             18600000
            subcommand  seg1/seg2      and    PATTERN  seg1 seg2        18610000
)X SYNTAX - none.                                                       18620000
)O OPERANDS - none.                                                     18630000
=UPDATE=UP=UPD=UPDA=UPDAT=SHR=SH                                        18640000
)F  The UPDATE HELP entry is provided to explain the update data        18650000
 set protection implemented for certain PDS subcommands.                18660000
                                                                        18670000
 If the data set is allocated as OLD, the STOW DCB is left open after   18680000
 the first data set update.  For OLD allocations, exclusive use of the  18690000
 data set is assured and the following does not apply.                  18700000
                                                                        18710000
 If the data set is allocated as SHR (SHR was specifically requested    18720000
 or SHR was defaulted to), PDS subcommands which update the data set    18730000
 such as ALIAS, ATTRIB (with attributes to be changed), DELETE,         18740000
 FIXPDS, RENAME, RESTORE or VERIFY could cause data set integrity       18750000
 problems if the data set is also being updated by another user.        18760000
                                                                        18770000
 To circumvent this problem, PDS uses the following SPF RESERVE         18780000
 logic to maintain data set integrity during data set updates.          18790000
                                                                        18800000
  A.  A  RESERVE  (SPFDSN,DSNAME,E,44,SYSTEMS),UCB=ADDRESS              18810000
      is performed.                                                     18820000
                                                                        18830000
  B.  If the data set is a load library, then a linkage-editor          18840000
      RESERVE or ENQUE is performed as appropriate:                     18850000
       A.  On a shared DASDI volume,                                    18860000
           RESERVE  (SYSIEWLP,DSNAME,E,44,SYSTEMS),UCB=ADDRESS          18870000
       B.  On a non-shared DASDI volume,                                18880000
           ENQ  (SPFIEWLP,DSNAME,E,44,SYSTEM)                           18890000
                                                                        18900000
  C.  The data set STOW DCB is opened                                   18910000
                                                                        18920000
  D.  All data set updates are performed.                               18930000
       A.  For the ATTRIB subcommand, the STOW DCB is left open         18940000
           while an entire member group is being processed.             18950000
       B.  For the DELETE subcommand, the STOW DCB is left open         18960000
           while an entire member group is being processed if no        18970000
           yes/no prompting is being provided for each member.          18980000
                                                                        18990000
  E.  The data set STOW DCB is closed                                   19000000
                                                                        19010000
  F.  DEQ's are performed to remove the RESERVE's and ENQ's             19020000
)X SYNTAX - none.                                                       19030000
)O OPERANDS - none.                                                     19040000
=MESSAGE=MS=MES=MSG=MESS=MSGS=MESSA=MESSAG=MESSAGES                     19050000
)F FUNCTION -                                                           19060000
 The MESSAGE HELP entry is provided to document PDS program messages.   19070000
                                                                        19080000
 PDS messages are of the format PDSnnnx (where nnn is numeric and       19090000
 x is the letter I, A, W or E).  The program messages are grouped in    19100000
 numeric ranges by message severity as shown below:                     19110000
                                                                        19120000
      MESSAGE RANGE         DESCRIPTION                                 19130000
      -----------------     -----------                                 19140000
      PDS000I - PDS299I     Informational messages                      19150000
      PDS300A - PDS399A     Action messages (a response is required)    19160000
      PDS400W - PDS599W     Warning message (possible error condition)  19170000
      PDS600E - PDS999E     Error messages                              19180000
                                                                        19190000
                                                                        19200000
 Messages above PDS399 (warning and error messages) can be explained    19210000
 via the extended help facility if these messages are received during   19220000
 PDS program execution.                                                 19230000
                                                                        19240000
 To use the extended help facility after warning and/or error messages  19250000
 have been received, enter a .?  response to the ENTER OPTIONS prompt   19260000
 message and up to five warning or error message explanations from the  19270000
 last subcommand will be requested from the HELP data set by the        19280000
 program.                                                               19290000
)X SYNTAX -                                                             19300000
     HELP MSG O(PDSxxx,PDSyyy, ...)                                     19310000
          (where PDSxxx and PDSyyy are messages to be explained)        19320000
                                                                        19335000
)O MESSAGES -                                                           19330000
   PDS has the following numbered messages:                             19340000
                                                                        19345000
))PDS001I TESTMESSAGES -- ALL NUMBERED MESSAGES FOLLOW:                 19350000
   This message is the header for CONTROL TESTMESSAGES.                 19360000
                                                                        19370000
))PDS002I DEFAULT MEMBER IS member                                      19380000
   This message displays the default member name.  This member is being 19390000
   identified as the member which will be acted upon by the current     19400000
   subcommand.  The default member name (or member group) will also be  19410000
   displayed on the PDS300A message after the  MEM=  keyword.           19420000
                                                                        19430000
))PDS005I END OF FILE                                                   19440000
   An end of file marker was input indicating the end of the member.    19450000
                                                                        19460000
))PDS006I END OF DATA SET                                               19470000
   An end of file marker was input indicating the end of the data set.  19480000
                                                                        19490000
))PDS010I THE ALIAS HAS BEEN ASSIGNED                                   19500000
   The ALIAS subcommand has completed successfully.                     19510000
                                                                        19520000
))PDS020I member ATTRIBUTES ARE: attrib1, attrib2, ...                  19530000
   This message lists the linkage editor attributes of the member:      19540000
     OVERLAY   - overlay load structure                                 19550000
     TEST      - linked with the TEST option                            19560000
     E-LEVEL   - not linked by the "F" level linkage editor             19570000
     SCTR      - scatter load structure                                 19580000
     RENT      - reentrant (executable by several tasks simultaneously) 19590000
     REUS      - reusable (executable by several tasks in serial order) 19600000
     REFR      - refreshable (replaceable by a copy during execution)   19610000
     LOAD ONLY - can only be brought into storage with a LOAD MACRO     19620000
     NOT EDIT  - can not be linkage edited again                        19630000
     NOT EXEC  - not executable                                         19640000
     DC        - downward compatible with linkage editor level E        19650000
     NONE      - none of the above linkage attributes                   19660000
                                                                        19670000
))PDS021I APF AUTHORIZED                                                19680000
   This member has been marked as authorized by the linkage editor.     19690000
                                                                        19700000
                                                                        19710000
))PDS022I NOT APF AUTHORIZED, OBSOLETE LINKAGE EDITOR                   19720000
   This member is not authorized; it was linked by a pre-OS/VS linkage  19730000
   editor.                                                              19740000
                                                                        19750000
))PDS023I APF AUTHORIZED, APF DATA VALUE GREATER THAN 1                 19760000
   This member was authorized by the linkage editor and the APF value   19770000
   exceeds one.                                                         19780000
                                                                        19790000
))PDS024I PAGE ALIGNMENT IS REQUIRED                                    19800000
   This member requires alignment on a page boundary.                   19810000
                                                                        19820000
))PDS025I SSI INFORMATION: hexvalue                                     19830000
   This member has the displayed SSI data.                              19840000
                                                                        19850000
))PDS030I GLOBAL OPERANDS: global1, global2, ...                        19860000
   This message lists the current CONTROL global values:                19870000
     ALIASINFO   - alias information is desired for MAP and ATTRIB.     19880000
     NOALIASINFO - no alias information is required.                    19890000
     LKEDDATE    - linkage edit dates are desired for ATTRIB.           19900000
     NOLKEDDATE  - no linkage edit date information is required.        19910000
     PROMPT      - yes/no prompts are desired as usual for DELETE,      19920000
                   FIXPDS, RENAME, REPRO, RESTORE and SUBMIT.           19930000
     NOPROMPT    - yes/no prompts are not required for DELETE, FIXPDS,  19940000
                   RENAME, REPRO, RESTORE or SUBMIT (a yes reply is     19950000
                   to be assumed).                                      19960000
     RECOVER     - STAE recovery should be attempted after an ABEND.    19970000
     NORECOVER   - STAE recovery should not be attempted.               19980000
     DSNAME(dsn) - names the data set which is receiving the session    19990000
                   log output; this will be combined with a data set    20000000
                   status such as OLD, NEW, SHR or MOD.                 20010000
     NODSNAME    - no session log is being output to a data set.        20020000
                                                                        20030000
))PDS031I INPUT BUFFERING: type                                         20040000
   This message lists the current input buffering mode:                 20050000
     SINGLE    - Read single (each read obtains one physical block).    20060000
     DOUBLE    - Read double (each read obtains two physical blocks).   20070000
     MULTIPLE  - Read multiple (each read obtains an entire track).     20080000
                                                                        20090000
   Note that the buffering type is reset for each data set allocated    20100000
   according to the device type on which the data set resides.  In      20110000
   general, MULTIPLE is used for device types which support the READ    20120000
   MULTIPLE CCW and DOUBLE is used otherwise.                           20130000
                                                                        20140000
))PDS032I TESTCPULOOP -- CPU LOOP FOLLOWS:                              20150000
   CONTROL TESTCPULOOP - performs a CPU loop for program testing.       20160000
                                                                        20170000
))PDS033I TESTABEND -- SYSTEM 0C1 FOLLOWS:                              20180000
   CONTROL TESTABEND - performs an ABEND for program testing.           20190000
                                                                        20200000
))PDS034I TESTOUTLOOP -- THIS DATA REPEATS                              20210000
   CONTROL TESTOUTLOOP - performs an output loop for program testing.   20220000
                                                                        20230000
))PDS035I TESTREAD -- EXCP RETURN CODE=nn; NEXT TTR ADDRESS IS ttraddr  20240000
   CONTROL TESTREAD -- verifies the operation of the input EXCP routine 20250000
   by using an initial TTR of 000001 in each case.                      20260000
                                                                        20270000
   EXCP is called for each of the buffering modes:                      20280000
     SINGLE    - Read single (each read obtains one physical block).    20290000
                 The return code should be 00 and NEXT TTR ADDRESS      20300000
                 should be 000002 if sufficient data is available.      20310000
     DOUBLE    - Read double (each read obtains two physical blocks).   20320000
                 The return code should be 00 and NEXT TTR ADDRESS      20330000
                 should be 000003 if sufficient data is available.      20340000
     MULTIPLE  - Read multiple (each read obtains an entire track).     20350000
                 If the disk unit supports the READ MULTIPLE CCW, the   20360000
                 return code should be 00 and NEXT TTR ADDRESS          20370000
                 should be 000101 if sufficient data is available.      20380000
                                                                        20390000
                 If this disk unit does not support the READ MULTIPLE   20400000
                 CCW, a PDS892E message should be received, the return  20410000
                 code should be 00 and NEXT TTR ADDRESS should be       20420000
                 000003 (double buffering is actually used).            20430000
                                                                        20440000
   Return codes from EXCP have the following meanings:                  20450000
        RC=00    Successful read                                        20460000
        RC=04    End of member                                          20470000
        RC=08    End of data set                                        20480000
        RC=12    I/O error                                              20490000
                                                                        20500000
))PDS040I member HAS BEEN DELETED                                       20510000
   DELETE has completed successfully.                                   20520000
                                                                        20530000
))PDS050I member1 WILL BE MOVED                                         20540000
   This member will be recreated by FIXPDS (FIXPDS moves                20550000
   members which are in the way of the expanded member directory).      20560000
                                                                        20570000
))PDS051I member IS BEING MOVED                                         20580000
   FIXPDS is currently moving this member.                              20590000
                                                                        20600000
PDS060I TRANSLATOR HISTORY BY CSECT -                                   20610000
))PDS060I TRANSLATOR HISTORY BY CSECT -                                 20620000
  IKJEFT03  9/22/80   5741SC103  V02 M02                                20630000
  IEFBR14  11/22/81   5741SC103  V02 M02                                20640000
                                                                        20650000
   This message is a header for assembler or compiler IDR records:      20660000
     IKJEFT03   - name of the CSECT.                                    20670000
     9/22/80    - date of the assembly or compilation.                  20680000
     5741SC103  - translator identification.                            20690000
     V02 M02    - translator version and modification level.            20700000
                                                                        20710000
))PDS061I IMASPZAP UPDATE HISTORY BY CSECT -                            20720000
  IEFBR14       6/14/84    HABLX                                        20730000
                                                                        20740000
   This message is a header for zap IDR records:                        20750000
     IEFBR14    - name of the CSECT.                                    20760000
     6/14/84    - date of the zap.                                      20770000
     HABLX      - zap user identification (USERID or JOB name).         20780000
                                                                        20790000
))PDS062I USER-SUPPLIED UPDATE HISTORY BY CSECT -                       20800000
  IEFBR14      11/29/81    UZ54057                                      20810000
                                                                        20820000
   This message is a header for user-supplied IDR records:              20830000
     IEFBR14     - name of the CSECT.                                   20840000
     11/29/81    - date of the information.                             20850000
     UZ54057     - user-supplied IDR information.                       20860000
                                                                        20870000
))PDS064I LAST LINK-EDITED ON mm/dd/yy  BY LKED lkedname  Vnn Mmm       20880000
   This message displays the last linkage edit date and linkage         20890000
   editor identification information.                                   20900000
                                                                        20910000
))PDS065I ASSOCIATED INFORMATION UPDATED FOR MEMBER: member             20920000
   This message is issued when a main member is renamed and the         20930000
   identified alias member's directory entry is updated to point        20940000
   to the renamed member.                                               20950000
                                                                        20960000
))PDS066I MEMBER IS AN ALIAS FOR: member                                20970000
   This member is an alias; the main member is identified.              20980000
                                                                        20990000
))PDS071I THE FOLLOWING OPTIONS ARE AVAILABLE:                          21000000
   This message is a header for the list of available subcommands.      21010000
                                                                        21020000
))PDS080I OUTCOPY DCB IS CLOSED                                         21030000
   FILE(PDSOUT) has been closed.                                        21040000
                                                                        21050000
))PDS080I LOGCOPY DCB IS CLOSED                                         21060000
   The session copy data set has been closed.                           21070000
                                                                        21080000
))PDS090I mem1 HAS BEEN RENAMED TO mem2                                 21090000
   RENAME has completed successfully; mem1 is now known as mem2.        21100000
                                                                        21110000
))PDS091I member HAS BEEN RESTORED                                      21120000
   RESTORE has completed successfully.                                  21130000
                                                                        21140000
))PDS100I PDS -- VERSION v.r.ll  month dd, yyyy                         21150000
   This message displays the name and release level of the PDS86        21160000
   program and displays the last PDS maintenance date;                  21170000
   this message should be received at program initialization            21180000
   and as the first message from the CONTROL subcommand.                21190000
                                                                        21200000
))PDS101I DELETED MEMBER FOUND AT TTR: hexttr                           21210000
   A previously deleted member was found at the displayed TTR address.  21220000
                                                                        21230000
))PDS102I ENTRY POINT AT hexaddress                                     21240000
   The entry offset of the module is displayed in hexadecimal.          21250000
                                                                        21260000
))PDS103I ENTRY POINT AT hexaddress --  symbol                          21270000
   The entry offset of the module is displayed in hexadecimal and the   21280000
   name of the corresponding entry point symbol is also displayed.      21290000
                                                                        21300000
))PDS104I MODULE LENGTH  hexlength  --  decimalK                        21310000
   The length of the module is provided in hexadecimal and in K         21320000
   units (units of 1024 bytes using the next higher boundary of 1024).  21330000
                                                                        21340000
))PDS110I nn,nnn LOGICAL RECORDS WERE INPUT                             21350000
   This is a count of the logical input records.                        21360000
                                                                        21370000
PDS111I<PARM#1> PHYSICAL BLOCKS WERE INPUT                              21380000
))PDS111I nn,nnn PHYSICAL BLOCKS WERE INPUT                             21390000
   This is a count of the physical input records.                       21400000
                                                                        21410000
))PDS112I nn,nnn CHARACTERS IN THE LARGEST PHYSICAL BLOCK               21420000
   This is the maximum physical blocksize read.                         21430000
                                                                        21440000
))PDS113I nn,nnn CHARACTERS PER AVERAGE PHYSICAL BLOCK                  21450000
   This average is from (total characters read)/(total blocks read).    21460000
                                                                        21470000
))PDS114I nn,nnn TRACKS COULD BE REGAINED BY COMPRESSING THIS DATA SET  21480000
   The number of tracks indicated contain deleted members; if a         21490000
   compress is performed on the data set, these tracks should become    21500000
   available for use.                                                   21510000
                                                                        21520000
))PDS115I nn,nnn MEMBERS WERE CHECKED                                   21530000
   This message indicates the number of members in the data set.        21540000
                                                                        21550000
))PDS116I DATA SET WAS CHECKED                                          21560000
   This message indicates that the data set was checked by VERIFY.      21570000
                                                                        21580000
))PDS120I PROGRAM RESIDENCE MODE IS rmode -- ADDRESSING MODE IS amode   21590000
   This message indicates the RMODE and AMODE values of the module:     21600000
     RMODE24  - residence mode is 24 (below the 16M line)               21610000
     RMODEANY - residence mode is ANY (above the 16M line)              21620000
     AMODE24  - addressing mode is 24 bit addresses                     21630000
     AMODE31  - addressing mode is 31 bit addresses                     21640000
     AMODEANY - addressing mode is 24 or 31 bit addresses               21650000
                                                                        21660000
))PDS140I BLOCK  RECORD nn,nnn  LENGTH nn,nnn  TTR hexttr               21670000
       or DUMP   RECORD nn,nnn  LENGTH nn,nnn  TTR hexttr               21680000
   This is a header for BLOCK or DUMP format LIST, FIND and REPLACE     21690000
   outputs:                                                             21700000
     RECORD   - the current physical record number                      21710000
     LENGTH   - the length of the current physical record               21720000
     TTR      - the disk address of this record in hexadecimal          21730000
                                                                        21740000
))PDS141I AT hexaddr  CSECT csectname  LENGTH hexlen                    21750000
                                   or  ENTRY entryname                  21760000
   This is a header for LBLOCK or LDUMP format LIST, FIND and REPLACE   21770000
   outputs for a CSECT or for an entry within a CSECT in a load module: 21780000
     AT       - start of this CSECT in the load module                  21790000
     CSECT    - the name of this CSECT                                  21800000
     LENGTH   - the length of this CSECT                                21810000
     ENTRY    - the name of this entry (note: if the ENTRY form is      21820000
                used, AT displays the start of this ENTRY symbol).      21830000
                                                                        21840000
))PDS142I nn,nnn LINES  IN THIS MEMBER                                  21850000
              or BLOCKS IN THIS MEMBER                                  21860000
   Note: this message means that an end of file marker has been         21870000
   recognized; it also summarizes the amount of data input -            21880000
     LINES    - number of logical records read                          21890000
     BLOCKS   - number of physical records read                         21900000
                                                                        21910000
))PDS143I member DIRECTORY ENTRY, LENGTH=nn                             21920000
   This is a header for a dump of the member's directory entry.         21930000
                                                                        21940000
))PDS144I DATA LINE n:                                                  21950000
   This is a header for a display of one line from a formerly           21960000
   deleted member.                                                      21970000
                                                                        21980000
))PDS160I ALIASES FOR THIS MEMBER ARE: alias1, alias2, ...              21990000
   This message displays the aliases associated with this main member.  22000000
                                                                        22010000
))PDS161I MEMBERS TO BE RENAMED ARE: member1, member2, ...              22020000
   This message displays the group of members which will be             22030000
   renamed if a "y" is provided to the next prompt.                     22040000
                                                                        22050000
))PDS162I MEMBERS TO BE DELETED ARE: member1, member2, ...              22060000
   This message displays the group of members which will be             22070000
   deleted if a "y" is provided to the next prompt.                     22080000
                                                                        22090000
))PDS163I ASSOCIATED MEMBERS TO BE DELETED ARE: member1, member2, ...   22100000
   This message displays the associated (alias, apparent alias and      22110000
   main) members which will also be deleted if a "y" is provided        22120000
   to the next prompt.                                                  22130000
                                                                        22140000
))PDS164I CSECTS ARE: csect1, csect2, ...                               22150000
   This message displays the CSECT names found in this previously       22160000
   deleted member.                                                      22170000
                                                                        22180000
))PDS171I COMPRESS HAS COMPLETED; RC=nnn                                22190000
   The compress operation has finished with the indicated               22200000
   return code.  This message is issued when the return code is         22210000
   non-zero.                                                            22220000
                                                                        22230000
))PDS180I DATA SET: CREATED  EXPIRES  LAST USE  UPDATED SECURITY        22240000
  PDS180I          mm/dd/yy mm/dd/yy  mm/dd/yy  yes/no  type            22250000
                                                                        22260000
   This message lists various data set characteristics:                 22270000
     CREATED  -  data set creation date.                                22280000
     EXPIRES  -  data set expiration date.                              22290000
     LAST USE -  last data set open date.                               22300000
     UPDATED  -  YES if data set has been opened for output or update.  22310000
                 NO if all opens have been for input.                   22320000
     SECURITY -  NONE if no data set password security bit is set.      22330000
                 WRITE if the data set is protected from output use.    22340000
                 READ if the data set is protected from input use.      22350000
                 RACF if the data set RACF bit is on.                   22360000
                                                                        22370000
))PDS181I EXTENTS IN TRACKS: nnn, nnn, ...                              22380000
   This message lists the size of each data set extent in tracks.       22390000
                                                                        22400000
))PDS182I TRACKS: ALLOCATED  USED  FREE  EXTENTS                        22410000
  PDS182I              nnnn  nnnn  nnnn     nnnn                        22420000
                                                                        22430000
   This message lists disk allocation characteristics:                  22440000
     ALLOCATED - number of allocated disk tracks.                       22450000
     USED      - number of in-use disk tracks.                          22460000
     FREE      - number of free disk tracks.                            22470000
     EXTENTS   - number of disk storage extents.                        22480000
                                                                        22490000
))PDS183I DIRECTORY: BLOCKS  USED  FREE  TRACKS  MEMBERS  ALIASES       22500000
  PDS183I              nnnn  nnnn  nnnn    nnnn     nnnn     nnnn       22510000
                                                                        22520000
   This message lists directory statistics:                             22530000
     BLOCKS    - number of allocated directory blocks.                  22540000
     USED      - number of in-use directory blocks.                     22550000
     FREE      - number of free directory blocks.                       22560000
     TRACKS    - number of tracks occupied by directory blocks.         22570000
     MEMBERS   - number of members in the data set.                     22580000
     ALIASES   - number of aliases in the data set.                     22590000
                                                                        22600000
))PDS184I EXTENT UCB LO TT-HI TT TRKS     LOW CCHH-HIGH CCHH   BOUNDARY 22610000
  PDS184I ------ --- ----- ----- ----  ----------- ----------- -------- 22620000
  PDS184I     nn ccc tt.tt tt.tt  nnn  cc.cc.hh.hh cc.cc.hh.hh type     22630000
  PDS184I    ...                                                        22640000
                                                                        22650000
   This message lists data from each extent of the data set:            22660000
     EXTENT    - number of this extent.                                 22670000
     UCB       - UCB for this extent.                                   22680000
     LO TT     - TT (of TTR) address for the first track in this extent.22690000
     HI TT     - TT (of TTR) address for the last track in this extent. 22700000
     TRACKS    - number of disk tracks in this extent.                  22710000
     LOW CCHH  - CCHH address of the first track of this extent.        22720000
     HIGH CCHH - CCHH address of the last track of this extent.         22730000
     BOUNDARY  - CYL if the extent is on a cylinder boundary.           22740000
                 TRK if the extent is not on a cylinder boundary.       22750000
                                                                        22760000
))PDS190I AN ALIAS NAMED member IS ALREADY AT THIS TTR                  22770000
   The identified alias member resides at this location -- RESTORE      22780000
   will continue if only alias members are found at this TTR address.   22790000
                                                                        22800000
PDS200I <PARM#1>                                                        22810000
))PDS200I DSP UNIT RECFM LRECL BLKSZ ALLOCTRK FREETRK SECONDARY FREEDIR 22820000
  PDS200I SHR 3380 FB       80  6320 3X   150      42     1 CYL      22 22830000
                                                                        22840000
   This message documents the current allocation; this format can be    22850000
   specifically requested by entering: DSNAME MSG                       22860000
     DISP      - SHR or OLD disposition.                                22870000
     UNIT      - disk unit device type.                                 22880000
     RECFM     - the record format from the DCB.                        22890000
     LRECL     - the logical record length from the DCB.                22900000
     BLKSIZE   - the blocksize from the DCB.                            22910000
     ALLOCTRK  - the number of disk extents allocated (example: 3X)     22920000
                 and the total space allocated in tracks.               22930000
     FREETRK   - the number of available disk tracks.                   22940000
     SECONDARY - secondary allocation size and type (CYL or TRK) units. 22950000
     FREEDIR   - if a PDS, the number of available directory blocks.    22960000
     DSORG     - if not DSORG=PO, the actual DSORG from the DCB.        22970000
                                                                        22980000
))PDS210I ALLOC F(SYS00001) DA('datasetname') disp UNIT(3380) -         22990000
  PDS210I   RECFM(F B) LRECL(80) BLKSIZE(6320) VOLUME(TSO003) -         23000000
  PDS210I   type SPACE(tot,sec) DIR(mm)     /*FREE TRK=42,FREE DIR=22*/ 23010000
                                                                        23020000
   This message documents the current allocation; this format can be    23030000
   specifically requested by entering: DSNAME TSO                       23040000
     F(SYS...   - this is the current DDNAME.                           23050000
     DA(        - this is the data set name.                            23060000
     disp       - SHR or OLD disposition.                               23070000
     UNIT(      - disk unit device type.                                23080000
     RECFM(     - the record format from the DCB.                       23090000
     LRECL(     - the logical record length from the DCB.               23100000
     BLKSIZE(   - the blocksize from the DCB.                           23110000
     DSORG(     - if not DSORG=PO, the actual DSORG from the DCB.       23120000
     VOLUME(    - the volume name.                                      23130000
     type       - CYLinder or TRAck allocation.                         23140000
     SPACE(     - tot is the total space allocated in "type" units.     23150000
                  sec is the secondary allocation size in "type" units. 23160000
     DIR(mm)    - if DSORG=PO, mm is the number of directory blocks.    23170000
     FREE TRK=  - the number of available disk tracks.                  23180000
     FREE DIR=  - if DSORG=PO, the number of available directory blocks 23190000
                                                                        23200000
))PDS220I //SYS00001  DD  DSN=datasetname,DISP=SHR,UNIT=3380,           23210000
  PDS220I //  DCB=(RECFM=FB,LRECL=80,BLKSIZE=6320),VOL=SER=TSO003,      23220000
  PDS220I //  SPACE=(type,(tot,sec,mm))     /*FREE TRK=42,FREE DIR=22*/ 23230000
                                                                        23240000
   This message documents the current allocation; this format can be    23250000
   specifically requested by entering: DSNAME JCL                       23260000
     //SYS..    - this is the current DDNAME.                           23270000
     DSN=       - this is the data set name.                            23280000
     DISP=      - SHR or OLD disposition.                               23290000
     UNIT=      - disk unit device type.                                23300000
     RECFM=     - the record format from the DCB.                       23310000
     LRECL=     - the logical record length from the DCB.               23320000
     BLKSIZE=   - the blocksize from the DCB.                           23330000
     DSORG=     - if not DSORG=PO, the actual DSORG from the DCB.       23340000
     VOLUME=    - the volume name.                                      23350000
     SPACE=     - type is CYL or TRK allocation.                        23360000
                  tot is the total space allocated in "type" units.     23370000
                  sec is the secondary allocation size in "type" units. 23380000
                  if DSORG=PO, mm is the number or directory blocks.    23390000
     FREE TRK=  - the number of available disk tracks.                  23400000
     FREE DIR=  - if DSORG=PO, the number of available directory blocks 23410000
                                                                        23420000
))PDS230I MEMBER      VER.MOD  CREATED   LAST MODIFIED  SIZE  INIT  MOD 23430000
  PDS230I  RESCPY      01.01  82/06/14  82/11/29 15:37    12    11   11 23440000
  PDS230I  RESCOMP     SSI: hexvalue                                    23450000
  PDS230I  RESCOMPL-A                                                   23460000
                                                                        23470000
   This message displays directory information for a member (ISPF       23480000
   statistics, SSI information and alias indicators):                   23490000
     MEMBER     - the member name.                                      23500000
     -A         - indicates that this member is an alias.               23510000
     VER.MOD    - if saved by ISPF, version and mod numbers.            23520000
                  if SSI:, the SSI data from the directory.             23530000
     CREATED    - creation date in yy/mm/dd format.                     23540000
     LAST       - last modification date in yy/mm/dd format.            23550000
     MODIFIED   - last modification time in hh:mm format.               23560000
     SIZE       - number of records in the member currently.            23570000
     INIT       - number of records in the member initially.            23580000
     MOD        - number of changed records in the member.              23590000
     ID         - identifier of the user who last updated this member.  23600000
                                                                        23610000
))PDS300A ENTER OPTION -- DSN=dsname,VOL=SER=volume  MEM=groupname      23620000
   The current data set name, the associated disk volume name and the   23630000
   current member group name are displayed in this subcommand prompt.   23640000
                                                                        23650000
))PDS380A REENTER THE FIND STRING WITH DELIMITERS:                      23660000
   Due to a previously noted error condition, the search string is not  23670000
   valid.  The string and its delimiters should be reentered.           23680000
                                                                        23690000
))PDS381A REENTER THE DATA SET NAME, VOLUME AND DISPOSITION:            23700000
   Due to a previously noted error condition, the data set name         23710000
   entered could not be used.  Another data set name and any volume     23720000
   or disposition data must be reentered.                               23730000
                                                                        23740000
))PDS382A REENTER THE FIRST TTR:                                        23750000
   Due to a previously noted error condition, the first TTR address     23760000
   entered could not be used and should be reentered.                   23770000
                                                                        23780000
))PDS383A REENTER THE SECOND TTR:                                       23790000
   Due to a previously noted error condition, the second TTR address    23800000
   entered could not be used and should be reentered.                   23810000
                                                                        23820000
))PDS384A REENTER THE HEX OFFSET:                                       23830000
   Due to a previously noted error condition, the hexadecimal offset    23840000
   entered could not be used.  The offset value should be reentered.    23850000
                                                                        23860000
))PDS385A REENTER THE SSI DATA:                                         23870000
   Due to a previously noted error condition, the hexadecimal SSI       23880000
   information entered could not be used.  The SSI data should be       23890000
   reentered.                                                           23900000
                                                                        23910000
))PDS390A SHOULD THIS MEMBER BE RESTORED (Y/N) ?                        23920000
   If the identified member should be restored, enter: y                23930000
   If the identified member should not be restored, enter: n            23940000
                                                                        23950000
))PDS391A SHOULD THESE MEMBERS BE RENAMED (Y/N) ?                       23960000
   If the identified members should be renamed, enter: y                23970000
   If the identified members should not be renamed, enter: n            23980000
                                                                        23990000
))PDS392A SHOULD THIS DATA SET BE MODIFIED (Y/N) ?                      24000000
   If this data set should be modified by FIXPDS, enter: y              24010000
   If this data set should not be modified by FIXPDS, enter: n          24020000
                                                                        24030000
))PDS393A SHOULD THIS MEMBER BE DELETED (Y/N) ?                         24040000
   If the identified member should be deleted, enter: y                 24050000
   If the identified member should not be deleted, enter: n             24060000
                                                                        24070000
))PDS394A SHOULD ALL OF THESE MEMBERS BE DELETED (Y/N) ?                24080000
   If the identified members should be deleted, enter: y                24090000
   If the identified members should not be deleted, enter: n            24100000
                                                                        24110000
))PDS400W NO MEMBERS ARE IN THE DATA SET                                24120000
   This data set has no member names in its directory.                  24130000
                                                                        24140000
))PDS401W NO MEMBER NAMES ARE IN THIS RANGE                             24150000
   A member range was specified, but the directory contains no members  24160000
   within the specified range.                                          24170000
                                                                        24180000
))PDS402W NO MEMBER NAMES MATCH THIS PATTERN                            24190000
   A string was specified with the PATTERN subcommand, but there are    24200000
   no members in the directory whose name contains the specified string.24210000
                                                                        24220000
))PDS441W name (WEAK)                                                   24220400
   This external name is a weak unresolved external reference; this     24220420
   name was not present when the module was linked.  If this module     24220440
   is relinked, the linkage-editor can resolve references to this       24220460
   name but its presence is not required.                               24220480
                                                                        24220500
))PDS442W name (MISSING)                                                24220520
   This external name is an unresolved external reference; this name    24220540
   was not present when the module was linked.  If this module is       24220560
   relinked, the linkage-editor can resolve references to this name;    24220580
   however, error messages will be generated if this name is again      24220600
   missing during the module linkage-edit.                              24220620
                                                                        24220650
))PDS450W ONE EXTRA PADDING DIRECTORY BLOCK WILL BE ADDED               24230000
                                                                        24240000
))PDS451W ALL MEMBERS IN THIS PDS WILL BE LOST                          24250000
   FIXPDS RESET deletes all members from the data set.                  24260000
                                                                        24270000
))PDS460W NO HISTORY DATA IS AVAILABLE                                  24280000
   This module has no associated history (translator, zap or user-      24290000
   supplied) IDR data.  This module was probably linked by an obsolete  24300000
   linkage editor.                                                      24310000
                                                                        24320000
))PDS470W THE PROGRAM IS PROBABLY IN A LOOP                             24330000
   The previous attention was noted but an interruption point was       24340000
   not encountered in the program before this attention.                24350000
                                                                        24360000
   Interruptions are checked for at a terminal input or output and      24370000
   when the input data set is read.                                     24380000
                                                                        24390000
   This message usually means that the program is in a loop --          24400000
   the looping subcommand will be terminated and the subcommand         24410000
   that was last entered will be given control.                         24420000
                                                                        24430000
))PDS480W COMPRESS IS IN PROGRESS                                       24440000
   A compress has been initiated.                                       24450000
                                                                        24460000
   Compress is performed in-place on your data set; if IEBCOPY does     24470000
   not complete its operation for any reason, the data set should be    24480000
   checked with a VERIFY subcommand.                                    24490000
                                                                        24500000
  PDS480W COMPRESS MAY NOT BE INTERRUPTED                               24510000
   Attentions received during a compress operation are ignored since    24520000
   the target data set may be destroyed if IEBCOPY does not complete.   24530000
                                                                        24540000
))PDS482W BLOCKSIZE SHOULD BE EVENLY DIVISIBLE BY THE DCB LRECL         24550000
   The requested BLKSIZE is not a multiple of the logical record        24560000
   length.  This is usually an error.                                   24570000
                                                                        24580000
))PDS510W THIS IS A NULL MEMBER                                         24590000
   This member contains no data.                                        24600000
                                                                        24610000
))PDS520W NO INFORMATION IS AVAILABLE                                   24620000
   No .? (extended help) information is available -- no warning or      24630000
   error messages are current.                                          24640000
                                                                        24650000
   To use the extended help facility, you should enter  .?              24660000
   immediately after any subcommand which receives warning (PDSnnnW)    24670000
   and/or error (PDSnnnE) messages.  Up to five of the most recent      24680000
   warning or error message explanations will be automatically          24690000
   requested from the HELP data set by the program.                     24700000
                                                                        24710000
))PDS530W THIS DATA SET IS NOT PARTITIONED                              24720000
   Several subcommands are not available since they are only defined    24730000
   for partitioned data sets.                                           24740000
                                                                        24750000
))PDS700E THIS RANGE OF NAMES IS INVALID                                24760000
   The range of names indicated is invalid (the range of names may      24770000
   not progress from one name to a name lower in collating sequence).   24780000
                                                                        24790000
   For example:                                                         24800000
       valid name ranges   --  bb:bb   bb:c   bb:bc   bb:b   bb:   :bb  24810000
       invalid name ranges --  bb:ba   bb:a                             24820000
                                                                        24830000
))PDS701E THIS DATA SET IS NOT A LOAD LIBRARY                           24840000
   This subcommand or operand is only defined for load libraries.       24850000
                                                                        24860000
))PDS702E THIS DATA SET IS A LOAD LIBRARY                               24870000
   This subcommand or operand is not defined for load libraries.        24880000
                                                                        24890000
))PDS703E THIS MODULE HAS NO EXTERNAL SYMBOLS                           24900000
   This usually indicates that the module was not created by a linkage  24910000
   editor or that it was constructed from incomplete data.              24920000
                                                                        24930000
))PDS704E MODULE member HAS NO EXTERNAL SYMBOLS                         24940000
   This usually indicates that the module was not created by a linkage  24950000
   editor or that it was constructed from incomplete data.              24960000
                                                                        24970000
))PDS710E INVALID APF INFORMATION FORMAT;                               24980000
          MEMBER IS ASSUMED NOT AUTHORIZED                              24981000
   The APF information for this module is invalid and the module        24990000
   is assumed to be not authorized.                                     25000000
                                                                        25010000
))PDS720E NOT APF AUTHORIZED; THE APF DATA IS MISSING                   25020000
   The APF data for this module is not present and the module is        25030000
   assumed to be not authorized.                                        25040000
                                                                        25050000
))PDS721E NOT APF AUTHORIZED, THE APF DATA IS THE WRONG LENGTH          25060000
   The APF data for this module is invalid (not one byte long) and      25070000
   the module is assumed to be not authorized.                          25080000
                                                                        25090000
))PDS722E THE APF DATA CAN NOT BE CHANGED                               25100000
   Due to missing or invalid APF data, the APF value was not modified.  25110000
   A module linked with an old linkage editor might not have APF data.  25120000
                                                                        25130000
))PDS723E THE RLD/CONTROL COUNT CAN NOT BE CHANGED                      25140000
   Due to non-existent RLD/control data in the member, the directory    25150000
   RLD/control count was not modified.  Note that a module linked with  25160000
   an obsolete linkage editor might not have a RLD/control count field. 25170000
                                                                        25180000
))PDS724E RMODE AND AMODE CAN NOT BE CHANGED -- OBSOLETE LINKAGE-EDITOR 25190000
   Residence and addressing mode values do not exist for this module    25200000
   since it was linked with an obsolete linkage editor.                 25210000
                                                                        25220000
))PDS726E PAGE ALIGNMENT CAN NOT BE CHANGED -- OBSOLETE LINKAGE-EDITOR  25230000
   The page alignment flag does not exist for this module since it was  25240000
   linked with an obsolete linkage editor.                              25250000
                                                                        25260000
))PDS740E THIS MODULE HAS NO MATCHING EXTERNAL SYMBOLS                  25270000
   The MODULE(name) requested is not contained in this member.          25280000
                                                                        25290000
))PDS750E A REQUIRED NOTELIST POINTER WAS NOT FOUND IN THIS MEMBER      25300000
   Due to an error condition, one or more load module records referred  25310000
   to in an overlay notelist record could not be located by FIXPDS.     25320000
                                                                        25330000
   This message may be due to data set or equipment errors.  A VERIFY   25340000
   subcommand may provide more information.                             25350000
                                                                        25360000
   The EXPANDDIR operation is terminated with the member in error       25370000
   unchanged.  Any previously moved members and their associated        25380000
   aliases are fully updated, however.                                  25390000
                                                                        25400000
   If this problem is due to data set errors, the data set may be       25410000
   damaged and should be recovered.                                     25420000
                                                                        25430000
))PDS751E A NOTELIST RECORD COULD NOT BE FOUND FOR THIS MEMBER          25440000
   Due to an error condition, an overlay notelist record could not      25450000
   be input by FIXPDS.                                                  25460000
                                                                        25470000
   This message may be due to data set or equipment errors.  A VERIFY   25480000
   subcommand may provide more information.                             25490000
                                                                        25500000
   The EXPANDDIR operation is terminated with the member in error       25510000
   unchanged.  Any previously moved members and their associated        25520000
   aliases are fully updated, however.                                  25530000
                                                                        25540000
   If this problem is due to data set errors, the data set may be       25550000
   damaged and should be recovered.                                     25560000
                                                                        25570000
))PDS752E THE NUMBER OF DESIRED DIRECTORY BLOCKS MUST BE SPECIFIED      25580000
   Due to a previously noted error condition, the number of directory   25590000
   blocks could not be determined.  Therefore, the number of directory  25600000
   blocks must be specified to expand or reset the data set directory.  25610000
                                                                        25620000
PDS770E THE FIRST FIND SUBCOMMAND MUST CONTAIN A STRING                 25630000
   A default search string cannot be used since a default string has    25640000
   not yet been established.                                            25650000
                                                                        25660000
))PDS771E name IS AN INVALID SUBCOMMAND; ENTER "HELP" OR "OPTIONS" ...  25670000
   The displayed subcommand name is not defined -- a table of valid     25680000
   subcommand names follows this header.                                25690000
                                                                        25700000
))PDS780E filename DCB OPEN ERROR -- REALLOCATE AND TRY AGAIN           25710000
   The FILE(PDSOUT) or session copy data set could not be opened;       25720000
   correct any problems with the current allocation and try again.      25730000
                                                                        25740000
))PDS781E filename DCB ATTRIBUTES CONFLICT -- USE SEQUENTIAL WITH       25750000
   RECFM=FB AND LRECL=80                                                25760000
   The attributes of the FILE(PDSOUT) and the session copy data set     25770000
   must be RECFM(F B) LRECL(80) with a blocksize which is a multiple    25780000
   of 80.  It must be allocated to a sequential output data set or a    25790000
   member of a partitioned data set.                                    25800000
                                                                        25810000
))PDS800E NO LOAD MODULE TEXT WAS FOUND FOR MEMBER                      25820000
   This member contains invalid load module data and it cannot          25830000
   be restored.                                                         25840000
                                                                        25850000
))PDS801E END OF MEMBER SIMULATED -- REMAINDER OF TRACK SKIPPED         25860000
   Due to a previously noted input error, the remainder of the          25870000
   track cannot be read.  RESTORE will begin processing with the        25880000
   following track as if it were the beginning of a new member.         25890000
                                                                        25900000
))PDS802E A MAIN MEMBER NAMED member IS ALREADY AT THIS TTR             25910000
   The identified main member resides at this location; RESTORE         25920000
   will terminate after checking for other associated members.          25930000
                                                                        25940000
))PDS804E RESTORE ABANDONED                                             25950000
   Due to a previously noted error condition, RESTORE cannot continue.  25960000
   You may wish to retry RESTORE with different operands.               25970000
                                                                        25980000
))PDS805E INVALID LOAD MODULE DATA                                      25990000
   This member contains invalid load module data and it cannot          26000000
   be restored.                                                         26010000
                                                                        26020000
))PDS811E RECORD LENGTH n IS INVALID                                    26030000
   The indicated logical record length (0, 1, 2 or 3) is invalid for    26040000
   RECFM(V) data sets.                                                  26050000
                                                                        26060000
   This type of error may indicate that your data set DCB has been      26070000
   altered.  If this is the case, the data set DCB can be reset         26080000
   with the following subcommand:                                       26090000
     FIXPDS RECFM(mm) LRECL(nn) BLKSIZE(pp)                             26100000
     (where mm, nn and pp are replaced by the proper DCB attributes)    26110000
                                                                        26120000
))PDS812E BLOCK LENGTH OF nn,nnn EXCEEDS THE DATA SET DCB BLKSIZE       26130000
   The physical blocksize exceeds the BLKSIZE of the data set.          26140000
                                                                        26150000
   This type of error may indicate that your data set DCB has been      26160000
   altered.  If this is the case, the data set DCB can be reset         26170000
   with the following subcommand:                                       26180000
     FIXPDS RECFM(mm) LRECL(nn) BLKSIZE(pp)                             26190000
     (where mm, nn and pp are replaced by the proper DCB attributes)    26200000
                                                                        26210000
))PDS813E RECORD LENGTH OF nn,nnn EXCEEDS THE MAXIMUM DCB LRECL         26220000
   The logical record length exceeds the LRECL of the data set.         26230000
                                                                        26240000
   This type of error may indicate that your data set DCB has been      26250000
   altered.  If this is the case, the data set DCB can be reset         26260000
   with the following subcommand:                                       26270000
     FIXPDS RECFM(mm) LRECL(nn) BLKSIZE(pp)                             26280000
     (where mm, nn and pp are replaced by the proper DCB attributes)    26290000
                                                                        26300000
))PDS814E BLOCK LENGTH OF nn,nnn IS NOT DIVISIBLE BY THE DCB LRECL      26310000
   The physical blocksize is not a multiple of the data set's LRECL.    26320000
                                                                        26330000
   This type of error may indicate that your data set DCB has been      26340000
   altered.  If this is the case, the data set DCB can be reset         26350000
   with the following subcommand:                                       26360000
     FIXPDS RECFM(mm) LRECL(nn) BLKSIZE(pp)                             26370000
     (where mm, nn and pp are replaced by the proper DCB attributes)    26380000
                                                                        26390000
))PDS820E THIS MEMBER IS AN ALIAS FOR member1 BUT IT POINTS TO member2  26400000
   This member is actually an alias for main member member1 (according  26410000
   to its TTR), but its directory entry indicates that it should be an  26420000
   alias of member2.                                                    26430000
                                                                        26440000
   This is usually caused by doing a rename of a main module with       26450000
   some utility which does not update the associated alias modules'     26460000
   directory entries correctly.                                         26470000
                                                                        26480000
   This type of error could cause serious problems if the members are   26490000
   in your LPALIB (you may not be able to IPL).                         26500000
                                                                        26510000
   To correct this problem with PDS, issue the following subcommand:    26520000
     RENAME member1 member1                                             26540000
        (where member1 is the name of the main module identified above) 26550000
                                                                        26560000
))PDS821E RMODE ENTRY DOES NOT CORRESPOND WITH MEMBER member            26570000
   The residence mode entry for this alias member does not match the    26580000
   residence mode entry of the identified main module.                  26590000
                                                                        26600000
   This type of error is unusual; the main module and its aliases       26610000
   should be reinstalled.                                               26620000
                                                                        26630000
   To correct this problem with PDS, issue the following subcommands:   26640000
     ATTRIB member                                                      26650000
        (where member is the main member identified above).             26660000
     ATTRIB member RMODExx                                              26670000
        (where RMODExx is the RMODE value displayed                     26680000
         by the above ATTRIB subcommand)                                26690000
                                                                        26700000
))PDS822E MAIN AMODE ENTRY DOES NOT CORRESPOND WITH MEMBER member       26710000
   The addressing mode entry for this alias member does not match       26720000
   the addressing mode entry of the identified main module.             26730000
                                                                        26740000
   This type of error is unusual; the main module and its aliases       26750000
   should be reinstalled.                                               26760000
                                                                        26770000
   To correct this problem with PDS, issue the following subcommands:   26780000
     ATTRIB member                                                      26790000
        (where member is the main member identified above).             26800000
     ATTRIB member AMODExx                                              26810000
        (where AMODExx is the AMODE value displayed                     26820000
         by the above ATTRIB subcommand)                                26830000
                                                                        26840000
))PDS823E RLD/CONTROL COUNT DOES NOT CORRESPOND WITH MEMBER member      26850000
   The RLD/control count for this alias member does not match           26860000
   the RLD/control count of the identified main module.                 26870000
                                                                        26880000
   This type of error is unusual; the main module and its aliases       26890000
   should be reinstalled.                                               26900000
                                                                        26910000
   In OS/390, this count field is used by program fetch to construct    26920000
   a channel program that will load the member.                         26930000
                                                                        26940000
   If this error is not resolved before program fetch uses this member, 26950000
   fetch may operate in a degraded mode (see message CSV300I).          26960000
                                                                        26970000
   To correct this problem with PDS, issue the following subcommand     26980000
   for the main module and each of its aliases:                         26990000
     ATTRIB memberx RLDFIX                                              27000000
                                                                        27010000
))PDS824E DUPLICATE MEMBER NAME -- IGNORED                              27020000
   This member name has previously been encountered in the data set     27030000
   directory.                                                           27040000
                                                                        27050000
   Your data set has been damaged -- it should be recovered in some     27060000
   fashion; it may suffice to just delete one of the duplicate member   27070000
   names.  Note: an interactive ZAP command may be useful here in       27080000
   changing the actual member names to ascending order.                 27090000
                                                                        27100000
))PDS825E MEMBER NAME IS OUT OF SEQUENCE -- IGNORED                     27110000
   Member names higher in the collating sequence than this member name  27120000
   have previously been encountered in the data set directory.          27130000
                                                                        27140000
   Your data set has been damaged -- it should be recovered in some     27150000
   fashion; it may suffice to delete the out-of-sequence member         27160000
   name or the member name just before this one in the directory.       27170000
   Note: an interactive ZAP command may be useful in changing the       27180000
   actual member names to ascending order.                              27190000
                                                                        27200000
))PDS826E THE DIRECTORY RLD/CONTROL COUNT DOES NOT MATCH THE FIRST RLD  27210000
   ENTRY                                                                27220000
   The RLD/control count for this member does not match the number      27230000
   of RLD or control records following the first TEXT record.           27240000
                                                                        27250000
   In OS/390, this count field is used by program fetch to construct    27260000
   a channel program that will load the member.                         27270000
                                                                        27280000
   If this error is not resolved before program fetch uses this member, 27290000
   fetch may operate in a degraded mode (see message CSV300I).          27300000
                                                                        27310000
   To correct this problem with PDS, issue the following subcommand     27320000
   for the main module and each of its aliases:                         27330000
     ATTRIB memberx RLDFIX                                              27340000
                                                                        27350000
))PDS827E member1 IS AN ALIAS FOR THIS MEMBER BUT IT POINTS TO member2  27360000
   Member1 is actually an alias for this main member (according to its  27370000
   TTR), but its directory entry indicates that it should be an alias   27380000
   of member2.                                                          27390000
                                                                        27400000
   This is usually caused by doing a rename of a main module with       27410000
   some utility which does not update the associated alias modules'     27420000
   directory entries correctly.                                         27430000
                                                                        27440000
   This type of error could cause serious problems if the members are   27450000
   in your LPALIB (you may not be able to IPL).                         27460000
                                                                        27470000
   To correct this problem with PDS, issue the following subcommand:    27480000
     RENAME mmember mmember                                             27490000
        (where mmember is the name of the main member)                  27500000
                                                                        27510000
))PDS830E OBTAIN ERROR -- PROGRAM TERMINATED                            27520000
   The data set name could not be found in the VTOC (Volume Table of    27530000
   Contents); this is probably a program error or the base name         27540000
   of a generation data group (GDG) has been entered.                   27550000
                                                                        27560000
))PDS831E UNABLE TO OPEN DATA SET                                       27570000
   The open for the input data set failed; this is probably a           27580000
   program error.                                                       27590000
                                                                        27600000
))PDS832E DUMMY MEMBER ADD FAILED, RC=8                                 27610000
   A dummy member, with name 9FIXPDS, was not added as expected to      27620000
   the data set directory; this is probably a program error.            27630000
                                                                        27640000
))PDS833E DUMMY MEMBER DELETE FAILED, RC=8                              27650000
   A dummy member, with name 9FIXPDS, was not deleted as expected from  27660000
   the data set directory; this is probably a program error.            27670000
                                                                        27680000
))PDS834E ERROR IN PARSE SERVICE ROUTINE; R15=nn                        27690000
   The parse system message routine failed with the indicated return    27700000
   code; this is probably a program error.                              27710000
                                                                        27720000
))PDS835E ERROR IN DAIRFAIL SERVICE ROUTINE; R15=nn                     27730000
   The DAIRFAIL system message routine failed with the indicated return 27740000
   code; this is probably a program error.                              27750000
                                                                        27760000
))PDS836E I/O ERROR IN DIRECTORY                                        27770000
   The system directory management routines indicate that the directory 27780000
   for this data set contains one or more I/O errors.                   27790000
                                                                        27800000
   This I/O error may be due to data set or equipment errors; entering  27810000
   a VERIFY subcommand may provide more information.                    27820000
                                                                        27830000
   Data set recovery will be required if this is a data set error.      27840000
                                                                        27850000
))PDS840E INVALID HEXADECIMAL STRING LENGTH                             27860000
   At most 64 hexadecimal digits may be used for a search or            27870000
   replacement string.                                                  27880000
                                                                        27890000
))PDS841E INVALID HEXADECIMAL CHARACTERS                                27900000
   Only numeric characters and the characters from A through F may be   27910000
   used in hexadecimal strings.                                         27920000
                                                                        27930000
))PDS842E THIS SEARCH STRING IS TOO LONG                                27940000
   At most 32 characters may be used for a search or replacement        27950000
   string.                                                              27960000
                                                                        27970000
))PDS843E ONLY DISK DATA SETS ARE SUPPORTED                             27980000
   The target data set must exist on a disk.                            27990000
                                                                        28000000
))PDS850E member IS BEING UPDATED BY username                           28010000
   This member is being modified by the named user or JOB; this member  28020000
   is currently owned by the indicated user or JOB and its status can   28030000
   not be changed.                                                      28040000
                                                                        28050000
))PDS851E THIS DATA SET IS BEING UPDATED BY username                    28060000
   This data set is being modified by the named user or JOB; this data  28070000
   set is currently owned by the indicated user or JOB and its status   28080000
   can not be changed.                                                  28090000
                                                                        28100000
))PDS852E member ALREADY EXISTS                                         28110000
   This member cannot be added to the data set; this member name is     28120000
   already in the data set.                                             28130000
                                                                        28140000
))PDS853E member NOT FOUND                                              28150000
   This member is not in the data set.                                  28160000
                                                                        28170000
))PDS854E member IS AN INVALID MEMBER NAME                              28180000
   This member name is invalid; member names may be entered in either   28190000
   character or hexadecimal mode.                                       28200000
                                                                        28210000
   Character member names may be from one to eight bytes long with no   28220000
   imbedded blanks, commas, parentheses, colons or slashes.             28230000
                                                                        28240000
   Hexadecimal member names may contain from one to sixteen hexadecimal 28250000
   digits delimited by x' and '.  Note: x'd7c4e2f9' and PDS9 are        28260000
   entirely equivalent; also, x'333' and x'0333' are equivalent.        28270000
                                                                        28280000
))PDS855E THE DATA SET DIRECTORY IS FULL AND MEMBERS CANNOT BE ADDED    28290000
   The directory is full; if you are currently trying to save a member  28300000
   using an editor, you may wish to save it in another data set.        28310000
                                                                        28320000
   This type of problem can be resolved in several ways:                28330000
     1.  clean up the directory of the data set by deleting obsolete    28340000
         members and make room for new member names.                    28350000
     2.  split the data set into two (or more) data sets.               28360000
     3.  reallocate the data set (with a larger directory) and copy     28370000
         all old members to the replacement data set.                   28380000
     4.  expand the directory with FIXPDS.  For example, enter          28390000
         FIXPDS EXPAND(30)  to add 30 directory blocks.                 28400000
                                                                        28410000
))PDS860E MEMBER IS AN ALIAS BUT NO MAIN MEMBER EXISTS                  28420000
   This alias member has no associated main member.  This type of       28430000
   alias member is termed an orphan.                                    28440000
                                                                        28450000
   This type of error is usually caused by not linking a main module    28460000
   and all of its aliases; the main module and its aliases should be    28470000
   reinstalled.                                                         28480000
                                                                        28490000
   To correct this problem with PDS, issue the following subcommands    28500000
   for each identified orphan member:                                   28510000
     DELETE memberz                                                     28520000
        (where memberz is the orphan member)                            28530000
     ALIAS memberx memberz                                              28540000
        (where memberx is the correct main member)                      28550000
                                                                        28560000
))PDS861E THE ALIAS DIRECTORY ENTRY NOTES THE MAIN MEMBER NAME AS membr 28570000
   This message displays the name of the main member for this alias     28580000
   member as noted by its directory entry.                              28590000
                                                                        28600000
PDS864E <PARM#1> IS AN APPARENT ALIAS FOR THIS MEMBER                   28610000
))PDS864E member IS AN APPARENT ALIAS FOR THIS MEMBER                   28620000
   This member and the identified member both point to the same TTR     28630000
   address but neither has its alias bit set.                           28640000
                                                                        28650000
   These members are called apparent aliases and the actual owner       28660000
   of the member data can not be determined.                            28670000
                                                                        28680000
   One cause of this type of problem is an open/close/EOV situation     28690000
   (OZ44857 -- also documented in II00587) in which opening a           28700000
   partitioned data set causes the FORMAT1 DSCB to be rewritten; If     28710000
   this occurs while the data set is open for update or output, then    28720000
   the DS1LSTAR (last TTR pointer) can be invalidated.                  28730000
                                                                        28740000
   Normally, this situation should only occur on the first access of    28750000
   each day; however, some user modifications cause the DSCB to be      28760000
   updated more often and increase the exposure for duplicate TTR's     28770000
   and overlaid members.                                                28780000
                                                                        28790000
   If the data set is copied or compressed, IEBCOPY will hide this      28800000
   error by creating two identical members during the copy.             28810000
                                                                        28820000
   To correct this problem with PDS, determine which apparent alias     28830000
   member name should correspond to the member data and issue the       28840000
   following subcommand:                                                28850000
     DELETE memberx                                                     28860000
        (where memberx is the non-corresponding alias name)             28870000
                                                                        28880000
))PDS865E THE IEBCOPY OUTPUT CAN NOT BE OPENED                          28890000
   A compress has been performed but a summary of IEBCOPY's messages    28900000
   cannot be provided since the message data set can not be opened.     28910000
                                                                        28920000
   This is probably a program error.                                    28930000
                                                                        28940000
))PDS870E PDS DIRECTORIES MUST BE CONTAINED IN ONE EXTENT               28950000
   The directory of a partitioned data set must be totally contained in 28960000
   the first extent of the data set.                                    28970000
                                                                        28980000
   From VERIFY, it indicates that your data set was allocated with a    28990000
   invalid directory and the data set should not be used as it may      29000000
   fail in program load or when used by IEBCOPY.                        29010000
                                                                        29020000
   From FIXPDS, it indicates that your data set will require more than  29030000
   its first extent to contain the expanded (or reset) directory.       29040000
   This is not permitted as it would create an invalid data set         29050000
   directory.                                                           29060000
                                                                        29070000
))PDS871E A TTR FOR THIS MEMBER WAS NOT FOUND                           29080000
   Due to an error condition, a record pointed by this member's         29090000
   directory entry could not be found in this load module.              29100000
                                                                        29110000
   This message may be due to data set or equipment errors.  A VERIFY   29120000
   subcommand may provide more information.                             29130000
                                                                        29140000
   If this error occurs in FIXPDS, the subcommand is terminated before  29150000
   changing the member in error.  Any previously moved members and      29160000
   their associated aliases are fully updated, however.                 29170000
                                                                        29180000
   If this problem is due to data set errors, the data set may be       29190000
   damaged and should be recovered.                                     29200000
                                                                        29210000
))PDS872E THIS MEMBER IS AFTER THE DATA SET END-OF-FILE                 29220000
   This member's data follows the end of data set marker (DS1LSTAR)     29230000
   for this data set.  To ensure that this diagnostic message is        29240000
   valid, PDS reopens the data set from the EXCP routine in case        29250000
   another user has saved into the data set.                            29260000
                                                                        29270000
   This message indicates that your data set contains one or more       29280000
   invalid TTR pointers and that the data set has been damaged;         29290000
   the data set should be recovered in some fashion.                    29300000
                                                                        29310000
))PDS873E TTR IS BEYOND THE USED PORTION OF THE DATA SET                29320000
   A TTR pointer in this member's directory has a value which exceeds   29330000
   the end of data marker for the data set.                             29340000
                                                                        29350000
   This type of error is unusual; it indicates that your data set       29360000
   contains one or more invalid TTR pointers and that the data set has  29370000
   been damaged -- the data set should be recovered in some fashion.    29380000
                                                                        29390000
))PDS874E TSO COMMAND NAME IS INVALID                                   29400000
   TSO SCAN service indicates that this TSO command name is invalid.    29410000
                                                                        29420000
   Valid TSO command names follow these rules:                          29430000
     1.  The TSO command name should be from one to eight bytes long.   29440000
     2.  The first character of the TSO command name must be a          29450000
         alphabetic or national character.                              29460000
     3.  Any additional characters should be alphabetic, numeric        29470000
         or national characters.                                        29480000
                                                                        29490000
))PDS875E THIS DATA SET HAS NO DIRECTORY BLOCKS                         29500000
   This is a null data set -- it contains no tracks and consequently,   29510000
   no directory blocks and no members.                                  29520000
                                                                        29530000
   When the data set takes an extent, it will receive actual disk       29540000
   tracks and directory blocks.                                         29550000
                                                                        29560000
))PDS876E A DIRECTORY RECORD HAS AN INCORRECT LENGTH                    29570000
          (NOT 256 CHARACTERS)                                          29571000
   This data set has an invalid directory block.  Directory blocks      29580000
   should be 256 characters long and each block should contain an       29590000
   eight byte key.                                                      29600000
                                                                        29610000
   This type of error usually indicates that your data set has been     29620000
   written over and the data set should be recovered in some fashion.   29630000
                                                                        29640000
))PDS877E INVALID SUBCOMMAND NAME                                       29650000
   TSO SCAN service indicates that this subcommand name is invalid.     29660000
                                                                        29670000
   Valid subcommand names follow these rules:                           29680000
     1.  The subcommand name should be from one to eight bytes long.    29690000
     2.  The first character of the subcommand name must be a           29700000
         alphabetic or national character.                              29710000
     3.  Any additional characters should be alphabetic, numeric        29720000
         or national characters.                                        29730000
                                                                        29740000
))PDS880E RESIDENCE MODE ANY AND ADDRESSING MODE xxx ARE INCOMPATIBLE   29750000
   Residence mode ANY and an addressing mode of either 24 or ANY are    29760000
   incompatible; this is an invalid combination of linkage editor       29770000
   attributes.                                                          29780000
                                                                        29790000
))PDS881E REENTRANT ATTRIBUTE CONFLICTS WITH NOT REUSABLE               29800000
   A reentrant attribute is incompatible with a not reusable attribute; 29810000
   this is an invalid combination of linkage editor attributes.         29820000
                                                                        29830000
))PDS882E TEST ATTRIBUTE CONFLICTS WITH NOT EDIT                        29840000
   A TEST attribute is incompatible with a NOT EDIT attribute;          29850000
   this is an invalid combination of linkage editor attributes.         29860000
                                                                        29870000
))PDS883E REUSABLE ATTRIBUTE CONFLICTS WITH SCATTER                     29880000
   A reusable attribute is incompatible with a scatter load attribute;  29890000
   this is an invalid combination of linkage editor attributes.         29900000
                                                                        29910000
))PDS884E OVERLAY ATTRIBUTE CONFLICTS WITH xxx                          29920000
   This message documents an incompatible combination of the overlay    29930000
   attribute and another linkage editor attribute as follows:           29940000
     1.  Overlay and reentrant are incompatible.                        29950000
     2.  Overlay and reusable are incompatible.                         29960000
     3.  Overlay and scatter load are incompatible.                     29970000
     4.  Overlay and RMODE ANY are incompatible.                        29980000
     5.  Overlay and AMODE 31 are incompatible.                         29990000
     6.  Overlay and AMODE 64 are incompatible.                         30000000
     7.  Overlay and AMODE ANY are incompatible.                        30005000
                                                                        30010000
))PDS892E READ MULTIPLE FAILED                                          30020000
   PDS has an input mode called "read multiple" which can read an       30030000
   entire track of disk data at a time.  A read multiple can fail       30040000
   for any of several reasons:                                          30050000
     I/O error     - an I/O error is on the current track               30060000
     Invalid addr  - the disk TTR address provided is invalid           30070000
     Not capable   - the device can not perform a read multiple CCW     30080000
     Track overrun - too much data is recorded on a physical track      30090000
                                                                        30100000
   After read multiple fails, PDS uses its alternate double             30110000
   buffering input mode for the remainder of the subcommand.  With      30120000
   the next subcommand, read multiple is attempted again.               30130000
                                                                        30140000
   If many subcommands issue failure messages for read multiple,        30150000
   consider changing the mode for input buffering to double with        30160000
   the following subcommand:                                            30170000
     CONTROL DOUBLE                                                     30180000
                                                                        30190000
))PDS910E TSO COMMAND name IS NOT ALLOWED                               30200000
   You are not authorized to use this TSO command.  Contact your        30210000
   systems support staff if this restriction causes a problem.          30220000
                                                                        30230000
))PDS911E TSO COMMAND name NOT FOUND                                    30240000
   The specified TSO command could not be found.                        30250000
                                                                        30260000
))PDS920E SUBCOMMAND name IS NOT ALLOWED FOR THIS DATA SET              30270000
   You are not authorized to use this subcommand.  Contact your         30280000
   systems support staff if this restriction causes a problem.          30290000
                                                                        30300000
))PDS930E name IS AN INVALID SUBCOMMAND ABBREVIATION                    30310000
   This subcommand name is not allowed.  You must enter additional      30320000
   characters to create a valid subcommand name.                        30330000
                                                                        30340000
))PDS990E EXTENT INITIALIZATION READ FAILED                             30350000
   The first read for an extent of this data set failed.  This type     30360000
   of problem is unusual unless your directory contains invalid TTR     30370000
   pointers.                                                            30380000
                                                                        30390000
))PDS991E PERMANENT I/O ERROR AT TTR=hexttr                             30400000
   An uncorrectable I/O error was encountered at the displayed TTR      30410000
   address.                                                             30420000
                                                                        30430000
   This error may be due to data set or equipment errors.  A VERIFY     30440000
   subcommand may provide more information.                             30450000
                                                                        30460000
   Data set recovery will be required if this is a data set error.      30470000
                                                                        30480000
))PDS998E ABEND Sxxx LOADING THIS MODULE                                30490000
   The displayed ABEND code was received while loading this module.     30500000
                                                                        30510000
   In the following table of common messages, the ABEND identifier      30560000
   from the PDS998E message and the first part of the associated        30570000
   IEA703I message are listed with a short error description:           30580000
                                                                        30600000
     ABEND  ASSOCIATED MSG   DESCRIPTION                                30610000
     -----  --------------   -----------                                30620000
     S106   IEA703I 106-D    Invalid record type in load module         30640000
     S106   IEA703I 106-E    Invalid TTR address in load module         30650000
     S106   IEA703I 106-F    Uncorrectable I/O error in load module     30660000
     S306   IEA703I 306-8    Uncorrectable I/O error searching linklist 30670000
     S706   IEA703I 706      "Not Executable" module                    30680000
                                                                        30760000
))PDS999E ABEND Sxxx Unnnn AT hexvalue IN PROGRAM progname              30770000
   This ABEND was noted during PDS execution. The various               30780000
   fields are as follows:                                               30790000
     Sxxx     - the system ABEND code                                   30800000
     Unnnn    - the user ABEND code                                     30810000
     hexvalue - if signed, an offset from the routine entry point;      30820000
                otherwise, the address of the abending instruction.     30830000
     progname - the name of the abending program (if available)         30840000
                a. PDSMAIN - ABEND in the PDS mainline assembly         30850000
                b. ALIAS   - ABEND in the subroutine assembly           30860000
                c. PARSE   - ABEND in the PARSE interface assembly      30870000
                d. ISPDSPY - ABEND in the dialog assembly               30880000
                e. VSUBCMD - ABEND in the subcommand check assembly     30890000
                f. VTSOCMD - ABEND in the TSO command check assembly    30900000
                                                                        30910000
./ ENDUP
??
//
